------------------------------------------------------------------------------
--  This file is a part of the GRLIB VHDL IP LIBRARY
--  Copyright (C) 2012, Aeroflex Gaisler AB - all rights reserved.
--
-- ANY USE OR REDISTRIBUTION IN PART OR IN WHOLE MUST BE HANDLED IN 
-- ACCORDANCE WITH THE GAISLER LICENSE AGREEMENT AND MUST BE APPROVED 
-- IN ADVANCE IN WRITING.
------------------------------------------------------------------------------

library ieee, stratixiii;
use ieee.std_logic_1164.all;
use stratixiii.stratixiii_components.all;
library altera;
use altera.altera_primitives_components.all;

library altera_mf;
use altera_mf.altera_mf_components.all;

entity grfpw_0_stratixiii is
port(
  rst :  in std_logic;
  clk :  in std_logic;
  holdn :  in std_logic;
  cpi_flush :  in std_logic;
  cpi_exack :  in std_logic;
  cpi_a_rs1 : in std_logic_vector(4 downto 0);
  cpi_d_pc : in std_logic_vector(31 downto 0);
  cpi_d_inst : in std_logic_vector(31 downto 0);
  cpi_d_cnt : in std_logic_vector(1 downto 0);
  cpi_d_trap :  in std_logic;
  cpi_d_annul :  in std_logic;
  cpi_d_pv :  in std_logic;
  cpi_a_pc : in std_logic_vector(31 downto 0);
  cpi_a_inst : in std_logic_vector(31 downto 0);
  cpi_a_cnt : in std_logic_vector(1 downto 0);
  cpi_a_trap :  in std_logic;
  cpi_a_annul :  in std_logic;
  cpi_a_pv :  in std_logic;
  cpi_e_pc : in std_logic_vector(31 downto 0);
  cpi_e_inst : in std_logic_vector(31 downto 0);
  cpi_e_cnt : in std_logic_vector(1 downto 0);
  cpi_e_trap :  in std_logic;
  cpi_e_annul :  in std_logic;
  cpi_e_pv :  in std_logic;
  cpi_m_pc : in std_logic_vector(31 downto 0);
  cpi_m_inst : in std_logic_vector(31 downto 0);
  cpi_m_cnt : in std_logic_vector(1 downto 0);
  cpi_m_trap :  in std_logic;
  cpi_m_annul :  in std_logic;
  cpi_m_pv :  in std_logic;
  cpi_x_pc : in std_logic_vector(31 downto 0);
  cpi_x_inst : in std_logic_vector(31 downto 0);
  cpi_x_cnt : in std_logic_vector(1 downto 0);
  cpi_x_trap :  in std_logic;
  cpi_x_annul :  in std_logic;
  cpi_x_pv :  in std_logic;
  cpi_lddata : in std_logic_vector(31 downto 0);
  cpi_dbg_enable :  in std_logic;
  cpi_dbg_write :  in std_logic;
  cpi_dbg_fsr :  in std_logic;
  cpi_dbg_addr : in std_logic_vector(4 downto 0);
  cpi_dbg_data : in std_logic_vector(31 downto 0);
  cpo_data : out std_logic_vector(31 downto 0);
  cpo_exc :  out std_logic;
  cpo_cc : out std_logic_vector(1 downto 0);
  cpo_ccv :  out std_logic;
  cpo_ldlock :  out std_logic;
  cpo_holdn :  out std_logic;
  cpo_dbg_data : out std_logic_vector(31 downto 0);
  rfi1_rd1addr : out std_logic_vector(3 downto 0);
  rfi1_rd2addr : out std_logic_vector(3 downto 0);
  rfi1_wraddr : out std_logic_vector(3 downto 0);
  rfi1_wrdata : out std_logic_vector(31 downto 0);
  rfi1_ren1 :  out std_logic;
  rfi1_ren2 :  out std_logic;
  rfi1_wren :  out std_logic;
  rfi2_rd1addr : out std_logic_vector(3 downto 0);
  rfi2_rd2addr : out std_logic_vector(3 downto 0);
  rfi2_wraddr : out std_logic_vector(3 downto 0);
  rfi2_wrdata : out std_logic_vector(31 downto 0);
  rfi2_ren1 :  out std_logic;
  rfi2_ren2 :  out std_logic;
  rfi2_wren :  out std_logic;
  rfo1_data1 : in std_logic_vector(31 downto 0);
  rfo1_data2 : in std_logic_vector(31 downto 0);
  rfo2_data1 : in std_logic_vector(31 downto 0);
  rfo2_data2 : in std_logic_vector(31 downto 0));
end grfpw_0_stratixiii;

architecture beh of grfpw_0_stratixiii is
  signal devclrn : std_logic := '1';
  signal devpor : std_logic := '1';
  signal devoe : std_logic := '0';
  signal \FPO.RES\ : std_logic_vector(63 downto 0);
  signal \FPO.CC\ : std_logic_vector(1 downto 0);
  signal \FPO.IDOUT\ : std_logic_vector(5 downto 0);
  signal \FPI.FLOP\ : std_logic_vector(8 downto 0);
  signal \FPI.OP1\ : std_logic_vector(63 downto 0);
  signal \FPI.OP2\ : std_logic_vector(63 downto 0);
  signal \FPI.FLUSHID\ : std_logic_vector(5 downto 0);
  signal \FPI.RNDMODE\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.DIVROMI\ : std_logic_vector(4 downto 1);
  signal \GRFPU0.MULO.MRES\ : std_logic_vector(120 downto 16);
  signal \GRFPU0.MULO.DRES_S\ : std_logic_vector(118 downto 65);
  signal \GRFPU0.MULO.DRES_1\ : std_logic_vector(121 downto 68);
  signal \GRFPU0.MULO.DRES_1S\ : std_logic_vector(118 downto 67);
  signal \GRFPU0.MULO.MRES_1\ : std_logic_vector(121 downto 66);
  signal \GRFPU0.MULO.MRES_1S\ : std_logic_vector(120 downto 68);
  signal \GRFPU0.FPMUL0.SX\ : std_logic_vector(121 downto 69);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I\ : std_logic_vector(60 to 60);
  signal \GRFPU0.DIVROM0.RADDR\ : std_logic_vector(7 downto 0);
  signal \GRFPU0.DIVROM0.DATA_1_0\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.DIVROM0.DATA_1_1\ : std_logic_vector(6 downto 0);
  signal \GRFPU0.DIVROM0.DATA_1_2\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.DIVROM0.DATA_1_3\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.SQRTROM0.DATA_1_0\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.SQRTROM0.DATA_1_1\ : std_logic_vector(6 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.DBUF\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.GRFPU_X0.ST3.LZCNT\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.EXP1\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.EXP2\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.REG\ : std_logic_vector(63 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.FLOP\ : std_logic_vector(8 downto 0);
  signal \GRFPU0.GRFPU_X0.ST3.REG\ : std_logic_vector(63 downto 0);
  signal \GRFPU0.GRFPU_X0.ST3.FLOP\ : std_logic_vector(8 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.GUARDS\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ST3.RNDMODE\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.CCSEL\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.EXPOP\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.RNDMODE\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ST4.SEL\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.EXPT\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.EXPT\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.R_I\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.FLOP\ : std_logic_vector(8 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2\ : std_logic_vector(52 downto 0);
  signal \GRFPU0.GRFPU_X0.ST3.FARRES\ : std_logic_vector(55 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.FLTYPE2\ : std_logic_vector(8 downto 3);
  signal \GRFPU0.GRFPU_X0.ST2.FLTYPE2\ : std_logic_vector(8 downto 3);
  signal \GRFPU0.GRFPU_X0.ST1.FLTYPE1\ : std_logic_vector(8 downto 3);
  signal \GRFPU0.GRFPU_X0.ST1.RAW2\ : std_logic_vector(63 downto 0);
  signal \GRFPU0.GRFPU_X0.ST3.ID\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.ID\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.RAW1\ : std_logic_vector(63 downto 29);
  signal \GRFPU0.GRFPU_X0.ST2.DIFF\ : std_logic_vector(53 downto 0);
  signal \GRFPU0.GRFPU_X0.ST3.EXC\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.STATE\ : std_logic_vector(24 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.BMLSB\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ST2.RNDMODE\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.SGNF1\ : std_logic_vector(51 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.SGNF2\ : std_logic_vector(43 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.RNDMODE\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.ALLOW\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.ND_I\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.ID\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.ID\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\ : std_logic_vector(51 downto 1);
  signal \GRFPU0.GRFPU_X0.ST2.EXC\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.UN8_C\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.EXP\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.C\ : std_logic_vector(11 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.ST4.REG\ : std_logic_vector(62 downto 2);
  signal \GRFPU0.GRFPU_X0.ST4.SGNF\ : std_logic_vector(51 downto 0);
  signal \GRFPU0.GRFPU_X0.ST4.AEXP\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.ST4.MSGNF\ : std_logic_vector(51 downto 0);
  signal \GRFPU0.GRFPU_X0.ST4.MEXP\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.VST3.REG_37\ : std_logic_vector(51 downto 0);
  signal \GRFPU0.GRFPU_X0.ST4.EXC\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\ : std_logic_vector(58 downto 23);
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\ : std_logic_vector(58 downto 23);
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP\ : std_logic_vector(51 downto 1);
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0\ : std_logic_vector(31 downto 1);
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP\ : std_logic_vector(52 downto 1);
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\ : std_logic_vector(56 downto 1);
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\ : std_logic_vector(11 downto 1);
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1\ : std_logic_vector(53 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\ : std_logic_vector(54 downto 33);
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\ : std_logic_vector(11 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\ : std_logic_vector(55 downto 0);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1\ : std_logic_vector(7 downto 6);
  signal \GRFPU0.GRFPU_X0.UN1_INTO\ : std_logic_vector(31 downto 0);
  signal \GRFPU0.GRFPU_X0.ITER.TZR\ : std_logic_vector(6 downto 0);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1\ : std_logic_vector(7 downto 6);
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2\ : std_logic_vector(51 downto 1);
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1\ : std_logic_vector(28 downto 0);
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2\ : std_logic_vector(53 downto 1);
  signal \GRFPU0.GRFPU_X0.VST2.DIFF_1\ : std_logic_vector(53 downto 50);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\ : std_logic_vector(62 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\ : std_logic_vector(56 downto 20);
  signal \GRFPU0.GRFPU_X0.VST3.EXC_1\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.VST3.REG_1\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX\ : std_logic_vector(22 downto 0);
  signal \GRFPU0.GRFPU_X0.VST3.REG_47\ : std_logic_vector(62 downto 52);
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3\ : std_logic_vector(23 downto 0);
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC\ : std_logic_vector(11 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.GRFPU_X0.VST2.EXC_8\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.DIFFIN2_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.S3ADDI\ : std_logic_vector(29 downto 28);
  signal \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\ : std_logic_vector(9 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ALLOW_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\ : std_logic_vector(63 downto 45);
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1\ : std_logic_vector(51 downto 29);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\ : std_logic_vector(51 downto 18);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\ : std_logic_vector(50 downto 29);
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\ : std_logic_vector(40 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\ : std_logic_vector(10 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\ : std_logic_vector(44 downto 32);
  signal \GRFPC0.FIFO.INST_0\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.FIFO.INST_1\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.WR2.CNT\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.EX.CTRL.VCNT\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.R.STATE\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.RFA2.FOP\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.MEM.CTRL.VCNT\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FIFO.VCNT_1\ : std_logic_vector(2 downto 0);
  signal \GRFPC0.FIFO.VCNT_0\ : std_logic_vector(2 downto 0);
  signal \GRFPC0.DIV.RD\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.WR.CTRL.RD\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.DIV.INST\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.EX.CTRL.INST\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.WR2.CTRL.INST\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.MEM.CTRL.INST\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.WR.CTRL.INST\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.EX.CTRL.RD\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.MEM.CTRL.RD\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.WR2.CTRL.RD\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.DIV.EXCT\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.FIFO.WR\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FIFO.RD\ : std_logic_vector(0 to 0);
  signal \GRFPC0.WR.CTRL.VCNT\ : std_logic_vector(0 to 0);
  signal \GRFPC0.RFA.RD\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FPR.ID\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.MEM.CTRL.ID\ : std_logic_vector(7 downto 0);
  signal \GRFPC0.EX.CTRL.ID\ : std_logic_vector(7 downto 0);
  signal \GRFPC0.WR2.CTRL.ID\ : std_logic_vector(7 downto 0);
  signal \GRFPC0.WR.CTRL.ID\ : std_logic_vector(7 downto 0);
  signal \GRFPC0.WR2.RREG.EXCT\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.R.FSR.AEXC\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.R.FSR.TEM\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FIFO.PC_0\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.FIFO.PC_1\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.FPR.ALLOW\ : std_logic_vector(2 downto 0);
  signal \GRFPC0.RFA2.RS2SEL\ : std_logic_vector(7 downto 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.RFA2.RS1SEL\ : std_logic_vector(7 downto 1);
  signal \GRFPC0.DIV.ID\ : std_logic_vector(7 downto 0);
  signal \GRFPC0.EX.RREG.RES\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.MEM.RREG.RES\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.WR.RREG.RES\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.WR2.RREG.RES\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.R.FSR.FCC\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.D.LDLCK\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.D.STDLCK\ : std_logic_vector(15 downto 0);
  signal \GRFPC0.DIV.RESULT\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.D.STLCK\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.WR.RREG.EXCT\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.MEM.RREG.EXCT\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.EX.RREG.EXCT\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.R.STDATA\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.R.FSR.CEXC\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.R.FSR.FTT\ : std_logic_vector(2 downto 0);
  signal \GRFPC0.DIV.PC\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.WR2.CTRL.PC\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.WR.CTRL.PC\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.MEM.CTRL.PC\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.EX.CTRL.PC\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.INST\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.RFA.RS2\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FID_1\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.RFA.RS1\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.FPRIN.ALLOW\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FPUSEL_1\ : std_logic_vector(4 downto 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_120\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_25_I_I_0\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.WRDATA_3\ : std_logic_vector(63 downto 0);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1\ : std_logic_vector(31 downto 2);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\ : std_logic_vector(49 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\ : std_logic_vector(71 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\ : std_logic_vector(121 downto 16);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\ : std_logic_vector(96 downto 36);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_1_IV_I\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\ : std_logic_vector(60 downto 0);
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\ : std_logic_vector(97 downto 72);
  signal \FPO.EXC\ : std_logic_vector(2 downto 0);
  signal \FPI.OPID\ : std_logic_vector(5 downto 0);
  signal \GRFPC0.V.STDATA_14\ : std_logic_vector(31 downto 18);
  signal \GRFPC0.FP_PIPELINE.3.1.REGDEPX_62\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_17\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_103\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_405\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_10\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_17\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_410\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\ : std_logic_vector(30 downto 0);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\ : std_logic_vector(30 downto 2);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\ : std_logic_vector(31 downto 2);
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_23_IV\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_394\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_22_IV\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_153\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_155\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_24_IV\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_19\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_18\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_296\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_299\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_7\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_295\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.WR2SEL_1\ : std_logic_vector(7 downto 4);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_20\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FPUSEL_6_1\ : std_logic_vector(7 to 7);
  signal \GRFPC0.FP_PIPELINE.RS1_6\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_243\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_245\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.DEP_2_I\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_252\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.0.CHECK_DEP.DEP_2_I\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_20\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_168\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.VDIV.RD_1\ : std_logic_vector(4 downto 1);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_172\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_26\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_164\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_604\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_492\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_488\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_332_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_332\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_8\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_15\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_85\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_89\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_80\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_83\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_90\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX_174\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.DEP_2_I\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.UN4_CNTX\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\ : std_logic_vector(26 downto 23);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\ : std_logic_vector(23 downto 8);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\ : std_logic_vector(23 downto 8);
  signal \GRFPU0.GRFPU_X0.UN1_RAW1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.WREN_17_I\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_6\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_359\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_358\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_355\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_256\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_259\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_255\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX_194\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX_197\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX_192\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_16\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_170\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_320\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.0.REGDEPX_60\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX_156\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_132\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.5.0.REGDEPX_95\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_420\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX_86\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX_88\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.DEP\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_11\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_363\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_24_IV\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_235\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_7\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_238\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_13\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_220\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_125\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_11\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_128\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_11\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_70\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_11\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_19\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_18\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\ : std_logic_vector(31 downto 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_25_I_I_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_608\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.0.REGDEPX_168\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_56\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_55\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_45\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_7\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_48\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_136\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.15.STDEP_612\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4_M\ : std_logic_vector(4 downto 1);
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_21\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_20\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_5\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.WREN_17_IV\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.DEP\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX_210\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_160\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_12\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_165\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_315\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_94\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_128\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_158\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_110\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX_177\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX_176\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX_179\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.STDEP_496\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.1.REGDEPX_65\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.V.FSR.AEXC_2_M\ : std_logic_vector(3 downto 0);
  signal \GRFPC0.FPUSEL_6_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FPUSEL_6_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FPUSEL_1_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_246\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_248\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_7\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_250\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_20\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_9\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_8\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_16\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_130\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_225\ : std_logic_vector(1 to 1);
  signal \GRFPC0.EXSEL_1\ : std_logic_vector(2 to 2);
  signal \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\ : std_logic_vector(4 downto 0);
  signal \GRFPC0.CPI_M\ : std_logic_vector(401 downto 399);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_15\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.1.REGDEPX_170\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.1.REGDEPX_172\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_25_I\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M0\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.FCC_1_M2\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.FCC_1_M0\ : std_logic_vector(1 downto 0);
  signal \FPO.RES_1\ : std_logic_vector(25 to 25);
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_8\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_11\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\ : std_logic_vector(31 downto 10);
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\ : std_logic_vector(31 downto 10);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_9\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_8\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.ALTB\ : std_logic_vector(3 downto 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_1\ : std_logic_vector(24 to 24);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_135\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_318\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_413\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_411\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_415\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_138\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_140\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.0.REGDEPX_238\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX_84\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX_214\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX_178\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_343\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_345\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_340\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_226\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_26\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_116\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_59\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_25\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_29\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_115\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_119\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_445\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_168\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_298\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_348\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_408\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_435\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_350\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_113\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_175\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_425\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_423\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_49\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_256\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_448\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_446\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_449\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_568\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_92\ : std_logic_vector(1 to 1);
  signal \GRFPC0.VFIFO.INST_0_4\ : std_logic_vector(15 to 15);
  signal \GRFPC0.VFIFO.INST_1_4\ : std_logic_vector(15 to 15);
  signal \GRFPC0.FP_PIPELINE.12.0.REGDEPX_221\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_21\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.0.REGDEPX_257\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_18\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.DEP_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_25_I\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_15\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_18\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_11\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_7\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_9\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_11\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13_M\ : std_logic_vector(3 to 3);
  signal \GRFPC0.FP_PIPELINE.V.FSR.CEXC_12_M\ : std_logic_vector(3 to 3);
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_7\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_9\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_14\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_3\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_11\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.DEP_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_12\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_8\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_11\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_16\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_17\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_16\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_7\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_19\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_9\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_20\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_19\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_8\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_18\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_15\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_8\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_6\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\ : std_logic_vector(59 downto 7);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\ : std_logic_vector(59 downto 33);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\ : std_logic_vector(59 downto 8);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\ : std_logic_vector(59 downto 39);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\ : std_logic_vector(60 downto 8);
  signal \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\ : std_logic_vector(18 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\ : std_logic_vector(63 downto 2);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\ : std_logic_vector(63 downto 0);
  signal \GRFPU0.GRFPU_X0.UN253_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.UN253_BCO_LSB_1\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.INF_ABS0_3\ : std_logic_vector(31 downto 3);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_53\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_47\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_19\ : std_logic_vector(63 to 63);
  signal \GRFPU0.GRFPU_X0.REST_1_1\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\ : std_logic_vector(37 downto 22);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\ : std_logic_vector(59 downto 55);
  signal \GRFPU0.GRFPU_X0.EXP_11\ : std_logic_vector(9 downto 2);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\ : std_logic_vector(62 downto 45);
  signal \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\ : std_logic_vector(62 downto 29);
  signal \GRFPU0.GRFPU_X0.UN23_EXP\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.COMB.EXP_14\ : std_logic_vector(10 downto 1);
  signal \GRFPU0.GRFPU_X0.UN248_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L1_3\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L3_0_7\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L2_0_6\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.UN242_BCO_MSB_1\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.UN28_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.L1_4_5\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.UN23_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.L4_6\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_3_5\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_5_6\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L3_0_6\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_5_4\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.UN33_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.VST3.REG_37_1\ : std_logic_vector(9 to 9);
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.OUT_1\ : std_logic_vector(84 to 84);
  signal \GRFPU0.GRFPU_X0.UN78_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.L4_1\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.L3_0_3\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.UN73_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.UN83_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.UN228_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.UN233_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.L1_6\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.UN238_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.L4_3\ : std_logic_vector(4 downto 2);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_6_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\ : std_logic_vector(36 downto 8);
  signal \GRFPU0.GRFPU_X0.COMB.UN1_L4.ALTB\ : std_logic_vector(3 downto 1);
  signal \GRFPU0.GRFPU_X0.L3_0\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.L4_2_1\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L2_0_2\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_6_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_4_2\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_5\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_4\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.L1_2_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_0_2\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.UN163_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_5_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN158_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.L1_1_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN153_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.UN148_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.TZI2\ : std_logic_vector(23 downto 1);
  signal \GRFPU0.GRFPU_X0.L1_2_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\ : std_logic_vector(53 downto 32);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_5_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.TZI\ : std_logic_vector(20 downto 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_6_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_5_1_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_6_1_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.REST_2\ : std_logic_vector(5 downto 2);
  signal \GRFPU0.GRFPU_X0.REST_1_2\ : std_logic_vector(7 downto 2);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.IEXC_6\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.EXC_11_IV\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.MULO_M\ : std_logic_vector(91 downto 76);
  signal \GRFPU0.GRFPU_X0.UN53_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\ : std_logic_vector(59 downto 8);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_M\ : std_logic_vector(33 downto 8);
  signal \GRFPU0.GRFPU_X0.L1_4_6\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.UN58_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.L1_5_5\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.UN63_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.L1_5_1_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_6_1_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN68_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.L1_0_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_0_1_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L4_7\ : std_logic_vector(4 downto 2);
  signal \GRFPU0.GRFPU_X0.L2_0_5\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.L2_1_4\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.L1_2_4\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L3_1_1\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L3_0_5\ : std_logic_vector(1 downto 0);
  signal \GRFPU0.GRFPU_X0.L4_2\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.UN1_INC_DP\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN1_INC_DP_S\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.RNDM_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.RMND_13\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.1.REGDEPX_63\ : std_logic_vector(1 to 1);
  signal \GRFPU0.DIVAPPR\ : std_logic_vector(6 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_4_1\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L3_0_1\ : std_logic_vector(5 downto 0);
  signal \GRFPU0.GRFPU_X0.L2_0_1\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_5_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_3_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN113_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.UN108_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.L1_4_1_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_6_1_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_1_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_3_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_3_1_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_1_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_1_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_6\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L2_0_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_0_6\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\ : std_logic_vector(50 downto 13);
  signal \GRFPU0.GRFPU_X0.L1_2_1_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L2_0\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN168_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.L2_1_1\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.L1_3_1_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_5\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.LOB2.AXB\ : std_logic_vector(2 downto 1);
  signal \GRFPU0.GRFPU_X0.UN133_BCO_LSB_2\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.L1_5_3\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_2\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_4_4\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_5_1_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN1_ST2.FLTYPE2_6\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH.ALTB\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.RNDOP_14\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.RNDOP_32\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV\ : std_logic_vector(44 downto 37);
  signal \GRFPU0.GRFPU_X0.L1_0_1_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\ : std_logic_vector(58 downto 53);
  signal \GRFPU0.GRFPU_X0.L2_0_3\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.L3_0_2\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.L1_0_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_3\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_3_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_4_3\ : std_logic_vector(3 downto 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_5_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_6_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_7\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_7\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_1_6\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_3_1_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_0_7\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_7\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L2_1\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2\ : std_logic_vector(19 downto 16);
  signal \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.ALTB\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.ALTB\ : std_logic_vector(3 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.ALTB\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.COMB.IEXC5.ALTB\ : std_logic_vector(3 downto 1);
  signal \GRFPU0.GRFPU_X0.VITER.R_I_33_M\ : std_logic_vector(7 to 7);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\ : std_logic_vector(58 downto 37);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\ : std_logic_vector(44 downto 37);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\ : std_logic_vector(58 downto 37);
  signal \GRFPU0.GRFPU_X0.UN118_BCO_LSB_2\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_4_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_5_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_1_5_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_3_1_5_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_7_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_1_6_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_7_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_7_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_6_1_3_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_O2_6_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_I_A4_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_I_A4_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_482_0_IV_0_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_482_0_IV_0_A2_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.STDEP_194_0_IV_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_140_I_M_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_I_A4_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A2_1\ : std_logic_vector(10 to 10);
  signal \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_390_I_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.0.STDEP_385_I_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_398_I_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.STDEP_150_I_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_4_1_4_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_6_4_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_5_4_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_4_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_6_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_5_1_1_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_3_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_5_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_3_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_5_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_4_4_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_O2_1_0_TZ\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\ : std_logic_vector(23 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_A2_3_1\ : std_logic_vector(52 to 52);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_13\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\ : std_logic_vector(58 downto 40);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\ : std_logic_vector(52 to 52);
  signal \GRFPU0.GRFPU_X0.COMB.CCV_8_0_1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_355_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_3_TZ\ : std_logic_vector(52 to 52);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0_0_TZ\ : std_logic_vector(22 to 22);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_S_0_TZ\ : std_logic_vector(20 to 20);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_5_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_2_6_0_A4_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_2_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_1_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_1_4_TZ\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.DEP_1_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_I_A2_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_18_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_0_A2_5_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_6_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_A0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_10_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.CCV_8_0_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_13_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.0.REGDEPX_203_0_A4_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A4_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_0\ : std_logic_vector(29 downto 20);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_380_0_A2_3_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_380_0_A2_2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_400_0_A2_2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2_0\ : std_logic_vector(20 downto 14);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_I_A2_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_125_0_A2_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_465_0_A2_4_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_454_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_A2_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.0.REGDEPX_113_0_A4_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_8_0\ : std_logic_vector(14 to 14);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_0_A2_0\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_16\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_65_0_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_8_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_9_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_A2_3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_598_I_M_I_A3_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L4_1_I\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L4_3_I\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_2\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6_S_0\ : std_logic_vector(43 to 43);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A5_1_0\ : std_logic_vector(4 to 4);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_0_0\ : std_logic_vector(3 downto 2);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A2_1_0_0\ : std_logic_vector(13 to 13);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_5_0\ : std_logic_vector(25 to 25);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_2_I_A3_4\ : std_logic_vector(32 to 32);
  signal \GRFPU0.GRFPU_X0.L1_4_1_5_0_I_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.0.REGDEPX_149_0_A2_1_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A2_6_2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A2_0_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_8_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_13_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_A2_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_465_0_A2_3_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_0_A2_8_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_1_2\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.REST_2_IV_0\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.REST_1_2_IV_0\ : std_logic_vector(2 to 2);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_0_A2_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_O3_2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_A2_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_I_A2_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_4_I_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_110_0_IV_0_O3_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_1_5_I_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.BCO_MSB_3_5_I_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_355_A0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_25_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_A0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_1_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_3_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_0_A2_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_8_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_385_0_A3_3_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_0_A4_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_0_A3_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_0_A2_6_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_334_0_A2_0_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_O2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_I_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_5_2_0\ : std_logic_vector(3 to 3);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_100_I_A4_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_A2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.L2_0_0_0\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.VST2.EXC_13_I_M_2\ : std_logic_vector(4 to 4);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.12.0.REGDEPX_221_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.0.REGDEPX_168_0_A4_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_442_0_IV_I_O3_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_3_0\ : std_logic_vector(14 to 14);
  signal \GRFPC0.FP_PIPELINE.9.0.REGDEPX_167_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_0\ : std_logic_vector(60 downto 32);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_1\ : std_logic_vector(60 downto 32);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_0_0\ : std_logic_vector(47 downto 39);
  signal \GRFPU0.GRFPU_X0.RES_1_6_I_0_1\ : std_logic_vector(47 downto 39);
  signal \GRFPU0.GRFPU_X0.L1_0_10_1\ : std_logic_vector(3 to 3);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_3_0\ : std_logic_vector(24 to 24);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_33_0_A2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX_120_0_A2_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.0.REGDEPX_149_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_O2_4_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O3_5_0\ : std_logic_vector(3 to 3);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_A4_2_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L1_2_1\ : std_logic_vector(3 to 3);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_100_0_A2_4_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_9_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_9_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\ : std_logic_vector(36 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\ : std_logic_vector(36 downto 4);
  signal \GRFPC0.FP_PIPELINE.15.0.REGDEPX_275_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.0.STDEP_145_0_IV_M_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_O2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_2\ : std_logic_vector(14 to 14);
  signal \GRFPU0.GRFPU_X0.L3_2_1\ : std_logic_vector(5 to 5);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A2_2_0\ : std_logic_vector(13 to 13);
  signal \GRFPU0.GRFPU_X0.ST4.SEL_0_I_A2_0_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.0.REGDEPX_77_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.6.0.REGDEPX_113_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_0\ : std_logic_vector(26 downto 6);
  signal \GRFPU0.GRFPU_X0.L2_0_7_0\ : std_logic_vector(4 to 4);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX_156_0_O2_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_2\ : std_logic_vector(14 to 14);
  signal \GRFPU0.GRFPU_X0.L3_2\ : std_logic_vector(5 to 5);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_185_I_I2_0_O2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_O2_2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_334_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.REGDEPX2_185_I_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_215_I_A2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.1.REGDEPX_65_I_A2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX_84_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L3_0_3_1\ : std_logic_vector(5 to 5);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A2_4_1\ : std_logic_vector(3 to 3);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A2_4_3\ : std_logic_vector(3 downto 2);
  signal \GRFPU0.GRFPU_X0.L3_0_4_2\ : std_logic_vector(5 to 5);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A2_4_0\ : std_logic_vector(2 to 2);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX_84_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX_192_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX_192_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A5_6_1_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A5_2_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A5_3_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_2_0_TZ_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0_0_TZ_0\ : std_logic_vector(22 to 22);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_S_0_TZ_1\ : std_logic_vector(20 to 20);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_0_14_2\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_0_14_4\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_0_1\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\ : std_logic_vector(55 downto 33);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_2\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_0\ : std_logic_vector(8 to 8);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_0_13_7\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_2_10\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_2_12\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_2_16\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_O2_1_4\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_3_1\ : std_logic_vector(52 to 52);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_2_0\ : std_logic_vector(52 to 52);
  signal \GRFPC0.FP_PIPELINE.5.STDEP_234_0_IV_I_O2_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_92_3_I_0_A5_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_82_0_IV_I_A3_2_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_1\ : std_logic_vector(59 to 59);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_3\ : std_logic_vector(59 to 59);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_O2_0_4\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\ : std_logic_vector(52 downto 20);
  signal \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_4\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_5\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_10\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_12\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_13\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_15\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_376_3_I_A2_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_4_16\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_4_17\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_4_18\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_4_19\ : std_logic_vector(4 to 4);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_A2_1_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\ : std_logic_vector(48 downto 21);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_3\ : std_logic_vector(30 to 30);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_0\ : std_logic_vector(50 downto 27);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_2\ : std_logic_vector(50 downto 27);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_82_0_IV_I_A3_3_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FIFO.RD_I_M_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.L2_0_9_0\ : std_logic_vector(4 to 4);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_I_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_I_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_250_0_O2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_125_0_A2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_159_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A5_1\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_2\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O4_0\ : std_logic_vector(31 to 31);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O4_3\ : std_logic_vector(31 to 31);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O4_5\ : std_logic_vector(31 to 31);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O4_7\ : std_logic_vector(31 to 31);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_O2_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_O2_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_O2_7\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_O2_8\ : std_logic_vector(0 to 0);
  signal \GRFPC0.INST_I_0\ : std_logic_vector(18 downto 17);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_275_0_A2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.STDEP_558_I_M_I_A3_10_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_16\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_18\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_20\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_22\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_24\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_26\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_27\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_38\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_41\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_45\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_46\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_48\ : std_logic_vector(18 to 18);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_49\ : std_logic_vector(18 to 18);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FIFO.RD_M_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_O2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_O2_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_8\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_10\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_7\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_9\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_11\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_45_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_7\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_8\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_12\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_O2_3_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A5_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.REGDEPX2_255_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_14_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_1\ : std_logic_vector(19 downto 13);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_I_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_6\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_9\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_10\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_4\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_5\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_6\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_8\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_429_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.12.REGDEPX2_380_0_O2_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_O2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_O2_3\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\ : std_logic_vector(30 downto 7);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_2\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_0\ : std_logic_vector(52 to 52);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1\ : std_logic_vector(52 to 52);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_2_IV_1\ : std_logic_vector(60 to 60);
  signal \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_1_0\ : std_logic_vector(24 to 24);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_1_1\ : std_logic_vector(24 to 24);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_1_6\ : std_logic_vector(24 to 24);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_1\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_2\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_4\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_9_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_9_3\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_0_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_0_5\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_25_0_2\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_1\ : std_logic_vector(6 to 6);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_5\ : std_logic_vector(6 to 6);
  signal \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_7\ : std_logic_vector(6 to 6);
  signal \GRFPC0.FP_PIPELINE.4.REGDEPX2_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_2_0\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VST4.EXC_11_IV_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\ : std_logic_vector(34 downto 12);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\ : std_logic_vector(50 downto 37);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_3\ : std_logic_vector(37 to 37);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\ : std_logic_vector(58 downto 38);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\ : std_logic_vector(59 downto 38);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\ : std_logic_vector(59 downto 50);
  signal \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A2_7_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_A4_1_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_A2_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_O2_6_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_16_3_I_O2_I_A3_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_568_3_0_A2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_376_3_I_A2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.14.STDEP_568_3_0_0\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_A2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.STDEP_482_0_IV_0_A2_6_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A2_4_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_332_3_I_A4_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_A2_1_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_A2_1_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.13.STDEP_536_3_I_A3_I_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.13.STDEP_536_3_I_A3_I_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O3_4_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O3_4_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6_1_1\ : std_logic_vector(43 to 43);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_2\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_3_0\ : std_logic_vector(41 to 41);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_252_3_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.6.STDEP_252_3_0_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_A2_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_A2_0_3\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_4\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_5\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6_1\ : std_logic_vector(41 to 41);
  signal \GRFPC0.FP_PIPELINE.13.STDEP_558_I_M_I_A3_14_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_O2_0\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O2_0\ : std_logic_vector(52 to 52);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O2_1\ : std_logic_vector(52 to 52);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6_0_0\ : std_logic_vector(43 to 43);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6_0_4\ : std_logic_vector(43 to 43);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6_0_5\ : std_logic_vector(43 to 43);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\ : std_logic_vector(41 to 41);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5\ : std_logic_vector(41 to 41);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O2_1\ : std_logic_vector(1 to 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_0\ : std_logic_vector(54 to 54);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_3\ : std_logic_vector(54 to 54);
  signal \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_0_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FPO_I_6_I_0\ : std_logic_vector(69 to 69);
  signal \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\ : std_logic_vector(3 to 3);
  signal \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\ : std_logic_vector(4 to 4);
  signal \GRFPU0.GRFPU_X0.UN123_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.UN128_BCO_LSB\ : std_logic_vector(15 to 15);
  signal \GRFPU0.GRFPU_X0.RNDOP_29_IV\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.RS2_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.V.STDATA_14_I_M_10\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FIFO.INST_0_I_M_11\ : std_logic_vector(25 to 25);
  signal \GRFPC0.FIFO.INST_0_M_11\ : std_logic_vector(25 to 25);
  signal \GRFPU0.GRFPU_X0.L4_4\ : std_logic_vector(4 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_31\ : std_logic_vector(62 downto 59);
  signal \GRFPU0.MULO.MRES_RETI\ : std_logic_vector(96 downto 66);
  signal \GRFPU0.FPMUL0.UN1_SIN_2\ : std_logic_vector(56 downto 55);
  signal \GRFPU0.MULO.DRES_1_RETI\ : std_logic_vector(102 downto 68);
  signal \GRFPU0.FPMUL0.UN1_SIN_3\ : std_logic_vector(57 downto 56);
  signal \GRFPU0.MULO.DRES_1S_RETI\ : std_logic_vector(100 downto 67);
  signal \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_16_RETI\ : std_logic_vector(0 to 0);
  signal \GRFPC0.WR2SEL_1_RETO\ : std_logic_vector(7 downto 4);
  signal \GRFPC0.DIV.RD_RETO\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FPUSEL_6_1_RETO\ : std_logic_vector(7 to 7);
  signal \GRFPC0.MEM.CTRL.INSTI\ : std_logic_vector(29 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6_RETI\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_RETI\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FPUSEL_6_2_RETO\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FPUSEL_6_3_RETO\ : std_logic_vector(1 to 1);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_RETI\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_RETI\ : std_logic_vector(1 downto 0);
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_RETI\ : std_logic_vector(1 downto 0);
  signal \FPI.OP1_RETO\ : std_logic_vector(28 downto 0);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_RETO\ : std_logic_vector(59 downto 39);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_RETO\ : std_logic_vector(58 downto 53);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_RETO\ : std_logic_vector(58 downto 53);
  signal \GRFPU0.DIVAPPR_RETO\ : std_logic_vector(6 downto 1);
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_RETO\ : std_logic_vector(44 to 44);
  signal \GRFPC0.FPUSEL_6\ : std_logic_vector(2 to 2);
  signal \GRFPU0.GRFPU_X0.C_I\ : std_logic_vector(11 to 11);
  signal \GRFPC0.FIFO.RD_0\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FIFO.RD_1\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FIFO.RD_2\ : std_logic_vector(0 to 0);
  signal \GRFPC0.FIFO.RD_3\ : std_logic_vector(0 to 0);
  signal \GRFPU0.GRFPU_X0.ST4.SEL_0\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.ST4.SEL_1\ : std_logic_vector(2 downto 0);
  signal \GRFPU0.GRFPU_X0.ST4.SEL_2\ : std_logic_vector(2 downto 0);
  signal \GRFPC0.RFA2.RS2SEL_0\ : std_logic_vector(1 to 1);
  signal \GRFPC0.RFA2.RS2SEL_1\ : std_logic_vector(1 to 1);
  signal \GRFPC0.RFA2.RS1SEL_0\ : std_logic_vector(7 downto 1);
  signal \GRFPC0.RFA2.RS1SEL_1\ : std_logic_vector(7 downto 1);
  signal \GRFPU0.GRFPU_X0.ST4.SEL_2_0\ : std_logic_vector(2 downto 0);
  signal CPO_DATAZ : std_logic_vector(31 downto 0);
  signal CPO_CCZ : std_logic_vector(1 downto 0);
  signal CPO_DBG_DATAZ : std_logic_vector(31 downto 0);
  signal RFI1_WRDATAZ : std_logic_vector(31 downto 0);
  signal RFI2_RD1ADDRZ : std_logic_vector(3 downto 0);
  signal RFI2_RD2ADDRZ : std_logic_vector(3 downto 0);
  signal RFI2_WRADDRZ : std_logic_vector(3 downto 0);
  signal RFI2_WRDATAZ : std_logic_vector(31 downto 0);
  signal CLK_INTERNAL : std_logic ;
  signal CPI_FLUSH_INTERNAL : std_logic ;
  signal CPI_EXACK_INTERNAL : std_logic ;
  signal CPI_A_RS1_INTERNAL : std_logic ;
  signal CPI_A_RS1_INTERNAL_0 : std_logic ;
  signal CPI_A_RS1_INTERNAL_1 : std_logic ;
  signal CPI_A_RS1_INTERNAL_2 : std_logic ;
  signal CPI_A_RS1_INTERNAL_3 : std_logic ;
  signal CPI_D_PC_INTERNAL : std_logic ;
  signal CPI_D_PC_INTERNAL_0 : std_logic ;
  signal CPI_D_PC_INTERNAL_1 : std_logic ;
  signal CPI_D_PC_INTERNAL_2 : std_logic ;
  signal CPI_D_PC_INTERNAL_3 : std_logic ;
  signal CPI_D_PC_INTERNAL_4 : std_logic ;
  signal CPI_D_PC_INTERNAL_5 : std_logic ;
  signal CPI_D_PC_INTERNAL_6 : std_logic ;
  signal CPI_D_PC_INTERNAL_7 : std_logic ;
  signal CPI_D_PC_INTERNAL_8 : std_logic ;
  signal CPI_D_PC_INTERNAL_9 : std_logic ;
  signal CPI_D_PC_INTERNAL_10 : std_logic ;
  signal CPI_D_PC_INTERNAL_11 : std_logic ;
  signal CPI_D_PC_INTERNAL_12 : std_logic ;
  signal CPI_D_PC_INTERNAL_13 : std_logic ;
  signal CPI_D_PC_INTERNAL_14 : std_logic ;
  signal CPI_D_PC_INTERNAL_15 : std_logic ;
  signal CPI_D_PC_INTERNAL_16 : std_logic ;
  signal CPI_D_PC_INTERNAL_17 : std_logic ;
  signal CPI_D_PC_INTERNAL_18 : std_logic ;
  signal CPI_D_PC_INTERNAL_19 : std_logic ;
  signal CPI_D_PC_INTERNAL_20 : std_logic ;
  signal CPI_D_PC_INTERNAL_21 : std_logic ;
  signal CPI_D_PC_INTERNAL_22 : std_logic ;
  signal CPI_D_PC_INTERNAL_23 : std_logic ;
  signal CPI_D_PC_INTERNAL_24 : std_logic ;
  signal CPI_D_PC_INTERNAL_25 : std_logic ;
  signal CPI_D_PC_INTERNAL_26 : std_logic ;
  signal CPI_D_PC_INTERNAL_27 : std_logic ;
  signal CPI_D_PC_INTERNAL_28 : std_logic ;
  signal CPI_D_PC_INTERNAL_29 : std_logic ;
  signal CPI_D_PC_INTERNAL_30 : std_logic ;
  signal CPI_D_INST_INTERNAL : std_logic ;
  signal CPI_D_INST_INTERNAL_0 : std_logic ;
  signal CPI_D_INST_INTERNAL_1 : std_logic ;
  signal CPI_D_INST_INTERNAL_2 : std_logic ;
  signal CPI_D_INST_INTERNAL_3 : std_logic ;
  signal CPI_D_INST_INTERNAL_4 : std_logic ;
  signal CPI_D_INST_INTERNAL_5 : std_logic ;
  signal CPI_D_INST_INTERNAL_6 : std_logic ;
  signal CPI_D_INST_INTERNAL_7 : std_logic ;
  signal CPI_D_INST_INTERNAL_8 : std_logic ;
  signal CPI_D_INST_INTERNAL_9 : std_logic ;
  signal CPI_D_INST_INTERNAL_10 : std_logic ;
  signal CPI_D_INST_INTERNAL_11 : std_logic ;
  signal CPI_D_INST_INTERNAL_12 : std_logic ;
  signal CPI_D_INST_INTERNAL_13 : std_logic ;
  signal CPI_D_INST_INTERNAL_14 : std_logic ;
  signal CPI_D_INST_INTERNAL_15 : std_logic ;
  signal CPI_D_INST_INTERNAL_16 : std_logic ;
  signal CPI_D_INST_INTERNAL_17 : std_logic ;
  signal CPI_D_INST_INTERNAL_18 : std_logic ;
  signal CPI_D_INST_INTERNAL_19 : std_logic ;
  signal CPI_D_INST_INTERNAL_20 : std_logic ;
  signal CPI_D_INST_INTERNAL_21 : std_logic ;
  signal CPI_D_INST_INTERNAL_22 : std_logic ;
  signal CPI_D_INST_INTERNAL_23 : std_logic ;
  signal CPI_D_INST_INTERNAL_24 : std_logic ;
  signal CPI_D_INST_INTERNAL_25 : std_logic ;
  signal CPI_D_INST_INTERNAL_26 : std_logic ;
  signal CPI_D_INST_INTERNAL_27 : std_logic ;
  signal CPI_D_INST_INTERNAL_28 : std_logic ;
  signal CPI_D_INST_INTERNAL_29 : std_logic ;
  signal CPI_D_INST_INTERNAL_30 : std_logic ;
  signal CPI_D_CNT_INTERNAL : std_logic ;
  signal CPI_D_CNT_INTERNAL_0 : std_logic ;
  signal CPI_D_TRAP_INTERNAL : std_logic ;
  signal CPI_D_ANNUL_INTERNAL : std_logic ;
  signal CPI_D_PV_INTERNAL : std_logic ;
  signal CPI_A_PC_INTERNAL : std_logic ;
  signal CPI_A_PC_INTERNAL_0 : std_logic ;
  signal CPI_A_PC_INTERNAL_1 : std_logic ;
  signal CPI_A_PC_INTERNAL_2 : std_logic ;
  signal CPI_A_PC_INTERNAL_3 : std_logic ;
  signal CPI_A_PC_INTERNAL_4 : std_logic ;
  signal CPI_A_PC_INTERNAL_5 : std_logic ;
  signal CPI_A_PC_INTERNAL_6 : std_logic ;
  signal CPI_A_PC_INTERNAL_7 : std_logic ;
  signal CPI_A_PC_INTERNAL_8 : std_logic ;
  signal CPI_A_PC_INTERNAL_9 : std_logic ;
  signal CPI_A_PC_INTERNAL_10 : std_logic ;
  signal CPI_A_PC_INTERNAL_11 : std_logic ;
  signal CPI_A_PC_INTERNAL_12 : std_logic ;
  signal CPI_A_PC_INTERNAL_13 : std_logic ;
  signal CPI_A_PC_INTERNAL_14 : std_logic ;
  signal CPI_A_PC_INTERNAL_15 : std_logic ;
  signal CPI_A_PC_INTERNAL_16 : std_logic ;
  signal CPI_A_PC_INTERNAL_17 : std_logic ;
  signal CPI_A_PC_INTERNAL_18 : std_logic ;
  signal CPI_A_PC_INTERNAL_19 : std_logic ;
  signal CPI_A_PC_INTERNAL_20 : std_logic ;
  signal CPI_A_PC_INTERNAL_21 : std_logic ;
  signal CPI_A_PC_INTERNAL_22 : std_logic ;
  signal CPI_A_PC_INTERNAL_23 : std_logic ;
  signal CPI_A_PC_INTERNAL_24 : std_logic ;
  signal CPI_A_PC_INTERNAL_25 : std_logic ;
  signal CPI_A_PC_INTERNAL_26 : std_logic ;
  signal CPI_A_PC_INTERNAL_27 : std_logic ;
  signal CPI_A_PC_INTERNAL_28 : std_logic ;
  signal CPI_A_PC_INTERNAL_29 : std_logic ;
  signal CPI_A_PC_INTERNAL_30 : std_logic ;
  signal CPI_A_INST_INTERNAL : std_logic ;
  signal CPI_A_INST_INTERNAL_0 : std_logic ;
  signal CPI_A_INST_INTERNAL_1 : std_logic ;
  signal CPI_A_INST_INTERNAL_2 : std_logic ;
  signal CPI_A_INST_INTERNAL_3 : std_logic ;
  signal CPI_A_INST_INTERNAL_4 : std_logic ;
  signal CPI_A_INST_INTERNAL_5 : std_logic ;
  signal CPI_A_INST_INTERNAL_6 : std_logic ;
  signal CPI_A_INST_INTERNAL_7 : std_logic ;
  signal CPI_A_INST_INTERNAL_8 : std_logic ;
  signal CPI_A_INST_INTERNAL_9 : std_logic ;
  signal CPI_A_INST_INTERNAL_10 : std_logic ;
  signal CPI_A_INST_INTERNAL_11 : std_logic ;
  signal CPI_A_INST_INTERNAL_12 : std_logic ;
  signal CPI_A_INST_INTERNAL_13 : std_logic ;
  signal CPI_A_INST_INTERNAL_14 : std_logic ;
  signal CPI_A_INST_INTERNAL_15 : std_logic ;
  signal CPI_A_INST_INTERNAL_16 : std_logic ;
  signal CPI_A_INST_INTERNAL_17 : std_logic ;
  signal CPI_A_INST_INTERNAL_18 : std_logic ;
  signal CPI_A_INST_INTERNAL_19 : std_logic ;
  signal CPI_A_INST_INTERNAL_20 : std_logic ;
  signal CPI_A_INST_INTERNAL_21 : std_logic ;
  signal CPI_A_INST_INTERNAL_22 : std_logic ;
  signal CPI_A_INST_INTERNAL_23 : std_logic ;
  signal CPI_A_INST_INTERNAL_24 : std_logic ;
  signal CPI_A_INST_INTERNAL_25 : std_logic ;
  signal CPI_A_INST_INTERNAL_26 : std_logic ;
  signal CPI_A_INST_INTERNAL_27 : std_logic ;
  signal CPI_A_INST_INTERNAL_28 : std_logic ;
  signal CPI_A_INST_INTERNAL_29 : std_logic ;
  signal CPI_A_INST_INTERNAL_30 : std_logic ;
  signal CPI_A_CNT_INTERNAL : std_logic ;
  signal CPI_A_CNT_INTERNAL_0 : std_logic ;
  signal CPI_A_TRAP_INTERNAL : std_logic ;
  signal CPI_A_ANNUL_INTERNAL : std_logic ;
  signal CPI_A_PV_INTERNAL : std_logic ;
  signal CPI_E_PC_INTERNAL : std_logic ;
  signal CPI_E_PC_INTERNAL_0 : std_logic ;
  signal CPI_E_PC_INTERNAL_1 : std_logic ;
  signal CPI_E_PC_INTERNAL_2 : std_logic ;
  signal CPI_E_PC_INTERNAL_3 : std_logic ;
  signal CPI_E_PC_INTERNAL_4 : std_logic ;
  signal CPI_E_PC_INTERNAL_5 : std_logic ;
  signal CPI_E_PC_INTERNAL_6 : std_logic ;
  signal CPI_E_PC_INTERNAL_7 : std_logic ;
  signal CPI_E_PC_INTERNAL_8 : std_logic ;
  signal CPI_E_PC_INTERNAL_9 : std_logic ;
  signal CPI_E_PC_INTERNAL_10 : std_logic ;
  signal CPI_E_PC_INTERNAL_11 : std_logic ;
  signal CPI_E_PC_INTERNAL_12 : std_logic ;
  signal CPI_E_PC_INTERNAL_13 : std_logic ;
  signal CPI_E_PC_INTERNAL_14 : std_logic ;
  signal CPI_E_PC_INTERNAL_15 : std_logic ;
  signal CPI_E_PC_INTERNAL_16 : std_logic ;
  signal CPI_E_PC_INTERNAL_17 : std_logic ;
  signal CPI_E_PC_INTERNAL_18 : std_logic ;
  signal CPI_E_PC_INTERNAL_19 : std_logic ;
  signal CPI_E_PC_INTERNAL_20 : std_logic ;
  signal CPI_E_PC_INTERNAL_21 : std_logic ;
  signal CPI_E_PC_INTERNAL_22 : std_logic ;
  signal CPI_E_PC_INTERNAL_23 : std_logic ;
  signal CPI_E_PC_INTERNAL_24 : std_logic ;
  signal CPI_E_PC_INTERNAL_25 : std_logic ;
  signal CPI_E_PC_INTERNAL_26 : std_logic ;
  signal CPI_E_PC_INTERNAL_27 : std_logic ;
  signal CPI_E_PC_INTERNAL_28 : std_logic ;
  signal CPI_E_PC_INTERNAL_29 : std_logic ;
  signal CPI_E_PC_INTERNAL_30 : std_logic ;
  signal CPI_E_INST_INTERNAL : std_logic ;
  signal CPI_E_INST_INTERNAL_0 : std_logic ;
  signal CPI_E_INST_INTERNAL_1 : std_logic ;
  signal CPI_E_INST_INTERNAL_2 : std_logic ;
  signal CPI_E_INST_INTERNAL_3 : std_logic ;
  signal CPI_E_INST_INTERNAL_4 : std_logic ;
  signal CPI_E_INST_INTERNAL_5 : std_logic ;
  signal CPI_E_INST_INTERNAL_6 : std_logic ;
  signal CPI_E_INST_INTERNAL_7 : std_logic ;
  signal CPI_E_INST_INTERNAL_8 : std_logic ;
  signal CPI_E_INST_INTERNAL_9 : std_logic ;
  signal CPI_E_INST_INTERNAL_10 : std_logic ;
  signal CPI_E_INST_INTERNAL_11 : std_logic ;
  signal CPI_E_INST_INTERNAL_12 : std_logic ;
  signal CPI_E_INST_INTERNAL_13 : std_logic ;
  signal CPI_E_INST_INTERNAL_14 : std_logic ;
  signal CPI_E_INST_INTERNAL_15 : std_logic ;
  signal CPI_E_INST_INTERNAL_16 : std_logic ;
  signal CPI_E_INST_INTERNAL_17 : std_logic ;
  signal CPI_E_INST_INTERNAL_18 : std_logic ;
  signal CPI_E_INST_INTERNAL_19 : std_logic ;
  signal CPI_E_INST_INTERNAL_20 : std_logic ;
  signal CPI_E_INST_INTERNAL_21 : std_logic ;
  signal CPI_E_INST_INTERNAL_22 : std_logic ;
  signal CPI_E_INST_INTERNAL_23 : std_logic ;
  signal CPI_E_INST_INTERNAL_24 : std_logic ;
  signal CPI_E_INST_INTERNAL_25 : std_logic ;
  signal CPI_E_INST_INTERNAL_26 : std_logic ;
  signal CPI_E_INST_INTERNAL_27 : std_logic ;
  signal CPI_E_INST_INTERNAL_28 : std_logic ;
  signal CPI_E_INST_INTERNAL_29 : std_logic ;
  signal CPI_E_INST_INTERNAL_30 : std_logic ;
  signal CPI_E_CNT_INTERNAL : std_logic ;
  signal CPI_E_CNT_INTERNAL_0 : std_logic ;
  signal CPI_E_TRAP_INTERNAL : std_logic ;
  signal CPI_E_ANNUL_INTERNAL : std_logic ;
  signal CPI_E_PV_INTERNAL : std_logic ;
  signal CPI_M_PC_INTERNAL : std_logic ;
  signal CPI_M_PC_INTERNAL_0 : std_logic ;
  signal CPI_M_PC_INTERNAL_1 : std_logic ;
  signal CPI_M_PC_INTERNAL_2 : std_logic ;
  signal CPI_M_PC_INTERNAL_3 : std_logic ;
  signal CPI_M_PC_INTERNAL_4 : std_logic ;
  signal CPI_M_PC_INTERNAL_5 : std_logic ;
  signal CPI_M_PC_INTERNAL_6 : std_logic ;
  signal CPI_M_PC_INTERNAL_7 : std_logic ;
  signal CPI_M_PC_INTERNAL_8 : std_logic ;
  signal CPI_M_PC_INTERNAL_9 : std_logic ;
  signal CPI_M_PC_INTERNAL_10 : std_logic ;
  signal CPI_M_PC_INTERNAL_11 : std_logic ;
  signal CPI_M_PC_INTERNAL_12 : std_logic ;
  signal CPI_M_PC_INTERNAL_13 : std_logic ;
  signal CPI_M_PC_INTERNAL_14 : std_logic ;
  signal CPI_M_PC_INTERNAL_15 : std_logic ;
  signal CPI_M_PC_INTERNAL_16 : std_logic ;
  signal CPI_M_PC_INTERNAL_17 : std_logic ;
  signal CPI_M_PC_INTERNAL_18 : std_logic ;
  signal CPI_M_PC_INTERNAL_19 : std_logic ;
  signal CPI_M_PC_INTERNAL_20 : std_logic ;
  signal CPI_M_PC_INTERNAL_21 : std_logic ;
  signal CPI_M_PC_INTERNAL_22 : std_logic ;
  signal CPI_M_PC_INTERNAL_23 : std_logic ;
  signal CPI_M_PC_INTERNAL_24 : std_logic ;
  signal CPI_M_PC_INTERNAL_25 : std_logic ;
  signal CPI_M_PC_INTERNAL_26 : std_logic ;
  signal CPI_M_PC_INTERNAL_27 : std_logic ;
  signal CPI_M_PC_INTERNAL_28 : std_logic ;
  signal CPI_M_PC_INTERNAL_29 : std_logic ;
  signal CPI_M_PC_INTERNAL_30 : std_logic ;
  signal CPI_M_INST_INTERNAL : std_logic ;
  signal CPI_M_INST_INTERNAL_0 : std_logic ;
  signal CPI_M_INST_INTERNAL_1 : std_logic ;
  signal CPI_M_INST_INTERNAL_2 : std_logic ;
  signal CPI_M_INST_INTERNAL_3 : std_logic ;
  signal CPI_M_INST_INTERNAL_4 : std_logic ;
  signal CPI_M_INST_INTERNAL_5 : std_logic ;
  signal CPI_M_INST_INTERNAL_6 : std_logic ;
  signal CPI_M_INST_INTERNAL_7 : std_logic ;
  signal CPI_M_INST_INTERNAL_8 : std_logic ;
  signal CPI_M_INST_INTERNAL_9 : std_logic ;
  signal CPI_M_INST_INTERNAL_10 : std_logic ;
  signal CPI_M_INST_INTERNAL_11 : std_logic ;
  signal CPI_M_INST_INTERNAL_12 : std_logic ;
  signal CPI_M_INST_INTERNAL_13 : std_logic ;
  signal CPI_M_INST_INTERNAL_14 : std_logic ;
  signal CPI_M_INST_INTERNAL_15 : std_logic ;
  signal CPI_M_INST_INTERNAL_16 : std_logic ;
  signal CPI_M_INST_INTERNAL_17 : std_logic ;
  signal CPI_M_INST_INTERNAL_18 : std_logic ;
  signal CPI_M_INST_INTERNAL_19 : std_logic ;
  signal CPI_M_INST_INTERNAL_20 : std_logic ;
  signal CPI_M_INST_INTERNAL_21 : std_logic ;
  signal CPI_M_INST_INTERNAL_22 : std_logic ;
  signal CPI_M_INST_INTERNAL_23 : std_logic ;
  signal CPI_M_INST_INTERNAL_24 : std_logic ;
  signal CPI_M_INST_INTERNAL_25 : std_logic ;
  signal CPI_M_INST_INTERNAL_26 : std_logic ;
  signal CPI_M_INST_INTERNAL_27 : std_logic ;
  signal CPI_M_INST_INTERNAL_28 : std_logic ;
  signal CPI_M_INST_INTERNAL_29 : std_logic ;
  signal CPI_M_INST_INTERNAL_30 : std_logic ;
  signal CPI_M_CNT_INTERNAL : std_logic ;
  signal CPI_M_CNT_INTERNAL_0 : std_logic ;
  signal CPI_M_TRAP_INTERNAL : std_logic ;
  signal CPI_M_ANNUL_INTERNAL : std_logic ;
  signal CPI_M_PV_INTERNAL : std_logic ;
  signal CPI_X_PC_INTERNAL : std_logic ;
  signal CPI_X_PC_INTERNAL_0 : std_logic ;
  signal CPI_X_PC_INTERNAL_1 : std_logic ;
  signal CPI_X_PC_INTERNAL_2 : std_logic ;
  signal CPI_X_PC_INTERNAL_3 : std_logic ;
  signal CPI_X_PC_INTERNAL_4 : std_logic ;
  signal CPI_X_PC_INTERNAL_5 : std_logic ;
  signal CPI_X_PC_INTERNAL_6 : std_logic ;
  signal CPI_X_PC_INTERNAL_7 : std_logic ;
  signal CPI_X_PC_INTERNAL_8 : std_logic ;
  signal CPI_X_PC_INTERNAL_9 : std_logic ;
  signal CPI_X_PC_INTERNAL_10 : std_logic ;
  signal CPI_X_PC_INTERNAL_11 : std_logic ;
  signal CPI_X_PC_INTERNAL_12 : std_logic ;
  signal CPI_X_PC_INTERNAL_13 : std_logic ;
  signal CPI_X_PC_INTERNAL_14 : std_logic ;
  signal CPI_X_PC_INTERNAL_15 : std_logic ;
  signal CPI_X_PC_INTERNAL_16 : std_logic ;
  signal CPI_X_PC_INTERNAL_17 : std_logic ;
  signal CPI_X_PC_INTERNAL_18 : std_logic ;
  signal CPI_X_PC_INTERNAL_19 : std_logic ;
  signal CPI_X_PC_INTERNAL_20 : std_logic ;
  signal CPI_X_PC_INTERNAL_21 : std_logic ;
  signal CPI_X_PC_INTERNAL_22 : std_logic ;
  signal CPI_X_PC_INTERNAL_23 : std_logic ;
  signal CPI_X_PC_INTERNAL_24 : std_logic ;
  signal CPI_X_PC_INTERNAL_25 : std_logic ;
  signal CPI_X_PC_INTERNAL_26 : std_logic ;
  signal CPI_X_PC_INTERNAL_27 : std_logic ;
  signal CPI_X_PC_INTERNAL_28 : std_logic ;
  signal CPI_X_PC_INTERNAL_29 : std_logic ;
  signal CPI_X_PC_INTERNAL_30 : std_logic ;
  signal CPI_X_INST_INTERNAL : std_logic ;
  signal CPI_X_INST_INTERNAL_0 : std_logic ;
  signal CPI_X_INST_INTERNAL_1 : std_logic ;
  signal CPI_X_INST_INTERNAL_2 : std_logic ;
  signal CPI_X_INST_INTERNAL_3 : std_logic ;
  signal CPI_X_INST_INTERNAL_4 : std_logic ;
  signal CPI_X_INST_INTERNAL_5 : std_logic ;
  signal CPI_X_INST_INTERNAL_6 : std_logic ;
  signal CPI_X_INST_INTERNAL_7 : std_logic ;
  signal CPI_X_INST_INTERNAL_8 : std_logic ;
  signal CPI_X_INST_INTERNAL_9 : std_logic ;
  signal CPI_X_INST_INTERNAL_10 : std_logic ;
  signal CPI_X_INST_INTERNAL_11 : std_logic ;
  signal CPI_X_INST_INTERNAL_12 : std_logic ;
  signal CPI_X_INST_INTERNAL_13 : std_logic ;
  signal CPI_X_INST_INTERNAL_14 : std_logic ;
  signal CPI_X_INST_INTERNAL_15 : std_logic ;
  signal CPI_X_INST_INTERNAL_16 : std_logic ;
  signal CPI_X_INST_INTERNAL_17 : std_logic ;
  signal CPI_X_INST_INTERNAL_18 : std_logic ;
  signal CPI_X_INST_INTERNAL_19 : std_logic ;
  signal CPI_X_INST_INTERNAL_20 : std_logic ;
  signal CPI_X_INST_INTERNAL_21 : std_logic ;
  signal CPI_X_INST_INTERNAL_22 : std_logic ;
  signal CPI_X_INST_INTERNAL_23 : std_logic ;
  signal CPI_X_INST_INTERNAL_24 : std_logic ;
  signal CPI_X_INST_INTERNAL_25 : std_logic ;
  signal CPI_X_INST_INTERNAL_26 : std_logic ;
  signal CPI_X_INST_INTERNAL_27 : std_logic ;
  signal CPI_X_INST_INTERNAL_28 : std_logic ;
  signal CPI_X_INST_INTERNAL_29 : std_logic ;
  signal CPI_X_INST_INTERNAL_30 : std_logic ;
  signal CPI_X_CNT_INTERNAL : std_logic ;
  signal CPI_X_CNT_INTERNAL_0 : std_logic ;
  signal CPI_X_TRAP_INTERNAL : std_logic ;
  signal CPI_X_ANNUL_INTERNAL : std_logic ;
  signal CPI_X_PV_INTERNAL : std_logic ;
  signal CPI_LDDATA_INTERNAL : std_logic ;
  signal CPI_LDDATA_INTERNAL_0 : std_logic ;
  signal CPI_LDDATA_INTERNAL_1 : std_logic ;
  signal CPI_LDDATA_INTERNAL_2 : std_logic ;
  signal CPI_LDDATA_INTERNAL_3 : std_logic ;
  signal CPI_LDDATA_INTERNAL_4 : std_logic ;
  signal CPI_LDDATA_INTERNAL_5 : std_logic ;
  signal CPI_LDDATA_INTERNAL_6 : std_logic ;
  signal CPI_LDDATA_INTERNAL_7 : std_logic ;
  signal CPI_LDDATA_INTERNAL_8 : std_logic ;
  signal CPI_LDDATA_INTERNAL_9 : std_logic ;
  signal CPI_LDDATA_INTERNAL_10 : std_logic ;
  signal CPI_LDDATA_INTERNAL_11 : std_logic ;
  signal CPI_LDDATA_INTERNAL_12 : std_logic ;
  signal CPI_LDDATA_INTERNAL_13 : std_logic ;
  signal CPI_LDDATA_INTERNAL_14 : std_logic ;
  signal CPI_LDDATA_INTERNAL_15 : std_logic ;
  signal CPI_LDDATA_INTERNAL_16 : std_logic ;
  signal CPI_LDDATA_INTERNAL_17 : std_logic ;
  signal CPI_LDDATA_INTERNAL_18 : std_logic ;
  signal CPI_LDDATA_INTERNAL_19 : std_logic ;
  signal CPI_LDDATA_INTERNAL_20 : std_logic ;
  signal CPI_LDDATA_INTERNAL_21 : std_logic ;
  signal CPI_LDDATA_INTERNAL_22 : std_logic ;
  signal CPI_LDDATA_INTERNAL_23 : std_logic ;
  signal CPI_LDDATA_INTERNAL_24 : std_logic ;
  signal CPI_LDDATA_INTERNAL_25 : std_logic ;
  signal CPI_LDDATA_INTERNAL_26 : std_logic ;
  signal CPI_LDDATA_INTERNAL_27 : std_logic ;
  signal CPI_LDDATA_INTERNAL_28 : std_logic ;
  signal CPI_LDDATA_INTERNAL_29 : std_logic ;
  signal CPI_LDDATA_INTERNAL_30 : std_logic ;
  signal CPI_DBG_ENABLE_INTERNAL : std_logic ;
  signal CPI_DBG_WRITE_INTERNAL : std_logic ;
  signal CPI_DBG_FSR_INTERNAL : std_logic ;
  signal CPI_DBG_ADDR_INTERNAL : std_logic ;
  signal CPI_DBG_ADDR_INTERNAL_0 : std_logic ;
  signal CPI_DBG_ADDR_INTERNAL_1 : std_logic ;
  signal CPI_DBG_ADDR_INTERNAL_2 : std_logic ;
  signal CPI_DBG_ADDR_INTERNAL_3 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_0 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_1 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_2 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_3 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_4 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_5 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_6 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_7 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_8 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_9 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_10 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_11 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_12 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_13 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_14 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_15 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_16 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_17 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_18 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_19 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_20 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_21 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_22 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_23 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_24 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_25 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_26 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_27 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_28 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_29 : std_logic ;
  signal CPI_DBG_DATA_INTERNAL_30 : std_logic ;
  signal RFO1_DATA1_INTERNAL : std_logic ;
  signal RFO1_DATA1_INTERNAL_0 : std_logic ;
  signal RFO1_DATA1_INTERNAL_1 : std_logic ;
  signal RFO1_DATA1_INTERNAL_2 : std_logic ;
  signal RFO1_DATA1_INTERNAL_3 : std_logic ;
  signal RFO1_DATA1_INTERNAL_4 : std_logic ;
  signal RFO1_DATA1_INTERNAL_5 : std_logic ;
  signal RFO1_DATA1_INTERNAL_6 : std_logic ;
  signal RFO1_DATA1_INTERNAL_7 : std_logic ;
  signal RFO1_DATA1_INTERNAL_8 : std_logic ;
  signal RFO1_DATA1_INTERNAL_9 : std_logic ;
  signal RFO1_DATA1_INTERNAL_10 : std_logic ;
  signal RFO1_DATA1_INTERNAL_11 : std_logic ;
  signal RFO1_DATA1_INTERNAL_12 : std_logic ;
  signal RFO1_DATA1_INTERNAL_13 : std_logic ;
  signal RFO1_DATA1_INTERNAL_14 : std_logic ;
  signal RFO1_DATA1_INTERNAL_15 : std_logic ;
  signal RFO1_DATA1_INTERNAL_16 : std_logic ;
  signal RFO1_DATA1_INTERNAL_17 : std_logic ;
  signal RFO1_DATA1_INTERNAL_18 : std_logic ;
  signal RFO1_DATA1_INTERNAL_19 : std_logic ;
  signal RFO1_DATA1_INTERNAL_20 : std_logic ;
  signal RFO1_DATA1_INTERNAL_21 : std_logic ;
  signal RFO1_DATA1_INTERNAL_22 : std_logic ;
  signal RFO1_DATA1_INTERNAL_23 : std_logic ;
  signal RFO1_DATA1_INTERNAL_24 : std_logic ;
  signal RFO1_DATA1_INTERNAL_25 : std_logic ;
  signal RFO1_DATA1_INTERNAL_26 : std_logic ;
  signal RFO1_DATA1_INTERNAL_27 : std_logic ;
  signal RFO1_DATA1_INTERNAL_28 : std_logic ;
  signal RFO1_DATA1_INTERNAL_29 : std_logic ;
  signal RFO1_DATA1_INTERNAL_30 : std_logic ;
  signal RFO1_DATA2_INTERNAL : std_logic ;
  signal RFO1_DATA2_INTERNAL_0 : std_logic ;
  signal RFO1_DATA2_INTERNAL_1 : std_logic ;
  signal RFO1_DATA2_INTERNAL_2 : std_logic ;
  signal RFO1_DATA2_INTERNAL_3 : std_logic ;
  signal RFO1_DATA2_INTERNAL_4 : std_logic ;
  signal RFO1_DATA2_INTERNAL_5 : std_logic ;
  signal RFO1_DATA2_INTERNAL_6 : std_logic ;
  signal RFO1_DATA2_INTERNAL_7 : std_logic ;
  signal RFO1_DATA2_INTERNAL_8 : std_logic ;
  signal RFO1_DATA2_INTERNAL_9 : std_logic ;
  signal RFO1_DATA2_INTERNAL_10 : std_logic ;
  signal RFO1_DATA2_INTERNAL_11 : std_logic ;
  signal RFO1_DATA2_INTERNAL_12 : std_logic ;
  signal RFO1_DATA2_INTERNAL_13 : std_logic ;
  signal RFO1_DATA2_INTERNAL_14 : std_logic ;
  signal RFO1_DATA2_INTERNAL_15 : std_logic ;
  signal RFO1_DATA2_INTERNAL_16 : std_logic ;
  signal RFO1_DATA2_INTERNAL_17 : std_logic ;
  signal RFO1_DATA2_INTERNAL_18 : std_logic ;
  signal RFO1_DATA2_INTERNAL_19 : std_logic ;
  signal RFO1_DATA2_INTERNAL_20 : std_logic ;
  signal RFO1_DATA2_INTERNAL_21 : std_logic ;
  signal RFO1_DATA2_INTERNAL_22 : std_logic ;
  signal RFO1_DATA2_INTERNAL_23 : std_logic ;
  signal RFO1_DATA2_INTERNAL_24 : std_logic ;
  signal RFO1_DATA2_INTERNAL_25 : std_logic ;
  signal RFO1_DATA2_INTERNAL_26 : std_logic ;
  signal RFO1_DATA2_INTERNAL_27 : std_logic ;
  signal RFO1_DATA2_INTERNAL_28 : std_logic ;
  signal RFO1_DATA2_INTERNAL_29 : std_logic ;
  signal RFO1_DATA2_INTERNAL_30 : std_logic ;
  signal RFO2_DATA1_INTERNAL : std_logic ;
  signal RFO2_DATA1_INTERNAL_0 : std_logic ;
  signal RFO2_DATA1_INTERNAL_1 : std_logic ;
  signal RFO2_DATA1_INTERNAL_2 : std_logic ;
  signal RFO2_DATA1_INTERNAL_3 : std_logic ;
  signal RFO2_DATA1_INTERNAL_4 : std_logic ;
  signal RFO2_DATA1_INTERNAL_5 : std_logic ;
  signal RFO2_DATA1_INTERNAL_6 : std_logic ;
  signal RFO2_DATA1_INTERNAL_7 : std_logic ;
  signal RFO2_DATA1_INTERNAL_8 : std_logic ;
  signal RFO2_DATA1_INTERNAL_9 : std_logic ;
  signal RFO2_DATA1_INTERNAL_10 : std_logic ;
  signal RFO2_DATA1_INTERNAL_11 : std_logic ;
  signal RFO2_DATA1_INTERNAL_12 : std_logic ;
  signal RFO2_DATA1_INTERNAL_13 : std_logic ;
  signal RFO2_DATA1_INTERNAL_14 : std_logic ;
  signal RFO2_DATA1_INTERNAL_15 : std_logic ;
  signal RFO2_DATA1_INTERNAL_16 : std_logic ;
  signal RFO2_DATA1_INTERNAL_17 : std_logic ;
  signal RFO2_DATA1_INTERNAL_18 : std_logic ;
  signal RFO2_DATA1_INTERNAL_19 : std_logic ;
  signal RFO2_DATA1_INTERNAL_20 : std_logic ;
  signal RFO2_DATA1_INTERNAL_21 : std_logic ;
  signal RFO2_DATA1_INTERNAL_22 : std_logic ;
  signal RFO2_DATA1_INTERNAL_23 : std_logic ;
  signal RFO2_DATA1_INTERNAL_24 : std_logic ;
  signal RFO2_DATA1_INTERNAL_25 : std_logic ;
  signal RFO2_DATA1_INTERNAL_26 : std_logic ;
  signal RFO2_DATA1_INTERNAL_27 : std_logic ;
  signal RFO2_DATA1_INTERNAL_28 : std_logic ;
  signal RFO2_DATA1_INTERNAL_29 : std_logic ;
  signal RFO2_DATA1_INTERNAL_30 : std_logic ;
  signal RFO2_DATA2_INTERNAL : std_logic ;
  signal RFO2_DATA2_INTERNAL_0 : std_logic ;
  signal RFO2_DATA2_INTERNAL_1 : std_logic ;
  signal RFO2_DATA2_INTERNAL_2 : std_logic ;
  signal RFO2_DATA2_INTERNAL_3 : std_logic ;
  signal RFO2_DATA2_INTERNAL_4 : std_logic ;
  signal RFO2_DATA2_INTERNAL_5 : std_logic ;
  signal RFO2_DATA2_INTERNAL_6 : std_logic ;
  signal RFO2_DATA2_INTERNAL_7 : std_logic ;
  signal RFO2_DATA2_INTERNAL_8 : std_logic ;
  signal RFO2_DATA2_INTERNAL_9 : std_logic ;
  signal RFO2_DATA2_INTERNAL_10 : std_logic ;
  signal RFO2_DATA2_INTERNAL_11 : std_logic ;
  signal RFO2_DATA2_INTERNAL_12 : std_logic ;
  signal RFO2_DATA2_INTERNAL_13 : std_logic ;
  signal RFO2_DATA2_INTERNAL_14 : std_logic ;
  signal RFO2_DATA2_INTERNAL_15 : std_logic ;
  signal RFO2_DATA2_INTERNAL_16 : std_logic ;
  signal RFO2_DATA2_INTERNAL_17 : std_logic ;
  signal RFO2_DATA2_INTERNAL_18 : std_logic ;
  signal RFO2_DATA2_INTERNAL_19 : std_logic ;
  signal RFO2_DATA2_INTERNAL_20 : std_logic ;
  signal RFO2_DATA2_INTERNAL_21 : std_logic ;
  signal RFO2_DATA2_INTERNAL_22 : std_logic ;
  signal RFO2_DATA2_INTERNAL_23 : std_logic ;
  signal RFO2_DATA2_INTERNAL_24 : std_logic ;
  signal RFO2_DATA2_INTERNAL_25 : std_logic ;
  signal RFO2_DATA2_INTERNAL_26 : std_logic ;
  signal RFO2_DATA2_INTERNAL_27 : std_logic ;
  signal RFO2_DATA2_INTERNAL_28 : std_logic ;
  signal RFO2_DATA2_INTERNAL_29 : std_logic ;
  signal RFO2_DATA2_INTERNAL_30 : std_logic ;
  signal \FPI.NONSTD\ : std_logic ;
  signal \FPI.FLUSH\ : std_logic ;
  signal GND : std_logic ;
  signal \GRFPU0.MULI.DP\ : std_logic ;
  signal \GRFPU0.FPMUL0.CS_ITER_R\ : std_logic ;
  signal \GRFPU0.FPMUL0.CS_DP_R\ : std_logic ;
  signal \GRFPU0.N_439\ : std_logic ;
  signal \GRFPU0.N_440\ : std_logic ;
  signal \GRFPU0.N_441\ : std_logic ;
  signal \GRFPU0.N_442\ : std_logic ;
  signal \GRFPU0.N_443\ : std_logic ;
  signal \GRFPU0.N_444\ : std_logic ;
  signal \GRFPU0.N_445\ : std_logic ;
  signal \GRFPU0.N_446\ : std_logic ;
  signal \GRFPU0.N_447\ : std_logic ;
  signal \GRFPU0.N_448\ : std_logic ;
  signal \GRFPU0.N_449\ : std_logic ;
  signal \GRFPU0.N_450\ : std_logic ;
  signal \GRFPU0.N_451\ : std_logic ;
  signal \GRFPU0.N_452\ : std_logic ;
  signal \GRFPU0.N_453\ : std_logic ;
  signal \GRFPU0.N_454\ : std_logic ;
  signal \GRFPU0.N_455\ : std_logic ;
  signal \GRFPU0.N_456\ : std_logic ;
  signal \GRFPU0.N_457\ : std_logic ;
  signal \GRFPU0.N_458\ : std_logic ;
  signal \GRFPU0.N_459\ : std_logic ;
  signal \GRFPU0.N_460\ : std_logic ;
  signal \GRFPU0.N_461\ : std_logic ;
  signal \GRFPU0.N_462\ : std_logic ;
  signal \GRFPU0.N_463\ : std_logic ;
  signal \GRFPU0.N_464\ : std_logic ;
  signal \GRFPU0.N_465\ : std_logic ;
  signal \GRFPU0.N_466\ : std_logic ;
  signal \GRFPU0.N_467\ : std_logic ;
  signal \GRFPU0.N_468\ : std_logic ;
  signal \GRFPU0.N_469\ : std_logic ;
  signal \GRFPU0.N_470\ : std_logic ;
  signal \GRFPU0.N_471\ : std_logic ;
  signal \GRFPU0.N_472\ : std_logic ;
  signal \GRFPU0.N_473\ : std_logic ;
  signal \GRFPU0.N_474\ : std_logic ;
  signal \GRFPU0.N_475\ : std_logic ;
  signal \GRFPU0.N_476\ : std_logic ;
  signal \GRFPU0.N_477\ : std_logic ;
  signal \GRFPU0.N_478\ : std_logic ;
  signal \GRFPU0.N_479\ : std_logic ;
  signal \GRFPU0.N_480\ : std_logic ;
  signal \GRFPU0.N_481\ : std_logic ;
  signal \GRFPU0.N_482\ : std_logic ;
  signal \GRFPU0.N_483\ : std_logic ;
  signal \GRFPU0.N_484\ : std_logic ;
  signal \GRFPU0.N_485\ : std_logic ;
  signal \GRFPU0.N_486\ : std_logic ;
  signal \GRFPU0.N_487\ : std_logic ;
  signal \GRFPU0.N_488\ : std_logic ;
  signal \GRFPU0.N_489\ : std_logic ;
  signal \GRFPU0.N_490\ : std_logic ;
  signal \GRFPU0.N_491\ : std_logic ;
  signal \GRFPU0.N_492\ : std_logic ;
  signal \GRFPU0.N_493\ : std_logic ;
  signal \GRFPU0.N_494\ : std_logic ;
  signal \GRFPU0.N_495\ : std_logic ;
  signal \GRFPU0.N_496\ : std_logic ;
  signal \GRFPU0.N_497\ : std_logic ;
  signal \GRFPU0.N_498\ : std_logic ;
  signal \GRFPU0.N_499\ : std_logic ;
  signal \GRFPU0.N_500\ : std_logic ;
  signal \GRFPU0.N_501\ : std_logic ;
  signal \GRFPU0.N_502\ : std_logic ;
  signal \GRFPU0.N_503\ : std_logic ;
  signal \GRFPU0.N_504\ : std_logic ;
  signal \GRFPU0.N_505\ : std_logic ;
  signal \GRFPU0.N_506\ : std_logic ;
  signal \GRFPU0.N_507\ : std_logic ;
  signal \GRFPU0.N_508\ : std_logic ;
  signal \GRFPU0.N_509\ : std_logic ;
  signal \GRFPU0.N_510\ : std_logic ;
  signal \GRFPU0.N_511\ : std_logic ;
  signal \GRFPU0.N_512\ : std_logic ;
  signal \GRFPU0.N_513\ : std_logic ;
  signal \GRFPU0.N_514\ : std_logic ;
  signal \GRFPU0.N_515\ : std_logic ;
  signal \GRFPU0.N_516\ : std_logic ;
  signal \GRFPU0.N_517\ : std_logic ;
  signal \GRFPU0.N_518\ : std_logic ;
  signal \GRFPU0.N_519\ : std_logic ;
  signal \GRFPU0.N_520\ : std_logic ;
  signal \GRFPU0.N_521\ : std_logic ;
  signal \GRFPU0.N_522\ : std_logic ;
  signal \GRFPU0.N_523\ : std_logic ;
  signal \GRFPU0.N_524\ : std_logic ;
  signal \GRFPU0.N_525\ : std_logic ;
  signal \GRFPU0.N_526\ : std_logic ;
  signal \GRFPU0.N_527\ : std_logic ;
  signal \GRFPU0.N_528\ : std_logic ;
  signal \GRFPU0.N_529\ : std_logic ;
  signal \GRFPU0.N_530\ : std_logic ;
  signal \GRFPU0.N_531\ : std_logic ;
  signal \GRFPU0.N_532\ : std_logic ;
  signal \GRFPU0.N_533\ : std_logic ;
  signal \GRFPU0.N_534\ : std_logic ;
  signal \GRFPU0.N_535\ : std_logic ;
  signal \GRFPU0.N_536\ : std_logic ;
  signal \GRFPU0.N_537\ : std_logic ;
  signal \GRFPU0.N_538\ : std_logic ;
  signal \GRFPU0.N_539\ : std_logic ;
  signal \GRFPU0.N_540\ : std_logic ;
  signal \GRFPU0.N_541\ : std_logic ;
  signal \GRFPU0.N_542\ : std_logic ;
  signal \GRFPU0.N_543\ : std_logic ;
  signal \GRFPU0.N_544\ : std_logic ;
  signal \GRFPU0.N_545\ : std_logic ;
  signal \GRFPU0.N_546\ : std_logic ;
  signal \GRFPU0.N_547\ : std_logic ;
  signal \GRFPU0.N_548\ : std_logic ;
  signal \GRFPU0.N_549\ : std_logic ;
  signal \GRFPU0.N_550\ : std_logic ;
  signal \GRFPU0.N_551\ : std_logic ;
  signal \GRFPU0.N_552\ : std_logic ;
  signal \GRFPU0.N_553\ : std_logic ;
  signal \GRFPU0.N_554\ : std_logic ;
  signal \GRFPU0.N_555\ : std_logic ;
  signal \GRFPU0.N_556\ : std_logic ;
  signal \GRFPU0.N_557\ : std_logic ;
  signal \GRFPU0.N_558\ : std_logic ;
  signal \GRFPU0.N_559\ : std_logic ;
  signal \GRFPU0.N_560\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.RDY\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.SIGN2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.NORM\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.V\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.RDY\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.OP2NX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SIGN\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.OP1NX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.V\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.V\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.ODDEXP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SGNFEQ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.LOB\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.NX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EMAXP1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.RDY\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.DIFFV\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.DIFFV\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.DIFFN\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.ADD\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.SQRT\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.FLUSH0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.IOF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.MOF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.ADDOF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.STICKY\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.SIGN1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.DEFERNX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.DEFERNX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.EMIN\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EMIN\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.V\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.INF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.ZERO\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.ZERO\ : std_logic ;
  signal \GRFPC0.DIV.EXCT_0_0_1__I1_I_3\ : std_logic ;
  signal \GRFPC0.DIV.EXCT_0_0_4__I1_I_2\ : std_logic ;
  signal \GRFPC0.DIV.EXCT_0_0_5__I1_I_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.QSNAN\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.QSNAN\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.INF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.INF_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EMINM1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.EMINM1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MOF_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3207\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3209\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3210\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3211\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3212\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3213\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3214\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3215\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3216\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.ADDOF_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6321\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3406\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7113\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3206\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5791\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5937\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4364\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3475\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10035\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10037\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10039\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10041\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10043\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10045\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10047\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10049\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10060\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10064\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10065\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10066\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10067\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10068\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10069\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10071\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10075\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10076\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10077\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10079\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10083\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10085\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10086\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10087\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10088\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10089\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10090\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10091\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10092\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10094\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10095\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10096\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10097\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10098\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10099\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10100\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10101\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10102\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10103\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10104\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10105\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10106\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10107\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10108\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10109\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10113\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10114\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10118\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10179\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10180\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10189\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10191\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.ADD_1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15794\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15795\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15796\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15797\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15798\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15799\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15800\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15801\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15802\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15803\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15804\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15805\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15806\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15807\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15808\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15809\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15810\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15811\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15812\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15813\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15814\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15815\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15816\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15817\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15818\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15819\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15820\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15821\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15822\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15823\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15824\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15825\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15826\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15827\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15828\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15829\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15830\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15831\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15832\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15833\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15834\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15835\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15836\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15837\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15838\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15842\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15843\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15844\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15845\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15847\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15850\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15851\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15852\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15853\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15854\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15855\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15856\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15857\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15858\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15859\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15860\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15861\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15862\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15863\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15864\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15865\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15866\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15867\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15868\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15869\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15870\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15871\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15872\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15873\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15874\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15875\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15876\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15884\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15885\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15886\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15887\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15888\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15889\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15890\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15891\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15892\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15893\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15894\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15895\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15896\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15897\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16923\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16925\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16926\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16927\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16928\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16929\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16931\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16932\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16933\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16934\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16935\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16936\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16937\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16938\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16939\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16940\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16941\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16942\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16943\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16944\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16945\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16946\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16947\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16948\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16949\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16950\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16951\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16952\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16953\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16954\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16955\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16956\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16957\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16959\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16960\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16961\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16962\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16963\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16964\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16965\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16966\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16967\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16968\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16969\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16970\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16971\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16972\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16973\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16974\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16975\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16976\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16977\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16978\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16979\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16980\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16981\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16982\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16985\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16986\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16987\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16988\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16989\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16990\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16991\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16993\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16994\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16995\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16996\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16997\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16998\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16999\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17000\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17001\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17002\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17003\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17004\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17005\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17006\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17007\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17008\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17009\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17010\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17011\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17012\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17013\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17014\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17015\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17016\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17017\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17018\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17019\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17020\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17021\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17022\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17023\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17024\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17025\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17026\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17027\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17028\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17029\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17030\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17031\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17032\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17033\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17034\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17035\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17036\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_8835\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_8869\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7321\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18336\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18337\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18340\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18563\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18615\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18616\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18617\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18618\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18619\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_74\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18620\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18621\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18622\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18623\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18624\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18625\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18626\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18683\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18684\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18957\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18981\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_2_01\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13447\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20518\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M17_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M18_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M19_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M20_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M21_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M22_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M23_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M24_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M25_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M26_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M27_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M28_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M84_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M39_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M40_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M41_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M42_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M43_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M44_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M45_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M46_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M39_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M40_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M41_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M42_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M43_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M44_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M45_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M46_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_0_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_2_01\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_35\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_39\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_35\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_42\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_44\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_39\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_48\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_50\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_42\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_43\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_52\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_44\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_53\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_54\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_56\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_57\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_48\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_58\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_49\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_59\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_50\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_60\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_62\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_52\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_63\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_53\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_64\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_54\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_65\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_55\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_66\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_56\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_68\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_57\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_69\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_58\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_70\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_59\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_71\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_60\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_72\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.LT_61\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_74\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.N_75\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.CCWR\ : std_logic ;
  signal \GRFPC0.WR.RREG.RESV\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.LD\ : std_logic ;
  signal \GRFPC0.FIFO.FULL\ : std_logic ;
  signal \GRFPC0.RFA.RS2D\ : std_logic ;
  signal \GRFPC0.WR2.RREG.RESV\ : std_logic ;
  signal \GRFPC0.EX.RREG.RESV\ : std_logic ;
  signal \GRFPC0.DIV.VALID\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RESV\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.RDD\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.SEQERR\ : std_logic ;
  signal \GRFPC0.DIV.PEND\ : std_logic ;
  signal \GRFPC0.DIV.RDD\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.LD\ : std_logic ;
  signal \GRFPC0.EX.CTRL.AFSR\ : std_logic ;
  signal \GRFPC0.EX.CTRL.STDFQ\ : std_logic ;
  signal \GRFPC0.EX.CTRL.LD\ : std_logic ;
  signal \GRFPC0.RFA.ST\ : std_logic ;
  signal \GRFPC0.RFA2.RS2DEP\ : std_logic ;
  signal \GRFPC0.RFA.WRITE_RD\ : std_logic ;
  signal \GRFPC0.WR.CTRL.LD\ : std_logic ;
  signal \GRFPC0.WR.CTRL.RDWR\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.RDWR\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDWR\ : std_logic ;
  signal \GRFPC0.WR.CTRL.CCWR\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.CCWR\ : std_logic ;
  signal \GRFPC0.EX.CTRL.CCWR\ : std_logic ;
  signal \GRFPC0.FPR.RDY\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.RDWR\ : std_logic ;
  signal \GRFPC0.WR2.EXC\ : std_logic ;
  signal \GRFPC0.DIV.EXC\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.PEND\ : std_logic ;
  signal \GRFPC0.RFA.RS1D\ : std_logic ;
  signal \GRFPC0.RFA.LD\ : std_logic ;
  signal \GRFPC0.RFA.READ_RS1\ : std_logic ;
  signal \GRFPC0.RFA2.RS1DEP\ : std_logic ;
  signal \GRFPC0.RFA2.DIVLCK\ : std_logic ;
  signal \GRFPC0.DIV.EXEC\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.AFSR\ : std_logic ;
  signal \GRFPC0.WR.CTRL.AFSR\ : std_logic ;
  signal \GRFPC0.WR.CTRL.STDFQ\ : std_logic ;
  signal \GRFPC0.WR.CTRL.SEQERR\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.AFSR\ : std_logic ;
  signal \GRFPC0.EX.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.WR.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PEND\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.PEND\ : std_logic ;
  signal \GRFPC0.WR.CTRL.PEND\ : std_logic ;
  signal \GRFPC0.N_9481\ : std_logic ;
  signal \GRFPC0.N_9483\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RS1V\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.RS1V\ : std_logic ;
  signal \GRFPC0.WR.CTRL.RS1V\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN616_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.1.CHECK_DEP.UN1120_REGDEPX\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.STDFQ\ : std_logic ;
  signal \GRFPC0.RFA.RDD\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.RS1V\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\ : std_logic ;
  signal \GRFPC0.DIV.RS1V\ : std_logic ;
  signal \GRFPC0.D.FSTLCK\ : std_logic ;
  signal \GRFPC0.D.FLDLCK\ : std_logic ;
  signal \GRFPC0.RFA.AFSR\ : std_logic ;
  signal \GRFPC0.RFA.RDWR\ : std_logic ;
  signal \GRFPC0.RFA.STDFQ\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.STDFQ\ : std_logic ;
  signal \GRFPC0.RFA.SEQERR\ : std_logic ;
  signal \GRFPC0.EX.CTRL.SEQERR\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.SEQERR\ : std_logic ;
  signal \GRFPC0.REGDEP_0_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.REGDEP_0_SQMUXA_2\ : std_logic ;
  signal \GRFPC0.N_9441\ : std_logic ;
  signal \GRFPC0.N_10557\ : std_logic ;
  signal \GRFPC0.N_10559\ : std_logic ;
  signal \GRFPC0.N_10561\ : std_logic ;
  signal \GRFPC0.N_10562\ : std_logic ;
  signal \GRFPC0.N_10564\ : std_logic ;
  signal \GRFPC0.N_10565\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID_1\ : std_logic ;
  signal \GRFPC0.N_10569\ : std_logic ;
  signal \GRFPC0.N_10571\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.EXEC_1\ : std_logic ;
  signal \GRFPC0.N_10577\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.DEPMUX.RES\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FLUSH_1\ : std_logic ;
  signal \GRFPC0.N_19199\ : std_logic ;
  signal \GRFPC0.N_19200\ : std_logic ;
  signal \GRFPC0.N_19201\ : std_logic ;
  signal \GRFPC0.N_19202\ : std_logic ;
  signal \GRFPC0.N_19203\ : std_logic ;
  signal \GRFPC0.N_19204\ : std_logic ;
  signal \GRFPC0.N_19205\ : std_logic ;
  signal \GRFPC0.N_19206\ : std_logic ;
  signal \GRFPC0.N_19207\ : std_logic ;
  signal \GRFPC0.N_19208\ : std_logic ;
  signal \GRFPC0.N_19209\ : std_logic ;
  signal \GRFPC0.N_19210\ : std_logic ;
  signal \GRFPC0.N_19211\ : std_logic ;
  signal \GRFPC0.N_19212\ : std_logic ;
  signal \GRFPC0.N_19213\ : std_logic ;
  signal \GRFPC0.N_19214\ : std_logic ;
  signal \GRFPC0.N_19215\ : std_logic ;
  signal \GRFPC0.N_19216\ : std_logic ;
  signal \GRFPC0.N_19217\ : std_logic ;
  signal \GRFPC0.N_19218\ : std_logic ;
  signal \GRFPC0.N_19219\ : std_logic ;
  signal \GRFPC0.N_19220\ : std_logic ;
  signal \GRFPC0.N_19221\ : std_logic ;
  signal \GRFPC0.N_19222\ : std_logic ;
  signal \GRFPC0.N_19223\ : std_logic ;
  signal \GRFPC0.N_19224\ : std_logic ;
  signal \GRFPC0.N_19225\ : std_logic ;
  signal \GRFPC0.N_19226\ : std_logic ;
  signal \GRFPC0.N_19227\ : std_logic ;
  signal \GRFPC0.N_19228\ : std_logic ;
  signal \GRFPC0.N_19229\ : std_logic ;
  signal \GRFPC0.N_19230\ : std_logic ;
  signal \GRFPC0.N_19231\ : std_logic ;
  signal \GRFPC0.N_19232\ : std_logic ;
  signal \GRFPC0.N_19233\ : std_logic ;
  signal \GRFPC0.N_19234\ : std_logic ;
  signal \GRFPC0.N_19235\ : std_logic ;
  signal \GRFPC0.N_19236\ : std_logic ;
  signal \GRFPC0.N_19237\ : std_logic ;
  signal \GRFPC0.N_19238\ : std_logic ;
  signal \GRFPC0.N_19239\ : std_logic ;
  signal \GRFPC0.N_19240\ : std_logic ;
  signal \GRFPC0.N_19241\ : std_logic ;
  signal \GRFPC0.N_19242\ : std_logic ;
  signal \GRFPC0.N_19243\ : std_logic ;
  signal \GRFPC0.N_19244\ : std_logic ;
  signal \GRFPC0.N_19245\ : std_logic ;
  signal \GRFPC0.N_19246\ : std_logic ;
  signal \GRFPC0.N_19247\ : std_logic ;
  signal \GRFPC0.N_19248\ : std_logic ;
  signal \GRFPC0.N_19249\ : std_logic ;
  signal \GRFPC0.N_19250\ : std_logic ;
  signal \GRFPC0.N_19251\ : std_logic ;
  signal \GRFPC0.N_19252\ : std_logic ;
  signal \GRFPC0.N_19253\ : std_logic ;
  signal \GRFPC0.N_19254\ : std_logic ;
  signal \GRFPC0.N_19255\ : std_logic ;
  signal \GRFPC0.N_19256\ : std_logic ;
  signal \GRFPC0.N_19257\ : std_logic ;
  signal \GRFPC0.N_19258\ : std_logic ;
  signal \GRFPC0.N_19259\ : std_logic ;
  signal \GRFPC0.N_19260\ : std_logic ;
  signal \GRFPC0.N_19261\ : std_logic ;
  signal \GRFPC0.N_19262\ : std_logic ;
  signal \GRFPC0.N_19264\ : std_logic ;
  signal \GRFPC0.N_19265\ : std_logic ;
  signal \GRFPC0.N_19266\ : std_logic ;
  signal \GRFPC0.N_19267\ : std_logic ;
  signal \GRFPC0.N_19268\ : std_logic ;
  signal \GRFPC0.N_19269\ : std_logic ;
  signal \GRFPC0.N_19270\ : std_logic ;
  signal \GRFPC0.N_19271\ : std_logic ;
  signal \GRFPC0.N_19272\ : std_logic ;
  signal \GRFPC0.N_19273\ : std_logic ;
  signal \GRFPC0.N_19274\ : std_logic ;
  signal \GRFPC0.N_19275\ : std_logic ;
  signal \GRFPC0.N_19276\ : std_logic ;
  signal \GRFPC0.N_19277\ : std_logic ;
  signal \GRFPC0.N_19278\ : std_logic ;
  signal \GRFPC0.N_19279\ : std_logic ;
  signal \GRFPC0.N_19280\ : std_logic ;
  signal \GRFPC0.N_19281\ : std_logic ;
  signal \GRFPC0.N_19282\ : std_logic ;
  signal \GRFPC0.N_19283\ : std_logic ;
  signal \GRFPC0.N_19284\ : std_logic ;
  signal \GRFPC0.N_19285\ : std_logic ;
  signal \GRFPC0.N_19286\ : std_logic ;
  signal \GRFPC0.N_19287\ : std_logic ;
  signal \GRFPC0.N_19288\ : std_logic ;
  signal \GRFPC0.N_19289\ : std_logic ;
  signal \GRFPC0.N_19290\ : std_logic ;
  signal \GRFPC0.N_19291\ : std_logic ;
  signal \GRFPC0.N_19292\ : std_logic ;
  signal \GRFPC0.N_19293\ : std_logic ;
  signal \GRFPC0.N_19294\ : std_logic ;
  signal \GRFPC0.N_19295\ : std_logic ;
  signal \GRFPC0.N_19296\ : std_logic ;
  signal \GRFPC0.N_19297\ : std_logic ;
  signal \GRFPC0.N_19298\ : std_logic ;
  signal \GRFPC0.N_19299\ : std_logic ;
  signal \GRFPC0.N_19300\ : std_logic ;
  signal \GRFPC0.N_19301\ : std_logic ;
  signal \GRFPC0.N_19302\ : std_logic ;
  signal \GRFPC0.N_19303\ : std_logic ;
  signal \GRFPC0.N_19304\ : std_logic ;
  signal \GRFPC0.N_19305\ : std_logic ;
  signal \GRFPC0.N_19306\ : std_logic ;
  signal \GRFPC0.N_19307\ : std_logic ;
  signal \GRFPC0.N_19308\ : std_logic ;
  signal \GRFPC0.N_19309\ : std_logic ;
  signal \GRFPC0.N_19310\ : std_logic ;
  signal \GRFPC0.N_19311\ : std_logic ;
  signal \GRFPC0.N_19312\ : std_logic ;
  signal \GRFPC0.N_19313\ : std_logic ;
  signal \GRFPC0.N_19314\ : std_logic ;
  signal \GRFPC0.N_19315\ : std_logic ;
  signal \GRFPC0.N_19316\ : std_logic ;
  signal \GRFPC0.N_19317\ : std_logic ;
  signal \GRFPC0.N_19318\ : std_logic ;
  signal \GRFPC0.N_19319\ : std_logic ;
  signal \GRFPC0.N_19320\ : std_logic ;
  signal \GRFPC0.N_19321\ : std_logic ;
  signal \GRFPC0.N_19322\ : std_logic ;
  signal \GRFPC0.N_19323\ : std_logic ;
  signal \GRFPC0.N_19324\ : std_logic ;
  signal \GRFPC0.N_19325\ : std_logic ;
  signal \GRFPC0.N_19326\ : std_logic ;
  signal \GRFPC0.N_19327\ : std_logic ;
  signal \GRFPC0.N_20384\ : std_logic ;
  signal \GRFPC0.N_20385\ : std_logic ;
  signal \GRFPC0.N_176\ : std_logic ;
  signal \GRFPC0.N_106_I\ : std_logic ;
  signal \GRFPC0.N_21353\ : std_logic ;
  signal \GRFPC0.N_21419\ : std_logic ;
  signal \GRFPC0.N_21626\ : std_logic ;
  signal \GRFPC0.N_21634\ : std_logic ;
  signal \GRFPC0.WR.CTRL.RDD\ : std_logic ;
  signal \GRFPC0.N_22243\ : std_logic ;
  signal \GRFPC0.N_22252\ : std_logic ;
  signal \GRFPC0.N_21454\ : std_logic ;
  signal \GRFPC0.N_22813\ : std_logic ;
  signal \GRFPC0.N_23514\ : std_logic ;
  signal \GRFPC0.N_17951\ : std_logic ;
  signal \GRFPC0.N_23921\ : std_logic ;
  signal \GRFPC0.N_23978\ : std_logic ;
  signal \GRFPC0.N_24767\ : std_logic ;
  signal \GRFPC0.N_25010\ : std_logic ;
  signal \GRFPC0.N_25013\ : std_logic ;
  signal \GRFPC0.N_25056\ : std_logic ;
  signal \GRFPC0.N_25334\ : std_logic ;
  signal \GRFPC0.N_22902_1\ : std_logic ;
  signal \GRFPC0.N_21948_1\ : std_logic ;
  signal \GRFPC0.N_23515_I\ : std_logic ;
  signal \GRFPC0.N_22975_I\ : std_logic ;
  signal \GRFPC0.N_23522_I\ : std_logic ;
  signal \GRFPC0.N_505\ : std_logic ;
  signal \GRFPC0.N_571\ : std_logic ;
  signal \GRFPC0.N_579\ : std_logic ;
  signal \GRFPC0.N_22809\ : std_logic ;
  signal \GRFPC0.N_116\ : std_logic ;
  signal \GRFPC0.N_24062\ : std_logic ;
  signal \GRFPC0.N_24063\ : std_logic ;
  signal \GRFPC0.N_22822\ : std_logic ;
  signal \GRFPC0.N_22825\ : std_logic ;
  signal \GRFPC0.N_21274\ : std_logic ;
  signal \GRFPC0.N_20160\ : std_logic ;
  signal \GRFPC0.N_25343\ : std_logic ;
  signal \GRFPC0.N_19690\ : std_logic ;
  signal \GRFPC0.N_507\ : std_logic ;
  signal \GRFPC0.N_24984\ : std_logic ;
  signal \GRFPC0.N_24455_I\ : std_logic ;
  signal \GRFPC0.N_491\ : std_logic ;
  signal \GRFPC0.N_501\ : std_logic ;
  signal \GRFPC0.N_490\ : std_logic ;
  signal \GRFPC0.N_462\ : std_logic ;
  signal N_6 : std_logic ;
  signal N_7 : std_logic ;
  signal N_8 : std_logic ;
  signal N_9 : std_logic ;
  signal N_10 : std_logic ;
  signal N_11 : std_logic ;
  signal N_12 : std_logic ;
  signal N_13 : std_logic ;
  signal N_14 : std_logic ;
  signal N_15 : std_logic ;
  signal N_16 : std_logic ;
  signal N_17 : std_logic ;
  signal N_18 : std_logic ;
  signal N_19 : std_logic ;
  signal N_20 : std_logic ;
  signal N_21 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_SM0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FCC_1_SM0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13398_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18859_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18860_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18841_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18751_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18752_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18744_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18198_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18442_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18441_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_102_I\ : std_logic ;
  signal N_26925 : std_logic ;
  signal N_26926 : std_logic ;
  signal N_26927 : std_logic ;
  signal N_27009 : std_logic ;
  signal N_27123 : std_logic ;
  signal N_27201 : std_logic ;
  signal N_27203 : std_logic ;
  signal N_27204 : std_logic ;
  signal N_27205 : std_logic ;
  signal N_27207 : std_logic ;
  signal N_27209 : std_logic ;
  signal N_27210 : std_logic ;
  signal N_27211 : std_logic ;
  signal N_27213 : std_logic ;
  signal N_27215 : std_logic ;
  signal N_27216 : std_logic ;
  signal N_27217 : std_logic ;
  signal N_27218 : std_logic ;
  signal N_27219 : std_logic ;
  signal N_27220 : std_logic ;
  signal N_27221 : std_logic ;
  signal N_27222 : std_logic ;
  signal N_27223 : std_logic ;
  signal N_27320 : std_logic ;
  signal N_27322 : std_logic ;
  signal N_27323 : std_logic ;
  signal N_27325 : std_logic ;
  signal N_27326 : std_logic ;
  signal N_27327 : std_logic ;
  signal N_27328 : std_logic ;
  signal N_27329 : std_logic ;
  signal N_27330 : std_logic ;
  signal N_27331 : std_logic ;
  signal N_27332 : std_logic ;
  signal N_27333 : std_logic ;
  signal N_27334 : std_logic ;
  signal N_27335 : std_logic ;
  signal N_27336 : std_logic ;
  signal N_27337 : std_logic ;
  signal N_27339 : std_logic ;
  signal N_27340 : std_logic ;
  signal N_27342 : std_logic ;
  signal N_27345 : std_logic ;
  signal N_27348 : std_logic ;
  signal N_27351 : std_logic ;
  signal N_27384 : std_logic ;
  signal N_27386 : std_logic ;
  signal N_27387 : std_logic ;
  signal N_27389 : std_logic ;
  signal N_27390 : std_logic ;
  signal N_27391 : std_logic ;
  signal N_27392 : std_logic ;
  signal N_27393 : std_logic ;
  signal N_27394 : std_logic ;
  signal N_27395 : std_logic ;
  signal N_27396 : std_logic ;
  signal N_27397 : std_logic ;
  signal N_27398 : std_logic ;
  signal N_27399 : std_logic ;
  signal N_27400 : std_logic ;
  signal N_27401 : std_logic ;
  signal N_27403 : std_logic ;
  signal N_27404 : std_logic ;
  signal N_27406 : std_logic ;
  signal N_27409 : std_logic ;
  signal N_27412 : std_logic ;
  signal N_27415 : std_logic ;
  signal N_27777 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\ : std_logic ;
  signal N_28055 : std_logic ;
  signal N_28057 : std_logic ;
  signal N_28059 : std_logic ;
  signal N_28061 : std_logic ;
  signal N_28063 : std_logic ;
  signal N_28065 : std_logic ;
  signal N_28067 : std_logic ;
  signal N_28069 : std_logic ;
  signal N_28071 : std_logic ;
  signal N_28073 : std_logic ;
  signal N_28075 : std_logic ;
  signal N_28077 : std_logic ;
  signal N_28079 : std_logic ;
  signal N_28081 : std_logic ;
  signal N_28083 : std_logic ;
  signal N_28085 : std_logic ;
  signal N_28087 : std_logic ;
  signal N_28089 : std_logic ;
  signal N_28091 : std_logic ;
  signal N_28093 : std_logic ;
  signal N_28095 : std_logic ;
  signal N_28097 : std_logic ;
  signal N_28099 : std_logic ;
  signal N_28101 : std_logic ;
  signal N_28103 : std_logic ;
  signal N_28105 : std_logic ;
  signal N_28107 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\ : std_logic ;
  signal N_28112 : std_logic ;
  signal N_28114 : std_logic ;
  signal N_28116 : std_logic ;
  signal N_28117 : std_logic ;
  signal N_28118 : std_logic ;
  signal N_28119 : std_logic ;
  signal N_28120 : std_logic ;
  signal N_28121 : std_logic ;
  signal N_28122 : std_logic ;
  signal N_28125 : std_logic ;
  signal N_28126 : std_logic ;
  signal N_28127 : std_logic ;
  signal N_28128 : std_logic ;
  signal N_28129 : std_logic ;
  signal N_28130 : std_logic ;
  signal N_28131 : std_logic ;
  signal N_28132 : std_logic ;
  signal N_28133 : std_logic ;
  signal N_28134 : std_logic ;
  signal N_28135 : std_logic ;
  signal N_28136 : std_logic ;
  signal N_28137 : std_logic ;
  signal N_28138 : std_logic ;
  signal N_28139 : std_logic ;
  signal N_28140 : std_logic ;
  signal N_28141 : std_logic ;
  signal N_28142 : std_logic ;
  signal N_28143 : std_logic ;
  signal N_28144 : std_logic ;
  signal N_28145 : std_logic ;
  signal N_28146 : std_logic ;
  signal N_28147 : std_logic ;
  signal N_28148 : std_logic ;
  signal N_28149 : std_logic ;
  signal N_28150 : std_logic ;
  signal N_28151 : std_logic ;
  signal N_28152 : std_logic ;
  signal N_28153 : std_logic ;
  signal N_28154 : std_logic ;
  signal N_28155 : std_logic ;
  signal N_28156 : std_logic ;
  signal N_28157 : std_logic ;
  signal N_28158 : std_logic ;
  signal N_28159 : std_logic ;
  signal N_28160 : std_logic ;
  signal N_28163 : std_logic ;
  signal N_28164 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\ : std_logic ;
  signal N_28169 : std_logic ;
  signal N_28171 : std_logic ;
  signal N_28173 : std_logic ;
  signal N_28174 : std_logic ;
  signal N_28175 : std_logic ;
  signal N_28176 : std_logic ;
  signal N_28177 : std_logic ;
  signal N_28180 : std_logic ;
  signal N_28181 : std_logic ;
  signal N_28184 : std_logic ;
  signal N_28185 : std_logic ;
  signal N_28186 : std_logic ;
  signal N_28187 : std_logic ;
  signal N_28188 : std_logic ;
  signal N_28189 : std_logic ;
  signal N_28190 : std_logic ;
  signal N_28191 : std_logic ;
  signal N_28192 : std_logic ;
  signal N_28193 : std_logic ;
  signal N_28194 : std_logic ;
  signal N_28195 : std_logic ;
  signal N_28196 : std_logic ;
  signal N_28197 : std_logic ;
  signal N_28198 : std_logic ;
  signal N_28199 : std_logic ;
  signal N_28200 : std_logic ;
  signal N_28201 : std_logic ;
  signal N_28202 : std_logic ;
  signal N_28203 : std_logic ;
  signal N_28204 : std_logic ;
  signal N_28205 : std_logic ;
  signal N_28206 : std_logic ;
  signal N_28207 : std_logic ;
  signal N_28208 : std_logic ;
  signal N_28209 : std_logic ;
  signal N_28210 : std_logic ;
  signal N_28211 : std_logic ;
  signal N_28212 : std_logic ;
  signal N_28213 : std_logic ;
  signal N_28214 : std_logic ;
  signal N_28215 : std_logic ;
  signal N_28216 : std_logic ;
  signal N_28217 : std_logic ;
  signal N_28220 : std_logic ;
  signal N_28221 : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\ : std_logic ;
  signal N_28226 : std_logic ;
  signal N_28228 : std_logic ;
  signal N_28230 : std_logic ;
  signal N_28232 : std_logic ;
  signal N_28234 : std_logic ;
  signal N_28236 : std_logic ;
  signal N_28238 : std_logic ;
  signal N_28240 : std_logic ;
  signal N_28242 : std_logic ;
  signal N_28244 : std_logic ;
  signal N_28246 : std_logic ;
  signal N_28248 : std_logic ;
  signal N_28250 : std_logic ;
  signal N_28252 : std_logic ;
  signal N_28254 : std_logic ;
  signal N_28256 : std_logic ;
  signal N_28258 : std_logic ;
  signal N_28260 : std_logic ;
  signal N_28262 : std_logic ;
  signal N_28264 : std_logic ;
  signal N_28266 : std_logic ;
  signal N_28268 : std_logic ;
  signal N_28270 : std_logic ;
  signal N_28272 : std_logic ;
  signal N_28274 : std_logic ;
  signal N_28276 : std_logic ;
  signal N_28290 : std_logic ;
  signal N_28291 : std_logic ;
  signal N_28292 : std_logic ;
  signal N_28293 : std_logic ;
  signal N_28294 : std_logic ;
  signal N_28295 : std_logic ;
  signal N_28296 : std_logic ;
  signal N_28297 : std_logic ;
  signal N_28298 : std_logic ;
  signal N_28299 : std_logic ;
  signal N_28300 : std_logic ;
  signal N_28301 : std_logic ;
  signal N_28302 : std_logic ;
  signal N_28303 : std_logic ;
  signal N_28304 : std_logic ;
  signal N_28305 : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_96\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_47\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_48\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_49\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_50\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_51\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_52\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_53\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_54\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_55\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_56\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_57\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_58\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_59\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_60\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_61\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_62\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_63\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_64\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_65\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_66\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_67\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_68\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_69\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_70\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_71\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_72\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_73\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_74\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_75\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_76\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_77\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_78\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_79\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_80\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_81\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_82\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_83\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_84\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_85\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_86\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_87\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_88\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_89\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_90\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_91\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_92\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_93\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_94\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_95\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_49\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_28\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_29\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_30\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_31\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_32\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_33\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_34\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_35\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_47\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_48\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_28\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_29\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_30\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_31\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_32\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_33\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_34\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_35\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_47\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_48\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_49\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_50\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_51\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_52\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_53\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_54\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_55\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_56\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_57\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_58\ : std_logic ;
  signal \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_59\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_53\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_28\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_29\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_30\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_31\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_32\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_33\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_34\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_35\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_47\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_48\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_49\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_50\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_51\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_52\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_53\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_28\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_29\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_30\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_31\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_32\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_33\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_34\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_35\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_47\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_48\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_49\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_50\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_51\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_52\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_51\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_28\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_29\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_30\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_31\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_32\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_33\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_34\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_35\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_36\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_37\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_38\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_39\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_40\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_41\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_42\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_43\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_44\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_45\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_46\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_47\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_48\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_49\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_50\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_55\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_35\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_39\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_42\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_43\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_44\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_48\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_49\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_50\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_52\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_53\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_54\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_53\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_35\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_39\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_42\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_43\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_44\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_48\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_49\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_50\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_52\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_35\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_39\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_42\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_43\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_44\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_48\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_49\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_50\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_35\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_39\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_42\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_43\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_44\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_48\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_49\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_50\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_52\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_35\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_39\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_42\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_43\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_44\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_48\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_49\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_50\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_50\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_35\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_39\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_42\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_43\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_44\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_45\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_48\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_49\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.C_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN8_C_CARRY_10\ : std_logic ;
  signal \GRFPC0.N_25793_1\ : std_logic ;
  signal \GRFPC0.N_22433_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.OP2NX_0_0_N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_5__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_5__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_6__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_6__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_7__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_7__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_8__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_8__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_9__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_9__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_10__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_10__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_11__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_11__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_12__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_12__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_13__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_13__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_14__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_14__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_15__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_15__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_16__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_16__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_17__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_17__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_18__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_18__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_19__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_19__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_20__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_20__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_21__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_21__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_22__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_22__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_23__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_23__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_24__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_24__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_25__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_25__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_26__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_26__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_27__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_27__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_28__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_28__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_29__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_29__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_30__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_30__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_31__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_31__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_32__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_32__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_33__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_33__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_34__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_34__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_35__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_35__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_36__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_36__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_37__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_37__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_38__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_38__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_39__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_39__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_40__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_40__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_41__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_41__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_42__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_42__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_43__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_43__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_44__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_44__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_45__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_45__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_46__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_46__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_47__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_47__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_48__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_48__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_49__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_49__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_50__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_50__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_51__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_51__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_52__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_52__G4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_2__N_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_3__N_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_4__N_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_5__N_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_6__N_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_7__N_36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_8__N_41\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_10__N_51\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_0__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_2__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_3__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_4__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_5__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_6__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_7__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_8__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_10__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_0__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_2__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_3__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_4__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_5__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_6__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_7__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_8__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_9__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_10__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_11__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_12__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_13__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_14__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_15__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_16__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_17__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_18__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_19__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_20__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_21__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_22__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_23__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_24__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_25__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_26__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_27__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_28__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_29__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_30__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_31__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_29__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_30__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_31__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_32__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_33__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_34__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_35__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_36__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_37__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_38__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_39__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_40__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_41__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_42__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_43__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_44__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_45__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_46__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_47__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_48__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_49__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_50__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_51__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1_0_0_1__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_5__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_4_03_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.DP_0_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.BMLSB_0_0_0__N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.BMLSB_0_0_1__N_5\ : std_logic ;
  signal \GRFPC0.RFA.WRITE_RD_0_0_G1\ : std_logic ;
  signal \GRFPC0.RFA.READ_RS1_0_0_G1\ : std_logic ;
  signal \GRFPC0.FIFO.FULL_0_0_G1\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1\ : std_logic ;
  signal \GRFPC0.D.FLDLCK_0_0_G1\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.PEND_0_0_G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PEND_0_0_G1\ : std_logic ;
  signal \GRFPC0.WR.CTRL.PEND_0_0_G1\ : std_logic ;
  signal \GRFPC0.FIFO.WR_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.FIFO.RD_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.DIV_0_0_G1\ : std_logic ;
  signal \GRFPC0.WR2.EXC_0_0_G1\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.RDD_0_0_G1\ : std_logic ;
  signal \GRFPC0.WR.CTRL.STDFQ_0_0_G1\ : std_logic ;
  signal \GRFPC0.WR.CTRL.RDD_0_0_G1\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.STDFQ_0_0_G1\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.RDD_0_0_G1\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.PEND_0_0_G1\ : std_logic ;
  signal \GRFPC0.R.FSR.NONSTD_0_0_G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RS1V_0_0_G1\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.VCNT_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.VCNT_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.VCNT_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.VCNT_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.RD_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.RD_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.TEM_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.TEM_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.TEM_0_0_2__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.TEM_0_0_3__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.TEM_0_0_4__G1\ : std_logic ;
  signal \GRFPC0.EX.RREG.EXCT_0_0_3__N_6\ : std_logic ;
  signal \GRFPC0.MEM.RREG.EXCT_0_0_3__N_6\ : std_logic ;
  signal \GRFPC0.WR2.RREG.EXCT_0_0_0__G3\ : std_logic ;
  signal \GRFPC0.WR2.RREG.EXCT_0_0_1__G3\ : std_logic ;
  signal \GRFPC0.WR2.RREG.EXCT_0_0_2__G3\ : std_logic ;
  signal \GRFPC0.WR2.RREG.EXCT_0_0_3__G3\ : std_logic ;
  signal \GRFPC0.WR2.RREG.EXCT_0_0_4__G3\ : std_logic ;
  signal \GRFPC0.WR2.RREG.EXCT_0_0_5__G3\ : std_logic ;
  signal \GRFPC0.R.STDATA_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.R.STDATA_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.R.STATE_0_0_0__G2\ : std_logic ;
  signal \GRFPC0.R.FSR.FCC_0_0_0__N_6\ : std_logic ;
  signal \GRFPC0.R.FSR.FCC_0_0_1__N_6\ : std_logic ;
  signal \GRFPC0.R.FSR.FTT_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.FTT_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.AEXC_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.AEXC_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.AEXC_0_0_2__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.AEXC_0_0_3__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.AEXC_0_0_4__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_2__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_3__G1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_4__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.INST_0_0_18__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_2__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_3__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_4__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_5__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_6__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_7__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_8__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_9__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_10__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_11__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_12__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_13__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_14__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_15__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_16__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_17__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_18__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_19__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_20__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_21__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_22__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_23__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_24__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_25__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_26__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_27__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_28__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_29__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_30__G1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PC_0_0_31__G1\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_0_0_0_2__G2\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_1_0_0_2__G2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_2__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_3__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_4__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_5__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_6__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_7__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_8__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_9__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_10__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_11__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_12__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_13__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_14__G1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_15__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_2__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_3__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_4__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_5__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_6__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_8__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_9__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_10__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_11__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_12__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_13__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_14__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_15__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_16__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_17__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_18__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_19__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_20__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_21__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_22__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_23__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_24__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_25__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_26__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_27__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_28__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_29__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_30__G1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_31__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_0__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_2__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_3__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_4__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_5__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_6__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_7__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_8__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_9__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_10__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_11__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_12__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_13__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_14__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_15__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_16__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_17__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_18__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_19__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_20__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_21__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_22__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_23__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_24__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_25__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_26__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_27__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_28__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_29__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_30__G1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_31__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.TZR_1_0_0__N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.TZR_1_0_1__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.TZR_1_0_3__N_4_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.TZR_1_0_4__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.TZR_1_0_5__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.TZR_1_0_6__N_4_I\ : std_logic ;
  signal N_44766 : std_logic ;
  signal N_44776 : std_logic ;
  signal N_44787 : std_logic ;
  signal N_44808 : std_logic ;
  signal N_44868 : std_logic ;
  signal N_44946 : std_logic ;
  signal N_45010 : std_logic ;
  signal N_45021 : std_logic ;
  signal N_45038 : std_logic ;
  signal N_45054 : std_logic ;
  signal N_45066 : std_logic ;
  signal N_45076 : std_logic ;
  signal N_45085 : std_logic ;
  signal N_45102 : std_logic ;
  signal N_45120 : std_logic ;
  signal N_45139 : std_logic ;
  signal N_45157 : std_logic ;
  signal N_45173 : std_logic ;
  signal N_45216 : std_logic ;
  signal N_45251 : std_logic ;
  signal N_46865 : std_logic ;
  signal N_46866 : std_logic ;
  signal \GRFPC0.EX.CTRL.RD_0_0_1__G3\ : std_logic ;
  signal N_46892 : std_logic ;
  signal \GRFPC0.EX.CTRL.RD_0_0_2__G3\ : std_logic ;
  signal N_46918 : std_logic ;
  signal \GRFPC0.EX.CTRL.RD_0_0_3__G3\ : std_logic ;
  signal N_46944 : std_logic ;
  signal \GRFPC0.EX.CTRL.RD_0_0_4__G3\ : std_logic ;
  signal N_46970 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18528_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18842_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18843_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18844_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18845_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18846_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18847_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18848_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18849_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18850_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18851_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18852_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18747_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18853_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18854_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18855_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18856_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18857_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18858_I\ : std_logic ;
  signal N_47178 : std_logic ;
  signal N_47179 : std_logic ;
  signal N_47180 : std_logic ;
  signal N_47181 : std_logic ;
  signal N_47182 : std_logic ;
  signal N_47183 : std_logic ;
  signal N_47184 : std_logic ;
  signal N_47185 : std_logic ;
  signal N_47186 : std_logic ;
  signal N_47187 : std_logic ;
  signal N_47188 : std_logic ;
  signal N_47189 : std_logic ;
  signal N_47190 : std_logic ;
  signal N_47191 : std_logic ;
  signal N_47192 : std_logic ;
  signal N_47193 : std_logic ;
  signal N_47194 : std_logic ;
  signal N_47195 : std_logic ;
  signal N_47196 : std_logic ;
  signal N_47197 : std_logic ;
  signal N_47198 : std_logic ;
  signal N_47199 : std_logic ;
  signal N_47200 : std_logic ;
  signal N_47201 : std_logic ;
  signal N_47202 : std_logic ;
  signal N_47203 : std_logic ;
  signal N_47204 : std_logic ;
  signal N_47205 : std_logic ;
  signal N_47206 : std_logic ;
  signal N_47207 : std_logic ;
  signal N_47208 : std_logic ;
  signal N_47209 : std_logic ;
  signal N_47210 : std_logic ;
  signal N_47211 : std_logic ;
  signal N_47212 : std_logic ;
  signal N_47213 : std_logic ;
  signal N_47214 : std_logic ;
  signal N_47215 : std_logic ;
  signal N_47216 : std_logic ;
  signal N_47217 : std_logic ;
  signal N_47218 : std_logic ;
  signal N_47219 : std_logic ;
  signal N_47220 : std_logic ;
  signal N_47221 : std_logic ;
  signal N_47222 : std_logic ;
  signal N_47223 : std_logic ;
  signal N_47224 : std_logic ;
  signal N_47225 : std_logic ;
  signal N_47226 : std_logic ;
  signal N_47227 : std_logic ;
  signal N_47228 : std_logic ;
  signal N_47229 : std_logic ;
  signal N_47230 : std_logic ;
  signal N_47231 : std_logic ;
  signal N_47232 : std_logic ;
  signal N_47233 : std_logic ;
  signal N_47234 : std_logic ;
  signal N_47235 : std_logic ;
  signal N_47236 : std_logic ;
  signal N_47237 : std_logic ;
  signal N_47238 : std_logic ;
  signal N_47239 : std_logic ;
  signal N_47240 : std_logic ;
  signal N_47241 : std_logic ;
  signal N_47242 : std_logic ;
  signal N_47243 : std_logic ;
  signal N_47244 : std_logic ;
  signal N_47245 : std_logic ;
  signal N_47246 : std_logic ;
  signal N_47247 : std_logic ;
  signal N_47248 : std_logic ;
  signal N_47249 : std_logic ;
  signal N_47250 : std_logic ;
  signal N_47251 : std_logic ;
  signal N_47252 : std_logic ;
  signal N_47253 : std_logic ;
  signal N_47254 : std_logic ;
  signal N_47255 : std_logic ;
  signal N_47256 : std_logic ;
  signal N_47257 : std_logic ;
  signal N_47258 : std_logic ;
  signal N_47259 : std_logic ;
  signal N_47260 : std_logic ;
  signal N_47261 : std_logic ;
  signal N_47262 : std_logic ;
  signal N_47263 : std_logic ;
  signal N_47264 : std_logic ;
  signal N_47265 : std_logic ;
  signal N_47266 : std_logic ;
  signal N_47267 : std_logic ;
  signal N_47268 : std_logic ;
  signal N_47269 : std_logic ;
  signal N_47270 : std_logic ;
  signal N_47271 : std_logic ;
  signal N_47272 : std_logic ;
  signal N_47273 : std_logic ;
  signal N_47274 : std_logic ;
  signal N_47275 : std_logic ;
  signal N_47276 : std_logic ;
  signal N_47277 : std_logic ;
  signal N_47278 : std_logic ;
  signal N_47279 : std_logic ;
  signal N_47280 : std_logic ;
  signal N_47281 : std_logic ;
  signal N_47282 : std_logic ;
  signal N_47283 : std_logic ;
  signal N_47284 : std_logic ;
  signal N_47285 : std_logic ;
  signal HOLDN_INTERNAL : std_logic ;
  signal \GRFPC0.R.STATE_0_0_1__G0\ : std_logic ;
  signal N_53551 : std_logic ;
  signal N_53552 : std_logic ;
  signal N_53553 : std_logic ;
  signal N_53555 : std_logic ;
  signal N_53556 : std_logic ;
  signal N_53557 : std_logic ;
  signal N_53558 : std_logic ;
  signal N_53559 : std_logic ;
  signal N_53560 : std_logic ;
  signal N_53561 : std_logic ;
  signal N_53562 : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_28__G5\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_27__G5\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_6__G5\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_1__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_194\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VALLOW_3_SQMUXA_5_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VALLOW_5_SQMUXA_7_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_140\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_8__G5\ : std_logic ;
  signal \GRFPC0.N_20155\ : std_logic ;
  signal \GRFPC0.N_21391\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18200\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ALLOW_1_SN_N_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4364_1\ : std_logic ;
  signal N_45853 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18784\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_22__G5\ : std_logic ;
  signal N_32416 : std_logic ;
  signal N_32421 : std_logic ;
  signal \GRFPC0.N_19685\ : std_logic ;
  signal \GRFPC0.N_755\ : std_logic ;
  signal \GRFPC0.N_63\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_11__G5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VFIFO.RD10\ : std_logic ;
  signal \GRFPC0.N_235\ : std_logic ;
  signal \GRFPC0.N_24621\ : std_logic ;
  signal \GRFPC0.N_24622\ : std_logic ;
  signal \GRFPC0.N_223\ : std_logic ;
  signal \GRFPC0.N_24568\ : std_logic ;
  signal \GRFPC0.N_27\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1622_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1637_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_707\ : std_logic ;
  signal \GRFPC0.N_705\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6092_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_703\ : std_logic ;
  signal \GRFPC0.N_24487\ : std_logic ;
  signal \GRFPC0.N_24579\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN369_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.N_263\ : std_logic ;
  signal \GRFPC0.N_24627_1\ : std_logic ;
  signal \GRFPC0.N_24750_1\ : std_logic ;
  signal \GRFPC0.N_24554\ : std_logic ;
  signal \GRFPC0.N_24555\ : std_logic ;
  signal \GRFPC0.N_24581\ : std_logic ;
  signal \GRFPC0.N_25851\ : std_logic ;
  signal \GRFPC0.N_24623\ : std_logic ;
  signal \GRFPC0.N_25204\ : std_logic ;
  signal \GRFPC0.N_256\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.N_24166\ : std_logic ;
  signal \GRFPC0.N_24168\ : std_logic ;
  signal \GRFPC0.N_24167\ : std_logic ;
  signal \GRFPC0.N_25153\ : std_logic ;
  signal \GRFPC0.N_25686_1\ : std_logic ;
  signal \GRFPC0.N_25154_1\ : std_logic ;
  signal \GRFPC0.N_25199\ : std_logic ;
  signal \GRFPC0.N_24307\ : std_logic ;
  signal \GRFPC0.N_25162_1\ : std_logic ;
  signal \GRFPC0.N_25197\ : std_logic ;
  signal \GRFPC0.N_24322\ : std_logic ;
  signal \GRFPC0.N_24580\ : std_logic ;
  signal \GRFPC0.N_24488\ : std_logic ;
  signal \GRFPC0.N_24489\ : std_logic ;
  signal \GRFPC0.N_23941_1\ : std_logic ;
  signal \GRFPC0.N_24271\ : std_logic ;
  signal \GRFPC0.N_25658\ : std_logic ;
  signal \GRFPC0.N_25727_1\ : std_logic ;
  signal \GRFPC0.N_24597\ : std_logic ;
  signal \GRFPC0.N_24611_1\ : std_logic ;
  signal \GRFPC0.N_23994_1\ : std_logic ;
  signal \GRFPC0.N_23994_2\ : std_logic ;
  signal \GRFPC0.N_260_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6767_REGDEPX2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5885_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_177_2\ : std_logic ;
  signal \GRFPC0.N_24500\ : std_logic ;
  signal \GRFPC0.N_24502\ : std_logic ;
  signal \GRFPC0.N_24501\ : std_logic ;
  signal \GRFPC0.N_24642\ : std_logic ;
  signal \GRFPC0.N_24611\ : std_logic ;
  signal \GRFPC0.N_24608\ : std_logic ;
  signal \GRFPC0.N_25169_2\ : std_logic ;
  signal \GRFPC0.N_23994\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5591_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_24137\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN302_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN285_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_24198\ : std_logic ;
  signal \GRFPC0.N_24183\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN740_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_24181\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5165_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1181_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25383\ : std_logic ;
  signal \GRFPC0.N_24193\ : std_logic ;
  signal \GRFPC0.N_24539\ : std_logic ;
  signal \GRFPC0.N_24531\ : std_logic ;
  signal \GRFPC0.N_24180\ : std_logic ;
  signal \GRFPC0.N_25535\ : std_logic ;
  signal \GRFPC0.N_24160_1\ : std_logic ;
  signal \GRFPC0.N_24159\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3842_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25710\ : std_logic ;
  signal \GRFPC0.N_25299\ : std_logic ;
  signal \GRFPC0.N_25301\ : std_logic ;
  signal \GRFPC0.N_25255\ : std_logic ;
  signal \GRFPC0.N_264\ : std_logic ;
  signal \GRFPC0.N_227\ : std_logic ;
  signal \GRFPC0.N_25715\ : std_logic ;
  signal \GRFPC0.N_25687\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN695_REGDEPX2_2\ : std_logic ;
  signal \GRFPC0.N_24327\ : std_logic ;
  signal \GRFPC0.N_25727\ : std_logic ;
  signal \GRFPC0.N_24503\ : std_logic ;
  signal \GRFPC0.N_21346\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.WR2EN2\ : std_logic ;
  signal \GRFPC0.N_25237\ : std_logic ;
  signal \GRFPC0.N_25296\ : std_logic ;
  signal \GRFPC0.N_24118\ : std_logic ;
  signal \GRFPC0.N_24115\ : std_logic ;
  signal \GRFPC0.N_56_I\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN800_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.N_25421_1\ : std_logic ;
  signal \GRFPC0.UN1_WRENX2_2_3_0\ : std_logic ;
  signal \GRFPC0.N_25705\ : std_logic ;
  signal \GRFPC0.N_25704\ : std_logic ;
  signal \GRFPC0.N_25282\ : std_logic ;
  signal \GRFPC0.N_25273\ : std_logic ;
  signal \GRFPC0.N_25228\ : std_logic ;
  signal \GRFPC0.N_25293_1\ : std_logic ;
  signal \GRFPC0.N_25250\ : std_logic ;
  signal \GRFPC0.N_24173\ : std_logic ;
  signal \GRFPC0.N_24174\ : std_logic ;
  signal \GRFPC0.N_24177\ : std_logic ;
  signal \GRFPC0.N_24175\ : std_logic ;
  signal \GRFPC0.N_25608_2\ : std_logic ;
  signal \GRFPC0.N_25295\ : std_logic ;
  signal \GRFPC0.N_25753\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_19__G3\ : std_logic ;
  signal \GRFPC0.N_25362\ : std_logic ;
  signal \GRFPC0.N_24359\ : std_logic ;
  signal \GRFPC0.N_24145\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2976_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_706\ : std_logic ;
  signal \GRFPC0.N_25190\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2004_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN253_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.N_25760_2\ : std_logic ;
  signal \GRFPC0.N_23714\ : std_logic ;
  signal \GRFPC0.N_313\ : std_logic ;
  signal \GRFPC0.N_220\ : std_logic ;
  signal \GRFPC0.N_9203\ : std_logic ;
  signal \GRFPC0.N_22615\ : std_logic ;
  signal \GRFPC0.N_9475_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.ST_1_1\ : std_logic ;
  signal \GRFPC0.N_193\ : std_logic ;
  signal \GRFPC0.N_196\ : std_logic ;
  signal \GRFPC0.N_200\ : std_logic ;
  signal \GRFPC0.N_23590\ : std_logic ;
  signal \GRFPC0.N_206\ : std_logic ;
  signal \GRFPC0.N_17502\ : std_logic ;
  signal \GRFPC0.N_17516\ : std_logic ;
  signal \GRFPC0.N_17510\ : std_logic ;
  signal \GRFPC0.N_17496\ : std_logic ;
  signal \GRFPC0.N_161\ : std_logic ;
  signal \GRFPC0.N_23575\ : std_logic ;
  signal \GRFPC0.N_164\ : std_logic ;
  signal \GRFPC0.N_23577\ : std_logic ;
  signal \GRFPC0.N_23579\ : std_logic ;
  signal \GRFPC0.N_23580\ : std_logic ;
  signal \GRFPC0.N_171\ : std_logic ;
  signal \GRFPC0.N_172\ : std_logic ;
  signal \GRFPC0.N_23584\ : std_logic ;
  signal \GRFPC0.N_23585\ : std_logic ;
  signal \GRFPC0.N_23586\ : std_logic ;
  signal \GRFPC0.N_23587\ : std_logic ;
  signal \GRFPC0.N_183\ : std_logic ;
  signal \GRFPC0.N_184\ : std_logic ;
  signal \GRFPC0.N_186\ : std_logic ;
  signal \GRFPC0.N_187\ : std_logic ;
  signal N_45055_1 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.RDD_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN205_HOLDN\ : std_logic ;
  signal \GRFPC0.N_9482\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_0_7__G2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_CPI\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.ORV.TMP_1\ : std_logic ;
  signal \GRFPC0.N_21108\ : std_logic ;
  signal \GRFPC0.N_22358\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN26_OP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN24_OP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN77_PENDEXC\ : std_logic ;
  signal \GRFPC0.N_21934\ : std_logic ;
  signal \GRFPC0.N_21965\ : std_logic ;
  signal N_45011 : std_logic ;
  signal \GRFPC0.N_23695\ : std_logic ;
  signal N_45055 : std_logic ;
  signal N_45102_11 : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_24__G5\ : std_logic ;
  signal \GRFPC0.N_20278\ : std_logic ;
  signal \GRFPC0.N_20015\ : std_logic ;
  signal \GRFPC0.N_19949\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_5__G5\ : std_logic ;
  signal \GRFPC0.N_20259\ : std_logic ;
  signal \GRFPC0.N_19996\ : std_logic ;
  signal \GRFPC0.N_19930\ : std_logic ;
  signal \GRFPC0.N_100\ : std_logic ;
  signal \GRFPC0.N_20000\ : std_logic ;
  signal \GRFPC0.N_19934\ : std_logic ;
  signal \GRFPC0.N_20263\ : std_logic ;
  signal \GRFPC0.N_19999\ : std_logic ;
  signal \GRFPC0.N_19933\ : std_logic ;
  signal \GRFPC0.N_20262\ : std_logic ;
  signal \GRFPC0.N_20265\ : std_logic ;
  signal \GRFPC0.N_20002\ : std_logic ;
  signal \GRFPC0.N_19936\ : std_logic ;
  signal \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_4__G5\ : std_logic ;
  signal \GRFPC0.N_22910\ : std_logic ;
  signal \GRFPC0.N_9474\ : std_logic ;
  signal \GRFPC0.N_24875\ : std_logic ;
  signal \GRFPC0.N_21205\ : std_logic ;
  signal \GRFPC0.N_21208\ : std_logic ;
  signal \GRFPC0.N_21203\ : std_logic ;
  signal \GRFPC0.N_22231\ : std_logic ;
  signal \GRFPC0.N_594\ : std_logic ;
  signal \GRFPC0.N_60\ : std_logic ;
  signal \GRFPC0.N_21227_2\ : std_logic ;
  signal \GRFPC0.N_120\ : std_logic ;
  signal \GRFPC0.N_9480\ : std_logic ;
  signal \GRFPC0.N_22725\ : std_logic ;
  signal \GRFPC0.N_22878\ : std_logic ;
  signal \GRFPC0.N_26\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL0\ : std_logic ;
  signal \GRFPC0.N_22157\ : std_logic ;
  signal \GRFPC0.N_22836\ : std_logic ;
  signal \GRFPC0.N_22820\ : std_logic ;
  signal \GRFPC0.N_22819\ : std_logic ;
  signal \GRFPC0.N_23512\ : std_logic ;
  signal \GRFPC0.N_569\ : std_logic ;
  signal \GRFPC0.N_557\ : std_logic ;
  signal \GRFPC0.N_730\ : std_logic ;
  signal \GRFPC0.N_751\ : std_logic ;
  signal \GRFPC0.N_762\ : std_logic ;
  signal \GRFPC0.N_9467\ : std_logic ;
  signal \GRFPC0.N_9468\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_128_I_1\ : std_logic ;
  signal \GRFPC0.N_9465\ : std_logic ;
  signal \GRFPC0.N_856\ : std_logic ;
  signal \GRFPC0.N_23184_2\ : std_logic ;
  signal \GRFPC0.N_21639_2\ : std_logic ;
  signal \GRFPC0.N_9476\ : std_logic ;
  signal \GRFPC0.N_22960\ : std_logic ;
  signal \GRFPC0.N_9453\ : std_logic ;
  signal \GRFPC0.N_21916\ : std_logic ;
  signal \GRFPC0.N_28\ : std_logic ;
  signal \GRFPC0.N_102\ : std_logic ;
  signal \GRFPC0.N_22468_1\ : std_logic ;
  signal \GRFPC0.N_23136\ : std_logic ;
  signal \GRFPC0.N_18394_1\ : std_logic ;
  signal \GRFPC0.N_23330\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_174\ : std_logic ;
  signal \GRFPC0.UN1_STDDEP_0_SQMUXA_108\ : std_logic ;
  signal \GRFPC0.N_74\ : std_logic ;
  signal \GRFPC0.N_22406_I\ : std_logic ;
  signal \GRFPC0.N_22063\ : std_logic ;
  signal \GRFPC0.N_9479\ : std_logic ;
  signal \GRFPC0.STDEP_0_SQMUXA_81_2_I\ : std_logic ;
  signal \GRFPC0.N_22080\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_118\ : std_logic ;
  signal \GRFPC0.N_23088\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.STDDEP_1_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV10_I_M_10_7\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_10\ : std_logic ;
  signal N_47188_2 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2370_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1058_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_2\ : std_logic ;
  signal \GRFPC0.N_21285\ : std_logic ;
  signal \GRFPC0.N_461\ : std_logic ;
  signal \GRFPC0.N_664\ : std_logic ;
  signal \GRFPC0.N_22564\ : std_logic ;
  signal \GRFPC0.N_23261\ : std_logic ;
  signal \GRFPC0.N_23234\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_25_I_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_13_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.STDEP_496_SEL0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.STDEP_488_SEL0_1\ : std_logic ;
  signal \GRFPC0.N_482\ : std_logic ;
  signal \GRFPC0.N_580\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_24_I_1\ : std_logic ;
  signal \GRFPC0.N_22546\ : std_logic ;
  signal \GRFPC0.N_22606\ : std_logic ;
  signal \GRFPC0.N_21672\ : std_logic ;
  signal \GRFPC0.N_21701\ : std_logic ;
  signal \GRFPC0.N_21690\ : std_logic ;
  signal \GRFPC0.N_21676\ : std_logic ;
  signal \GRFPC0.N_21612\ : std_logic ;
  signal \GRFPC0.N_860\ : std_logic ;
  signal \GRFPC0.N_21678\ : std_logic ;
  signal \GRFPC0.N_841\ : std_logic ;
  signal \GRFPC0.N_484\ : std_logic ;
  signal \GRFPC0.N_449\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3026_DEP_2\ : std_logic ;
  signal \GRFPC0.N_119\ : std_logic ;
  signal \GRFPC0.N_615\ : std_logic ;
  signal \GRFPC0.N_21269\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_26\ : std_logic ;
  signal \GRFPC0.N_21899\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN919_DEP_2\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_10\ : std_logic ;
  signal \GRFPC0.N_23478\ : std_logic ;
  signal \GRFPC0.N_173\ : std_logic ;
  signal \GRFPC0.N_842\ : std_logic ;
  signal \GRFPC0.N_742_1\ : std_logic ;
  signal \GRFPC0.N_500\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_14_I_1\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_131_I_1\ : std_logic ;
  signal \GRFPC0.N_22689\ : std_logic ;
  signal \GRFPC0.N_22639\ : std_logic ;
  signal N_40688 : std_logic ;
  signal \GRFPC0.N_23122\ : std_logic ;
  signal \GRFPC0.N_22633\ : std_logic ;
  signal \GRFPC0.N_76\ : std_logic ;
  signal \GRFPC0.N_16_I\ : std_logic ;
  signal \GRFPC0.N_805\ : std_logic ;
  signal \GRFPC0.N_525\ : std_logic ;
  signal \GRFPC0.N_21878_1\ : std_logic ;
  signal \GRFPC0.N_362\ : std_logic ;
  signal \GRFPC0.STDEP_2_SQMUXA_133\ : std_logic ;
  signal \GRFPC0.N_21954\ : std_logic ;
  signal \GRFPC0.N_670\ : std_logic ;
  signal \GRFPC0.N_21947\ : std_logic ;
  signal \GRFPC0.N_21951\ : std_logic ;
  signal \GRFPC0.N_21951_1\ : std_logic ;
  signal \GRFPC0.N_18814\ : std_logic ;
  signal \GRFPC0.N_22325\ : std_logic ;
  signal \GRFPC0.N_22718\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4940_DEP\ : std_logic ;
  signal \GRFPC0.STDEP_2_SQMUXA_129\ : std_logic ;
  signal \GRFPC0.N_502\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.STDEP682\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3956_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.STDEP_332_SEL0_1\ : std_logic ;
  signal \GRFPC0.N_123\ : std_logic ;
  signal \GRFPC0.N_55\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4583_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1775_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN839_REGDEPX_2\ : std_logic ;
  signal \GRFPC0.N_24911\ : std_logic ;
  signal \GRFPC0.N_25085\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2176_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_23529\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3439_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_24849_1\ : std_logic ;
  signal \GRFPC0.N_23348_1\ : std_logic ;
  signal \GRFPC0.N_23530_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3424_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_25795_1\ : std_logic ;
  signal \GRFPC0.N_277\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN839_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2087_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4271_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_24039\ : std_logic ;
  signal \GRFPC0.N_22253\ : std_logic ;
  signal \GRFPC0.N_22250\ : std_logic ;
  signal \GRFPC0.N_22259\ : std_logic ;
  signal \GRFPC0.N_22244\ : std_logic ;
  signal \GRFPC0.N_23808\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2644_DEP\ : std_logic ;
  signal \GRFPC0.N_22777\ : std_logic ;
  signal \GRFPC0.N_24821\ : std_logic ;
  signal \GRFPC0.N_22282\ : std_logic ;
  signal \GRFPC0.N_21192\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2711_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_22126\ : std_logic ;
  signal \GRFPC0.N_465\ : std_logic ;
  signal \GRFPC0.N_453\ : std_logic ;
  signal \GRFPC0.N_469\ : std_logic ;
  signal \GRFPC0.N_21725\ : std_logic ;
  signal \GRFPC0.N_21241\ : std_logic ;
  signal \GRFPC0.N_561\ : std_logic ;
  signal \GRFPC0.N_18739\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2024_DEP\ : std_logic ;
  signal \GRFPC0.N_21616\ : std_logic ;
  signal \GRFPC0.N_22000\ : std_logic ;
  signal \GRFPC0.N_474\ : std_logic ;
  signal \GRFPC0.UN1_STDEP2530\ : std_logic ;
  signal \GRFPC0.N_25889\ : std_logic ;
  signal \GRFPC0.N_21820\ : std_logic ;
  signal \GRFPC0.N_21818\ : std_logic ;
  signal \GRFPC0.N_663\ : std_logic ;
  signal \GRFPC0.N_655\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1300_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_24880\ : std_logic ;
  signal \GRFPC0.N_24819\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1286_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1257_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1271_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_22447\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.UN735_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.UN735_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN97_REGDEPX_2\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_87_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.0.CHECK_DEP.UN1983_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_25011\ : std_logic ;
  signal \GRFPC0.N_25356_1\ : std_logic ;
  signal \GRFPC0.N_22444_1\ : std_logic ;
  signal \GRFPC0.N_22773\ : std_logic ;
  signal \GRFPC0.N_24926\ : std_logic ;
  signal \GRFPC0.N_22426\ : std_logic ;
  signal \GRFPC0.N_22446\ : std_logic ;
  signal \GRFPC0.N_25336\ : std_logic ;
  signal \GRFPC0.N_25340\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN824_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_25355_2\ : std_logic ;
  signal \GRFPC0.N_22742_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN943_REGDEPX_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.UN720_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_22445_1\ : std_logic ;
  signal \GRFPC0.N_22035\ : std_logic ;
  signal \GRFPC0.N_22593_1\ : std_logic ;
  signal \GRFPC0.N_22427\ : std_logic ;
  signal \GRFPC0.N_24924\ : std_logic ;
  signal \GRFPC0.N_23522_I_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN928_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.N_25357_1\ : std_logic ;
  signal \GRFPC0.N_23976\ : std_logic ;
  signal \GRFPC0.N_22740_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1015_REGDEPX_I_1\ : std_logic ;
  signal \GRFPC0.N_13\ : std_logic ;
  signal \GRFPC0.N_15\ : std_logic ;
  signal \GRFPC0.N_149\ : std_logic ;
  signal \GRFPC0.N_65\ : std_logic ;
  signal \GRFPC0.N_74_I_I\ : std_logic ;
  signal \GRFPC0.N_548\ : std_logic ;
  signal \GRFPC0.N_21212\ : std_logic ;
  signal \GRFPC0.N_23810\ : std_logic ;
  signal \GRFPC0.N_21225\ : std_logic ;
  signal \GRFPC0.N_24959\ : std_logic ;
  signal \GRFPC0.N_23887\ : std_logic ;
  signal \GRFPC0.N_22429\ : std_logic ;
  signal \GRFPC0.N_25004\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.UN3008_REGDEPX_2\ : std_logic ;
  signal \GRFPC0.N_24957\ : std_logic ;
  signal \GRFPC0.N_23963\ : std_logic ;
  signal \GRFPC0.N_24921\ : std_logic ;
  signal \GRFPC0.N_23923\ : std_logic ;
  signal \GRFPC0.N_22273_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN78_PENDEXC\ : std_logic ;
  signal \GRFPC0.UN1_VFIFO.VCNT_1_1_SQMUXA\ : std_logic ;
  signal \GRFPC0.UN1_VFIFO.VCNT_0_1_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN87_PENDEXC\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2\ : std_logic ;
  signal N_47071 : std_logic ;
  signal N_47098 : std_logic ;
  signal N_47093 : std_logic ;
  signal N_47125 : std_logic ;
  signal N_47153 : std_logic ;
  signal N_47101 : std_logic ;
  signal N_47157_2 : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_3_SQMUXA\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_3_SQMUXA_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FPRDY_1_1\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_2_SQMUXA\ : std_logic ;
  signal \GRFPC0.V.FSR.AEXC_1_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_FIFO.VCNT_1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FIFOV2\ : std_logic ;
  signal N_47178_2 : std_logic ;
  signal \GRFPC0.N_24034\ : std_logic ;
  signal \GRFPC0.DIVI_0_SQMUXA_8\ : std_logic ;
  signal N_44738_1 : std_logic ;
  signal \GRFPC0.N_24035\ : std_logic ;
  signal \GRFPC0.N_23625\ : std_logic ;
  signal \GRFPC0.N_24061\ : std_logic ;
  signal \GRFPC0.N_222\ : std_logic ;
  signal \GRFPC0.N_236\ : std_logic ;
  signal \GRFPC0.N_23982\ : std_logic ;
  signal \GRFPC0.N_23629\ : std_logic ;
  signal \GRFPC0.N_72_I\ : std_logic ;
  signal \GRFPC0.N_93\ : std_logic ;
  signal \GRFPC0.N_23795\ : std_logic ;
  signal \GRFPC0.N_19620\ : std_logic ;
  signal \GRFPC0.N_19751\ : std_logic ;
  signal \GRFPC0.N_20052\ : std_logic ;
  signal \GRFPC0.N_19986\ : std_logic ;
  signal \GRFPC0.N_23696\ : std_logic ;
  signal \GRFPC0.N_23687\ : std_logic ;
  signal \GRFPC0.N_23712\ : std_logic ;
  signal \GRFPC0.VDIV.EXEC_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.N_23746\ : std_logic ;
  signal \GRFPC0.DIV.PEND_0_0_G5\ : std_logic ;
  signal \GRFPC0.DIV.PEND_0_0_N_5\ : std_logic ;
  signal N_45196_1 : std_logic ;
  signal \FPI.START_3\ : std_logic ;
  signal \GRFPC0.N_10575_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F1_A0_C\ : std_logic ;
  signal N_46992 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FLUSH_1_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN6_FIFOV\ : std_logic ;
  signal \FPI.START_1\ : std_logic ;
  signal \GRFPC0.N_21133\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDWR_0_0_G2\ : std_logic ;
  signal \GRFPC0.N_9163\ : std_logic ;
  signal \FPI.START_2\ : std_logic ;
  signal N_45188 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\ : std_logic ;
  signal \GRFPC0.N_9159\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN11_SHARE\ : std_logic ;
  signal \GRFPC0.N_250\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VFIFO.FULL_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.ORV.TMP\ : std_logic ;
  signal \GRFPC0.N_20235\ : std_logic ;
  signal \GRFPC0.N_20104\ : std_logic ;
  signal \GRFPC0.N_20169\ : std_logic ;
  signal \GRFPC0.V.FSR.FTT_2_SQMUXA\ : std_logic ;
  signal \GRFPC0.V.FSR.FTT_1_SQMUXA_2\ : std_logic ;
  signal \GRFPC0.V.FSR.FTT_1_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.N_23699\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.PEND_0_0_N_5\ : std_logic ;
  signal \GRFPC0.N_20102\ : std_logic ;
  signal \GRFPC0.N_20233\ : std_logic ;
  signal \GRFPC0.N_20167\ : std_logic ;
  signal \GRFPC0.N_23697\ : std_logic ;
  signal \GRFPC0.N_20267\ : std_logic ;
  signal \GRFPC0.N_20004\ : std_logic ;
  signal \GRFPC0.N_19938\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_13__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18833\ : std_logic ;
  signal \GRFPC0.N_19947\ : std_logic ;
  signal \GRFPC0.N_20013\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18751_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18754\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_0_7__N_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18768\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18831\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18805\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18871\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18772\ : std_logic ;
  signal N_32589 : std_logic ;
  signal \GRFPC0.N_19753\ : std_logic ;
  signal \GRFPC0.N_19622\ : std_logic ;
  signal \GRFPC0.N_19687\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18781\ : std_logic ;
  signal \GRFPC0.WREN_1_SQMUXA_4\ : std_logic ;
  signal \GRFPC0.WREN_0_SQMUXA_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_CPI_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_PENDEXC_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN25_HOLDN\ : std_logic ;
  signal \GRFPC0.N_10567_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN29_WREN_1\ : std_logic ;
  signal \GRFPC0.N_9172\ : std_logic ;
  signal \GRFPC0.N_20255\ : std_logic ;
  signal \GRFPC0.N_19992\ : std_logic ;
  signal \GRFPC0.N_19926\ : std_logic ;
  signal \GRFPC0.N_6\ : std_logic ;
  signal \GRFPC0.CCWR_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN25_HOLDN_1\ : std_logic ;
  signal \GRFPC0.WREN_2_SQMUXA\ : std_logic ;
  signal \GRFPC0.N_20021\ : std_logic ;
  signal \GRFPC0.N_19955\ : std_logic ;
  signal \GRFPC0.N_20284\ : std_logic ;
  signal \GRFPC0.N_19946\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20301\ : std_logic ;
  signal \GRFPC0.N_20012\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4785_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4814_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_24677\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4769_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_702\ : std_logic ;
  signal \GRFPC0.N_24784\ : std_logic ;
  signal \GRFPC0.N_24785\ : std_logic ;
  signal \GRFPC0.N_24782\ : std_logic ;
  signal \GRFPC0.N_24772\ : std_logic ;
  signal \GRFPC0.N_25560_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3872_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3887_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_24937\ : std_logic ;
  signal \GRFPC0.N_25550\ : std_logic ;
  signal \GRFPC0.N_25545\ : std_logic ;
  signal \GRFPC0.N_275\ : std_logic ;
  signal \GRFPC0.N_25244_1\ : std_logic ;
  signal \GRFPC0.N_25592_1\ : std_logic ;
  signal \GRFPC0.N_24976\ : std_logic ;
  signal \GRFPC0.N_24976_2\ : std_logic ;
  signal \GRFPC0.N_24087_1\ : std_logic ;
  signal \GRFPC0.N_24770\ : std_logic ;
  signal \GRFPC0.N_25842\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4664_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_24765_1\ : std_logic ;
  signal \GRFPC0.N_24671\ : std_logic ;
  signal \GRFPC0.N_24974\ : std_logic ;
  signal \GRFPC0.N_24975\ : std_logic ;
  signal \GRFPC0.N_25620\ : std_logic ;
  signal \GRFPC0.N_25621\ : std_logic ;
  signal \GRFPC0.N_24761_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3917_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3975_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_24221\ : std_logic ;
  signal \GRFPC0.N_704\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_22__G3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_18__G3\ : std_logic ;
  signal \GRFPC0.N_24733\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1233_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1233_DEP_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN5169_DEP_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN243_DEP_1\ : std_logic ;
  signal \GRFPC0.N_801\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1889_DEP\ : std_logic ;
  signal \GRFPC0.N_661_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4513_DEP\ : std_logic ;
  signal \GRFPC0.N_21737\ : std_logic ;
  signal \GRFPC0.N_661\ : std_logic ;
  signal \GRFPC0.N_21515\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV14_I_M_13\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV10_I_M_13_4\ : std_logic ;
  signal \GRFPC0.UN1_STDDEP_0_SQMUXA_101\ : std_logic ;
  signal \GRFPC0.N_21557\ : std_logic ;
  signal \GRFPC0.N_21902\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_2_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP34\ : std_logic ;
  signal \GRFPC0.N_23390\ : std_logic ;
  signal \GRFPC0.N_21729\ : std_logic ;
  signal \GRFPC0.N_25899\ : std_logic ;
  signal \GRFPC0.N_666\ : std_logic ;
  signal \GRFPC0.N_21253\ : std_logic ;
  signal \GRFPC0.N_21327\ : std_logic ;
  signal \GRFPC0.N_315\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3628_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3534_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3505_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1047_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_22892_1\ : std_logic ;
  signal \GRFPC0.N_24818\ : std_logic ;
  signal \GRFPC0.N_23349_1\ : std_logic ;
  signal \GRFPC0.STDEP_0_SQMUXA_80_2\ : std_logic ;
  signal \GRFPC0.N_21186_1\ : std_logic ;
  signal \GRFPC0.N_24385\ : std_logic ;
  signal \GRFPC0.N_24383\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4984_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_23988_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2815_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1032_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_18500\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.STDEP_136_SEL0\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_114\ : std_logic ;
  signal \GRFPC0.N_21933\ : std_logic ;
  signal \GRFPC0.N_21983\ : std_logic ;
  signal \GRFPC0.N_21984\ : std_logic ;
  signal \GRFPC0.N_24846\ : std_logic ;
  signal \GRFPC0.N_21641\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1864_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1760_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_22535\ : std_logic ;
  signal \GRFPC0.N_21639\ : std_logic ;
  signal \GRFPC0.N_9478\ : std_logic ;
  signal \GRFPC0.N_24845\ : std_logic ;
  signal \GRFPC0.LDLOCK_1\ : std_logic ;
  signal \GRFPC0.N_23591\ : std_logic ;
  signal \GRFPC0.N_167\ : std_logic ;
  signal \GRFPC0.N_23582\ : std_logic ;
  signal \GRFPC0.N_23589\ : std_logic ;
  signal \GRFPC0.N_189\ : std_logic ;
  signal \GRFPC0.N_21246\ : std_logic ;
  signal \GRFPC0.N_21331\ : std_logic ;
  signal \GRFPC0.N_169\ : std_logic ;
  signal \GRFPC0.N_21257\ : std_logic ;
  signal \GRFPC0.N_22579\ : std_logic ;
  signal \GRFPC0.N_23560\ : std_logic ;
  signal \GRFPC0.N_24936\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_440\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4552_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2056_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_546\ : std_logic ;
  signal \GRFPC0.N_492\ : std_logic ;
  signal \GRFPC0.N_23403\ : std_logic ;
  signal \GRFPC0.N_23396\ : std_logic ;
  signal \GRFPC0.N_749\ : std_logic ;
  signal \GRFPC0.N_23270\ : std_logic ;
  signal \GRFPC0.N_23266\ : std_logic ;
  signal \GRFPC0.N_23265\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4360_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4375_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_22837\ : std_logic ;
  signal \GRFPC0.N_854\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_19__G3\ : std_logic ;
  signal \GRFPC0.N_23324\ : std_logic ;
  signal \GRFPC0.N_21866\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1448_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_25083\ : std_logic ;
  signal \GRFPC0.N_24910\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2072_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_96_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_9__G3\ : std_logic ;
  signal \GRFPC0.N_23542\ : std_logic ;
  signal \GRFPC0.N_23511\ : std_logic ;
  signal \GRFPC0.N_23551\ : std_logic ;
  signal \GRFPC0.N_23550\ : std_logic ;
  signal \GRFPC0.N_23543\ : std_logic ;
  signal \GRFPC0.N_9477\ : std_logic ;
  signal \GRFPC0.N_17399\ : std_logic ;
  signal \GRFPC0.N_22657\ : std_logic ;
  signal \GRFPC0.N_22656\ : std_logic ;
  signal \GRFPC0.N_258\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.N_25120\ : std_logic ;
  signal \GRFPC0.N_25403\ : std_logic ;
  signal \GRFPC0.N_25500\ : std_logic ;
  signal \GRFPC0.N_25407\ : std_logic ;
  signal \GRFPC0.N_25409\ : std_logic ;
  signal \GRFPC0.N_225\ : std_logic ;
  signal \GRFPC0.N_25662_2\ : std_logic ;
  signal \GRFPC0.N_226\ : std_logic ;
  signal \GRFPC0.N_25450_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4193_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN665_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.N_24624\ : std_logic ;
  signal \GRFPC0.N_25406\ : std_logic ;
  signal \GRFPC0.N_25406_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5724_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_24215_1\ : std_logic ;
  signal \GRFPC0.N_261_1\ : std_logic ;
  signal \GRFPC0.N_25783\ : std_logic ;
  signal \GRFPC0.N_25784\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN383_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.N_25501\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN351_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.N_25503\ : std_logic ;
  signal \GRFPC0.N_25370\ : std_logic ;
  signal \GRFPC0.N_25405\ : std_logic ;
  signal \GRFPC0.N_25410\ : std_logic ;
  signal \GRFPC0.N_24213_2\ : std_logic ;
  signal \GRFPC0.N_25274\ : std_logic ;
  signal \GRFPC0.N_25421\ : std_logic ;
  signal \GRFPC0.N_25441\ : std_logic ;
  signal \GRFPC0.N_25460\ : std_logic ;
  signal \GRFPC0.N_25420\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5739_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3797_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25496\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.N_25507\ : std_logic ;
  signal \GRFPC0.N_24760\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3327_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6945_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1653_REGDEPX2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN771_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3356_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25509\ : std_logic ;
  signal \GRFPC0.N_25294_1\ : std_logic ;
  signal \GRFPC0.N_25859\ : std_logic ;
  signal \GRFPC0.N_25557\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5181_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2535_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_24709\ : std_logic ;
  signal \GRFPC0.N_25497\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2004_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2033_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_24736\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4344_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25250_3\ : std_logic ;
  signal \GRFPC0.N_25423\ : std_logic ;
  signal \GRFPC0.N_25426\ : std_logic ;
  signal \GRFPC0.N_25319\ : std_logic ;
  signal \GRFPC0.N_25388\ : std_logic ;
  signal \GRFPC0.N_23995\ : std_logic ;
  signal \GRFPC0.N_24750\ : std_logic ;
  signal \GRFPC0.N_25598\ : std_logic ;
  signal \GRFPC0.N_24749\ : std_logic ;
  signal \GRFPC0.N_24735\ : std_logic ;
  signal \GRFPC0.N_280\ : std_logic ;
  signal \GRFPC0.N_9484\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4240_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_21721\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN80_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_25062\ : std_logic ;
  signal \GRFPC0.N_165\ : std_logic ;
  signal \GRFPC0.N_21636\ : std_logic ;
  signal \GRFPC0.N_21817\ : std_logic ;
  signal \GRFPC0.N_22366\ : std_logic ;
  signal \GRFPC0.N_25063\ : std_logic ;
  signal \GRFPC0.N_25067\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN207_REGDEPX\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_0__G3\ : std_logic ;
  signal \GRFPC0.N_25042\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN300_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_24551\ : std_logic ;
  signal \GRFPC0.N_24550\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.UN408_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.N_22706\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4568_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_24986\ : std_logic ;
  signal \GRFPC0.N_121\ : std_logic ;
  signal \GRFPC0.N_122\ : std_logic ;
  signal \GRFPC0.N_21307\ : std_logic ;
  signal \GRFPC0.N_22631\ : std_logic ;
  signal \GRFPC0.N_21322\ : std_logic ;
  signal \GRFPC0.N_21262\ : std_logic ;
  signal \GRFPC0.N_21281\ : std_logic ;
  signal \GRFPC0.N_21329\ : std_logic ;
  signal \GRFPC0.N_22273_1\ : std_logic ;
  signal \GRFPC0.N_18769\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL0_1\ : std_logic ;
  signal \GRFPC0.N_22118\ : std_logic ;
  signal \GRFPC0.N_23807\ : std_logic ;
  signal \GRFPC0.N_23806\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_WR.CTRL.RD_2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV6_I_M_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV14_I_M_5\ : std_logic ;
  signal \GRFPC0.N_22644\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_145\ : std_logic ;
  signal \GRFPC0.N_22636\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_182\ : std_logic ;
  signal \GRFPC0.N_22621\ : std_logic ;
  signal \GRFPC0.N_21943\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN2972_DEP\ : std_logic ;
  signal N_40689 : std_logic ;
  signal \GRFPC0.N_735\ : std_logic ;
  signal \GRFPC0.N_21290\ : std_logic ;
  signal \GRFPC0.N_675\ : std_logic ;
  signal \GRFPC0.N_25341_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.RDWR_1\ : std_logic ;
  signal \GRFPC0.N_22758\ : std_logic ;
  signal \GRFPC0.N_22779\ : std_logic ;
  signal \GRFPC0.N_757\ : std_logic ;
  signal \GRFPC0.N_810\ : std_logic ;
  signal \GRFPC0.N_528\ : std_logic ;
  signal \GRFPC0.N_23380\ : std_logic ;
  signal \GRFPC0.N_23383\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2607_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_24902\ : std_logic ;
  signal \GRFPC0.N_23915\ : std_logic ;
  signal \GRFPC0.N_23178_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2887_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_23460\ : std_logic ;
  signal \GRFPC0.N_23950\ : std_logic ;
  signal \GRFPC0.N_23916\ : std_logic ;
  signal \GRFPC0.N_22313\ : std_logic ;
  signal \GRFPC0.N_36\ : std_logic ;
  signal \GRFPC0.N_24892\ : std_logic ;
  signal \GRFPC0.N_21184\ : std_logic ;
  signal \GRFPC0.N_22274\ : std_logic ;
  signal \GRFPC0.N_23953\ : std_logic ;
  signal \GRFPC0.N_23178\ : std_logic ;
  signal \GRFPC0.N_23180\ : std_logic ;
  signal \GRFPC0.N_23854_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15366\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15365\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13485\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP18\ : std_logic ;
  signal \GRFPC0.N_20241\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_WR2.CTRL.RD\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP118\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN785_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN800_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25415\ : std_logic ;
  signal \GRFPC0.N_25416\ : std_logic ;
  signal \GRFPC0.N_25419\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3386_REGDEPX2_2\ : std_logic ;
  signal \GRFPC0.N_25417\ : std_logic ;
  signal \GRFPC0.N_24403_1\ : std_logic ;
  signal \GRFPC0.N_25566\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP30\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_1\ : std_logic ;
  signal \GRFPC0.N_24585\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.STDEP_132_SEL0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1040_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP\ : std_logic ;
  signal \GRFPC0.UN1_STDEP514\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.STDEP_136_SEL0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV14_I_M_6\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_179\ : std_logic ;
  signal \GRFPC0.UN1_STDDEP_0_SQMUXA_102\ : std_logic ;
  signal \GRFPC0.N_737_2\ : std_logic ;
  signal \GRFPC0.N_22331\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_1\ : std_logic ;
  signal \GRFPC0.N_23059\ : std_logic ;
  signal \GRFPC0.N_23091\ : std_logic ;
  signal \GRFPC0.N_23089\ : std_logic ;
  signal \GRFPC0.N_23127\ : std_logic ;
  signal \GRFPC0.N_23371\ : std_logic ;
  signal \GRFPC0.N_128\ : std_logic ;
  signal \GRFPC0.N_690\ : std_logic ;
  signal \GRFPC0.N_23897\ : std_logic ;
  signal \GRFPC0.N_22120\ : std_logic ;
  signal \GRFPC0.N_22855\ : std_logic ;
  signal \GRFPC0.N_22854\ : std_logic ;
  signal \GRFPC0.N_22875\ : std_logic ;
  signal \GRFPC0.N_23201_2\ : std_logic ;
  signal \GRFPC0.N_21884\ : std_logic ;
  signal \GRFPC0.N_18122\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4976_DEP\ : std_logic ;
  signal \GRFPC0.N_24813\ : std_logic ;
  signal \GRFPC0.N_24900\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4999_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_24854\ : std_logic ;
  signal \GRFPC0.N_24855\ : std_logic ;
  signal \GRFPC0.N_24857\ : std_logic ;
  signal \GRFPC0.N_18829\ : std_logic ;
  signal \GRFPC0.N_18634\ : std_logic ;
  signal \GRFPC0.N_22983\ : std_logic ;
  signal \GRFPC0.N_22982\ : std_logic ;
  signal \GRFPC0.N_23102\ : std_logic ;
  signal \GRFPC0.N_23119\ : std_logic ;
  signal \GRFPC0.N_23108\ : std_logic ;
  signal \GRFPC0.N_23028\ : std_logic ;
  signal \GRFPC0.N_367\ : std_logic ;
  signal \GRFPC0.N_21521\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4855_DEP\ : std_logic ;
  signal \GRFPC0.N_23010\ : std_logic ;
  signal \GRFPC0.N_23012\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_22959\ : std_logic ;
  signal \GRFPC0.N_694\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\ : std_logic ;
  signal \GRFPC0.V.FSR.AEXC_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_0_SQMUXA_2\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_1_SQMUXA\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN11_FPEXC\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1660_DEP_2\ : std_logic ;
  signal \GRFPC0.N_18198\ : std_logic ;
  signal \GRFPC0.N_25432\ : std_logic ;
  signal \GRFPC0.N_25637_1\ : std_logic ;
  signal \GRFPC0.N_24777_1_0\ : std_logic ;
  signal \GRFPC0.N_25610\ : std_logic ;
  signal \GRFPC0.N_25613\ : std_logic ;
  signal \GRFPC0.N_25543\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP160\ : std_logic ;
  signal \GRFPC0.UN1_REGDEP173\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2698_DEP_1\ : std_logic ;
  signal \GRFPC0.N_473_1\ : std_logic ;
  signal \GRFPC0.N_428\ : std_logic ;
  signal \GRFPC0.N_20110\ : std_logic ;
  signal \GRFPC0.N_20175\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP26\ : std_logic ;
  signal \GRFPC0.N_22829\ : std_logic ;
  signal \GRFPC0.WREN_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.N_24233\ : std_logic ;
  signal \GRFPC0.N_24703_I\ : std_logic ;
  signal \GRFPC0.N_25098\ : std_logic ;
  signal \GRFPC0.N_25099\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_VRFA.ST\ : std_logic ;
  signal \GRFPC0.N_22480_2\ : std_logic ;
  signal \GRFPC0.N_22899_1\ : std_logic ;
  signal \GRFPC0.N_22957\ : std_logic ;
  signal \GRFPC0.N_23985\ : std_logic ;
  signal \GRFPC0.N_23480\ : std_logic ;
  signal \GRFPC0.N_23479\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3647_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1386_DEP\ : std_logic ;
  signal \GRFPC0.N_765\ : std_logic ;
  signal \GRFPC0.N_861\ : std_logic ;
  signal \GRFPC0.N_738\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7062_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25630\ : std_logic ;
  signal \GRFPC0.N_25871\ : std_logic ;
  signal \GRFPC0.N_25122\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2504_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25715_1\ : std_logic ;
  signal \GRFPC0.N_24325\ : std_logic ;
  signal \GRFPC0.N_25624\ : std_logic ;
  signal \GRFPC0.N_24067\ : std_logic ;
  signal \GRFPC0.N_25817\ : std_logic ;
  signal \GRFPC0.N_25510\ : std_logic ;
  signal \GRFPC0.N_25511\ : std_logic ;
  signal \GRFPC0.N_24311\ : std_logic ;
  signal \GRFPC0.N_24279\ : std_logic ;
  signal \GRFPC0.N_24194\ : std_logic ;
  signal \GRFPC0.N_25124\ : std_logic ;
  signal \GRFPC0.N_25257\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6869_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3813_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25680\ : std_logic ;
  signal \GRFPC0.N_24404_1\ : std_logic ;
  signal \GRFPC0.N_25137\ : std_logic ;
  signal \GRFPC0.N_24504\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6414_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_24655\ : std_logic ;
  signal \GRFPC0.N_24656\ : std_logic ;
  signal \GRFPC0.N_25444_1\ : std_logic ;
  signal \GRFPC0.N_24657_2\ : std_logic ;
  signal \GRFPC0.N_25129\ : std_logic ;
  signal \GRFPC0.N_261_2\ : std_logic ;
  signal \GRFPC0.N_25130\ : std_logic ;
  signal \GRFPC0.N_858\ : std_logic ;
  signal \GRFPC0.N_689\ : std_logic ;
  signal \GRFPC0.N_23043\ : std_logic ;
  signal \GRFPC0.N_24820\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN873_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_22821\ : std_logic ;
  signal \GRFPC0.N_19961\ : std_logic ;
  signal \GRFPC0.N_20027\ : std_logic ;
  signal \GRFPC0.N_20290\ : std_logic ;
  signal \GRFPC0.N_18933\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2474_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2459_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VFIFO.FULL10\ : std_logic ;
  signal \GRFPC0.N_24199\ : std_logic ;
  signal \GRFPC0.N_25376\ : std_logic ;
  signal \GRFPC0.N_25382\ : std_logic ;
  signal \GRFPC0.N_24168_1\ : std_logic ;
  signal \GRFPC0.N_25156\ : std_logic ;
  signal \GRFPC0.N_25178\ : std_logic ;
  signal \GRFPC0.N_25179\ : std_logic ;
  signal \GRFPC0.N_25692\ : std_logic ;
  signal \GRFPC0.N_25693\ : std_logic ;
  signal \GRFPC0.N_25823\ : std_logic ;
  signal \GRFPC0.N_25823_2\ : std_logic ;
  signal \GRFPC0.N_25576\ : std_logic ;
  signal \GRFPC0.N_25824_1\ : std_logic ;
  signal \GRFPC0.N_25717\ : std_logic ;
  signal \GRFPC0.N_25635\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3127_REGDEPX\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_12_I_1\ : std_logic ;
  signal \GRFPC0.STDEP_0_SQMUXA_9\ : std_logic ;
  signal \GRFPC0.N_18232\ : std_logic ;
  signal \GRFPC0.STDEP_0_SQMUXA_136_2\ : std_logic ;
  signal \GRFPC0.N_18319\ : std_logic ;
  signal \GRFPC0.N_21462\ : std_logic ;
  signal \GRFPC0.N_514\ : std_logic ;
  signal \GRFPC0.UN1_STDEP382\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0\ : std_logic ;
  signal \GRFPC0.N_19008\ : std_logic ;
  signal \GRFPC0.N_21539\ : std_logic ;
  signal \GRFPC0.N_23177\ : std_logic ;
  signal \GRFPC0.N_21589\ : std_logic ;
  signal \GRFPC0.N_23152\ : std_logic ;
  signal \GRFPC0.N_23830\ : std_logic ;
  signal \GRFPC0.N_23829\ : std_logic ;
  signal \GRFPC0.N_23842\ : std_logic ;
  signal \GRFPC0.N_23173\ : std_logic ;
  signal \GRFPC0.N_17401\ : std_logic ;
  signal \GRFPC0.N_17405\ : std_logic ;
  signal \GRFPC0.N_17407\ : std_logic ;
  signal \GRFPC0.N_17411\ : std_logic ;
  signal \GRFPC0.N_17419\ : std_logic ;
  signal \GRFPC0.N_24732\ : std_logic ;
  signal \GRFPC0.N_17425\ : std_logic ;
  signal \GRFPC0.N_24729\ : std_logic ;
  signal \GRFPC0.N_24730\ : std_logic ;
  signal \GRFPC0.N_20092\ : std_logic ;
  signal \GRFPC0.N_20157\ : std_logic ;
  signal \GRFPC0.N_20223\ : std_logic ;
  signal \GRFPC0.N_20275\ : std_logic ;
  signal \GRFPC0.N_20100\ : std_logic ;
  signal \GRFPC0.N_20231\ : std_logic ;
  signal \GRFPC0.N_20165\ : std_logic ;
  signal \GRFPC0.V.FSR.AEXC_0_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.N_19929\ : std_logic ;
  signal \GRFPC0.N_19995\ : std_logic ;
  signal \GRFPC0.N_20258\ : std_logic ;
  signal \GRFPC0.N_20108\ : std_logic ;
  signal \GRFPC0.N_20239\ : std_logic ;
  signal \GRFPC0.N_20173\ : std_logic ;
  signal \GRFPC0.N_20237\ : std_logic ;
  signal \GRFPC0.N_20105\ : std_logic ;
  signal \GRFPC0.N_20236\ : std_logic ;
  signal \GRFPC0.N_20170\ : std_logic ;
  signal \GRFPC0.N_20234\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18808\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18829\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18829_13\ : std_logic ;
  signal \GRFPC0.N_20099\ : std_logic ;
  signal \GRFPC0.N_20230\ : std_logic ;
  signal \GRFPC0.N_20164\ : std_logic ;
  signal \GRFPC0.N_20098\ : std_logic ;
  signal \GRFPC0.N_20229\ : std_logic ;
  signal \GRFPC0.N_20163\ : std_logic ;
  signal \GRFPC0.N_20096\ : std_logic ;
  signal \GRFPC0.N_20161\ : std_logic ;
  signal \GRFPC0.N_20227\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_31__G5\ : std_logic ;
  signal \GRFPC0.N_20091\ : std_logic ;
  signal \GRFPC0.N_20156\ : std_logic ;
  signal \GRFPC0.N_20222\ : std_logic ;
  signal \GRFPC0.N_20022\ : std_logic ;
  signal \GRFPC0.N_19975\ : std_logic ;
  signal \GRFPC0.N_20041\ : std_logic ;
  signal \GRFPC0.N_20304\ : std_logic ;
  signal \GRFPC0.N_23731_4\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.PEND_0_0_G2\ : std_logic ;
  signal \GRFPC0.N_20109\ : std_logic ;
  signal \GRFPC0.N_20240\ : std_logic ;
  signal \GRFPC0.N_20174\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.EXEN2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP78\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN730_DEP\ : std_logic ;
  signal \GRFPC0.N_21615\ : std_logic ;
  signal \GRFPC0.N_24386\ : std_logic ;
  signal \GRFPC0.N_24401\ : std_logic ;
  signal \GRFPC0.N_249\ : std_logic ;
  signal \GRFPC0.N_494\ : std_logic ;
  signal \GRFPC0.N_867\ : std_logic ;
  signal \GRFPC0.N_644_2\ : std_logic ;
  signal \GRFPC0.N_644\ : std_logic ;
  signal \GRFPC0.N_23783\ : std_logic ;
  signal \GRFPC0.N_95\ : std_logic ;
  signal \GRFPC0.N_23781\ : std_logic ;
  signal \GRFPC0.N_24140\ : std_logic ;
  signal \GRFPC0.N_25519\ : std_logic ;
  signal \GRFPC0.N_24141\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2123_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25518\ : std_logic ;
  signal \GRFPC0.N_24170\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN24_FPUSTART\ : std_logic ;
  signal \GRFPC0.N_9160\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VALLOW_1_SQMUXA_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_138\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.STATE2_1\ : std_logic ;
  signal \GRFPC0.N_20117\ : std_logic ;
  signal \GRFPC0.N_20248\ : std_logic ;
  signal \GRFPC0.N_20182\ : std_logic ;
  signal \GRFPC0.N_20247\ : std_logic ;
  signal \GRFPC0.N_20280\ : std_logic ;
  signal \GRFPC0.N_19489\ : std_logic ;
  signal N_32594 : std_logic ;
  signal \GRFPC0.N_19983\ : std_logic ;
  signal \GRFPC0.N_20049\ : std_logic ;
  signal \GRFPC0.N_20312\ : std_logic ;
  signal \GRFPC0.N_20114\ : std_logic ;
  signal N_40640 : std_logic ;
  signal \GRFPC0.N_24389\ : std_logic ;
  signal \GRFPC0.N_155_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.MEMEN10\ : std_logic ;
  signal \GRFPC0.UN1_WRENX10_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.EXEN7\ : std_logic ;
  signal \GRFPC0.UN1_WRENX10\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.WRENX10\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.WR2EN10\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.DIVEN10_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.DIVEN10_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN3_FIFO_CLR\ : std_logic ;
  signal \GRFPC0.FIFO_INC_5_SQMUXA\ : std_logic ;
  signal N_44904 : std_logic ;
  signal N_44831 : std_logic ;
  signal \GRFPC0.DIVI_0_SQMUXA_1_2\ : std_logic ;
  signal \GRFPC0.N_244\ : std_logic ;
  signal \GRFPC0.N_25233\ : std_logic ;
  signal \GRFPC0.N_23778_2\ : std_logic ;
  signal \GRFPC0.N_23789\ : std_logic ;
  signal \GRFPC0.RFA.READ_RS1_0_0_G3\ : std_logic ;
  signal \GRFPC0.VFIFO.WR_0_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.VFIFO.WR_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.VFIFO.WR_1_SQMUXA\ : std_logic ;
  signal \GRFPC0.FIFO.WR_0_0_0__G3\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_7__G5\ : std_logic ;
  signal \GRFPC0.N_19932\ : std_logic ;
  signal \GRFPC0.N_25895\ : std_logic ;
  signal \GRFPC0.N_21502_2\ : std_logic ;
  signal \GRFPC0.N_533\ : std_logic ;
  signal \GRFPC0.N_21502\ : std_logic ;
  signal \GRFPC0.N_25896\ : std_logic ;
  signal \GRFPC0.N_21496\ : std_logic ;
  signal \GRFPC0.N_21499\ : std_logic ;
  signal \GRFPC0.N_21524\ : std_logic ;
  signal \GRFPC0.REGDEP_1_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP90\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDD_0_0_G1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_0\ : std_logic ;
  signal \GRFPC0.N_24644\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_3\ : std_logic ;
  signal \GRFPC0.N_21713\ : std_logic ;
  signal \GRFPC0.N_21674\ : std_logic ;
  signal \GRFPC0.N_168\ : std_logic ;
  signal N_40549 : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_11__G3\ : std_logic ;
  signal \GRFPC0.N_21822\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP132\ : std_logic ;
  signal \GRFPC0.N_21855\ : std_logic ;
  signal \GRFPC0.N_21572\ : std_logic ;
  signal \GRFPC0.N_21200\ : std_logic ;
  signal \GRFPC0.N_21199\ : std_logic ;
  signal \GRFPC0.N_113\ : std_logic ;
  signal \GRFPC0.N_543_1\ : std_logic ;
  signal \GRFPC0.N_21617\ : std_logic ;
  signal \GRFPC0.N_23491\ : std_logic ;
  signal \GRFPC0.N_23284\ : std_logic ;
  signal \GRFPC0.N_21295\ : std_logic ;
  signal \GRFPC0.N_21297\ : std_logic ;
  signal \GRFPC0.N_21325\ : std_logic ;
  signal \GRFPC0.N_21298\ : std_logic ;
  signal \GRFPC0.N_21581_2\ : std_logic ;
  signal \GRFPC0.N_21564\ : std_logic ;
  signal \GRFPC0.N_21563\ : std_logic ;
  signal \GRFPC0.N_21579\ : std_logic ;
  signal \GRFPC0.N_21577\ : std_logic ;
  signal \GRFPC0.N_23036\ : std_logic ;
  signal \GRFPC0.N_24978_1\ : std_logic ;
  signal \GRFPC0.N_23334\ : std_logic ;
  signal \GRFPC0.N_22967\ : std_logic ;
  signal \GRFPC0.N_23032\ : std_logic ;
  signal \GRFPC0.N_23041\ : std_logic ;
  signal \GRFPC0.N_25028\ : std_logic ;
  signal \GRFPC0.N_25078\ : std_logic ;
  signal \GRFPC0.N_25034\ : std_logic ;
  signal \GRFPC0.N_25082\ : std_logic ;
  signal \GRFPC0.N_25037\ : std_logic ;
  signal \GRFPC0.N_22370_2\ : std_logic ;
  signal \GRFPC0.N_22370_3\ : std_logic ;
  signal \GRFPC0.N_22810\ : std_logic ;
  signal \GRFPC0.N_22903\ : std_logic ;
  signal \GRFPC0.N_22900\ : std_logic ;
  signal \GRFPC0.N_22536\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.UN423_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_22808\ : std_logic ;
  signal \GRFPC0.N_24006\ : std_logic ;
  signal \GRFPC0.N_22587\ : std_logic ;
  signal \GRFPC0.N_23299\ : std_logic ;
  signal \GRFPC0.N_22571\ : std_logic ;
  signal \GRFPC0.N_24943\ : std_logic ;
  signal \GRFPC0.N_24948\ : std_logic ;
  signal \GRFPC0.N_24942\ : std_logic ;
  signal \GRFPC0.N_24945\ : std_logic ;
  signal \GRFPC0.N_24944\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4687_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_24979\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4672_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_570\ : std_logic ;
  signal \GRFPC0.N_674\ : std_logic ;
  signal \GRFPC0.N_68_I\ : std_logic ;
  signal \GRFPC0.N_22125\ : std_logic ;
  signal \GRFPC0.N_35_I\ : std_logic ;
  signal \GRFPC0.N_22133\ : std_logic ;
  signal \GRFPC0.N_22196\ : std_logic ;
  signal \GRFPC0.N_22867\ : std_logic ;
  signal \GRFPC0.N_22869\ : std_logic ;
  signal \GRFPC0.N_18150\ : std_logic ;
  signal \GRFPC0.N_21474\ : std_logic ;
  signal \GRFPC0.N_22753\ : std_logic ;
  signal \GRFPC0.N_21438\ : std_logic ;
  signal \GRFPC0.N_22764\ : std_logic ;
  signal \GRFPC0.N_22757\ : std_logic ;
  signal \GRFPC0.N_21477\ : std_logic ;
  signal \GRFPC0.N_40\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\ : std_logic ;
  signal \GRFPC0.N_23281\ : std_logic ;
  signal \GRFPC0.N_22588\ : std_logic ;
  signal \GRFPC0.N_92_I\ : std_logic ;
  signal \GRFPC0.N_23289\ : std_logic ;
  signal \GRFPC0.N_22514\ : std_logic ;
  signal \GRFPC0.N_22589\ : std_logic ;
  signal \GRFPC0.N_22377\ : std_logic ;
  signal \GRFPC0.N_22341\ : std_logic ;
  signal \GRFPC0.N_22380\ : std_logic ;
  signal \GRFPC0.N_22360\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_2\ : std_logic ;
  signal \GRFPC0.N_24935\ : std_logic ;
  signal \GRFPC0.N_22517\ : std_logic ;
  signal \GRFPC0.N_23961\ : std_logic ;
  signal \GRFPC0.N_708\ : std_logic ;
  signal \GRFPC0.N_742\ : std_logic ;
  signal \GRFPC0.N_23431\ : std_logic ;
  signal \GRFPC0.N_23382\ : std_logic ;
  signal \GRFPC0.N_23389\ : std_logic ;
  signal \GRFPC0.N_23495\ : std_logic ;
  signal \GRFPC0.N_23454\ : std_logic ;
  signal \GRFPC0.N_23439\ : std_logic ;
  signal \GRFPC0.N_18322\ : std_logic ;
  signal \GRFPC0.N_18320\ : std_logic ;
  signal \GRFPC0.N_139\ : std_logic ;
  signal \GRFPC0.N_196_I\ : std_logic ;
  signal \GRFPC0.N_197_I\ : std_logic ;
  signal \GRFPC0.N_198_I\ : std_logic ;
  signal \GRFPC0.N_24011\ : std_logic ;
  signal N_45232_1 : std_logic ;
  signal \GRFPC0.N_19998\ : std_logic ;
  signal \GRFPC0.N_20261\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_0__G5\ : std_logic ;
  signal \GRFPC0.N_19925\ : std_logic ;
  signal \GRFPC0.N_19991\ : std_logic ;
  signal \GRFPC0.N_20254\ : std_logic ;
  signal \GRFPC0.N_20154\ : std_logic ;
  signal N_38 : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_2__G5\ : std_logic ;
  signal \GRFPC0.N_19927\ : std_logic ;
  signal \GRFPC0.N_19993\ : std_logic ;
  signal \GRFPC0.N_20256\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_3__G5\ : std_logic ;
  signal \GRFPC0.N_19994\ : std_logic ;
  signal \GRFPC0.N_19931\ : std_logic ;
  signal \GRFPC0.N_19997\ : std_logic ;
  signal \GRFPC0.N_20260\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_9__G5\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_10__G5\ : std_logic ;
  signal \GRFPC0.N_19935\ : std_logic ;
  signal \GRFPC0.N_20001\ : std_logic ;
  signal \GRFPC0.N_20264\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_12__G5\ : std_logic ;
  signal \GRFPC0.N_19937\ : std_logic ;
  signal \GRFPC0.N_20003\ : std_logic ;
  signal \GRFPC0.N_20101\ : std_logic ;
  signal \GRFPC0.N_20266\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_14__G5\ : std_logic ;
  signal \GRFPC0.N_19939\ : std_logic ;
  signal \GRFPC0.N_20005\ : std_logic ;
  signal \GRFPC0.N_20268\ : std_logic ;
  signal \GRFPC0.N_19940\ : std_logic ;
  signal \GRFPC0.N_20006\ : std_logic ;
  signal \GRFPC0.N_20269\ : std_logic ;
  signal \GRFPC0.N_19941\ : std_logic ;
  signal \GRFPC0.N_20007\ : std_logic ;
  signal \GRFPC0.N_20270\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_17__G5\ : std_logic ;
  signal \GRFPC0.N_19942\ : std_logic ;
  signal \GRFPC0.N_20106\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_18__G5\ : std_logic ;
  signal \GRFPC0.N_20009\ : std_logic ;
  signal \GRFPC0.N_19943\ : std_logic ;
  signal \GRFPC0.N_20272\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_19__G5\ : std_logic ;
  signal \GRFPC0.N_19944\ : std_logic ;
  signal \GRFPC0.N_20010\ : std_logic ;
  signal \GRFPC0.N_20273\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_20__G5\ : std_logic ;
  signal \GRFPC0.N_19945\ : std_logic ;
  signal \GRFPC0.N_20011\ : std_logic ;
  signal \GRFPC0.N_20274\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_21__G5\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_23__G5\ : std_logic ;
  signal \GRFPC0.N_19950\ : std_logic ;
  signal \GRFPC0.N_19951\ : std_logic ;
  signal \GRFPC0.N_20017\ : std_logic ;
  signal \GRFPC0.N_20181\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_29__G5\ : std_logic ;
  signal \GRFPC0.N_19954\ : std_logic ;
  signal \GRFPC0.N_20020\ : std_logic ;
  signal \GRFPC0.N_20283\ : std_logic ;
  signal \GRFPC0.N_19953\ : std_logic ;
  signal \GRFPC0.N_20019\ : std_logic ;
  signal \GRFPC0.N_20282\ : std_logic ;
  signal \GRFPC0.N_19956\ : std_logic ;
  signal \GRFPC0.N_20285\ : std_logic ;
  signal \GRFPC0.N_24575\ : std_logic ;
  signal \GRFPC0.N_245\ : std_logic ;
  signal \GRFPC0.N_22826\ : std_logic ;
  signal \GRFPC0.N_22827\ : std_logic ;
  signal \GRFPC0.N_22237\ : std_logic ;
  signal \GRFPC0.N_241\ : std_logic ;
  signal \GRFPC0.N_20116\ : std_logic ;
  signal \GRFPC0.N_240\ : std_logic ;
  signal \GRFPC0.N_25562\ : std_logic ;
  signal \GRFPC0.N_25807\ : std_logic ;
  signal \GRFPC0.N_25842_1\ : std_logic ;
  signal \GRFPC0.N_25561\ : std_logic ;
  signal \GRFPC0.N_239\ : std_logic ;
  signal \GRFPC0.DIV.EXC_0_0_N_7\ : std_logic ;
  signal N_45119_I : std_logic ;
  signal \GRFPC0.N_23131\ : std_logic ;
  signal \GRFPC0.N_23117\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_8__G3\ : std_logic ;
  signal \GRFPC0.N_22742\ : std_logic ;
  signal \GRFPC0.RFA2.FOP_0_0_0_1__G1\ : std_logic ;
  signal \GRFPC0.RFA2.FOP_0_0_0_1__N_4\ : std_logic ;
  signal \GRFPC0.N_23771\ : std_logic ;
  signal \GRFPC0.N_19818\ : std_logic ;
  signal \GRFPC0.N_20243\ : std_logic ;
  signal \GRFPC0.N_20310\ : std_logic ;
  signal \GRFPC0.N_20245\ : std_logic ;
  signal \GRFPC0.N_20315\ : std_logic ;
  signal \GRFPC0.N_20316\ : std_logic ;
  signal \GRFPC0.N_257\ : std_logic ;
  signal \GRFPC0.N_255\ : std_logic ;
  signal \GRFPC0.N_254\ : std_logic ;
  signal \GRFPC0.N_25236\ : std_logic ;
  signal \GRFPC0.N_253\ : std_logic ;
  signal \GRFPC0.N_252\ : std_logic ;
  signal \GRFPC0.N_251\ : std_logic ;
  signal \GRFPC0.N_248\ : std_logic ;
  signal \GRFPC0.N_247\ : std_logic ;
  signal \GRFPC0.N_246\ : std_logic ;
  signal \GRFPC0.N_25235\ : std_logic ;
  signal \GRFPC0.N_25234\ : std_logic ;
  signal \GRFPC0.N_243\ : std_logic ;
  signal \GRFPC0.N_242\ : std_logic ;
  signal \GRFPC0.N_238\ : std_logic ;
  signal \GRFPC0.N_237\ : std_logic ;
  signal \GRFPC0.N_24723\ : std_logic ;
  signal \GRFPC0.N_17410\ : std_logic ;
  signal \GRFPC0.N_17422\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.IS_RDD.TMP\ : std_logic ;
  signal \GRFPC0.N_20168\ : std_logic ;
  signal \GRFPC0.N_20171\ : std_logic ;
  signal \GRFPC0.N_19756\ : std_logic ;
  signal \GRFPC0.N_19625\ : std_logic ;
  signal \GRFPC0.N_20232\ : std_logic ;
  signal \GRFPC0.N_20166\ : std_logic ;
  signal \GRFPC0.N_20103\ : std_logic ;
  signal \GRFPC0.N_20277\ : std_logic ;
  signal \GRFPC0.N_20014\ : std_logic ;
  signal \GRFPC0.N_19948\ : std_logic ;
  signal \GRFPC0.N_20177\ : std_logic ;
  signal \GRFPC0.N_20047\ : std_logic ;
  signal \GRFPC0.N_19981\ : std_logic ;
  signal \GRFPC0.N_19555\ : std_logic ;
  signal \GRFPC0.N_20257\ : std_logic ;
  signal \GRFPC0.N_19928\ : std_logic ;
  signal \GRFPC0.N_20112\ : std_logic ;
  signal \GRFPC0.N_20220\ : std_logic ;
  signal \GRFPC0.N_20089\ : std_logic ;
  signal \GRFPC0.N_20271\ : std_logic ;
  signal \GRFPC0.N_20008\ : std_logic ;
  signal \GRFPC0.N_20054\ : std_logic ;
  signal \GRFPC0.N_19988\ : std_logic ;
  signal \GRFPC0.N_24725\ : std_logic ;
  signal \GRFPC0.N_24712\ : std_logic ;
  signal \GRFPC0.N_20228\ : std_logic ;
  signal \GRFPC0.N_20097\ : std_logic ;
  signal \GRFPC0.N_20162\ : std_logic ;
  signal \GRFPC0.N_20279\ : std_logic ;
  signal \GRFPC0.N_20179\ : std_logic ;
  signal \GRFPC0.N_20016\ : std_logic ;
  signal \GRFPC0.N_20053\ : std_logic ;
  signal \GRFPC0.N_19987\ : std_logic ;
  signal \GRFPC0.N_23174\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.STDBL_1_1\ : std_logic ;
  signal \GRFPC0.N_23705\ : std_logic ;
  signal \GRFPC0.N_23706\ : std_logic ;
  signal \GRFPC0.N_22357\ : std_logic ;
  signal \GRFPC0.N_22354\ : std_logic ;
  signal \GRFPC0.N_22355\ : std_logic ;
  signal \GRFPC0.N_22351\ : std_logic ;
  signal \GRFPC0.N_22352\ : std_logic ;
  signal \GRFPC0.N_22346\ : std_logic ;
  signal \GRFPC0.N_22349\ : std_logic ;
  signal \GRFPC0.N_20317\ : std_logic ;
  signal \GRFPC0.N_25223\ : std_logic ;
  signal \GRFPC0.N_23939\ : std_logic ;
  signal \GRFPC0.N_20276\ : std_logic ;
  signal N_32562 : std_logic ;
  signal \GRFPC0.VEX.CTRL.ID_2_1_CO1\ : std_logic ;
  signal \GRFPC0.N_25344_1\ : std_logic ;
  signal \GRFPC0.N_24643\ : std_logic ;
  signal \GRFPC0.WR.CTRL.PEND_0_0_N_5\ : std_logic ;
  signal \GRFPC0.TMP_0_SQMUXA_2\ : std_logic ;
  signal \GRFPC0.N_23694\ : std_logic ;
  signal \GRFPC0.N_23288\ : std_logic ;
  signal \GRFPC0.N_24834\ : std_logic ;
  signal \GRFPC0.N_24836\ : std_logic ;
  signal \GRFPC0.N_23857\ : std_logic ;
  signal \GRFPC0.N_24839\ : std_logic ;
  signal \GRFPC0.N_24829\ : std_logic ;
  signal \GRFPC0.N_25442\ : std_logic ;
  signal \GRFPC0.N_23932\ : std_logic ;
  signal \GRFPC0.N_23933\ : std_logic ;
  signal \GRFPC0.N_25663\ : std_logic ;
  signal \GRFPC0.N_23966\ : std_logic ;
  signal \GRFPC0.N_261\ : std_logic ;
  signal \GRFPC0.N_25564\ : std_logic ;
  signal \GRFPC0.N_25226\ : std_logic ;
  signal \GRFPC0.N_25632\ : std_logic ;
  signal \GRFPC0.N_25633\ : std_logic ;
  signal \GRFPC0.N_25841\ : std_logic ;
  signal \GRFPC0.N_24143\ : std_logic ;
  signal \GRFPC0.N_267\ : std_logic ;
  signal \GRFPC0.N_25634\ : std_logic ;
  signal \GRFPC0.N_25448\ : std_logic ;
  signal \GRFPC0.N_25498\ : std_logic ;
  signal \GRFPC0.N_25170\ : std_logic ;
  signal \GRFPC0.N_25401\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3960_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.N_25294\ : std_logic ;
  signal \GRFPC0.N_25293\ : std_logic ;
  signal \GRFPC0.N_24528\ : std_logic ;
  signal \GRFPC0.N_25848\ : std_logic ;
  signal \GRFPC0.N_25854\ : std_logic ;
  signal \GRFPC0.N_25133\ : std_logic ;
  signal \GRFPC0.N_25134\ : std_logic ;
  signal \GRFPC0.N_25021\ : std_logic ;
  signal \GRFPC0.N_23199\ : std_logic ;
  signal \GRFPC0.N_23208\ : std_logic ;
  signal \GRFPC0.N_24081\ : std_logic ;
  signal \GRFPC0.N_24072\ : std_logic ;
  signal \GRFPC0.N_22453\ : std_logic ;
  signal \GRFPC0.N_22454\ : std_logic ;
  signal \GRFPC0.N_24142\ : std_logic ;
  signal \GRFPC0.N_24085\ : std_logic ;
  signal \GRFPC0.N_24787\ : std_logic ;
  signal \GRFPC0.N_22305\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_181_I_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17540\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7363\ : std_logic ;
  signal \GRFPC0.N_512_I\ : std_logic ;
  signal \GRFPC0.N_513_I\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2191_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_9\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN334_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4254_REGDEPX2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3975_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.N_25785\ : std_logic ;
  signal \GRFPC0.N_24076\ : std_logic ;
  signal \GRFPC0.N_24074\ : std_logic ;
  signal \GRFPC0.N_22593\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_2\ : std_logic ;
  signal \GRFPC0.N_22452\ : std_logic ;
  signal \GRFPC0.N_23184\ : std_logic ;
  signal \GRFPC0.N_24084\ : std_logic ;
  signal \GRFPC0.N_24083\ : std_logic ;
  signal \GRFPC0.N_24463_2\ : std_logic ;
  signal \GRFPC0.N_24449_I\ : std_logic ;
  signal \GRFPC0.N_24421\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_3\ : std_logic ;
  signal \GRFPC0.N_22583\ : std_logic ;
  signal \GRFPC0.N_22582\ : std_logic ;
  signal \GRFPC0.N_22311\ : std_logic ;
  signal \GRFPC0.N_25064\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1879_REGDEPX_1\ : std_logic ;
  signal \GRFPC0.N_25791\ : std_logic ;
  signal \GRFPC0.N_25802\ : std_logic ;
  signal \GRFPC0.N_25803\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3736_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_25036\ : std_logic ;
  signal \GRFPC0.N_25570\ : std_logic ;
  signal \GRFPC0.N_25571\ : std_logic ;
  signal \GRFPC0.N_25569\ : std_logic ;
  signal \GRFPC0.N_24779\ : std_logic ;
  signal \GRFPC0.N_22767\ : std_logic ;
  signal \GRFPC0.N_24775\ : std_logic ;
  signal \GRFPC0.N_25050\ : std_logic ;
  signal \GRFPC0.N_24080\ : std_logic ;
  signal \GRFPC0.N_24796\ : std_logic ;
  signal \GRFPC0.N_24087\ : std_logic ;
  signal \GRFPC0.N_25618\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1567_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1879_REGDEPX_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN928_REGDEPX_2\ : std_logic ;
  signal \GRFPC0.N_22762\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.IS_RDD.UN1_V.STDATA_15\ : std_logic ;
  signal \GRFPC0.N_177\ : std_logic ;
  signal \GRFPC0.N_25166\ : std_logic ;
  signal \GRFPC0.N_25811\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1552_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5105_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25253\ : std_logic ;
  signal \GRFPC0.N_25227\ : std_logic ;
  signal \GRFPC0.N_24518\ : std_logic ;
  signal \GRFPC0.N_24525\ : std_logic ;
  signal \GRFPC0.N_24526\ : std_logic ;
  signal \GRFPC0.N_24527\ : std_logic ;
  signal \GRFPC0.N_24516\ : std_logic ;
  signal \GRFPC0.N_25568\ : std_logic ;
  signal \GRFPC0.N_25595\ : std_logic ;
  signal \GRFPC0.N_25805\ : std_logic ;
  signal \GRFPC0.N_25806\ : std_logic ;
  signal \GRFPC0.N_25781\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5210_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5195_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_23946_2\ : std_logic ;
  signal \GRFPC0.N_24278\ : std_logic ;
  signal \GRFPC0.N_25171\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6428_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_24162\ : std_logic ;
  signal \GRFPC0.N_24163\ : std_logic ;
  signal \GRFPC0.N_25147\ : std_logic ;
  signal \GRFPC0.N_25399\ : std_logic ;
  signal \GRFPC0.N_25846\ : std_logic ;
  signal \GRFPC0.N_25384\ : std_logic ;
  signal \GRFPC0.N_24171\ : std_logic ;
  signal \GRFPC0.N_25805_1\ : std_logic ;
  signal \GRFPC0.N_25433\ : std_logic ;
  signal \GRFPC0.N_25287\ : std_logic ;
  signal \GRFPC0.N_25291\ : std_logic ;
  signal \GRFPC0.N_23818_2\ : std_logic ;
  signal \GRFPC0.N_22291\ : std_logic ;
  signal \GRFPC0.N_22812\ : std_logic ;
  signal \GRFPC0.N_23336\ : std_logic ;
  signal \GRFPC0.N_23421\ : std_logic ;
  signal \GRFPC0.N_23418\ : std_logic ;
  signal \GRFPC0.N_23417\ : std_logic ;
  signal \GRFPC0.N_23415\ : std_logic ;
  signal \GRFPC0.N_24219\ : std_logic ;
  signal \GRFPC0.N_24242\ : std_logic ;
  signal \GRFPC0.N_25563\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4754_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25603\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4048_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_22823\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN6_SHARE\ : std_logic ;
  signal \GRFPC0.FIFO_INC_5_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.N_25676_1\ : std_logic ;
  signal \GRFPC0.N_25711\ : std_logic ;
  signal \GRFPC0.N_23348\ : std_logic ;
  signal \GRFPC0.N_23349\ : std_logic ;
  signal \GRFPC0.N_23345\ : std_logic ;
  signal \GRFPC0.N_23347\ : std_logic ;
  signal \GRFPC0.N_25840\ : std_logic ;
  signal \GRFPC0.N_25673\ : std_logic ;
  signal \GRFPC0.N_25672\ : std_logic ;
  signal \GRFPC0.N_24201\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3959_REGDEPX\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.15.1.CHECK_DEP.UN4895_REGDEPX_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN873_REGDEPX2_2\ : std_logic ;
  signal \GRFPC0.N_22390\ : std_logic ;
  signal \GRFPC0.N_22481\ : std_logic ;
  signal \GRFPC0.N_25886\ : std_logic ;
  signal \GRFPC0.N_21302\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP104\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD_2_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD_2_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD_2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.REGDEP146\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_MEM.CTRL.RD_2_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP62\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.RD_2_3\ : std_logic ;
  signal \GRFPC0.REGDEP_2_SQMUXA\ : std_logic ;
  signal \GRFPC0.N_21347\ : std_logic ;
  signal \GRFPC0.REGDEP_2_SQMUXA_2\ : std_logic ;
  signal \GRFPC0.REGDEP_2_SQMUXA_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP10\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4063_REGDEPX\ : std_logic ;
  signal \GRFPC0.N_23125\ : std_logic ;
  signal \GRFPC0.N_24977_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2196_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25568_1\ : std_logic ;
  signal \GRFPC0.N_25746\ : std_logic ;
  signal \GRFPC0.N_24837_1\ : std_logic ;
  signal N_32619 : std_logic ;
  signal N_32604 : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN13_EXP_1_CO5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN13_EXP_1_CO3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN13_EXP_1_CO1\ : std_logic ;
  signal \GRFPC0.N_23298\ : std_logic ;
  signal \GRFPC0.N_531\ : std_logic ;
  signal \GRFPC0.N_467\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4401_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_24651\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1770_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2168_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_23895\ : std_logic ;
  signal \GRFPC0.N_24066\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4612_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN447_REGDEPX2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN681_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25380\ : std_logic ;
  signal \GRFPC0.N_25652\ : std_logic ;
  signal \GRFPC0.N_24280\ : std_logic ;
  signal \GRFPC0.N_24071\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6122_REGDEPX2\ : std_logic ;
  signal \GRFPC0.N_25377\ : std_logic ;
  signal \GRFPC0.N_22428\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4201\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13895\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18311\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15125\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15745\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13865\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3407\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3413\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13562_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3440\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13592_M\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19563\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_73_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3504_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4202\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG88\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17110\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.REG_4_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST2.REG82_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17179\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17245\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15254\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17158\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17224\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15215\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19937\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17185\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17119\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19553\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19554\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19582\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19549\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_272\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13572_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3499\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.INF_3_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4245\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18867\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18948\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18947\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18880\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18870\ : std_logic ;
  signal N_32396 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18954\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18882_1\ : std_logic ;
  signal \GRFPC0.N_19682\ : std_logic ;
  signal \GRFPC0.N_19748\ : std_logic ;
  signal \GRFPC0.N_19617\ : std_logic ;
  signal \GRFPC0.N_19689\ : std_logic ;
  signal \GRFPC0.N_19755\ : std_logic ;
  signal \GRFPC0.N_19624\ : std_logic ;
  signal \GRFPC0.N_19618\ : std_logic ;
  signal \GRFPC0.N_19749\ : std_logic ;
  signal \GRFPC0.N_19683\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7241\ : std_logic ;
  signal \GRFPC0.N_19799\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M84_2_03_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19031\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_21__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_7__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_7__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__I3_I_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_2__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_21__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19079\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_18__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19064\ : std_logic ;
  signal N_32260 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17233\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_391\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19897\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19896\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19902\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19982\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19984\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19944\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19949\ : std_logic ;
  signal N_40510 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_394\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_71\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17217\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17204\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15607\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17807\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16518\ : std_logic ;
  signal N_32527 : std_logic ;
  signal N_32537 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16466\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPINC_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16401\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXP57\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15544\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16067\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16452\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15545\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16068\ : std_logic ;
  signal N_32517 : std_logic ;
  signal N_32458 : std_logic ;
  signal N_32649 : std_logic ;
  signal N_32463 : std_logic ;
  signal N_32654 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5661\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18491\ : std_logic ;
  signal N_32507 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16498\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16464\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16399\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_48\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_78_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_53\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18998\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19662\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15237\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17207\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16743\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19566\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19777\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17322\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17323\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13440\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_282\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_283\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_287\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19592_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13532_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13512\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19960\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19958\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13522\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15214\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17184\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13552_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19590\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19585\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16755\ : std_logic ;
  signal \GRFPC0.N_19783\ : std_logic ;
  signal \GRFPC0.N_19520\ : std_logic ;
  signal \GRFPC0.N_19454\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__G4\ : std_logic ;
  signal \GRFPC0.N_19501\ : std_logic ;
  signal \GRFPC0.N_19435\ : std_logic ;
  signal \GRFPC0.N_19764\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16769\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13655\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13725\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9554\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13625\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9608\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9595\ : std_logic ;
  signal \GRFPC0.N_19770\ : std_logic ;
  signal \GRFPC0.N_19507\ : std_logic ;
  signal \GRFPC0.N_19441\ : std_logic ;
  signal \GRFPC0.N_21182\ : std_logic ;
  signal \GRFPC0.N_21266\ : std_logic ;
  signal \GRFPC0.N_583\ : std_logic ;
  signal \GRFPC0.N_756\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.V2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17542\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5539\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ADDI2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ADDI3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ADDI3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3274\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7278\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_8975\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13455\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18516\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18513\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7296\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18509\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18515\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18522\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18454\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_8976\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_97\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6038_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6050_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6051_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18472\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18523\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18500\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6408_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19046\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19058\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_22__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_24__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_26__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_27__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_28__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_12__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_12__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_14__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_16__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_20__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_28__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_27__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_26__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_25__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_24__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_22__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_13__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_14__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_25__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_13__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_18__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_20__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_19__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18748\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14998\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14999\ : std_logic ;
  signal N_32401 : std_logic ;
  signal N_32406 : std_logic ;
  signal N_32411 : std_logic ;
  signal N_32426 : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN38_EXP_1_CO1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN38_EXP_1_CO4\ : std_logic ;
  signal \GRFPC0.N_19623\ : std_logic ;
  signal \GRFPC0.N_19688\ : std_logic ;
  signal \GRFPC0.N_19754\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18749\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18838\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18408_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4623_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19742\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16776\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14045\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14265_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9678\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14025_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9673\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9732\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13955\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13945\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18191\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6149\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16485\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16420\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6535\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6540\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6541\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14175\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9856\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18381\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18387\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_15__G5\ : std_logic ;
  signal \GRFPC0.N_19806\ : std_logic ;
  signal \GRFPC0.N_19543\ : std_logic ;
  signal \GRFPC0.N_19541\ : std_logic ;
  signal \GRFPC0.N_19804\ : std_logic ;
  signal \GRFPC0.N_19509\ : std_logic ;
  signal \GRFPC0.N_17570\ : std_logic ;
  signal \GRFPC0.N_19772\ : std_logic ;
  signal \GRFPC0.N_19443\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9794_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14255_1\ : std_logic ;
  signal \GRFPC0.N_19452\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16779\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16748\ : std_logic ;
  signal \GRFPC0.N_20242\ : std_logic ;
  signal \GRFPC0.N_20111\ : std_logic ;
  signal \GRFPC0.N_20176\ : std_logic ;
  signal \GRFPC0.N_19497\ : std_logic ;
  signal \GRFPC0.N_19780\ : std_logic ;
  signal \GRFPC0.N_19517\ : std_logic ;
  signal \GRFPC0.N_19451\ : std_logic ;
  signal \GRFPC0.N_19763\ : std_logic ;
  signal \GRFPC0.N_21407\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18220\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18221\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18213\ : std_logic ;
  signal N_32483 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16454\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_87\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_86\ : std_logic ;
  signal N_32669 : std_logic ;
  signal N_32664 : std_logic ;
  signal N_32677 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18489\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16501\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15647\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15651\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15657\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16436\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16442\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16507\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15537\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15535\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15540\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16522\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16072\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15549\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19707\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18443\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18467\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16516\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16069\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15666\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15546\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18448\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13648\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13815_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13845_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16770\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16759\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9549\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9548_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13675_1\ : std_logic ;
  signal \GRFPC0.N_22824\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.EXC_0_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_CCV12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.CCV12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_REST_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_GT.EXPT18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_42\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18269\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST2.EXC_0_SQMUXA_2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__N_7_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VITER.EXP28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN7_DP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4175\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18262\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_43\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_44\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4275\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18250\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4260\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3638_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18526\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_191\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_236\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19750\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16773\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16741\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_172\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19733\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5790\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3723\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.EMAXP1_1_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10086_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19690\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5505\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.IEXC25_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7502\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16197_M\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6071\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER_OF_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6404\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VALLOW_0_SQMUXA_2\ : std_logic ;
  signal \GRFPC0.N_19681\ : std_logic ;
  signal \GRFPC0.N_19746\ : std_logic ;
  signal \GRFPC0.N_19615\ : std_logic ;
  signal \GRFPC0.N_19680\ : std_logic ;
  signal \GRFPC0.N_19747\ : std_logic ;
  signal \GRFPC0.N_19616\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18685\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16495\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16500\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14305\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16430\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16114\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16099\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13605\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_163\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19671\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18477\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19692_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6736\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6833\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18487\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15548\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13685\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18481_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15646\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15649\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16071\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16456\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9500\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13855_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13825_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13695_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9487\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13735\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.IEXC25_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13805_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19055\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_15__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_22__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5755_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5758\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5756_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5775\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5757\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST3.EXC_4_SQMUXA_TZ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5768\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_3__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_3__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LT9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EXC19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LTO9_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6798\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_335\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5834\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VCS_DP_1_I_0_I_0_N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19705\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19700\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EXC18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19691\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_162_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19694\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.DBUF_7_1_CO2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18635\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13465\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18629_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.INCX_1_M0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18662\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_48\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14345_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14275_1\ : std_logic ;
  signal \GRFPC0.N_21393\ : std_logic ;
  signal N_32333 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4438\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5820\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18419\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40LTO9_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13387\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5511\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6151\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18570\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18572\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9318\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6053\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6038\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18252\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18238\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18241\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18237\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18234\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16418\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16483\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19703\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9344\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_104\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18440_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5678\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_134\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4264\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4664\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4482\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.FLUSH0_0_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6509\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4481\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14295_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6\ : std_logic ;
  signal \GRFPC0.N_19466\ : std_logic ;
  signal \GRFPC0.N_19532\ : std_logic ;
  signal \GRFPC0.N_19795\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16764\ : std_logic ;
  signal \GRFPC0.N_19531\ : std_logic ;
  signal \GRFPC0.N_19463\ : std_logic ;
  signal \GRFPC0.N_19529\ : std_logic ;
  signal \GRFPC0.N_20090\ : std_logic ;
  signal \GRFPC0.N_20221\ : std_logic ;
  signal \GRFPC0.N_19614\ : std_logic ;
  signal \GRFPC0.N_19679\ : std_logic ;
  signal \GRFPC0.N_19745\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16767\ : std_logic ;
  signal \GRFPC0.N_19539\ : std_logic ;
  signal \GRFPC0.N_19802\ : std_logic ;
  signal \GRFPC0.N_19434\ : std_logic ;
  signal \GRFPC0.N_19500\ : std_logic ;
  signal \GRFPC0.N_19744\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18326\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18318\ : std_logic ;
  signal \GRFPC0.N_19479\ : std_logic ;
  signal \GRFPC0.N_19545\ : std_logic ;
  signal \GRFPC0.N_19808\ : std_logic ;
  signal \GRFPC0.N_19544\ : std_logic ;
  signal \GRFPC0.N_19807\ : std_logic ;
  signal \GRFPC0.N_19476\ : std_logic ;
  signal \GRFPC0.N_19542\ : std_logic ;
  signal \GRFPC0.N_19805\ : std_logic ;
  signal \GRFPC0.N_19803\ : std_logic ;
  signal \GRFPC0.N_19472\ : std_logic ;
  signal \GRFPC0.N_19538\ : std_logic ;
  signal \GRFPC0.N_19801\ : std_logic ;
  signal \GRFPC0.N_19537\ : std_logic ;
  signal \GRFPC0.N_19800\ : std_logic ;
  signal \GRFPC0.N_19469\ : std_logic ;
  signal \GRFPC0.N_19535\ : std_logic ;
  signal \GRFPC0.N_19798\ : std_logic ;
  signal \GRFPC0.N_20095\ : std_logic ;
  signal \GRFPC0.N_20226\ : std_logic ;
  signal \GRFPC0.N_19534\ : std_logic ;
  signal \GRFPC0.N_19461\ : std_logic ;
  signal \GRFPC0.N_19527\ : std_logic ;
  signal \GRFPC0.N_19790\ : std_logic ;
  signal \GRFPC0.N_19464\ : std_logic ;
  signal \GRFPC0.N_19530\ : std_logic ;
  signal \GRFPC0.N_19793\ : std_logic ;
  signal \GRFPC0.N_19480\ : std_logic ;
  signal \GRFPC0.N_19546\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18315\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18307\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13875\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14185\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14065\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14145\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14095\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14075\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6546\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16484\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16419\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16421\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13835_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16766\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13705\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18314\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15751\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18674\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15134\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14205_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14115\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14195_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13377\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16758\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18349\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18350\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6535_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_145\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16778\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18677\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16777\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13885_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.G_DP_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14488\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.S_DP_1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18633\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18611\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18637\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18638\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16754\ : std_logic ;
  signal \GRFPC0.N_19619\ : std_logic ;
  signal \GRFPC0.N_19684\ : std_logic ;
  signal \GRFPC0.N_19750\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.TMP316\ : std_logic ;
  signal N_40568 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19061\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19019\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_17__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6206\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5773\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ST2.FLTYPE2_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5940\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5937_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.INF_1_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_188\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_191_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.DEFERNX_0_0_G4\ : std_logic ;
  signal \GRFPC0.N_731\ : std_logic ;
  signal \GRFPC0.N_24962\ : std_logic ;
  signal \GRFPC0.N_19503\ : std_logic ;
  signal \GRFPC0.N_19496\ : std_logic ;
  signal \GRFPC0.N_19431\ : std_logic ;
  signal \GRFPC0.N_19760\ : std_logic ;
  signal \GRFPC0.N_19528\ : std_logic ;
  signal \GRFPC0.N_19791\ : std_logic ;
  signal \GRFPC0.N_19432\ : std_logic ;
  signal \GRFPC0.N_19498\ : std_logic ;
  signal \GRFPC0.N_19761\ : std_logic ;
  signal \GRFPC0.N_19433\ : std_logic ;
  signal \GRFPC0.N_19499\ : std_logic ;
  signal \GRFPC0.N_19762\ : std_logic ;
  signal \GRFPC0.N_20159\ : std_logic ;
  signal \GRFPC0.N_19502\ : std_logic ;
  signal \GRFPC0.N_19439\ : std_logic ;
  signal \GRFPC0.N_19505\ : std_logic ;
  signal \GRFPC0.N_19440\ : std_logic ;
  signal \GRFPC0.N_19506\ : std_logic ;
  signal \GRFPC0.N_19769\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16738\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16739\ : std_logic ;
  signal \GRFPC0.N_19442\ : std_logic ;
  signal \GRFPC0.N_19508\ : std_logic ;
  signal \GRFPC0.N_19771\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_16__G5\ : std_logic ;
  signal \GRFPC0.N_19446\ : std_logic ;
  signal \GRFPC0.N_19447\ : std_logic ;
  signal \GRFPC0.N_19513\ : std_logic ;
  signal \GRFPC0.N_19776\ : std_logic ;
  signal \GRFPC0.N_19514\ : std_logic ;
  signal \GRFPC0.N_19515\ : std_logic ;
  signal \GRFPC0.N_19450\ : std_logic ;
  signal \GRFPC0.N_19516\ : std_logic ;
  signal \GRFPC0.N_19779\ : std_logic ;
  signal \GRFPC0.N_19430\ : std_logic ;
  signal \GRFPC0.N_19759\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16752\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_26__G5\ : std_logic ;
  signal \GRFPC0.N_19456\ : std_logic ;
  signal \GRFPC0.N_19952\ : std_logic ;
  signal \GRFPC0.N_20018\ : std_logic ;
  signal \GRFPC0.N_20281\ : std_logic ;
  signal \GRFPC0.N_19457\ : std_logic ;
  signal \GRFPC0.N_19459\ : std_logic ;
  signal \GRFPC0.N_19525\ : std_logic ;
  signal \GRFPC0.N_19788\ : std_logic ;
  signal \GRFPC0.N_19533\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16763\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_184\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5754\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPOP_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXPOP_1_SQMUXA\ : std_logic ;
  signal N_40517 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_183\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.V_0_0_G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXP37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18235\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_82\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19973\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_18__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19561\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15229\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17199\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16525\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15552\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16488\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16423\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16075\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_81\ : std_logic ;
  signal N_32473 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16491\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16426\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_85\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18329\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_1__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_2__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_16__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_17__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_15__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_8__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_8__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_1__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_23__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15645\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15648\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15650\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15652\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15653\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15654\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15655\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15656\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19927\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19933\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_8__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19915\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19788\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19890\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19889\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19888\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19887\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_79\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18236\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_0__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_5__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_9__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_10__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_11__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_19__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_21__G1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__N_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EMINM1_0_0_N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_46\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14517\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14518\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14519\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14520\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14521\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14522\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14523\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14524\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14525\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14526\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14527\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14528\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14529\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14530\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14531\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14532\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14533\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14534\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14535\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14536\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14537\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14538\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14539\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16728\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16729\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16730\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16731\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16732\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16733\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16734\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16735\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16736\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16737\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16740\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16742\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16744\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16745\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16683\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16747\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16686\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18676\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16753\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14516\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14515\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.S_SP_1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16523\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16073\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15550\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.NXX_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16411\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16410\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16412\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16425\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16398\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18338\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16400\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18342\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18330\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18384\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16415\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16416\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16422\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18686\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16762\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16760\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15750\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_89\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15135\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16765\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16768\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16775\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16621\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15138\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18681\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16772\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16761\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15141\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19931\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14381\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15374\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19574\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17220\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15250\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17214\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15244\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15203\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19932\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17186\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19926\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15227\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19923\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15226\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17211\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15241\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17219\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18324\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17194\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15224\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17191\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15221\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17193\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17192\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15223\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15222\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17189\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15219\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17243\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15208\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17188\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17239\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15204\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17240\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15205\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17238\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15373\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5226\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17218\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15248\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17242\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15207\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_91\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_100\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15752\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15753\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15765\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15130\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15755\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18386\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15126\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15538\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16435\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16440\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16505\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15541\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15539\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13428\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SIGN1_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17187\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15217\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17198\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15228\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15132\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15136\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18316\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16756\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16424\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16433\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15748\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16441\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16506\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15120\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15124\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17196\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16520\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16439\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16504\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16070\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15536\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15547\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16437\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16502\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16438\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16503\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16459\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16074\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15551\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17227\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15257\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19772\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16624\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14235\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15127\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16771\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17244\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15209\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M0_4_03_0_G2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.IEXC5LT6\ : std_logic ;
  signal \GRFPC0.N_19797\ : std_logic ;
  signal \GRFPC0.N_19468\ : std_logic ;
  signal \GRFPC0.N_19766\ : std_logic ;
  signal \GRFPC0.N_19437\ : std_logic ;
  signal \GRFPC0.N_19536\ : std_logic ;
  signal \GRFPC0.N_19540\ : std_logic ;
  signal \GRFPC0.N_19474\ : std_logic ;
  signal \GRFPC0.N_19809\ : std_logic ;
  signal \GRFPC0.N_19778\ : std_logic ;
  signal \GRFPC0.N_19613\ : std_logic ;
  signal \GRFPC0.N_19678\ : std_logic ;
  signal \GRFPC0.N_19449\ : std_logic ;
  signal \GRFPC0.N_19774\ : std_logic ;
  signal \GRFPC0.N_19511\ : std_logic ;
  signal \GRFPC0.N_19445\ : std_logic ;
  signal \GRFPC0.N_19786\ : std_logic ;
  signal \GRFPC0.N_19523\ : std_logic ;
  signal \GRFPC0.N_19796\ : std_logic ;
  signal \GRFPC0.N_19794\ : std_logic ;
  signal \GRFPC0.N_19765\ : std_logic ;
  signal \GRFPC0.N_19436\ : std_logic ;
  signal \GRFPC0.N_19768\ : std_logic ;
  signal \GRFPC0.N_19773\ : std_logic ;
  signal \GRFPC0.N_19510\ : std_logic ;
  signal \GRFPC0.N_19444\ : std_logic ;
  signal \GRFPC0.N_19777\ : std_logic ;
  signal \GRFPC0.N_19448\ : std_logic ;
  signal \GRFPC0.N_19784\ : std_logic ;
  signal \GRFPC0.N_19521\ : std_logic ;
  signal \GRFPC0.N_19455\ : std_logic ;
  signal \GRFPC0.N_19785\ : std_logic ;
  signal \GRFPC0.N_19522\ : std_logic ;
  signal \GRFPC0.N_19789\ : std_logic ;
  signal \GRFPC0.N_19526\ : std_logic ;
  signal \GRFPC0.N_19460\ : std_logic ;
  signal \GRFPC0.N_19767\ : std_logic ;
  signal \GRFPC0.N_19504\ : std_logic ;
  signal \GRFPC0.N_19438\ : std_logic ;
  signal \GRFPC0.N_19775\ : std_logic ;
  signal \GRFPC0.N_19512\ : std_logic ;
  signal \GRFPC0.N_19787\ : std_logic ;
  signal \GRFPC0.N_19524\ : std_logic ;
  signal \GRFPC0.N_19458\ : std_logic ;
  signal \GRFPC0.N_20225\ : std_logic ;
  signal \GRFPC0.N_20094\ : std_logic ;
  signal \GRFPC0.N_19782\ : std_logic ;
  signal \GRFPC0.N_19519\ : std_logic ;
  signal \GRFPC0.N_19453\ : std_logic ;
  signal \GRFPC0.N_19792\ : std_logic ;
  signal \GRFPC0.N_19781\ : std_logic ;
  signal \GRFPC0.N_19518\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_20__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_23__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16463\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16465\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16475\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16476\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16477\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16480\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16481\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16486\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16487\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16489\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16490\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_2_03\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_0__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_5__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_9__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_1_10__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_11__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_19__G5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_21__G5\ : std_logic ;
  signal N_44701 : std_logic ;
  signal N_44700 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19067\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19052\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19049\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19028\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19025\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19022\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18706\ : std_logic ;
  signal N_32545 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19963\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19959\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_262\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18242\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_72\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_116\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18258\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18275\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19954\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_279\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_280\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19905\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17234\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_172_I_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_245\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18705\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18364\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18372\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_177\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18371\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3444\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18366\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18365\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_152\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19802_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_270\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_273\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_274\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_271\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_277\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_278\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19991\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19814\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19815\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19811\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19812\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19804\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18264\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_108\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18219\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20729\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4276\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5850\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18310\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18360\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_143\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN55_BLSBLT5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6509_I_M\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9793_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST3.REG22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_4_SQMUXA\ : std_logic ;
  signal \GRFPC0.N_23538\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6041\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6039\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18308\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18216\ : std_logic ;
  signal N_60909 : std_logic ;
  signal N_60914 : std_logic ;
  signal N_60915 : std_logic ;
  signal N_61097 : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3_I_A4_1_0\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_6_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_1__G1_6\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_1__G1_TZ\ : std_logic ;
  signal N_45174_TZ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_6__G1_TZ\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_18__G1_TZ\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_1__G1_TZ\ : std_logic ;
  signal \GRFPC0.N_14_TZ\ : std_logic ;
  signal N_60912_TZ : std_logic ;
  signal N_61057_TZ : std_logic ;
  signal N_61113_TZ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_0_7__G0_0_0_TZ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_4_TZ\ : std_logic ;
  signal \GRFPC0.N_25362_TZ_TZ\ : std_logic ;
  signal N_60930_TZ_TZ : std_logic ;
  signal N_1_0 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_1_N_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.G_16_0_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.G_16_0_O2_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_0__G1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1__G1_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_307\ : std_logic ;
  signal N_67744 : std_logic ;
  signal N_67748 : std_logic ;
  signal N_67750 : std_logic ;
  signal N_67751 : std_logic ;
  signal D_N_6_1 : std_logic ;
  signal N_1_1 : std_logic ;
  signal N_6_0 : std_logic ;
  signal N_1_2 : std_logic ;
  signal N_1_3 : std_logic ;
  signal N_1_4 : std_logic ;
  signal N_2_6 : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_54_N_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_43_N_12\ : std_logic ;
  signal D_N_5_1 : std_logic ;
  signal D_N_5_2 : std_logic ;
  signal D_N_5_3 : std_logic ;
  signal D_N_5_4 : std_logic ;
  signal \GRFPC0.CCWR_0_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN771_REGDEPX2_2\ : std_logic ;
  signal \GRFPC0.N_25316\ : std_logic ;
  signal \GRFPC0.N_24189\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_58_0_A2_0\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_54_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5633\ : std_logic ;
  signal \GRFPC0.N_25839_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A2_0\ : std_logic ;
  signal \GRFPC0.N_25624_1\ : std_logic ;
  signal \GRFPC0.N_22707\ : std_logic ;
  signal \GRFPC0.N_680\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN512_REGDEPX_0\ : std_logic ;
  signal \GRFPC0.N_23986_1\ : std_logic ;
  signal \GRFPC0.N_21610\ : std_logic ;
  signal \GRFPC0.N_24616\ : std_logic ;
  signal \GRFPC0.DIV.EXCT_0_0_2__G0_0_A3_0\ : std_logic ;
  signal \GRFPC0.N_23802\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.QNE2_I_A4_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13638\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13718\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_123_I_I_A2_I_O2_0\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_111_I_I_A2_0_A3_0\ : std_logic ;
  signal \GRFPC0.N_23345_1\ : std_logic ;
  signal \GRFPC0.N_25516_2\ : std_logic ;
  signal \GRFPC0.N_21277_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5806\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_25_3250_I_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_20_3380_I_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_27_3198_I_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_13_3562_I_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_19_3406_I_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_38_2912_I_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_33_3042_I_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_18_3432_I_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_17_3458_I_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_14_3536_I_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_16_3484_I_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_37_2938_I_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_40_2860_I_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_35_2990_I_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_39_2886_I_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_29_3146_I_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_30_3120_I_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_21_3354_I_A3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_31_3094_I_A3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.V_0_0_G0_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_16__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13515\ : std_logic ;
  signal \GRFPC0.VFIFO.WR_0_SQMUXA_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13441\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_5__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_13525\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.V_0_0_G0_0\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RESV_0_0_G0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.WRENX10_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.WR2EN10_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.DIFFN_0_0_G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.DEFERNX_0_0_G0_I_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_57_M4_E_2\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_139\ : std_logic ;
  signal \GRFPC0.N_747\ : std_logic ;
  signal \GRFPC0.UN1_WRENX2_2_4_0\ : std_logic ;
  signal N_80124 : std_logic ;
  signal N_80125 : std_logic ;
  signal N_80126 : std_logic ;
  signal N_80127 : std_logic ;
  signal N_80128 : std_logic ;
  signal N_80129 : std_logic ;
  signal N_80134 : std_logic ;
  signal N_80135 : std_logic ;
  signal N_80138 : std_logic ;
  signal N_80139 : std_logic ;
  signal N_80158 : std_logic ;
  signal N_80159 : std_logic ;
  signal N_80163 : std_logic ;
  signal N_80164 : std_logic ;
  signal N_80167 : std_logic ;
  signal N_80168 : std_logic ;
  signal N_80171 : std_logic ;
  signal N_80172 : std_logic ;
  signal N_80175 : std_logic ;
  signal N_80176 : std_logic ;
  signal N_80179 : std_logic ;
  signal N_80180 : std_logic ;
  signal N_80183 : std_logic ;
  signal N_80184 : std_logic ;
  signal N_80187 : std_logic ;
  signal N_80188 : std_logic ;
  signal N_80191 : std_logic ;
  signal N_80192 : std_logic ;
  signal N_80195 : std_logic ;
  signal N_80196 : std_logic ;
  signal N_80199 : std_logic ;
  signal N_80200 : std_logic ;
  signal N_80203 : std_logic ;
  signal N_80204 : std_logic ;
  signal N_80207 : std_logic ;
  signal N_80208 : std_logic ;
  signal N_80260 : std_logic ;
  signal N_80261 : std_logic ;
  signal N_80264 : std_logic ;
  signal N_80279 : std_logic ;
  signal N_80280 : std_logic ;
  signal N_80281 : std_logic ;
  signal N_80282 : std_logic ;
  signal N_80283 : std_logic ;
  signal N_80284 : std_logic ;
  signal N_80285 : std_logic ;
  signal N_80286 : std_logic ;
  signal N_80287 : std_logic ;
  signal N_80288 : std_logic ;
  signal N_80289 : std_logic ;
  signal N_80290 : std_logic ;
  signal N_80291 : std_logic ;
  signal N_80292 : std_logic ;
  signal N_80293 : std_logic ;
  signal N_80294 : std_logic ;
  signal N_80295 : std_logic ;
  signal N_80296 : std_logic ;
  signal N_80297 : std_logic ;
  signal N_80298 : std_logic ;
  signal N_80299 : std_logic ;
  signal N_80300 : std_logic ;
  signal N_80301 : std_logic ;
  signal N_80302 : std_logic ;
  signal N_80303 : std_logic ;
  signal N_80304 : std_logic ;
  signal N_80305 : std_logic ;
  signal N_80306 : std_logic ;
  signal N_80307 : std_logic ;
  signal N_80308 : std_logic ;
  signal N_80309 : std_logic ;
  signal N_80310 : std_logic ;
  signal N_80311 : std_logic ;
  signal N_80312 : std_logic ;
  signal N_80313 : std_logic ;
  signal N_80314 : std_logic ;
  signal N_80315 : std_logic ;
  signal N_80316 : std_logic ;
  signal N_80317 : std_logic ;
  signal N_80318 : std_logic ;
  signal N_80319 : std_logic ;
  signal N_80320 : std_logic ;
  signal N_80321 : std_logic ;
  signal N_80322 : std_logic ;
  signal N_80323 : std_logic ;
  signal N_80324 : std_logic ;
  signal N_80325 : std_logic ;
  signal N_80326 : std_logic ;
  signal N_80327 : std_logic ;
  signal N_80328 : std_logic ;
  signal N_80329 : std_logic ;
  signal N_80552 : std_logic ;
  signal N_80553 : std_logic ;
  signal \GRFPC0.N_23599_I_0\ : std_logic ;
  signal RST_INTERNAL : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.EMAX\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18837\ : std_logic ;
  signal N_44987 : std_logic ;
  signal N_47157 : std_logic ;
  signal N_47103 : std_logic ;
  signal \GRFPC0.N_23636\ : std_logic ;
  signal \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18883\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST2.EXC_1_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.STATE_0_0_3__G0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_43_N_5_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_147_I\ : std_logic ;
  signal D_N_3_0_I : std_logic ;
  signal D_N_4_1_I : std_logic ;
  signal D_N_7_0_I : std_logic ;
  signal D_N_7_I : std_logic ;
  signal \GRFPC0.N_584_I\ : std_logic ;
  signal N_82172 : std_logic ;
  signal N_82173 : std_logic ;
  signal N_82177 : std_logic ;
  signal N_82179 : std_logic ;
  signal N_82180 : std_logic ;
  signal N_82183 : std_logic ;
  signal N_82184 : std_logic ;
  signal N_82186 : std_logic ;
  signal N_82187 : std_logic ;
  signal N_82188 : std_logic ;
  signal N_82190 : std_logic ;
  signal N_82191 : std_logic ;
  signal N_82192 : std_logic ;
  signal N_82193 : std_logic ;
  signal N_82194 : std_logic ;
  signal N_82195 : std_logic ;
  signal N_82196 : std_logic ;
  signal N_82198 : std_logic ;
  signal N_82199 : std_logic ;
  signal N_82200 : std_logic ;
  signal N_82202 : std_logic ;
  signal N_82203 : std_logic ;
  signal N_82204 : std_logic ;
  signal N_82205 : std_logic ;
  signal N_82207 : std_logic ;
  signal N_82208 : std_logic ;
  signal N_82210 : std_logic ;
  signal N_82213 : std_logic ;
  signal N_82214 : std_logic ;
  signal N_82215 : std_logic ;
  signal N_82216 : std_logic ;
  signal N_82217 : std_logic ;
  signal N_82219 : std_logic ;
  signal N_82225 : std_logic ;
  signal N_82230 : std_logic ;
  signal N_82234 : std_logic ;
  signal N_82235 : std_logic ;
  signal N_82237 : std_logic ;
  signal N_82238 : std_logic ;
  signal N_82240 : std_logic ;
  signal N_82241 : std_logic ;
  signal N_82245 : std_logic ;
  signal N_82253 : std_logic ;
  signal N_82374 : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_23__G1_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_2_TZ\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LOB2_I_M_1_I_0_0\ : std_logic ;
  signal N_93106 : std_logic ;
  signal N_93108 : std_logic ;
  signal N_93109 : std_logic ;
  signal N_93110 : std_logic ;
  signal N_93111 : std_logic ;
  signal N_93112 : std_logic ;
  signal N_93113 : std_logic ;
  signal N_93114 : std_logic ;
  signal N_93115 : std_logic ;
  signal N_93116 : std_logic ;
  signal N_93117 : std_logic ;
  signal N_93118 : std_logic ;
  signal N_93119 : std_logic ;
  signal N_93120 : std_logic ;
  signal N_93121 : std_logic ;
  signal N_93122 : std_logic ;
  signal N_93123 : std_logic ;
  signal N_93124 : std_logic ;
  signal N_93135 : std_logic ;
  signal N_93136 : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP_D\ : std_logic ;
  signal N_93159 : std_logic ;
  signal N_93160 : std_logic ;
  signal N_93163 : std_logic ;
  signal N_93189 : std_logic ;
  signal N_93190 : std_logic ;
  signal N_93231 : std_logic ;
  signal N_93232 : std_logic ;
  signal N_93235 : std_logic ;
  signal N_93236 : std_logic ;
  signal N_93295 : std_logic ;
  signal N_93296 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2191_REGDEPX_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3112_REGDEPX_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FCC_1_M2S4_0\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_13_I_O4_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5777_I_I_O2_I_O2_2_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST1.FLOP_55_0_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_41_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_1_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1653_REGDEPX2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN93_BCO_LSB_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN98_BCO_LSB_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_78_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN213_BCO_LSB_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_64_2\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_I_I_A2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_16_0_A2_0_A2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG17_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG17_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4167_REGDEPX_0_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_48_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_48_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_48_12\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1327_REGDEPX_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_42_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN496_REGDEPX_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5777_I_I_O2_I_O2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.EXCT_1_0_1733_I_A3_0_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I_A3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LT9_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A3_4_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID2_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID2_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID2_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1_0_A2_7_3\ : std_logic ;
  signal \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_1\ : std_logic ;
  signal \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_2\ : std_logic ;
  signal \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0__G0_0_0\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_63__G4_1\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_63__G4_2\ : std_logic ;
  signal \GRFPC0.WR.RREG.RES_0_0_63__G4_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.CNTX14_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.EXCT_1_1756_O4_0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.EXCT_1_1756_O4_0_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.EXCT_1_1756_O4_0_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.14.REGDEPX2_435TT_1_M3_0_A2_0\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PEND_0_0_G1_0_A3_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.CTRL.PEND_1_IV_0_A4_0_4_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.CTRL.PEND_1_IV_0_A4_0_4_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.ID_0_0_7__G1_0_1663_TZ_2\ : std_logic ;
  signal \GRFPC0.EX.CTRL.ID_0_0_7__G1_0_1663_TZ_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6736_I_I_X2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN48_BCO_LSB_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2357_REGDEPX2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2429_REGDEPX2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.RDY_2_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_29\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_31\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_32\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_34\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_43\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_44\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_47\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_48\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3680_REGDEPX2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_O2_0_845_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_O2_0_845_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_23_3302_I_A3_0_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_22_3328_I_A3_0_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_32_3068_I_A3_0_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_10_3640_I_A3_0_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_11_3614_I_A3_0_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_28_3172_I_A3_0_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_34_3016_I_A3_0_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_36_2964_I_A3_0_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_24_3276_I_A3_0_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_26_3224_I_A3_0_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_12_3588_I_A3_0_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_9_3666_I_A3_0_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G0_I_A2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.V2_1_A3_0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_16197_M_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_EXPCC_1_0_A2_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG36_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_642_0_A2_1\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_53__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_53__G3_1\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_33__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_33__G3_1\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_59__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_59__G3_1\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_36__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_36__G3_1\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_61__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_61__G3_1\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_50__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_50__G3_1\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_58__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_58__G3_1\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_62__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_62__G3_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VMEM.RREG.RES_1_3_2735_I_A3_3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VMEM.RREG.RES_1_3_2735_I_A3_3_1\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_55__G3_0\ : std_logic ;
  signal \GRFPC0.DIV.RESULT_0_0_55__G3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3_I_A2_0_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3_I_A2_0_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_4\ : std_logic ;
  signal \GRFPC0.STDDEP_0_SQMUXA_108_0_A2_0_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EXC_0_0_4__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_EXPCC_2_0_A2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_EXPCC_2_0_A2_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN68_HOLDN_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT63_0_A2_0_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_A2_1_1\ : std_logic ;
  signal \GRFPC0.STDEP_0_SQMUXA_98_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN258_BCO_LSB_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.REG59_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VCS_DP_1_I_0_I_0_G0_0_0\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1061_I_A5_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.V_0_0_G0_3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_10_0_A3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3_I_A4_0_1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_HOLDN_6_4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4415_M_0_A3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4415_M_0_A3_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_0_A5_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ANDV.TMP_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ANDV.TMP_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_2\ : std_logic ;
  signal \GRFPC0.FPEXC_0_SQMUXA_D\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1_0_A2_7_G0_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.INF_0_0_G0_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_I_A5_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_4\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_3__G1_TZ_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT67_0_A5_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.SEL_0_0_0_0__G0_0_TZ_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_2__G1_TZ_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.EMINM1_0_0_G0_I_A4_1\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_0_SQMUXA_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1332_DEP_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_I_O3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_1_0_F0_0_4__G0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.ZERO_0_0_G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN243_BCO_LSB_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE45_2\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_A6_1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV6_I_M_5_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV6_I_M_5_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV6_I_M_10_2_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV14_I_M_13_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV6_I_M_6_3\ : std_logic ;
  signal \GRFPC0.DIV.EXC_0_0_G4_0_1042_A2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_M3_0_A3_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.RDY_0_0_G0_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV10_I_M_6_7_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV10_I_M_5_7_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV10_I_M_13_1_A2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.IEXC25_NE_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.IEXC25_NE_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A3_2_0\ : std_logic ;
  signal \GRFPC0.DIV.PEND_0_0_G5_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VWR2.EXC_1_IV_I_A4_0_0\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_1_0_0__G1_1_4304_I_1\ : std_logic ;
  signal \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_0\ : std_logic ;
  signal \GRFPC0.EX.CTRL.RD_0_0_0__G1_0_3942_I_O4_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.LOB2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__G4_0\ : std_logic ;
  signal \GRFPC0.UN28_WREN_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_9\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_16_TZ_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_16_TZ_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_12_TZ_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_1_0_51__G0_0_A3_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_1_0_51__G0_0_A3_0_1\ : std_logic ;
  signal \GRFPC0.DIV.EXC_0_0_G0_I_O4_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.EXC_1_IV_0_0__G0_1\ : std_logic ;
  signal \GRFPC0.V.FSR.FTT_1_SQMUXA_2_1_0\ : std_logic ;
  signal \GRFPC0.V.FSR.FCC_2_SQMUXA_0\ : std_logic ;
  signal \GRFPC0.WR.CTRL.PEND_0_0_G2_7\ : std_logic ;
  signal \GRFPC0.FIFO.WR_0_0_0__G3_0_0\ : std_logic ;
  signal \GRFPC0.MEM.CTRL.PEND_0_0_G2_2\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PEND_0_0_G2_1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.PEND_0_0_G2_3\ : std_logic ;
  signal \GRFPC0.RFA.LD_0_0_G1_0_1612_A2_0\ : std_logic ;
  signal \GRFPC0.RFA.LD_0_0_G1_0_1612_A2_1\ : std_logic ;
  signal \GRFPC0.RFA.LD_0_0_G1_0_1612_A2_3\ : std_logic ;
  signal \GRFPC0.VFIFO.FULL_3_SQMUXA_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_16\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_24\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18860_I_0_G0_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_31__G1_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_1__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_2__G0_0\ : std_logic ;
  signal \GRFPC0.DIV.EXEC_0_0_G0_2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_TZ_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_TZ_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_TZ_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_TZ_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_TZ_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_TZ_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_TZ_9\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_12__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_12__G1_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ_10\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V17_I_0_O2_0\ : std_logic ;
  signal \GRFPC0.FIFO.WR_0_0_0__G1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.INCX_1_M2S2_I_A2_1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_13__G1_0\ : std_logic ;
  signal \GRFPC0.UN1_V.FSR.CEXC_3_SQMUXA_0\ : std_logic ;
  signal \GRFPC0.FIFO.RD_0_0_0__G1_0\ : std_logic ;
  signal \GRFPC0.WR2.CTRL.AFSR_0_0_G1_0_1123_A2_4_0\ : std_logic ;
  signal \GRFPC0.FIFO.FULL_0_0_G1_1\ : std_logic ;
  signal \GRFPC0.RFA.AFSR_0_0_G1_0_1639_A2_4\ : std_logic ;
  signal \GRFPC0.RFA.AFSR_0_0_G1_0_1639_A2_6\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_25__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_25__G1_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_20__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_20__G1_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_0_7__G2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_0_1\ : std_logic ;
  signal \GRFPC0.EX.CTRL.CCWR_0_0_G1_0_1438_A2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18859_I_0_G0_2\ : std_logic ;
  signal \GRFPC0.RFA.RDWR_0_0_G1_0_1554_A2_3\ : std_logic ;
  signal \GRFPC0.RFA.SEQERR_0_0_G1_0_1460_A2_0\ : std_logic ;
  signal \GRFPC0.RFA.ST_0_0_G1_0_1397_A2_0\ : std_logic ;
  signal \GRFPC0.RFA.RDD_0_0_G1_0_1586_A2_11_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1__G0_I_M2_M5_E_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_M4_0_A2_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_30__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_30__G1_3\ : std_logic ;
  signal \GRFPC0.RFA.RDD_0_0_G1_0_1586_A2_0\ : std_logic ;
  signal \GRFPC0.RFA.STDFQ_0_0_G1_0_1528_A2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18752_I_0_G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_A3_0_6__G0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_A3_0_6__G0_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN205_HOLDN_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_I_A2_1_1\ : std_logic ;
  signal \GRFPC0.R.FSR.AEXC_0_0_2__G1_1\ : std_logic ;
  signal \GRFPC0.R.FSR.AEXC_0_0_1__G1_1\ : std_logic ;
  signal \GRFPC0.R.FSR.AEXC_0_0_4__G1_1\ : std_logic ;
  signal \GRFPC0.R.FSR.AEXC_0_0_0__G1_0\ : std_logic ;
  signal \GRFPC0.R.FSR.AEXC_0_0_3__G1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_I_O3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_I_A2_0_4\ : std_logic ;
  signal \GRFPC0.RFA2.FOP_0_0_0_1__G0_0_A4_1\ : std_logic ;
  signal \GRFPC0.RFA2.FOP_0_0_0_1__G1_2\ : std_logic ;
  signal \GRFPC0.RFA2.FOP_0_0_A2_0_0__G0_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.WR2EN10_0_0\ : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_1__G0_3_1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_0__G1_0\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_0__G1_2\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_0__G1_4\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_2__G1_0\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_2__G1_2\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_2__G1_4\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_1__G1_0\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_1__G1_1\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_1__G1_3\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_3__G1_0\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_3__G1_3\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_3__G1_4\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_4__G1_0\ : std_logic ;
  signal \GRFPC0.R.FSR.CEXC_0_0_4__G1_3\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0__G0_0\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_0__G0_1\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_1__G0_0\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_1__G0_1\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_2__G0_0\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_2__G0_1\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_3__G0_0\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_3__G0_1\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_5__G0_0\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_5__G0_1\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_4__G0_0\ : std_logic ;
  signal \GRFPC0.FID_1_IV_0_4__G0_1\ : std_logic ;
  signal \GRFPC0.RFA2.FOP_0_0_0_1__G0_0_A4_0_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_8_0\ : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_1__G0_3_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_24__G1_1\ : std_logic ;
  signal \GRFPC0.RFA.READ_RS1_0_0_G1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_15\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_19\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_20\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_34\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.1.WRENX10_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_11\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_22\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_23\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_27\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_28\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_29\ : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_3__G0_E_0_0\ : std_logic ;
  signal \GRFPC0.FPUSEL_1_0_3__G0_E_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_60_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_16__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_16__G1_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_6__G1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_ITER.STATE_76_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.EMAXP1_1_SQMUXA_1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_17__G1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_10_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_VST4.ADDOF_0\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1_7\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1_8\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1_9\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1_13\ : std_logic ;
  signal \GRFPC0.D.FSTLCK_0_0_G1_15\ : std_logic ;
  signal \GRFPC0.D.FLDLCK_0_0_G1_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_5_7_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_7_0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_10_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_10_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_6_5_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV14_I_M_10_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV14_I_M_10_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O3_0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_13_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_13_4_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV2_I_M_13_6\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_4__G1_4\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_4__G1_7\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_3__G1_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_3__G1_3\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_3__G1_5\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_3__G1_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_52_M3_0_A2_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_14__G1_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_7_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O2_3_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_O3_2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A3_3_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV6_I_M_13_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV6_I_M_13_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_A2_3_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A2_0_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_15__G1_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_15__G1_2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_15__G1_3\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_15__G1_5\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_7__G1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_2__G1_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_2__G1_2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_2__G1_5\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_11__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_11__G1_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_O2_4_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A3_1_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_O2_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_O2_3\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_11__G1_2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_11__G1_3\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_11__G1_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_0_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_5__G1_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_5__G1_3\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_12__G1_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_12__G1_3\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_12__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_14__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_14__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_14__G1_5\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_8__G1_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_8__G1_2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_7__G1_2\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_7__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_15__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_15__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_15__G1_5\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_22__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_22__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_22__G1_5\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_23__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_23__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_23__G1_7\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_23__G1_9\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_14__G1_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_14__G1_4\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_1__G1_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_1__G1_4\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_1__G1_6_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_0_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_20__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_20__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_20__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_20__G1_5\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_20__G1_7\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_2__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_2__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_2__G1_5\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_0__G1_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_0__G1_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.WRENX2_I_S_0_4_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_18__G1_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_10__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_10__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_10__G1_4\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_26__G1_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_26__G1_4\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_13__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_3__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_3__G1_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP62_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP30_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP34_I_M_0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.WR2EN2_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_0__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_0__G1_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_43_M2_E_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_10__G1_0\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_10__G1_2\ : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_1__G0_3_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_5__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_5__G1_5\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_4__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_4__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_4__G1_5\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_26__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_26__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_10__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_10__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_10__G1_4\ : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_3__G0_E_0\ : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_3__G0_E_1\ : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_3__G0_E_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_28__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_28__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_28__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_28__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_29__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_29__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_29__G1_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18441_I_0_G0_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_4__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_4__G1_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_4__G1_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP18_I_M_0_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_16__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_16__G1_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_15__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_15__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_15__G1_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_0_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_29__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_19__G1_1\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_9__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_13__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_13__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_13__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_13__G1_5\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_21__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_21__G1_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_5__G1_0\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_5__G1_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_5__G1_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_5__G1_6\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_0__G1_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_0__G1_4\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_28__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_28__G1_4\ : std_logic ;
  signal \GRFPC0.D.STDLCK_0_0_6__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_27__G1_1\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_27__G1_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_43_M7_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_0_3\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_23__G1_2\ : std_logic ;
  signal \GRFPC0.D.LDLCK_0_0_23__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_12__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_7__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_7__G1_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP34_I_M_0_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_1__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_8__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_8__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_8__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_9__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_9__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_9__G1_5\ : std_logic ;
  signal \GRFPC0.RFA2.RS1DEP_0_0_G1_4749_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_27__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_27__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_17__G1_0\ : std_logic ;
  signal \GRFPC0.RFA2.RS1DEP_0_0_G1_0\ : std_logic ;
  signal \GRFPC0.RFA2.RS1DEP_0_0_G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_25__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_25__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_30__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_30__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_30__G1_5\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_6__G1_0\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_6__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_6__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_6__G1_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_24__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_24__G1_2\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_24__G1_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_31__G1_1\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_31__G1_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_VST3.EXC37\ : std_logic ;
  signal N_99625 : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18868\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18750\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5673\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10059_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20288_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20287_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20286_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20293_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20285_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20292_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20273_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19240_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20291_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20272_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20298_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20290_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20271_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20297_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20289_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19153_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20296_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20275_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20295_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20274_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_20294_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18289_I_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18290_I_0\ : std_logic ;
  signal \GRFPC0.N_23598_I_0\ : std_logic ;
  signal N_99660 : std_logic ;
  signal N_99661 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10088_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_291\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9793\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9792\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18204_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9787\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9486\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_148\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19681\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9402\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_33\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18408\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_8862\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9804\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9672\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9683\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9671\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_17818\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18449\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN13_ITER_OF\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9548\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9547\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9559\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9542\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_154\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19779\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18203\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18548\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_68\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19668\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18976\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_73\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18444\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18195\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_15611\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.EXP_0_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_6806\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5508\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19016\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5774\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\ : std_logic ;
  signal \GRFPC0.OP2_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4105\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SWAP_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG36\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18983_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3476\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19547\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5250\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3516\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18969\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_19546\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.INCX_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_11529\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_4401\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18527\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3560_I\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18664\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18663\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\ : std_logic ;
  signal \GRFPC0.N_25051_1\ : std_logic ;
  signal \GRFPC0.N_23631\ : std_logic ;
  signal \GRFPC0.N_24222_1\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_5_SQMUXA\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_6_SQMUXA\ : std_logic ;
  signal \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.STDEP_132_SEL0\ : std_logic ;
  signal \GRFPC0.N_25016\ : std_logic ;
  signal \GRFPC0.N_21627\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN17_SHARE\ : std_logic ;
  signal \GRFPC0.DIV.EXC_MB_2_I_0\ : std_logic ;
  signal \GRFPC0.N_23618\ : std_logic ;
  signal \GRFPC0.RFA.WRITE_RD_0_0_I1_I_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.V.STATE6\ : std_logic ;
  signal N_44718_1 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.3.STDEP_128_SEL0_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\ : std_logic ;
  signal \GRFPC0.N_458\ : std_logic ;
  signal \GRFPC0.N_481\ : std_logic ;
  signal \GRFPC0.N_114\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.4.STDEP_172_SEL0\ : std_logic ;
  signal \GRFPC0.PENDEXC_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.N_73\ : std_logic ;
  signal \GRFPC0.N_22173_I\ : std_logic ;
  signal N_40557 : std_logic ;
  signal \GRFPC0.N_23366\ : std_logic ;
  signal \GRFPC0.V.FSR.NONSTD_0_SQMUXA\ : std_logic ;
  signal \GRFPC0.R.FSR.FCC_0_0_1__N_5\ : std_logic ;
  signal \GRFPC0.OP1_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN109_HOLDN\ : std_logic ;
  signal \GRFPC0.VFIFO.PC_0_1_SQMUXA\ : std_logic ;
  signal \GRFPC0.VFIFO.INST_1_1_SQMUXA\ : std_logic ;
  signal \GRFPC0.N_23766\ : std_logic ;
  signal \GRFPC0.N_23673\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.ST_1\ : std_logic ;
  signal \GRFPC0.N_23980\ : std_logic ;
  signal \GRFPC0.N_59\ : std_logic ;
  signal \GRFPC0.N_62\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.N_25649\ : std_logic ;
  signal \GRFPC0.N_24484\ : std_logic ;
  signal \GRFPC0.N_23975\ : std_logic ;
  signal \GRFPC0.N_25221\ : std_logic ;
  signal \GRFPC0.N_23667\ : std_logic ;
  signal \GRFPC0.N_23669\ : std_logic ;
  signal \GRFPC0.N_23670\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\ : std_logic ;
  signal \GRFPC0.DIVI_0_SQMUXA\ : std_logic ;
  signal N_25 : std_logic ;
  signal N_46771_3 : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID2\ : std_logic ;
  signal N_99844 : std_logic ;
  signal \GRFPC0.N_24428\ : std_logic ;
  signal N_99846 : std_logic ;
  signal N_99847 : std_logic ;
  signal \GRFPC0.DIV.PC_0_0_9__G2\ : std_logic ;
  signal \GRFPC0.WR.CTRL.PC_0_0_9__G2\ : std_logic ;
  signal \GRFPC0.N_24361\ : std_logic ;
  signal \GRFPC0.N_82\ : std_logic ;
  signal \GRFPC0.N_21638_1\ : std_logic ;
  signal \GRFPC0.N_53\ : std_logic ;
  signal \GRFPC0.N_477\ : std_logic ;
  signal \GRFPC0.N_470\ : std_logic ;
  signal \GRFPC0.N_61_I\ : std_logic ;
  signal N_99867 : std_logic ;
  signal N_99868 : std_logic ;
  signal \GRFPC0.N_19\ : std_logic ;
  signal N_99870 : std_logic ;
  signal N_99871 : std_logic ;
  signal N_99872 : std_logic ;
  signal \GRFPC0.N_104\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.RESV14_I_1\ : std_logic ;
  signal \GRFPC0.VFIFO.INST_1_1_0\ : std_logic ;
  signal \GRFPC0.VFIFO.INST_0_1_0\ : std_logic ;
  signal N_99877 : std_logic ;
  signal N_99878 : std_logic ;
  signal N_99879 : std_logic ;
  signal N_99880 : std_logic ;
  signal N_99881 : std_logic ;
  signal N_99882 : std_logic ;
  signal N_99884 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN45_WREN\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN29_WREN\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VRFA.LD_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN68_HOLDN\ : std_logic ;
  signal \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_DEP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\ : std_logic ;
  signal \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.UN1_OP\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.UN1_CPI_2\ : std_logic ;
  signal \GRFPC0.WREN_0_SQMUXA_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_404\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_403\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_401\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_400\ : std_logic ;
  signal N_99904 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18746\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_128\ : std_logic ;
  signal N_99907 : std_logic ;
  signal N_99908_I : std_logic ;
  signal N_99909_I : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5987\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_9666\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_3386\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHV2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.MULBP_1\ : std_logic ;
  signal N_99920 : std_logic ;
  signal N_99921 : std_logic ;
  signal \FPI.START\ : std_logic ;
  signal N_108517 : std_logic ;
  signal N_108519 : std_logic ;
  signal N_108530 : std_logic ;
  signal N_108536 : std_logic ;
  signal N_108572 : std_logic ;
  signal N_108594 : std_logic ;
  signal N_108596 : std_logic ;
  signal N_108604 : std_logic ;
  signal N_108606 : std_logic ;
  signal N_108608 : std_logic ;
  signal N_108618 : std_logic ;
  signal N_108630 : std_logic ;
  signal N_108632 : std_logic ;
  signal N_108634 : std_logic ;
  signal N_108636 : std_logic ;
  signal N_108642 : std_logic ;
  signal N_108644 : std_logic ;
  signal N_108646 : std_logic ;
  signal N_108648 : std_logic ;
  signal N_108650 : std_logic ;
  signal N_108652 : std_logic ;
  signal N_108654 : std_logic ;
  signal N_108656 : std_logic ;
  signal N_108658 : std_logic ;
  signal N_108660 : std_logic ;
  signal N_108662 : std_logic ;
  signal N_108664 : std_logic ;
  signal N_108666 : std_logic ;
  signal N_108668 : std_logic ;
  signal N_108670 : std_logic ;
  signal N_108672 : std_logic ;
  signal N_108679 : std_logic ;
  signal N_108680 : std_logic ;
  signal N_108681 : std_logic ;
  signal N_108683 : std_logic ;
  signal N_108684 : std_logic ;
  signal N_108685 : std_logic ;
  signal N_108686 : std_logic ;
  signal N_108687 : std_logic ;
  signal N_108688 : std_logic ;
  signal N_108689 : std_logic ;
  signal N_108690 : std_logic ;
  signal N_108691 : std_logic ;
  signal N_108692 : std_logic ;
  signal N_108693 : std_logic ;
  signal N_108694 : std_logic ;
  signal N_108695 : std_logic ;
  signal N_108822 : std_logic ;
  signal N_108824 : std_logic ;
  signal N_108826 : std_logic ;
  signal N_108828 : std_logic ;
  signal N_108830 : std_logic ;
  signal N_108832 : std_logic ;
  signal N_108840 : std_logic ;
  signal N_108841 : std_logic ;
  signal N_108842 : std_logic ;
  signal N_108843 : std_logic ;
  signal \GRFPC0.G6\ : std_logic ;
  signal \GRFPC0.G1_1\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_0\ : std_logic ;
  signal \GRFPC0.N_8_0\ : std_logic ;
  signal \GRFPC0.G1_0_0\ : std_logic ;
  signal \GRFPC0.G1_3\ : std_logic ;
  signal \GRFPC0.G0_7_2\ : std_logic ;
  signal \GRFPC0.G4_1_0_0\ : std_logic ;
  signal \GRFPC0.G0_4_1\ : std_logic ;
  signal \GRFPC0.G1_0_0_0\ : std_logic ;
  signal \GRFPC0.G1_2_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.UN9_CMPI1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_12\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_17\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_25\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_26\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_37\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_38\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_44\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_50\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_52\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_53\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_57\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_8__N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_9__N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_2__G0_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_1__G0_2\ : std_logic ;
  signal N_80133 : std_logic ;
  signal N_80132 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_CARRY_27_RETI\ : std_logic ;
  signal N_80137 : std_logic ;
  signal N_80136 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_RETI\ : std_logic ;
  signal N_80131 : std_logic ;
  signal N_80130 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_26_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_25_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_24_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_23_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_22_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_21_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_20_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_19_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_18_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_17_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_16_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_15_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_14_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_13_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_12_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_11_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_10_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_9_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_8_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_7_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_6_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_5_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_4_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0_RETI\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_26\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_2\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_1\ : std_logic ;
  signal N_28107_RETI : std_logic ;
  signal N_28105_RETI : std_logic ;
  signal N_28103_RETI : std_logic ;
  signal N_28101_RETI : std_logic ;
  signal N_28099_RETI : std_logic ;
  signal N_28097_RETI : std_logic ;
  signal N_28095_RETI : std_logic ;
  signal N_28093_RETI : std_logic ;
  signal N_28091_RETI : std_logic ;
  signal N_28089_RETI : std_logic ;
  signal N_28087_RETI : std_logic ;
  signal N_28085_RETI : std_logic ;
  signal N_28083_RETI : std_logic ;
  signal N_28081_RETI : std_logic ;
  signal N_28079_RETI : std_logic ;
  signal N_28077_RETI : std_logic ;
  signal N_28075_RETI : std_logic ;
  signal N_28073_RETI : std_logic ;
  signal N_28071_RETI : std_logic ;
  signal N_28069_RETI : std_logic ;
  signal N_28067_RETI : std_logic ;
  signal N_28065_RETI : std_logic ;
  signal N_28063_RETI : std_logic ;
  signal N_28061_RETI : std_logic ;
  signal N_28059_RETI : std_logic ;
  signal N_28057_RETI : std_logic ;
  signal N_28055_RETI : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_26\ : std_logic ;
  signal N_28219 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_2\ : std_logic ;
  signal N_28221_RETI : std_logic ;
  signal N_28217_RETI : std_logic ;
  signal N_28215_RETI : std_logic ;
  signal N_28213_RETI : std_logic ;
  signal N_28211_RETI : std_logic ;
  signal N_28209_RETI : std_logic ;
  signal N_28207_RETI : std_logic ;
  signal N_28205_RETI : std_logic ;
  signal N_28203_RETI : std_logic ;
  signal N_28201_RETI : std_logic ;
  signal N_28199_RETI : std_logic ;
  signal N_28197_RETI : std_logic ;
  signal N_28195_RETI : std_logic ;
  signal N_28193_RETI : std_logic ;
  signal N_28191_RETI : std_logic ;
  signal N_28189_RETI : std_logic ;
  signal N_28187_RETI : std_logic ;
  signal N_28185_RETI : std_logic ;
  signal N_28183_RETI : std_logic ;
  signal N_28181_RETI : std_logic ;
  signal N_28179_RETI : std_logic ;
  signal N_28177_RETI : std_logic ;
  signal N_28175_RETI : std_logic ;
  signal N_28169_RETI : std_logic ;
  signal N_28171_RETI : std_logic ;
  signal N_28173_RETI : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_26\ : std_logic ;
  signal N_28162 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_4\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_3\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_1\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_2\ : std_logic ;
  signal N_28164_RETI : std_logic ;
  signal N_28160_RETI : std_logic ;
  signal N_28158_RETI : std_logic ;
  signal N_28156_RETI : std_logic ;
  signal N_28154_RETI : std_logic ;
  signal N_28152_RETI : std_logic ;
  signal N_28150_RETI : std_logic ;
  signal N_28148_RETI : std_logic ;
  signal N_28146_RETI : std_logic ;
  signal N_28144_RETI : std_logic ;
  signal N_28142_RETI : std_logic ;
  signal N_28140_RETI : std_logic ;
  signal N_28138_RETI : std_logic ;
  signal N_28136_RETI : std_logic ;
  signal N_28134_RETI : std_logic ;
  signal N_28132_RETI : std_logic ;
  signal N_28130_RETI : std_logic ;
  signal N_28128_RETI : std_logic ;
  signal N_28126_RETI : std_logic ;
  signal N_28124_RETI : std_logic ;
  signal N_28122_RETI : std_logic ;
  signal N_28120_RETI : std_logic ;
  signal N_28118_RETI : std_logic ;
  signal N_28112_RETI : std_logic ;
  signal N_28114_RETI : std_logic ;
  signal N_28116_RETI : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_26_0\ : std_logic ;
  signal N_28218 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_25_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_24_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_23_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_22_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_21_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_20_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_19_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_18_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_17_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_16_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_15_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_14_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_13_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_12_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_11_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_10_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_9_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_8_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_7_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_6_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_5_0\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_4_0\ : std_logic ;
  signal N_28220_RETI : std_logic ;
  signal N_28216_RETI : std_logic ;
  signal N_28214_RETI : std_logic ;
  signal N_28212_RETI : std_logic ;
  signal N_28210_RETI : std_logic ;
  signal N_28208_RETI : std_logic ;
  signal N_28206_RETI : std_logic ;
  signal N_28204_RETI : std_logic ;
  signal N_28202_RETI : std_logic ;
  signal N_28200_RETI : std_logic ;
  signal N_28198_RETI : std_logic ;
  signal N_28196_RETI : std_logic ;
  signal N_28194_RETI : std_logic ;
  signal N_28192_RETI : std_logic ;
  signal N_28190_RETI : std_logic ;
  signal N_28188_RETI : std_logic ;
  signal N_28186_RETI : std_logic ;
  signal N_28184_RETI : std_logic ;
  signal N_28182_RETI : std_logic ;
  signal N_28180_RETI : std_logic ;
  signal N_28178_RETI : std_logic ;
  signal N_28176_RETI : std_logic ;
  signal N_28174_RETI : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_26\ : std_logic ;
  signal N_28161 : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_25\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_24\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_23\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_22\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_21\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_20\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_19\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_18\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_17\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_16\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_15\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_14\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_13\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_12\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_11\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_10\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_9\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_8\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_7\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_6\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_5\ : std_logic ;
  signal \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_4\ : std_logic ;
  signal N_28163_RETI : std_logic ;
  signal N_28159_RETI : std_logic ;
  signal N_28157_RETI : std_logic ;
  signal N_28155_RETI : std_logic ;
  signal N_28153_RETI : std_logic ;
  signal N_28151_RETI : std_logic ;
  signal N_28149_RETI : std_logic ;
  signal N_28147_RETI : std_logic ;
  signal N_28145_RETI : std_logic ;
  signal N_28143_RETI : std_logic ;
  signal N_28141_RETI : std_logic ;
  signal N_28139_RETI : std_logic ;
  signal N_28137_RETI : std_logic ;
  signal N_28135_RETI : std_logic ;
  signal N_28133_RETI : std_logic ;
  signal N_28131_RETI : std_logic ;
  signal N_28129_RETI : std_logic ;
  signal N_28127_RETI : std_logic ;
  signal N_28125_RETI : std_logic ;
  signal N_28123_RETI : std_logic ;
  signal N_28121_RETI : std_logic ;
  signal N_28119_RETI : std_logic ;
  signal N_28117_RETI : std_logic ;
  signal N_99881_RETI : std_logic ;
  signal N_5 : std_logic ;
  signal N_5_0 : std_logic ;
  signal N_6_1 : std_logic ;
  signal N_5_1 : std_logic ;
  signal N_6_2 : std_logic ;
  signal N_5_2 : std_logic ;
  signal N_6_3 : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.DEFERNX_0_0_G0_I_MUX2_RETO\ : std_logic ;
  signal N_1 : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_3__G1_RETO\ : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_3__G7_RETO\ : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_3__G0_E_1_RETO\ : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_3__G0_E_2_RETO\ : std_logic ;
  signal \GRFPC0.FPUSEL_6_0_3__G0_E_0_RETO\ : std_logic ;
  signal N_1_5 : std_logic ;
  signal \GRFPC0.UN1_WRENX2_2_4_RETO\ : std_logic ;
  signal \GRFPC0.DIV.VALID_RETO\ : std_logic ;
  signal N_1_6 : std_logic ;
  signal \GRFPC0.UN1_WRENX2_2_3_0_RETO\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.WR2EN2_RETO\ : std_logic ;
  signal N_1_7 : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_3_RETI\ : std_logic ;
  signal N_1_8 : std_logic ;
  signal \GRFPC0.UN1_WRENX2_2_4_0_RETO\ : std_logic ;
  signal \GRFPC0.N_22829_RETO\ : std_logic ;
  signal N_2 : std_logic ;
  signal \GRFPC0.N_24359_RETO\ : std_logic ;
  signal N_1_9 : std_logic ;
  signal \GRFPC0.N_21346_RETO\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.0.EXEN2_RETO\ : std_logic ;
  signal \GRFPC0.N_24361_RETO\ : std_logic ;
  signal \GRFPC0.WR.RREG.RESV_RETO\ : std_logic ;
  signal HOLDN_RETO : std_logic ;
  signal N_1_10 : std_logic ;
  signal N_1_11 : std_logic ;
  signal N_2_0 : std_logic ;
  signal N_3 : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_16_RETI\ : std_logic ;
  signal N_4 : std_logic ;
  signal \GRFPC0.N_579I\ : std_logic ;
  signal N_21_0 : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_11_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_15_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_17_RETI\ : std_logic ;
  signal \GRFPC0.MEM.RREG.RESV_RETO\ : std_logic ;
  signal \GRFPC0.N_24428_RETO\ : std_logic ;
  signal N_1_12 : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_14_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_9_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_13_RETI\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10059_I_RETO\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST1.OP2NX_0_0_G0_I_MUX2_RETO\ : std_logic ;
  signal N_1_13 : std_logic ;
  signal \GRFPC0.EX.RREG.RESV_RETO\ : std_logic ;
  signal \GRFPC0.N_82_RETO\ : std_logic ;
  signal N_1_14 : std_logic ;
  signal \GRFPC0.N_24322_RETI\ : std_logic ;
  signal \GRFPC0.N_24327_RETI\ : std_logic ;
  signal N_1_15 : std_logic ;
  signal N_2_1 : std_logic ;
  signal N_3_0 : std_logic ;
  signal N_4_0 : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_22_RETI\ : std_logic ;
  signal N_5_3 : std_logic ;
  signal \GRFPC0.N_24325_RETI\ : std_logic ;
  signal N_1_16 : std_logic ;
  signal N_109356 : std_logic ;
  signal N_1_17 : std_logic ;
  signal N_109357 : std_logic ;
  signal N_1_18 : std_logic ;
  signal N_109358 : std_logic ;
  signal N_1_19 : std_logic ;
  signal N_109359 : std_logic ;
  signal N_1_20 : std_logic ;
  signal N_109360 : std_logic ;
  signal N_1_21 : std_logic ;
  signal N_109361 : std_logic ;
  signal N_1_22 : std_logic ;
  signal N_109362 : std_logic ;
  signal N_1_23 : std_logic ;
  signal N_109363 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18750_RETO\ : std_logic ;
  signal N_1_24 : std_logic ;
  signal N_109364 : std_logic ;
  signal N_1_25 : std_logic ;
  signal N_109365 : std_logic ;
  signal N_1_26 : std_logic ;
  signal N_109366 : std_logic ;
  signal N_1_27 : std_logic ;
  signal N_109367 : std_logic ;
  signal N_1_28 : std_logic ;
  signal N_2_2 : std_logic ;
  signal N_3_1 : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_14_RETI\ : std_logic ;
  signal N_4_1 : std_logic ;
  signal N_93111_RETO : std_logic ;
  signal N_1_29 : std_logic ;
  signal N_1_30 : std_logic ;
  signal N_109368 : std_logic ;
  signal N_1_31 : std_logic ;
  signal N_2_3 : std_logic ;
  signal N_3_2 : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_18_RETI\ : std_logic ;
  signal N_4_2 : std_logic ;
  signal N_1_32 : std_logic ;
  signal N_109369 : std_logic ;
  signal N_1_33 : std_logic ;
  signal N_109370 : std_logic ;
  signal N_1_34 : std_logic ;
  signal N_109371 : std_logic ;
  signal N_1_35 : std_logic ;
  signal N_109372 : std_logic ;
  signal N_1_36 : std_logic ;
  signal N_109373 : std_logic ;
  signal N_1_37 : std_logic ;
  signal N_109374 : std_logic ;
  signal N_1_38 : std_logic ;
  signal N_109375 : std_logic ;
  signal N_1_39 : std_logic ;
  signal N_109376 : std_logic ;
  signal N_5_4 : std_logic ;
  signal N_6_4 : std_logic ;
  signal N_7_0 : std_logic ;
  signal \GRFPU0.GRFPU_X0.NXX_1_48_11_RETI\ : std_logic ;
  signal N_8_0 : std_logic ;
  signal N_1_40 : std_logic ;
  signal N_109377 : std_logic ;
  signal N_1_41 : std_logic ;
  signal N_109378 : std_logic ;
  signal \GRFPC0.N_25384_RETI\ : std_logic ;
  signal N_1_42 : std_logic ;
  signal N_109379 : std_logic ;
  signal N_1_43 : std_logic ;
  signal N_109380 : std_logic ;
  signal N_1_44 : std_logic ;
  signal N_109381 : std_logic ;
  signal N_1_45 : std_logic ;
  signal N_109382 : std_logic ;
  signal N_1_46 : std_logic ;
  signal N_109383 : std_logic ;
  signal D_N_5_3_RETO : std_logic ;
  signal N_1_47 : std_logic ;
  signal D_N_5_1_RETO : std_logic ;
  signal N_1_48 : std_logic ;
  signal N_82240_RETO : std_logic ;
  signal N_1_49 : std_logic ;
  signal N_1_50 : std_logic ;
  signal N_109384 : std_logic ;
  signal N_17_0 : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_21_RETI\ : std_logic ;
  signal N_17_1 : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_22_RETI\ : std_logic ;
  signal D_N_5_4_RETO : std_logic ;
  signal N_1_51 : std_logic ;
  signal \GRFPC0.N_24183_RETI\ : std_logic ;
  signal D_N_5_2_RETO : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_57_M4_E_2_RETO\ : std_logic ;
  signal N_1_52 : std_logic ;
  signal N_93113_RETO : std_logic ;
  signal N_1_53 : std_logic ;
  signal N_93121_RETO : std_logic ;
  signal N_1_54 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18527_RETO\ : std_logic ;
  signal N_93112_RETO : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5673_RETO\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ITER.V_RETO\ : std_logic ;
  signal N_1_55 : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_13\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.S_SP_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_14\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_18\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_22\ : std_logic ;
  signal N_53554 : std_logic ;
  signal N_110093 : std_logic ;
  signal N_110109 : std_logic ;
  signal N_110211 : std_logic ;
  signal N_110215 : std_logic ;
  signal N_110219 : std_logic ;
  signal N_110223 : std_logic ;
  signal N_110247 : std_logic ;
  signal N_110249 : std_logic ;
  signal N_110253 : std_logic ;
  signal N_110255 : std_logic ;
  signal N_110257 : std_logic ;
  signal N_110261 : std_logic ;
  signal N_110263 : std_logic ;
  signal N_110265 : std_logic ;
  signal N_110267 : std_logic ;
  signal N_110269 : std_logic ;
  signal N_110275 : std_logic ;
  signal N_110287 : std_logic ;
  signal N_110289 : std_logic ;
  signal N_110291 : std_logic ;
  signal N_110293 : std_logic ;
  signal N_110295 : std_logic ;
  signal N_110299 : std_logic ;
  signal N_110303 : std_logic ;
  signal N_110307 : std_logic ;
  signal N_110311 : std_logic ;
  signal N_110313 : std_logic ;
  signal N_110317 : std_logic ;
  signal N_110323 : std_logic ;
  signal N_110331 : std_logic ;
  signal N_110337 : std_logic ;
  signal N_110339 : std_logic ;
  signal N_110346 : std_logic ;
  signal N_110348 : std_logic ;
  signal N_110352 : std_logic ;
  signal N_110356 : std_logic ;
  signal N_110360 : std_logic ;
  signal N_110364 : std_logic ;
  signal N_110366 : std_logic ;
  signal N_110368 : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_N_2\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_N_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_N_6\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FPUSTART_7_N_3\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FPUSTART_7_N_4\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.FPUSTART_7_N_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_4_REST_N_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_4_REST_N_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_4_REST_N_4\ : std_logic ;
  signal N_110850 : std_logic ;
  signal N_110874 : std_logic ;
  signal N_110947 : std_logic ;
  signal N_110951 : std_logic ;
  signal N_110955 : std_logic ;
  signal N_111097 : std_logic ;
  signal N_111099 : std_logic ;
  signal N_111101 : std_logic ;
  signal N_111113 : std_logic ;
  signal N_111131 : std_logic ;
  signal N_111133 : std_logic ;
  signal N_111143 : std_logic ;
  signal N_111147 : std_logic ;
  signal N_111149 : std_logic ;
  signal N_111151 : std_logic ;
  signal N_111153 : std_logic ;
  signal N_111157 : std_logic ;
  signal N_111161 : std_logic ;
  signal N_111169 : std_logic ;
  signal N_111179 : std_logic ;
  signal N_111189 : std_logic ;
  signal N_111193 : std_logic ;
  signal N_111207 : std_logic ;
  signal N_111213 : std_logic ;
  signal N_111215 : std_logic ;
  signal N_111219 : std_logic ;
  signal N_111221 : std_logic ;
  signal N_111225 : std_logic ;
  signal N_111229 : std_logic ;
  signal N_111231 : std_logic ;
  signal N_111239 : std_logic ;
  signal N_111241 : std_logic ;
  signal N_111243 : std_logic ;
  signal N_111245 : std_logic ;
  signal N_111247 : std_logic ;
  signal N_111249 : std_logic ;
  signal N_111251 : std_logic ;
  signal N_111253 : std_logic ;
  signal N_111255 : std_logic ;
  signal N_111257 : std_logic ;
  signal N_111259 : std_logic ;
  signal N_111267 : std_logic ;
  signal N_111269 : std_logic ;
  signal N_111297 : std_logic ;
  signal N_111299 : std_logic ;
  signal N_111301 : std_logic ;
  signal N_111307 : std_logic ;
  signal N_111309 : std_logic ;
  signal N_111315 : std_logic ;
  signal N_111319 : std_logic ;
  signal N_111321 : std_logic ;
  signal N_111323 : std_logic ;
  signal N_111325 : std_logic ;
  signal N_111327 : std_logic ;
  signal N_111329 : std_logic ;
  signal N_111331 : std_logic ;
  signal N_111333 : std_logic ;
  signal N_111335 : std_logic ;
  signal N_111337 : std_logic ;
  signal N_111341 : std_logic ;
  signal N_111343 : std_logic ;
  signal N_111345 : std_logic ;
  signal N_111347 : std_logic ;
  signal N_111349 : std_logic ;
  signal N_111351 : std_logic ;
  signal N_111357 : std_logic ;
  signal N_111359 : std_logic ;
  signal N_111361 : std_logic ;
  signal N_111363 : std_logic ;
  signal N_111365 : std_logic ;
  signal N_111369 : std_logic ;
  signal N_111371 : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_17__G1_N_3\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_17__G1_N_7\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_17__G1_N_8\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_31__G1_N_4\ : std_logic ;
  signal \GRFPC0.D.STLCK_0_0_31__G1_N_6\ : std_logic ;
  signal N_111405 : std_logic ;
  signal N_111537 : std_logic ;
  signal N_111665 : std_logic ;
  signal N_111673 : std_logic ;
  signal N_111689 : std_logic ;
  signal N_111691 : std_logic ;
  signal N_111725 : std_logic ;
  signal N_111727 : std_logic ;
  signal N_111737 : std_logic ;
  signal N_111741 : std_logic ;
  signal N_111747 : std_logic ;
  signal N_111753 : std_logic ;
  signal N_111773 : std_logic ;
  signal N_111781 : std_logic ;
  signal N_111783 : std_logic ;
  signal N_111787 : std_logic ;
  signal N_112285 : std_logic ;
  signal N_112286 : std_logic ;
  signal N_112287 : std_logic ;
  signal N_112288 : std_logic ;
  signal N_112289 : std_logic ;
  signal N_112290 : std_logic ;
  signal N_112291 : std_logic ;
  signal N_112292 : std_logic ;
  signal N_112293 : std_logic ;
  signal N_112294 : std_logic ;
  signal N_113274 : std_logic ;
  signal N_113276 : std_logic ;
  signal N_113277 : std_logic ;
  signal N_113278 : std_logic ;
  signal N_113279 : std_logic ;
  signal N_113280 : std_logic ;
  signal N_113281 : std_logic ;
  signal N_113282 : std_logic ;
  signal N_113283 : std_logic ;
  signal N_113284 : std_logic ;
  signal N_113285 : std_logic ;
  signal N_113286 : std_logic ;
  signal N_113287 : std_logic ;
  signal N_113288 : std_logic ;
  signal N_113289 : std_logic ;
  signal N_113290 : std_logic ;
  signal N_113291 : std_logic ;
  signal N_113292 : std_logic ;
  signal N_113293 : std_logic ;
  signal N_113294 : std_logic ;
  signal N_113295 : std_logic ;
  signal N_113296 : std_logic ;
  signal N_113297 : std_logic ;
  signal N_113298 : std_logic ;
  signal N_113299 : std_logic ;
  signal N_113300 : std_logic ;
  signal N_113301 : std_logic ;
  signal N_113302 : std_logic ;
  signal N_113303 : std_logic ;
  signal N_113304 : std_logic ;
  signal N_113305 : std_logic ;
  signal N_113306 : std_logic ;
  signal N_113307 : std_logic ;
  signal N_113308 : std_logic ;
  signal N_113309 : std_logic ;
  signal N_113310 : std_logic ;
  signal N_113311 : std_logic ;
  signal N_113312 : std_logic ;
  signal N_113313 : std_logic ;
  signal N_113314 : std_logic ;
  signal N_113315 : std_logic ;
  signal N_113316 : std_logic ;
  signal N_113317 : std_logic ;
  signal N_113318 : std_logic ;
  signal N_113319 : std_logic ;
  signal N_113320 : std_logic ;
  signal N_113321 : std_logic ;
  signal N_113322 : std_logic ;
  signal N_113323 : std_logic ;
  signal RST_I : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_10059_I_I\ : std_logic ;
  signal HOLDN_I : std_logic ;
  signal N_99866_I : std_logic ;
  signal N_99909_I_0 : std_logic ;
  signal \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_5673_0\ : std_logic ;
  signal N_99908_I_0 : std_logic ;
  signal \GRFPC0.VFIFO.INST_0_1_0_0\ : std_logic ;
  signal \GRFPC0.VFIFO.INST_1_1_0_0\ : std_logic ;
  signal \GRFPC0.FP_PIPELINE.VDIV.VALID2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SHV2_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\ : std_logic ;
  signal \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.ST2.DIFFV_0\ : std_logic ;
  signal N_99878_0 : std_logic ;
  signal N_99878_1 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_400_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_400_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_404_0\ : std_logic ;
  signal N_99904_0 : std_logic ;
  signal N_99904_1 : std_logic ;
  signal N_99904_2 : std_logic ;
  signal N_99879_0 : std_logic ;
  signal N_99877_0 : std_logic ;
  signal N_99877_1 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_21_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18746_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_8869_0\ : std_logic ;
  signal N_99880_0 : std_logic ;
  signal N_99880_1 : std_logic ;
  signal \GRFPU0.GRFPU_X0.N_18868_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.L30\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC.M4_0_00\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC.M4_0_000_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_10_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.QP1_SP_30\ : std_logic ;
  signal \GRFPC0.OP2_10\ : std_logic ;
  signal \GRFPC0.OP2_10_0\ : std_logic ;
  signal \GRFPC0.OP2_10_1\ : std_logic ;
  signal \GRFPC0.OP2_10_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_10_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_10_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_10_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_10\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_10_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_0\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_1\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_2\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_3\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_4\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_5\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_6\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_7\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_8\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB_00\ : std_logic ;
  signal \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB_00_0\ : std_logic ;
  signal VCC : std_logic ;
  signal N_22 : std_logic ;
  signal N_23 : std_logic ;
  signal N_24 : std_logic ;
  signal N_26 : std_logic ;
  signal N_27 : std_logic ;
  signal N_28 : std_logic ;
  signal N_29 : std_logic ;
  signal N_30 : std_logic ;
  signal N_31 : std_logic ;
  signal N_32 : std_logic ;
  signal N_33 : std_logic ;
  signal N_34 : std_logic ;
  signal N_35 : std_logic ;
  signal N_36 : std_logic ;
  signal N_37 : std_logic ;
  signal N_39 : std_logic ;
  signal N_40 : std_logic ;
  signal N_41 : std_logic ;
  signal N_42 : std_logic ;
  signal N_43 : std_logic ;
  signal N_44 : std_logic ;
  signal N_45 : std_logic ;
  signal N_46 : std_logic ;
  signal N_47 : std_logic ;
  signal N_48 : std_logic ;
  signal N_49 : std_logic ;
  signal N_50 : std_logic ;
  signal N_51 : std_logic ;
  signal N_52 : std_logic ;
  signal N_53 : std_logic ;
  signal N_54 : std_logic ;
  signal N_55 : std_logic ;
  signal N_56 : std_logic ;
  signal N_57 : std_logic ;
  signal N_58 : std_logic ;
  signal N_59 : std_logic ;
  signal N_60 : std_logic ;
  signal N_61 : std_logic ;
  signal N_62 : std_logic ;
  signal N_63 : std_logic ;
  signal N_64 : std_logic ;
  signal N_65 : std_logic ;
  signal N_66 : std_logic ;
  signal N_67 : std_logic ;
  signal N_68 : std_logic ;
  signal N_69 : std_logic ;
  signal N_70 : std_logic ;
  signal N_71 : std_logic ;
  signal N_72 : std_logic ;
  signal N_73 : std_logic ;
  signal N_74 : std_logic ;
  signal N_75 : std_logic ;
  signal N_76 : std_logic ;
  signal N_77 : std_logic ;
  signal N_78 : std_logic ;
  signal N_79 : std_logic ;
  signal N_80 : std_logic ;
  signal N_81 : std_logic ;
  signal N_82 : std_logic ;
  signal N_83 : std_logic ;
  signal N_84 : std_logic ;
  signal N_85 : std_logic ;
  signal N_86 : std_logic ;
  signal N_87 : std_logic ;
  signal N_88 : std_logic ;
  signal N_89 : std_logic ;
  signal N_90 : std_logic ;
  signal N_91 : std_logic ;
  signal N_92 : std_logic ;
  signal N_93 : std_logic ;
  signal N_94 : std_logic ;
  signal N_95 : std_logic ;
  signal N_96 : std_logic ;
  signal N_97 : std_logic ;
  signal N_98 : std_logic ;
  signal N_99 : std_logic ;
  signal N_100 : std_logic ;
  signal N_101 : std_logic ;
  signal N_102 : std_logic ;
  signal N_103 : std_logic ;
  signal N_104 : std_logic ;
  signal N_105 : std_logic ;
  signal N_106 : std_logic ;
  signal N_107 : std_logic ;
  signal N_108 : std_logic ;
  signal N_109 : std_logic ;
  signal N_110 : std_logic ;
  signal N_111 : std_logic ;
  signal N_112 : std_logic ;
  signal N_113 : std_logic ;
  signal N_114 : std_logic ;
  signal N_115 : std_logic ;
  signal N_116 : std_logic ;
  signal N_117 : std_logic ;
  signal N_118 : std_logic ;
  signal N_119 : std_logic ;
  signal N_120 : std_logic ;
  signal N_121 : std_logic ;
  signal N_122 : std_logic ;
  signal N_123 : std_logic ;
  signal N_124 : std_logic ;
  signal N_125 : std_logic ;
  signal N_126 : std_logic ;
  signal N_127 : std_logic ;
  signal N_128 : std_logic ;
  signal N_129 : std_logic ;
  signal N_130 : std_logic ;
  signal N_131 : std_logic ;
  signal N_132 : std_logic ;
  signal N_133 : std_logic ;
  signal N_134 : std_logic ;
  signal N_135 : std_logic ;
  signal N_136 : std_logic ;
  signal N_137 : std_logic ;
  signal N_138 : std_logic ;
  signal N_139 : std_logic ;
  signal N_140 : std_logic ;
  signal N_141 : std_logic ;
  signal N_142 : std_logic ;
  signal N_143 : std_logic ;
  signal N_144 : std_logic ;
  signal N_145 : std_logic ;
  signal N_146 : std_logic ;
  signal N_147 : std_logic ;
  signal N_148 : std_logic ;
  signal N_149 : std_logic ;
  signal N_150 : std_logic ;
  signal N_151 : std_logic ;
  signal N_152 : std_logic ;
  signal N_153 : std_logic ;
  signal N_154 : std_logic ;
  signal N_155 : std_logic ;
  signal N_156 : std_logic ;
  signal N_157 : std_logic ;
  signal N_158 : std_logic ;
  signal N_159 : std_logic ;
  signal N_160 : std_logic ;
  signal N_161 : std_logic ;
  signal N_162 : std_logic ;
  signal N_163 : std_logic ;
  signal N_164 : std_logic ;
  signal N_165 : std_logic ;
  signal N_166 : std_logic ;
  signal N_167 : std_logic ;
  signal N_168 : std_logic ;
  signal N_169 : std_logic ;
  signal N_170 : std_logic ;
  signal N_171 : std_logic ;
  signal N_172 : std_logic ;
  signal N_173 : std_logic ;
  signal N_174 : std_logic ;
  signal N_175 : std_logic ;
  signal N_176 : std_logic ;
  signal N_177 : std_logic ;
  signal N_178 : std_logic ;
  signal N_179 : std_logic ;
  signal N_180 : std_logic ;
  signal N_181 : std_logic ;
  signal N_182 : std_logic ;
  signal N_183 : std_logic ;
  signal N_184 : std_logic ;
  signal N_185 : std_logic ;
  signal N_186 : std_logic ;
  signal N_187 : std_logic ;
  signal N_188 : std_logic ;
  signal N_189 : std_logic ;
  signal N_190 : std_logic ;
  signal N_191 : std_logic ;
  signal N_192 : std_logic ;
  signal N_193 : std_logic ;
  signal N_194 : std_logic ;
  signal N_195 : std_logic ;
  signal N_196 : std_logic ;
  signal N_197 : std_logic ;
  signal N_198 : std_logic ;
  signal N_199 : std_logic ;
  signal N_200 : std_logic ;
  signal N_201 : std_logic ;
  signal N_202 : std_logic ;
  signal N_203 : std_logic ;
  signal N_204 : std_logic ;
  signal N_205 : std_logic ;
  signal N_206 : std_logic ;
  signal N_207 : std_logic ;
  signal N_208 : std_logic ;
  signal N_209 : std_logic ;
  signal N_210 : std_logic ;
  signal N_211 : std_logic ;
  signal N_212 : std_logic ;
  signal N_213 : std_logic ;
  signal N_214 : std_logic ;
  signal N_215 : std_logic ;
  signal N_216 : std_logic ;
  signal N_217 : std_logic ;
  signal N_218 : std_logic ;
  signal N_219 : std_logic ;
  signal N_220 : std_logic ;
  signal N_221 : std_logic ;
  signal N_222 : std_logic ;
  signal N_223 : std_logic ;
  signal N_224 : std_logic ;
  signal N_225 : std_logic ;
  signal N_226 : std_logic ;
  signal N_227 : std_logic ;
  signal N_228 : std_logic ;
  signal N_229 : std_logic ;
  signal N_230 : std_logic ;
  signal N_231 : std_logic ;
  signal N_232 : std_logic ;
  signal N_233 : std_logic ;
  signal N_234 : std_logic ;
  signal N_235 : std_logic ;
  signal N_236 : std_logic ;
  signal N_237 : std_logic ;
  signal N_238 : std_logic ;
  signal N_239 : std_logic ;
  signal N_240 : std_logic ;
  signal N_241 : std_logic ;
  signal N_242 : std_logic ;
  signal N_243 : std_logic ;
  signal N_244 : std_logic ;
  signal N_245 : std_logic ;
  signal N_246 : std_logic ;
  signal N_247 : std_logic ;
  signal N_248 : std_logic ;
  signal N_249 : std_logic ;
  signal N_250 : std_logic ;
  signal N_251 : std_logic ;
  signal N_252 : std_logic ;
  signal N_253 : std_logic ;
  signal N_254 : std_logic ;
  signal N_255 : std_logic ;
  signal N_256 : std_logic ;
  signal N_257 : std_logic ;
  signal N_258 : std_logic ;
  signal N_259 : std_logic ;
  signal N_260 : std_logic ;
  signal N_261 : std_logic ;
  signal N_262 : std_logic ;
  signal N_263 : std_logic ;
  signal N_264 : std_logic ;
  signal N_265 : std_logic ;
  signal N_266 : std_logic ;
  signal N_267 : std_logic ;
  signal N_268 : std_logic ;
  signal N_269 : std_logic ;
  signal N_270 : std_logic ;
  signal N_271 : std_logic ;
  signal N_272 : std_logic ;
  signal N_273 : std_logic ;
  signal N_274 : std_logic ;
  signal N_275 : std_logic ;
  signal N_276 : std_logic ;
  signal N_277 : std_logic ;
  signal N_278 : std_logic ;
  signal N_279 : std_logic ;
  signal N_280 : std_logic ;
  signal N_281 : std_logic ;
  signal N_282 : std_logic ;
  signal N_283 : std_logic ;
  signal N_284 : std_logic ;
  signal N_285 : std_logic ;
  signal N_286 : std_logic ;
  signal N_287 : std_logic ;
  signal N_288 : std_logic ;
  signal N_289 : std_logic ;
  signal N_290 : std_logic ;
  signal N_291 : std_logic ;
  signal N_292 : std_logic ;
  signal N_293 : std_logic ;
  signal N_294 : std_logic ;
  signal N_295 : std_logic ;
  signal N_296 : std_logic ;
  signal N_297 : std_logic ;
  signal N_298 : std_logic ;
  signal N_299 : std_logic ;
  signal N_300 : std_logic ;
  signal N_301 : std_logic ;
  signal N_302 : std_logic ;
  signal N_303 : std_logic ;
  signal N_304 : std_logic ;
  signal N_305 : std_logic ;
  signal N_306 : std_logic ;
  signal N_307 : std_logic ;
  signal N_308 : std_logic ;
  signal N_309 : std_logic ;
  signal N_310 : std_logic ;
  signal N_311 : std_logic ;
  signal N_312 : std_logic ;
  signal N_313 : std_logic ;
  signal N_314 : std_logic ;
  signal N_315 : std_logic ;
  signal N_316 : std_logic ;
  signal N_317 : std_logic ;
  signal N_318 : std_logic ;
  signal N_319 : std_logic ;
  signal N_320 : std_logic ;
  signal N_321 : std_logic ;
  signal N_322 : std_logic ;
  signal N_323 : std_logic ;
  signal N_324 : std_logic ;
  signal N_325 : std_logic ;
  signal N_326 : std_logic ;
  signal N_327 : std_logic ;
  signal N_328 : std_logic ;
  signal N_329 : std_logic ;
  signal N_330 : std_logic ;
  signal N_331 : std_logic ;
  signal N_332 : std_logic ;
  signal N_333 : std_logic ;
  signal N_334 : std_logic ;
  signal N_335 : std_logic ;
  signal N_336 : std_logic ;
  signal N_337 : std_logic ;
  signal N_338 : std_logic ;
  signal N_339 : std_logic ;
  signal N_340 : std_logic ;
  signal N_341 : std_logic ;
  signal N_342 : std_logic ;
  signal N_343 : std_logic ;
  signal N_344 : std_logic ;
  signal N_345 : std_logic ;
  signal N_346 : std_logic ;
  signal N_347 : std_logic ;
  signal N_348 : std_logic ;
  signal N_349 : std_logic ;
  signal N_350 : std_logic ;
  signal N_351 : std_logic ;
  signal N_352 : std_logic ;
  signal N_353 : std_logic ;
  signal N_354 : std_logic ;
  signal N_355 : std_logic ;
  signal N_356 : std_logic ;
  signal N_357 : std_logic ;
  signal N_358 : std_logic ;
  signal N_359 : std_logic ;
  signal N_360 : std_logic ;
  signal N_361 : std_logic ;
  signal N_362 : std_logic ;
  signal N_363 : std_logic ;
  signal N_364 : std_logic ;
  signal N_365 : std_logic ;
  signal N_366 : std_logic ;
  signal N_367 : std_logic ;
  signal N_368 : std_logic ;
  signal N_369 : std_logic ;
  signal N_370 : std_logic ;
  signal N_371 : std_logic ;
  signal N_372 : std_logic ;
  signal N_373 : std_logic ;
  signal N_374 : std_logic ;
  signal N_375 : std_logic ;
  signal N_376 : std_logic ;
  signal N_377 : std_logic ;
  signal N_378 : std_logic ;
  signal N_379 : std_logic ;
  signal N_380 : std_logic ;
  signal N_381 : std_logic ;
  signal N_382 : std_logic ;
  signal N_383 : std_logic ;
  signal N_384 : std_logic ;
  signal N_385 : std_logic ;
  signal N_386 : std_logic ;
  signal N_387 : std_logic ;
  signal N_388 : std_logic ;
  signal N_389 : std_logic ;
  signal N_390 : std_logic ;
  signal N_391 : std_logic ;
  signal N_392 : std_logic ;
  signal N_393 : std_logic ;
  signal N_394 : std_logic ;
  signal N_395 : std_logic ;
  signal N_396 : std_logic ;
  signal N_397 : std_logic ;
  signal N_398 : std_logic ;
  signal N_399 : std_logic ;
  signal N_400 : std_logic ;
  signal N_401 : std_logic ;
  signal N_402 : std_logic ;
  signal N_403 : std_logic ;
  signal N_404 : std_logic ;
  signal N_405 : std_logic ;
  signal N_406 : std_logic ;
  signal N_407 : std_logic ;
  signal N_408 : std_logic ;
  signal N_409 : std_logic ;
  signal N_410 : std_logic ;
  signal N_411 : std_logic ;
  signal N_412 : std_logic ;
  signal N_413 : std_logic ;
  signal N_414 : std_logic ;
  signal N_415 : std_logic ;
  signal N_416 : std_logic ;
  signal N_417 : std_logic ;
  signal N_418 : std_logic ;
  signal N_419 : std_logic ;
  signal N_420 : std_logic ;
  signal N_421 : std_logic ;
  signal N_422 : std_logic ;
  signal N_423 : std_logic ;
  signal N_424 : std_logic ;
  signal N_425 : std_logic ;
  signal N_426 : std_logic ;
  signal N_427 : std_logic ;
  signal N_428 : std_logic ;
  signal N_429 : std_logic ;
  signal N_430 : std_logic ;
  signal N_431 : std_logic ;
  signal N_432 : std_logic ;
  signal N_433 : std_logic ;
  signal N_434 : std_logic ;
  signal N_435 : std_logic ;
  signal N_436 : std_logic ;
  signal N_437 : std_logic ;
  signal N_438 : std_logic ;
  signal N_439 : std_logic ;
  signal N_440 : std_logic ;
  signal N_441 : std_logic ;
  signal N_442 : std_logic ;
  signal N_443 : std_logic ;
  signal N_444 : std_logic ;
  signal N_445 : std_logic ;
  signal N_446 : std_logic ;
  signal N_447 : std_logic ;
  signal N_448 : std_logic ;
  signal N_449 : std_logic ;
  signal N_450 : std_logic ;
  signal N_451 : std_logic ;
  signal N_452 : std_logic ;
  signal N_453 : std_logic ;
  signal N_454 : std_logic ;
  signal N_455 : std_logic ;
  signal N_456 : std_logic ;
  signal N_457 : std_logic ;
  signal N_458 : std_logic ;
  signal N_459 : std_logic ;
  signal N_460 : std_logic ;
  signal N_461 : std_logic ;
  signal N_462 : std_logic ;
  signal N_0 : std_logic ;
  signal N_1_56 : std_logic ;
  signal N_2_4 : std_logic ;
  signal N_3_3 : std_logic ;
  signal N_4_3 : std_logic ;
  signal N_5_5 : std_logic ;
  signal N_6_5 : std_logic ;
  signal N_7_1 : std_logic ;
  signal N_8_1 : std_logic ;
  signal N_9_0 : std_logic ;
  signal N_10_0 : std_logic ;
  signal N_11_0 : std_logic ;
  signal N_12_0 : std_logic ;
  signal N_13_0 : std_logic ;
  signal N_14_0 : std_logic ;
  signal N_15_0 : std_logic ;
  signal N_16_0 : std_logic ;
  signal N_17_2 : std_logic ;
  signal N_18_0 : std_logic ;
  signal N_19_0 : std_logic ;
  signal N_20_0 : std_logic ;
  signal N_21_1 : std_logic ;
  signal N_22_0 : std_logic ;
  signal N_23_0 : std_logic ;
  signal N_24_0 : std_logic ;
  signal N_25_0 : std_logic ;
  signal N_26_0 : std_logic ;
  signal N_27_0 : std_logic ;
  signal N_28_0 : std_logic ;
  signal N_29_0 : std_logic ;
  signal N_30_0 : std_logic ;
  signal N_31_0 : std_logic ;
  signal N_32_0 : std_logic ;
  signal N_33_0 : std_logic ;
  signal N_34_0 : std_logic ;
  signal N_35_0 : std_logic ;
  signal N_36_0 : std_logic ;
  signal N_37_0 : std_logic ;
  signal N_38_0 : std_logic ;
  signal N_39_0 : std_logic ;
  signal N_40_0 : std_logic ;
  signal N_41_0 : std_logic ;
  signal N_42_0 : std_logic ;
  signal N_43_0 : std_logic ;
  signal N_44_0 : std_logic ;
  signal N_45_0 : std_logic ;
  signal N_46_0 : std_logic ;
  signal N_47_0 : std_logic ;
  signal N_48_0 : std_logic ;
  signal N_49_0 : std_logic ;
  signal N_50_0 : std_logic ;
  signal N_51_0 : std_logic ;
  signal N_52_0 : std_logic ;
  signal N_53_0 : std_logic ;
  signal N_54_0 : std_logic ;
  signal N_55_0 : std_logic ;
  signal N_56_0 : std_logic ;
  signal N_57_0 : std_logic ;
  signal N_58_0 : std_logic ;
  signal N_59_0 : std_logic ;
  signal N_60_0 : std_logic ;
  signal N_61_0 : std_logic ;
  signal N_62_0 : std_logic ;
  signal N_63_0 : std_logic ;
  signal N_64_0 : std_logic ;
  signal N_65_0 : std_logic ;
  signal N_66_0 : std_logic ;
  signal N_67_0 : std_logic ;
  signal N_68_0 : std_logic ;
  signal N_69_0 : std_logic ;
  signal N_70_0 : std_logic ;
  signal N_71_0 : std_logic ;
  signal N_72_0 : std_logic ;
  signal N_73_0 : std_logic ;
  signal N_74_0 : std_logic ;
  signal N_75_0 : std_logic ;
  signal N_76_0 : std_logic ;
  signal N_77_0 : std_logic ;
  signal N_78_0 : std_logic ;
  signal N_79_0 : std_logic ;
  signal N_80_0 : std_logic ;
  signal N_81_0 : std_logic ;
  signal N_82_0 : std_logic ;
  signal N_83_0 : std_logic ;
  signal N_84_0 : std_logic ;
  signal N_85_0 : std_logic ;
  signal N_86_0 : std_logic ;
  signal N_87_0 : std_logic ;
  signal N_88_0 : std_logic ;
  signal N_89_0 : std_logic ;
  signal N_90_0 : std_logic ;
  signal N_91_0 : std_logic ;
  signal N_92_0 : std_logic ;
  signal N_93_0 : std_logic ;
  signal N_94_0 : std_logic ;
  signal N_95_0 : std_logic ;
  signal N_96_0 : std_logic ;
  signal N_97_0 : std_logic ;
  signal N_98_0 : std_logic ;
  signal N_99_0 : std_logic ;
  signal N_100_0 : std_logic ;
  signal N_101_0 : std_logic ;
  signal N_102_0 : std_logic ;
  signal N_103_0 : std_logic ;
  signal N_104_0 : std_logic ;
  signal N_105_0 : std_logic ;
  signal N_106_0 : std_logic ;
  signal N_107_0 : std_logic ;
  signal N_108_0 : std_logic ;
  signal N_109_0 : std_logic ;
  signal N_110_0 : std_logic ;
  signal N_111_0 : std_logic ;
  signal N_112_0 : std_logic ;
  signal N_113_0 : std_logic ;
  signal N_114_0 : std_logic ;
  signal N_115_0 : std_logic ;
  signal N_116_0 : std_logic ;
  signal N_117_0 : std_logic ;
  signal N_118_0 : std_logic ;
  signal N_119_0 : std_logic ;
  signal N_120_0 : std_logic ;
  signal N_121_0 : std_logic ;
  signal N_122_0 : std_logic ;
  signal N_123_0 : std_logic ;
  signal N_124_0 : std_logic ;
  signal N_125_0 : std_logic ;
  signal N_126_0 : std_logic ;
  signal N_127_0 : std_logic ;
  signal N_128_0 : std_logic ;
  signal N_129_0 : std_logic ;
  signal N_130_0 : std_logic ;
  signal N_131_0 : std_logic ;
  signal N_132_0 : std_logic ;
  signal N_133_0 : std_logic ;
  signal N_134_0 : std_logic ;
  signal N_135_0 : std_logic ;
  signal N_136_0 : std_logic ;
  signal N_137_0 : std_logic ;
  signal N_138_0 : std_logic ;
  signal N_139_0 : std_logic ;
  signal N_140_0 : std_logic ;
  signal N_141_0 : std_logic ;
  signal N_142_0 : std_logic ;
  signal N_143_0 : std_logic ;
  signal N_144_0 : std_logic ;
  signal N_145_0 : std_logic ;
  signal N_146_0 : std_logic ;
  signal N_147_0 : std_logic ;
  signal N_148_0 : std_logic ;
  signal N_149_0 : std_logic ;
  signal N_150_0 : std_logic ;
  signal N_151_0 : std_logic ;
  signal N_152_0 : std_logic ;
  signal N_153_0 : std_logic ;
  signal N_154_0 : std_logic ;
  signal N_155_0 : std_logic ;
  signal N_156_0 : std_logic ;
  signal N_157_0 : std_logic ;
  signal N_158_0 : std_logic ;
  signal N_159_0 : std_logic ;
  signal N_160_0 : std_logic ;
  signal N_161_0 : std_logic ;
  signal N_162_0 : std_logic ;
  signal N_163_0 : std_logic ;
  signal N_627 : std_logic ;
  signal N_628 : std_logic ;
  signal N_629 : std_logic ;
  signal N_630 : std_logic ;
  signal N_631 : std_logic ;
  signal N_632 : std_logic ;
  signal N_633 : std_logic ;
  signal N_634 : std_logic ;
  signal N_635 : std_logic ;
  signal N_636 : std_logic ;
  signal N_637 : std_logic ;
  signal N_638 : std_logic ;
  signal N_639 : std_logic ;
  signal N_640 : std_logic ;
  signal N_641 : std_logic ;
  signal N_642 : std_logic ;
  signal N_643 : std_logic ;
  signal N_644 : std_logic ;
  signal N_645 : std_logic ;
  signal N_646 : std_logic ;
  signal N_647 : std_logic ;
  signal N_648 : std_logic ;
  signal N_649 : std_logic ;
  signal N_650 : std_logic ;
  signal N_651 : std_logic ;
  signal N_652 : std_logic ;
  signal N_653 : std_logic ;
  signal N_654 : std_logic ;
  signal N_655 : std_logic ;
  signal N_656 : std_logic ;
  signal N_657 : std_logic ;
  signal N_658 : std_logic ;
  signal N_659 : std_logic ;
  signal N_660 : std_logic ;
  signal N_661 : std_logic ;
  signal N_662 : std_logic ;
  signal N_663 : std_logic ;
  signal N_664 : std_logic ;
  signal N_665 : std_logic ;
  signal N_666 : std_logic ;
  signal N_667 : std_logic ;
  signal N_668 : std_logic ;
  signal N_669 : std_logic ;
  signal N_670 : std_logic ;
  signal N_671 : std_logic ;
  signal N_672 : std_logic ;
  signal N_673 : std_logic ;
  signal N_674 : std_logic ;
  signal N_675 : std_logic ;
  signal N_676 : std_logic ;
  signal N_677 : std_logic ;
  signal N_678 : std_logic ;
  signal N_679 : std_logic ;
  signal N_680 : std_logic ;
  signal N_681 : std_logic ;
  signal N_682 : std_logic ;
  signal N_683 : std_logic ;
  signal N_684 : std_logic ;
  signal N_685 : std_logic ;
  signal N_686 : std_logic ;
  signal N_687 : std_logic ;
  signal N_688 : std_logic ;
  signal N_689 : std_logic ;
  signal N_690 : std_logic ;
  signal N_691 : std_logic ;
  signal N_692 : std_logic ;
  signal N_693 : std_logic ;
  signal N_694 : std_logic ;
  signal N_695 : std_logic ;
  signal N_696 : std_logic ;
  signal N_697 : std_logic ;
  signal N_698 : std_logic ;
  signal N_699 : std_logic ;
  signal N_700 : std_logic ;
  signal N_701 : std_logic ;
  signal N_702 : std_logic ;
  signal N_703 : std_logic ;
  signal N_704 : std_logic ;
  signal N_705 : std_logic ;
  signal N_706 : std_logic ;
  signal N_707 : std_logic ;
  signal N_708 : std_logic ;
  signal N_709 : std_logic ;
  signal N_710 : std_logic ;
  signal N_711 : std_logic ;
  signal N_712 : std_logic ;
  signal N_713 : std_logic ;
  signal N_714 : std_logic ;
  signal N_715 : std_logic ;
  signal N_716 : std_logic ;
  signal N_717 : std_logic ;
  signal N_718 : std_logic ;
  signal N_719 : std_logic ;
  signal N_720 : std_logic ;
  signal N_721 : std_logic ;
  signal N_722 : std_logic ;
  signal N_723 : std_logic ;
  signal N_724 : std_logic ;
  signal N_725 : std_logic ;
  signal N_726 : std_logic ;
  signal N_727 : std_logic ;
  signal N_728 : std_logic ;
  signal N_729 : std_logic ;
  signal N_730 : std_logic ;
  signal N_731 : std_logic ;
  signal N_732 : std_logic ;
  signal N_733 : std_logic ;
  signal N_734 : std_logic ;
  signal N_735 : std_logic ;
  signal N_736 : std_logic ;
  signal N_737 : std_logic ;
  signal N_738 : std_logic ;
  signal N_739 : std_logic ;
  signal N_740 : std_logic ;
  signal N_741 : std_logic ;
  signal N_742 : std_logic ;
  signal N_743 : std_logic ;
  signal N_744 : std_logic ;
  signal N_745 : std_logic ;
  signal N_746 : std_logic ;
  signal N_747 : std_logic ;
  signal N_748 : std_logic ;
  signal N_749 : std_logic ;
  signal N_750 : std_logic ;
  signal N_751 : std_logic ;
  signal N_752 : std_logic ;
  signal N_753 : std_logic ;
  signal N_754 : std_logic ;
  signal CPO_EXCZ : std_logic ;
  signal CPO_CCVZ : std_logic ;
  signal CPO_LDLOCKZ : std_logic ;
  signal RFI1_REN1Z : std_logic ;
  signal RFI1_REN2Z : std_logic ;
  signal RFI1_WRENZ : std_logic ;
  signal RFI2_REN1Z : std_logic ;
  signal RFI2_REN2Z : std_logic ;
  signal RFI2_WRENZ : std_logic ;
begin
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_1\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(0),
datad => \FPI.OP1_RETO\(0),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => GND);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_2\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(1),
datad => \FPI.OP1_RETO\(1),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_0\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_3\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_2\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(2),
datad => \FPI.OP1_RETO\(2),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_1\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_4\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_3\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(3),
datad => \FPI.OP1_RETO\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_2\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_5\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_4\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(4),
datad => \FPI.OP1_RETO\(4),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_3\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_6\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_5\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(5),
datad => \FPI.OP1_RETO\(5),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_4\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_8\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_6\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(6),
datad => \FPI.OP1_RETO\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_5\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_9\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_7\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(7),
datad => \FPI.OP1_RETO\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_6\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_10\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_8\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(8),
datad => \FPI.OP1_RETO\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_7\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_11\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_9\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(9),
datad => \FPI.OP1_RETO\(9),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_8\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_12\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_10\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(10),
datad => \FPI.OP1_RETO\(10),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_9\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_14\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_11\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(11),
datad => \FPI.OP1_RETO\(11),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_10\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_15\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_12\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(12),
datad => \FPI.OP1_RETO\(12),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_11\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_16\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_13\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(13),
datad => \FPI.OP1_RETO\(13),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_12\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_17\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_14\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(14),
datad => \FPI.OP1_RETO\(14),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_13\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_18\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_15\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(15),
datad => \FPI.OP1_RETO\(15),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_14\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_20\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_16\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(16),
datad => \FPI.OP1_RETO\(16),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_15\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_21\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_17\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(17),
datad => \FPI.OP1_RETO\(17),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_16\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_22\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_18\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(18),
datad => \FPI.OP1_RETO\(18),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_17\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_23\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_19\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(19),
datad => \FPI.OP1_RETO\(19),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_18\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_24\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_20\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(20),
datad => \FPI.OP1_RETO\(20),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_19\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_26\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_21\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(21),
datad => \FPI.OP1_RETO\(21),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_20\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_27\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_22\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(22),
datad => \FPI.OP1_RETO\(22),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_21\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_28\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_23\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(23),
datad => \FPI.OP1_RETO\(23),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_22\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_29\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_24\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(24),
datad => \FPI.OP1_RETO\(24),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_23\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_26: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_30\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_25\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(25),
datad => \FPI.OP1_RETO\(25),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_24\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_32\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_26\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(26),
datad => \FPI.OP1_RETO\(26),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_25\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_28: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_33\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_27\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(27),
datad => \FPI.OP1_RETO\(27),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_26\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_29: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_34\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_28\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(28),
datad => \FPI.OP1_RETO\(28),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_27\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_30: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_35\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_29\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(29),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(29),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_28\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_31: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_36\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_30\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(30),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(30),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_29\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_32: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_38\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_31\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(31),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(31),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_30\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_33: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_39\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_32\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(32),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_31\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_34: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_40\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_33\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(33),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(33),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_32\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_35: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_41\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_34\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(34),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(34),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_33\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_36: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_42\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_35\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(35),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(35),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_34\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_37: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_44\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_36\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(36),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_35\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_38: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_45\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_37\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(37),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(37),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_36\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_39: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_46\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_38\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(38),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(38),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_37\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_40: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_47\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_39\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(39),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(39),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_38\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_41: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_48\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_40\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(40),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(40),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_39\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_42: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_50\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_41\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(41),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(41),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_40\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_43: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_51\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_42\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(42),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(42),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_41\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_44: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_52\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_43\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(43),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(43),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_42\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_45: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_53\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_44\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(44),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(44),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_43\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_46: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_54\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_45\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(45),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(45),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_44\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_47: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_56\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_46\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(46),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(46),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_45\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_48: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_57\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_47\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(47),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(47),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_46\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_49: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_58\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_48\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(48),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(48),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_47\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_50: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_59\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_49\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(49),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_48\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_51: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_60\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_50\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(50),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(50),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_49\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_52: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_62\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_51\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(51),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(51),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_50\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_53: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_63\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_52\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(52),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(52),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_51\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_54: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_64\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_53\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(53),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(53),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_52\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_55: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_65\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_54\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(54),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(54),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_53\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_56: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_66\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_55\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(55),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(55),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_54\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_57: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_68\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_56\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(56),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(56),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_55\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_58: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_69\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_57\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(57),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(57),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_56\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_59: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_70\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_58\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(58),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(58),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_57\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_60: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_71\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_59\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(59),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_58\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_61: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_72\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_60\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(60),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_59\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_62: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_74\,
cout => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_61\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(61),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(61),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_60\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_63: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2.N_75\,
cout => N_80138,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(62),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(62),
cin => \GRFPU0.GRFPU_X0.COMB.LESS2.LT_61\);
VCC <= '1';
GND <= '0';
\GRFPU0_GRFPU_X0_S3ADDI_0_RNICUQQ4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(0),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.N_14488\,
datad => N_82253,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(3),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => GND);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIEDGT5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(1),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_1\,
datad => N_80158,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(4),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_0\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIIS507_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(2),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_2\,
datad => N_80159,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(5),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_1\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIOBR28_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(3),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_3\,
datad => N_80163,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(6),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_2\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNI0RG59_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(4),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_4\,
datad => N_80164,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_3\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIAA68A_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(5),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_5\,
datad => N_80167,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(8),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_4\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIMPRAB_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(6),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_6\,
datad => N_80168,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(9),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_5\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIB6TDC_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(7),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_7\,
datad => N_80171,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(10),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_6\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNI2NUGD_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(8),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_8\,
datad => N_80172,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(11),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_7\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIRB0KE_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(9),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_9\,
datad => N_80175,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(12),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_8\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIT580G_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(10),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_10\,
datad => N_80176,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(13),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_9\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNI18GCH_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(11),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_11\,
datad => N_80179,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(14),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_10\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNI7IOOI_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(12),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_12\,
datad => N_80180,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(15),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_11\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIF415K_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(13),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_13\,
datad => N_80183,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(16),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_12\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIPU9HL_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(14),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_14\,
datad => N_80184,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(17),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_13\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNI51JTM_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(15),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_15\,
datad => N_80187,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(18),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_14\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIJBS9O_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(16),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_16\,
datad => N_80188,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(19),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_15\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIQL4MP_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(17),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_17\,
datad => N_80191,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(20),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_16\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNI38D2R_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(18),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_18\,
datad => N_80192,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(21),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_17\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIE2MES_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(19),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_19\,
datad => N_80195,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(22),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_18\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIISTQT_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(20),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_20\,
datad => N_80196,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(23),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_19\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIOU57V_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(21),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_21\,
datad => N_80199,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(24),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_20\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNI09EJ01_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(22),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_22\,
datad => N_80200,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(25),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_21\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIARMV11_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(23),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_23\,
datad => N_80203,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(26),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_22\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIMLVB31_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(24),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_24\,
datad => N_80204,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(27),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_23\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNI4O8O41_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(25),
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_25\,
datad => N_80207,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(28),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_24\);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIK2I461_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f0cc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(26),
cout => N_80134,
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(29),
datab => N_80208,
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_25\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNITMEF3_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => N_28226,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.S3ADDI\(28),
datad => \GRFPU0.GRFPU_X0.N_14515\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(30),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => GND);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIJG0H4_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28228,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_2\,
datad => \GRFPU0.GRFPU_X0.N_14517\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(32),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_1\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI2AHI5_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28230,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_3\,
datad => \GRFPU0.GRFPU_X0.N_14518\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(33),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_2\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIJB2K6_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28232,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_4\,
datad => \GRFPU0.GRFPU_X0.N_14519\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(34),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_3\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI6LJL7_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28234,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_5\,
datad => \GRFPU0.GRFPU_X0.N_14520\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(35),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_4\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIR65N8_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28236,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_6\,
datad => \GRFPU0.GRFPU_X0.N_14521\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(36),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_5\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNII0NO9_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28238,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_7\,
datad => \GRFPU0.GRFPU_X0.N_14522\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(37),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_6\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIB29QA_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28240,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_8\,
datad => \GRFPU0.GRFPU_X0.N_14523\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(38),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_7\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI6CRRB_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28242,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_9\,
datad => \GRFPU0.GRFPU_X0.N_14524\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(39),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_8\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIQLCTC_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28244,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_10\,
datad => \GRFPU0.GRFPU_X0.N_14525\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(40),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_9\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIG7UUD_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28246,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_11\,
datad => \GRFPU0.GRFPU_X0.N_14526\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(41),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_10\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI81G0F_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28248,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_12\,
datad => \GRFPU0.GRFPU_X0.N_14527\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(42),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_11\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIPQ02G_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28250,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_13\,
datad => \GRFPU0.GRFPU_X0.N_14528\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(43),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_12\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNICSH3H_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28252,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_14\,
datad => \GRFPU0.GRFPU_X0.N_14529\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(44),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_13\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI1635I_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28254,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_15\,
datad => \GRFPU0.GRFPU_X0.N_14530\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(45),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_14\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIONK6J_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28256,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_16\,
datad => \GRFPU0.GRFPU_X0.N_14531\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(46),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_15\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIHH68K_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28258,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_17\,
datad => \GRFPU0.GRFPU_X0.N_14532\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(47),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_16\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNICJO9L_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28260,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_18\,
datad => \GRFPU0.GRFPU_X0.N_14533\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(48),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_17\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI9TABM_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28262,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_19\,
datad => \GRFPU0.GRFPU_X0.N_14534\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(49),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_18\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIV6SCN_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28264,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_20\,
datad => \GRFPU0.GRFPU_X0.N_14535\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(50),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_19\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNINODEO_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28266,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_21\,
datad => \GRFPU0.GRFPU_X0.N_14536\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(51),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_20\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIHIVFP_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28268,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_22\,
datad => \GRFPU0.GRFPU_X0.N_14537\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(52),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_21\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNI4CGHQ_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28270,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_23\,
datad => \GRFPU0.GRFPU_X0.N_14538\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(53),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_22\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIPD1JR_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => N_28272,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_24\,
datad => \GRFPU0.GRFPU_X0.N_14539\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_23\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIPD1JR_0_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28274,
cout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_25\,
datad => VCC,
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_24\);
\GRFPU0_GRFPU_X0_S3ADDI_0_RNIPD1JR_1_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => N_28276,
cout => N_22,
cin => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_0_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_36: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(36),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_36\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(0),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(36),
cin => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_37: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(37),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_37\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(1),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(37),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_36\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_38: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(38),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_38\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(2),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(38),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_37\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_39: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(39),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_39\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(3),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(39),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_38\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_40: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(40),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_40\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(4),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(40),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_39\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_41: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(41),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_41\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(5),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(41),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_40\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_42: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(42),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_42\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(6),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(42),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_41\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_43: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(43),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_43\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(7),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(43),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_42\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_44: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(44),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_44\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(8),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(44),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_43\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_45: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(45),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_45\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(9),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(45),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_44\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_46: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(46),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_46\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(10),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(46),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_45\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_47: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(47),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_47\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(11),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(47),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_46\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_48: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(48),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_48\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(12),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(48),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_47\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_49: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(49),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_49\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(13),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(49),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_48\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_50: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(50),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_50\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(14),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(50),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_49\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_51: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(51),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_51\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(15),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(51),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_50\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_52: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(52),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_52\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(16),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(52),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_51\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_53: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(53),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_53\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(17),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(53),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_52\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_54: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(54),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_54\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(18),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(54),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_53\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_55: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(55),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_55\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(19),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(55),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_54\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_56: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(56),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_56\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(20),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(56),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_55\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_57: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(57),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_57\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(21),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(57),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_56\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_58: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(58),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_58\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(22),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(58),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_57\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_59: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(59),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_59\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(23),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(59),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_58\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_60: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(60),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_60\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(24),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(60),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_59\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_61: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(61),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_61\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(25),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(61),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_60\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_62: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(62),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_62\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(26),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(62),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_61\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_63: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(63),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_63\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(27),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(63),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_62\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_64: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(64),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_64\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(28),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(64),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_63\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_65: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(65),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_65\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(29),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(65),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_64\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_66: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(66),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_66\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(30),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(66),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_65\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_67: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(67),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_67\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(31),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(67),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_66\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_68: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(68),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_68\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(32),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(68),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_67\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_69: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(69),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_69\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(33),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(69),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_68\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_70: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(70),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_70\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(34),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(70),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_69\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_71: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(71),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_71\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(35),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(71),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_70\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_72: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(72),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_72\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(36),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_71\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_73: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(73),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_73\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(37),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_72\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_74: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(74),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_74\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(38),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_73\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_75: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(75),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_75\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(39),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_74\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_76: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(76),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_76\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(40),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_75\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_77: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(77),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_77\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(41),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_76\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_78: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(78),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_78\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(42),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_77\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_79: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(79),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_79\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(43),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_78\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_80: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(80),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_80\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(44),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_79\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_81: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(81),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_81\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(45),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_80\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_82: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(82),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_82\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(46),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_81\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_83: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(83),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_83\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(47),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_82\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_84: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(84),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_84\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(48),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_83\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_85: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(85),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_85\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(49),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_84\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_86: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(86),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_86\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(50),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_85\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_87: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(87),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_87\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(51),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_86\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_88: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(88),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_88\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(52),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_87\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_89: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(89),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_89\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(53),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_88\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_90: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(90),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_90\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(54),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_89\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_91: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(91),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_91\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(55),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_90\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_92: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(92),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_92\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(56),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_91\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_93: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(93),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_93\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(57),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_92\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_94: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(94),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_94\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(58),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_93\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_95: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(95),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_95\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(59),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_94\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_A_CARRY_96: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(96),
cout => N_23,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(60),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_A_CARRY_95\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(72),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_0\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(72),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(72),
cin => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(73),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_1\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(73),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(73),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(74),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_2\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(74),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(74),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_1\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(75),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_3\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(75),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(75),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_2\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(76),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_4\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(76),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(76),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_3\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(77),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_5\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(77),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(77),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_4\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(78),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_6\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(78),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(78),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_5\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(79),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_7\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(79),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(79),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_6\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(80),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_8\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(80),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(80),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_7\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(81),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_9\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(81),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(81),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_8\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(82),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_10\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(82),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(82),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_9\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(83),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_11\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(83),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(83),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_10\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(84),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_12\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(84),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(84),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_11\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(85),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_13\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(85),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(85),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_12\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(86),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_14\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(86),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(86),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_13\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(87),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_15\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(87),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(87),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_14\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(88),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_16\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(88),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(88),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_15\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(89),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_17\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(89),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(89),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_16\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(90),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_18\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(90),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(90),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_17\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(91),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_19\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(91),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(91),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_18\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(92),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_20\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(92),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(92),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_19\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(93),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_21\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(93),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(93),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_20\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(94),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_22\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(94),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(94),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_21\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(95),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_23\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(95),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(95),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_22\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(96),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_24\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(96),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(96),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_23\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(97),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_25\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(97),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(25),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_24\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_26: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(98),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_26\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(26),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(99),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_27\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(27),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_26\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_28: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(100),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_28\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(28),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_27\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_29: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(101),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_29\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(29),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_28\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_30: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(102),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_30\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(30),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_29\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_31: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(103),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_31\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(31),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_30\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_32: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(104),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_32\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(32),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_31\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_33: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(105),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_33\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(33),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_32\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_34: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(106),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_34\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(34),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_33\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_35: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(107),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_35\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(35),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_34\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_36: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(108),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_36\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(36),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_35\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_37: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(109),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_37\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(37),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_36\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_38: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(110),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_38\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(38),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_37\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_39: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(111),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_39\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(39),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_38\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_40: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(112),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_40\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(40),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_39\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_41: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(113),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_41\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(41),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_40\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_42: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(114),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_42\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(42),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_41\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_43: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(115),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_43\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(43),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_42\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_44: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(116),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_44\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(44),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_43\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_45: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(117),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_45\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(45),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_44\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_46: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(118),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_46\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(46),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_45\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_47: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(119),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_47\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(47),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_46\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_48: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(120),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_48\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(48),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_47\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_CARRY_49: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(121),
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(49),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_CARRY_48\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(36),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_0\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(0),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(36),
cin => GND);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(37),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_1\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(1),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(37),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_0\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(38),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_2\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(2),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(38),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_1\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(39),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_3\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(3),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(39),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_2\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(40),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_4\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(4),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(40),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_3\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(41),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_5\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(5),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(41),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_4\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(42),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_6\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(6),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(42),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_5\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(43),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_7\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(7),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(43),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_6\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(44),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_8\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(8),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(44),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_7\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(45),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_9\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(9),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(45),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_8\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(46),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_10\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(10),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(46),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_9\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(47),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_11\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(11),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(47),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_10\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(48),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_12\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(12),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(48),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_11\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(49),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_13\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(13),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(49),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_12\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(50),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_14\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(14),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(50),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_13\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(51),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_15\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(15),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(51),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_14\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(52),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_16\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(16),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(52),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_15\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(53),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_17\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(17),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(53),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_16\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(54),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_18\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(18),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(54),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_17\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(55),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_19\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(19),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(55),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_18\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(56),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_20\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(20),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(56),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_19\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(57),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_21\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(21),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(57),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_20\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(58),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_22\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(22),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(58),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_21\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(59),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_23\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(23),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(59),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_22\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(60),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_24\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(24),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(60),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_23\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(61),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_25\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(25),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(61),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_24\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_26: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(62),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_26\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(26),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(62),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_25\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(63),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_27\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(27),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(63),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_26\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_28: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(64),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_28\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(28),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(64),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_27\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_29: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(65),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_29\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(29),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(65),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_28\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_30: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(66),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_30\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(30),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(66),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_29\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_31: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(67),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_31\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(31),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(67),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_30\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_32: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(68),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_32\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(32),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(68),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_31\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_33: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(69),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_33\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(33),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(69),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_32\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_34: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(70),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_34\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(34),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(70),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_33\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_35: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(71),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_35\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(35),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML\(71),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_34\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_36: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(72),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_36\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(36),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(0),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_35\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_37: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(73),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_37\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(37),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(1),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_36\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_38: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(74),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_38\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(38),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(2),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_37\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_39: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(75),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_39\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(39),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(3),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_38\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_40: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(76),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_40\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(40),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(4),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_39\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_41: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(77),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_41\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(41),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(5),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_40\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_42: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(78),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_42\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(42),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(6),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_41\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_43: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(79),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_43\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(43),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(7),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_42\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_44: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(80),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_44\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(44),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(8),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_43\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_45: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(81),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_45\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(45),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(9),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_44\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_46: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(82),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_46\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(46),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(10),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_45\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_47: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(83),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_47\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(47),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(11),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_46\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_48: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(84),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_48\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(48),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(12),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_47\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_49: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(85),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_49\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(49),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(13),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_48\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_50: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(86),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_50\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(50),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(14),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_49\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_51: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(87),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_51\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(51),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(15),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_50\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_52: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(88),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_52\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(52),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(16),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_51\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_53: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(89),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_53\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(53),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(17),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_52\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_54: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(90),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_54\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(54),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(18),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_53\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_55: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(91),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_55\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(55),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(19),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_54\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_56: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(92),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_56\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(56),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(20),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_55\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_57: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(93),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_57\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(57),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(21),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_56\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_58: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(94),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_58\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(58),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(22),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_57\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_59: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(95),
cout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_59\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(59),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(23),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_58\);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_60: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(96),
cout => N_80128,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(60),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(24),
cin => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0_CARRY_59\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_0\,
dataf => \GRFPU0.FPMUL0.CS_ITER_R\,
datad => \GRFPU0.MULO.MRES\(65),
cin => GND);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(66),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_1\,
datad => \GRFPU0.MULO.MRES_1\(66),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_0\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(67),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_2\,
datad => \GRFPU0.MULO.MRES_1\(67),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_1\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(68),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_3\,
datad => \GRFPU0.MULO.MRES_1S\(68),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_2\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(69),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_4\,
datad => \GRFPU0.FPMUL0.SX\(69),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_3\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(70),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_5\,
datad => \GRFPU0.FPMUL0.SX\(70),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_4\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(71),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_6\,
datad => \GRFPU0.FPMUL0.SX\(71),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_5\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(72),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_7\,
datad => \GRFPU0.FPMUL0.SX\(72),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_6\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(73),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_8\,
datad => \GRFPU0.FPMUL0.SX\(73),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_7\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(74),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_9\,
datad => \GRFPU0.FPMUL0.SX\(74),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_8\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(75),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_10\,
datad => \GRFPU0.FPMUL0.SX\(75),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_9\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(76),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_11\,
datad => \GRFPU0.FPMUL0.SX\(76),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_10\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(77),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_12\,
datad => \GRFPU0.FPMUL0.SX\(77),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_11\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(78),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_13\,
datad => \GRFPU0.FPMUL0.SX\(78),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_12\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(79),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_14\,
datad => \GRFPU0.FPMUL0.SX\(79),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_13\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(80),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_15\,
datad => \GRFPU0.FPMUL0.SX\(80),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_14\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(81),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_16\,
datad => \GRFPU0.FPMUL0.SX\(81),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_15\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(82),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_17\,
datad => \GRFPU0.FPMUL0.SX\(82),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_16\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(83),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_18\,
datad => \GRFPU0.FPMUL0.SX\(83),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_17\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(84),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_19\,
datad => \GRFPU0.FPMUL0.SX\(84),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_18\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(85),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_20\,
datad => \GRFPU0.FPMUL0.SX\(85),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_19\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(86),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_21\,
datad => \GRFPU0.FPMUL0.SX\(86),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_20\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(87),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_22\,
datad => \GRFPU0.FPMUL0.SX\(87),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_21\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(88),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_23\,
datad => \GRFPU0.FPMUL0.SX\(88),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_22\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(89),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_24\,
datad => \GRFPU0.FPMUL0.SX\(89),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_23\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(90),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_25\,
datad => \GRFPU0.FPMUL0.SX\(90),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_24\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_26: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(91),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\,
datad => \GRFPU0.FPMUL0.SX\(91),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_25\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(92),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(92),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_26\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_28: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(93),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_28\,
datad => \GRFPU0.FPMUL0.SX\(93),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_27\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_29: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(94),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_29\,
datad => \GRFPU0.FPMUL0.SX\(94),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_28\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_30: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(95),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_30\,
datad => \GRFPU0.FPMUL0.SX\(95),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_29\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_31: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(96),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_31\,
datad => \GRFPU0.FPMUL0.SX\(96),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_30\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_32: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(97),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_32\,
datad => \GRFPU0.FPMUL0.SX\(97),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_31\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_33: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(98),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_33\,
datad => \GRFPU0.FPMUL0.SX\(98),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_32\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_34: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(99),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_34\,
datad => \GRFPU0.FPMUL0.SX\(99),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_33\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_35: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(100),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_35\,
datad => \GRFPU0.FPMUL0.SX\(100),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_34\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_36: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(101),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_36\,
datad => \GRFPU0.FPMUL0.SX\(101),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_35\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_37: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(102),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_37\,
datad => \GRFPU0.FPMUL0.SX\(102),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_36\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_38: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(103),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_38\,
datad => \GRFPU0.FPMUL0.SX\(103),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_37\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_39: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(104),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_39\,
datad => \GRFPU0.FPMUL0.SX\(104),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_38\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_40: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(105),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_40\,
datad => \GRFPU0.FPMUL0.SX\(105),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_39\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_41: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(106),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_41\,
datad => \GRFPU0.FPMUL0.SX\(106),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_40\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_42: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(107),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_42\,
datad => \GRFPU0.FPMUL0.SX\(107),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_41\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_43: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(108),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_43\,
datad => \GRFPU0.FPMUL0.SX\(108),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_42\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_44: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(109),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_44\,
datad => \GRFPU0.FPMUL0.SX\(109),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_43\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_45: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(110),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_45\,
datad => \GRFPU0.FPMUL0.SX\(110),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_44\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_46: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(111),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_46\,
datad => \GRFPU0.FPMUL0.SX\(111),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_45\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_47: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(112),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_47\,
datad => \GRFPU0.FPMUL0.SX\(112),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_46\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_48: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(113),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_48\,
datad => \GRFPU0.FPMUL0.SX\(113),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_47\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_49: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(114),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_49\,
datad => \GRFPU0.FPMUL0.SX\(114),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_48\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_50: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(115),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_50\,
datad => \GRFPU0.FPMUL0.SX\(115),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_49\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_51: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(116),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_51\,
datad => \GRFPU0.FPMUL0.SX\(116),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_50\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_52: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(117),
cout => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_52\,
datad => \GRFPU0.FPMUL0.SX\(117),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_51\);
GRFPU0_FPMUL0_UN1_SIN_1_CARRY_53: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_S\(118),
cout => N_24,
datad => \GRFPU0.FPMUL0.SX\(118),
cin => \GRFPU0.FPMUL0.UN1_SIN_1_CARRY_52\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_0\,
dataf => \GRFPU0.FPMUL0.CS_DP_R\,
datad => \GRFPU0.MULO.MRES_1S\(68),
cin => GND);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(69),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_1\,
datad => \GRFPU0.FPMUL0.SX\(69),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_0\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(70),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_2\,
datad => \GRFPU0.FPMUL0.SX\(70),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_1\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(71),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_3\,
datad => \GRFPU0.FPMUL0.SX\(71),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_2\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(72),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_4\,
datad => \GRFPU0.FPMUL0.SX\(72),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_3\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(73),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_5\,
datad => \GRFPU0.FPMUL0.SX\(73),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_4\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(74),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_6\,
datad => \GRFPU0.FPMUL0.SX\(74),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_5\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(75),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_7\,
datad => \GRFPU0.FPMUL0.SX\(75),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_6\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(76),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_8\,
datad => \GRFPU0.FPMUL0.SX\(76),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_7\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(77),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_9\,
datad => \GRFPU0.FPMUL0.SX\(77),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_8\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(78),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_10\,
datad => \GRFPU0.FPMUL0.SX\(78),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_9\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(79),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_11\,
datad => \GRFPU0.FPMUL0.SX\(79),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_10\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(80),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_12\,
datad => \GRFPU0.FPMUL0.SX\(80),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_11\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(81),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_13\,
datad => \GRFPU0.FPMUL0.SX\(81),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_12\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(82),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_14\,
datad => \GRFPU0.FPMUL0.SX\(82),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_13\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(83),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_15\,
datad => \GRFPU0.FPMUL0.SX\(83),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_14\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(84),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_16\,
datad => \GRFPU0.FPMUL0.SX\(84),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_15\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(85),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_17\,
datad => \GRFPU0.FPMUL0.SX\(85),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_16\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(86),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_18\,
datad => \GRFPU0.FPMUL0.SX\(86),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_17\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(87),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_19\,
datad => \GRFPU0.FPMUL0.SX\(87),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_18\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(88),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_20\,
datad => \GRFPU0.FPMUL0.SX\(88),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_19\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(89),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_21\,
datad => \GRFPU0.FPMUL0.SX\(89),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_20\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(90),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_22\,
datad => \GRFPU0.FPMUL0.SX\(90),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_21\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(91),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_23\,
datad => \GRFPU0.FPMUL0.SX\(91),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_22\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(92),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_24\,
datad => \GRFPU0.FPMUL0.SX\(92),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_23\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(93),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_25\,
datad => \GRFPU0.FPMUL0.SX\(93),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_24\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_26: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(94),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\,
datad => \GRFPU0.FPMUL0.SX\(94),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_25\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(95),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(95),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_26\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_28: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(96),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_28\,
datad => \GRFPU0.FPMUL0.SX\(96),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_27\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_29: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f00f")
port map (
sumout => \GRFPU0.MULO.MRES_1\(97),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_29\,
datad => \GRFPU0.FPMUL0.SX\(97),
datac => \GRFPU0.FPMUL0.CS_DP_R\,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_28\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_30: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(98),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_30\,
dataf => \GRFPU0.FPMUL0.SX\(97),
datad => \GRFPU0.FPMUL0.SX\(98),
datac => \GRFPU0.FPMUL0.CS_DP_R\,
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_29\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_31: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(99),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_31\,
datad => \GRFPU0.FPMUL0.SX\(99),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_30\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_32: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(100),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_32\,
datad => \GRFPU0.FPMUL0.SX\(100),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_31\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_33: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(101),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_33\,
datad => \GRFPU0.FPMUL0.SX\(101),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_32\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_34: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(102),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_34\,
datad => \GRFPU0.FPMUL0.SX\(102),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_33\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_35: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(103),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_35\,
datad => \GRFPU0.FPMUL0.SX\(103),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_34\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_36: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(104),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_36\,
datad => \GRFPU0.FPMUL0.SX\(104),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_35\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_37: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(105),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_37\,
datad => \GRFPU0.FPMUL0.SX\(105),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_36\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_38: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(106),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_38\,
datad => \GRFPU0.FPMUL0.SX\(106),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_37\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_39: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(107),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_39\,
datad => \GRFPU0.FPMUL0.SX\(107),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_38\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_40: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(108),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_40\,
datad => \GRFPU0.FPMUL0.SX\(108),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_39\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_41: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(109),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_41\,
datad => \GRFPU0.FPMUL0.SX\(109),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_40\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_42: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(110),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_42\,
datad => \GRFPU0.FPMUL0.SX\(110),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_41\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_43: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(111),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_43\,
datad => \GRFPU0.FPMUL0.SX\(111),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_42\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_44: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(112),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_44\,
datad => \GRFPU0.FPMUL0.SX\(112),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_43\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_45: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(113),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_45\,
datad => \GRFPU0.FPMUL0.SX\(113),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_44\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_46: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(114),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_46\,
datad => \GRFPU0.FPMUL0.SX\(114),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_45\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_47: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(115),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_47\,
datad => \GRFPU0.FPMUL0.SX\(115),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_46\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_48: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(116),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_48\,
datad => \GRFPU0.FPMUL0.SX\(116),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_47\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_49: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(117),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_49\,
datad => \GRFPU0.FPMUL0.SX\(117),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_48\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_50: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(118),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_50\,
datad => \GRFPU0.FPMUL0.SX\(118),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_49\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_51: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(119),
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_51\,
datad => \GRFPU0.FPMUL0.SX\(119),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_50\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_52: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_52\,
datad => \GRFPU0.FPMUL0.SX\(120),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_51\);
GRFPU0_FPMUL0_UN2_MSUM1_I_CARRY_53: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1\(121),
datad => \GRFPU0.FPMUL0.SX\(121),
cin => \GRFPU0.FPMUL0.UN2_MSUM1_I_CARRY_52\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(69),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_0\,
dataf => \GRFPU0.FPMUL0.CS_DP_R\,
datad => \GRFPU0.FPMUL0.SX\(69),
cin => GND);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(70),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_1\,
datad => \GRFPU0.FPMUL0.SX\(70),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_0\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(71),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_2\,
datad => \GRFPU0.FPMUL0.SX\(71),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_1\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(72),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_3\,
datad => \GRFPU0.FPMUL0.SX\(72),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_2\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(73),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_4\,
datad => \GRFPU0.FPMUL0.SX\(73),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_3\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(74),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_5\,
datad => \GRFPU0.FPMUL0.SX\(74),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_4\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(75),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_6\,
datad => \GRFPU0.FPMUL0.SX\(75),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_5\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(76),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_7\,
datad => \GRFPU0.FPMUL0.SX\(76),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_6\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(77),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_8\,
datad => \GRFPU0.FPMUL0.SX\(77),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_7\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(78),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_9\,
datad => \GRFPU0.FPMUL0.SX\(78),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_8\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(79),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_10\,
datad => \GRFPU0.FPMUL0.SX\(79),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_9\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(80),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_11\,
datad => \GRFPU0.FPMUL0.SX\(80),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_10\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(81),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_12\,
datad => \GRFPU0.FPMUL0.SX\(81),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_11\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(82),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_13\,
datad => \GRFPU0.FPMUL0.SX\(82),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_12\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(83),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_14\,
datad => \GRFPU0.FPMUL0.SX\(83),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_13\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(84),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_15\,
datad => \GRFPU0.FPMUL0.SX\(84),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_14\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(85),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_16\,
datad => \GRFPU0.FPMUL0.SX\(85),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_15\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(86),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_17\,
datad => \GRFPU0.FPMUL0.SX\(86),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_16\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(87),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_18\,
datad => \GRFPU0.FPMUL0.SX\(87),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_17\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(88),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_19\,
datad => \GRFPU0.FPMUL0.SX\(88),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_18\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(89),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_20\,
datad => \GRFPU0.FPMUL0.SX\(89),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_19\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(90),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_21\,
datad => \GRFPU0.FPMUL0.SX\(90),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_20\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(91),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_22\,
datad => \GRFPU0.FPMUL0.SX\(91),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_21\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(92),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_23\,
datad => \GRFPU0.FPMUL0.SX\(92),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_22\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(93),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_24\,
datad => \GRFPU0.FPMUL0.SX\(93),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_23\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(94),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_25\,
datad => \GRFPU0.FPMUL0.SX\(94),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_24\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_26: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(95),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_26\,
datad => \GRFPU0.FPMUL0.SX\(95),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_25\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(96),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_27\,
datad => \GRFPU0.FPMUL0.SX\(96),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_26\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_28: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(97),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_28\,
datad => \GRFPU0.FPMUL0.SX\(97),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_27\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_29: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f00f")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(98),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_29\,
datad => \GRFPU0.FPMUL0.SX\(98),
datac => \GRFPU0.FPMUL0.CS_DP_R\,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_28\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_30: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(99),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_30\,
dataf => \GRFPU0.FPMUL0.SX\(98),
datad => \GRFPU0.FPMUL0.SX\(99),
datac => \GRFPU0.FPMUL0.CS_DP_R\,
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_29\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_31: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(100),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_31\,
datad => \GRFPU0.FPMUL0.SX\(100),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_30\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_32: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(101),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_32\,
datad => \GRFPU0.FPMUL0.SX\(101),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_31\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_33: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(102),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_33\,
datad => \GRFPU0.FPMUL0.SX\(102),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_32\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_34: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(103),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_34\,
datad => \GRFPU0.FPMUL0.SX\(103),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_33\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_35: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(104),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_35\,
datad => \GRFPU0.FPMUL0.SX\(104),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_34\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_36: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(105),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_36\,
datad => \GRFPU0.FPMUL0.SX\(105),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_35\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_37: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(106),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_37\,
datad => \GRFPU0.FPMUL0.SX\(106),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_36\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_38: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(107),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_38\,
datad => \GRFPU0.FPMUL0.SX\(107),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_37\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_39: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(108),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_39\,
datad => \GRFPU0.FPMUL0.SX\(108),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_38\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_40: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(109),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_40\,
datad => \GRFPU0.FPMUL0.SX\(109),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_39\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_41: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(110),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_41\,
datad => \GRFPU0.FPMUL0.SX\(110),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_40\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_42: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(111),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_42\,
datad => \GRFPU0.FPMUL0.SX\(111),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_41\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_43: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(112),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_43\,
datad => \GRFPU0.FPMUL0.SX\(112),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_42\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_44: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(113),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_44\,
datad => \GRFPU0.FPMUL0.SX\(113),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_43\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_45: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(114),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_45\,
datad => \GRFPU0.FPMUL0.SX\(114),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_44\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_46: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(115),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_46\,
datad => \GRFPU0.FPMUL0.SX\(115),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_45\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_47: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(116),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_47\,
datad => \GRFPU0.FPMUL0.SX\(116),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_46\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_48: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(117),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_48\,
datad => \GRFPU0.FPMUL0.SX\(117),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_47\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_49: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(118),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_49\,
datad => \GRFPU0.FPMUL0.SX\(118),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_48\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_50: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(119),
cout => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_50\,
datad => \GRFPU0.FPMUL0.SX\(119),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_49\);
GRFPU0_FPMUL0_UN2_MSUM2_I_CARRY_51: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_1S\(120),
datad => \GRFPU0.FPMUL0.SX\(120),
cin => \GRFPU0.FPMUL0.UN2_MSUM2_I_CARRY_50\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fff00000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(56),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY\,
datad => \GRFPU0.GRFPU_X0.ST2.GUARDS\(0),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => GND);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(55),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_1\,
datad => \GRFPU0.GRFPU_X0.ST2.GUARDS\(1),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_0\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(54),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(0),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(0),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_1\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(53),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(1),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(1),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_2\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(52),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(2),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(2),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_3\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(51),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_5\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(3),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(3),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_4\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(50),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_6\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(4),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(4),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_5\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(49),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_7\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(5),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(5),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_6\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(48),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_8\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(6),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(6),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_7\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(47),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_9\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(7),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(7),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_8\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(46),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_10\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(8),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(8),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_9\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(45),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_11\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(9),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(9),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_10\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(44),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_12\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(10),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(10),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_11\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(43),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_13\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(11),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(11),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_12\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(42),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_14\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(12),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(12),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_13\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(41),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_15\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(13),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(13),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_14\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(40),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_16\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(14),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(14),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_15\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(39),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_17\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(15),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(15),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_16\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(38),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_18\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(16),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(16),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_17\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(37),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_19\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(17),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(17),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_18\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(36),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_20\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(18),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(18),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_19\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(35),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_21\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(19),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(19),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_20\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(34),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_22\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(20),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_21\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(33),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_23\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(21),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_22\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(32),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_24\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(22),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(22),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_23\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(31),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_25\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(23),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_24\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_26: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(30),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_26\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(24),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_25\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(29),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_27\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(25),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(25),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_26\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_28: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(28),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_28\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(26),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(26),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_27\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_29: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(27),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_29\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(27),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(27),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_28\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_30: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(26),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_30\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(28),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(28),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_29\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_31: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(25),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_31\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(29),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_30\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_32: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(24),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_32\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(30),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_31\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_33: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(23),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_33\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(31),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(31),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_32\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_34: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(22),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_34\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(32),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_33\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_35: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(21),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_35\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(33),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(33),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_34\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_36: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(20),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_36\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(34),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_35\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_37: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(19),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_37\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(35),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(35),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_36\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_38: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(18),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_38\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(36),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_37\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_39: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(17),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_39\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(37),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_38\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_40: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(16),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_40\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(38),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_39\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_41: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(15),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_41\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(39),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(39),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_40\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_42: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(14),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_42\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(40),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_41\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_43: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(13),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_43\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(41),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_42\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_44: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(12),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_44\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(42),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_43\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_45: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(11),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_45\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(43),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_44\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_46: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(10),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_46\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(44),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_45\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_47: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(9),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_47\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(45),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_46\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_48: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(8),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_48\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(46),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_47\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_49: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(7),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_49\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(47),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_48\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_50: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(6),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_50\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(48),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_49\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_51: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(5),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_51\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(49),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(49),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_50\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_52: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(4),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_52\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(50),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(50),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_51\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_53: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(3),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_53\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(51),
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(51),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_52\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_54: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f00f")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(2),
cout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_54\,
dataf => VCC,
datad => \GRFPU0.GRFPU_X0.ST2.SGNF2\(52),
datac => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_53\);
GRFPU0_GRFPU_X0_UN1_ADDSUBI2_CARRY_55: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00003333")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(1),
cout => N_26,
datab => \GRFPU0.GRFPU_X0.ST2.ADD\,
cin => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2_CARRY_54\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000003ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(1),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1\(1),
datad => \GRFPU0.GRFPU_X0.N_14381\,
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => GND);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(2),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_2\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(2),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_1\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(3),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_3\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(3),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_2\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(4),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_4\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(4),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_3\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(5),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_5\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(5),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_4\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(6),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_6\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(6),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_5\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(7),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_7\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(7),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_6\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(8),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_8\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(8),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_7\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(9),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_9\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(9),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_8\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(10),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_10\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(10),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_9\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(11),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_11\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(11),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_10\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(12),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_12\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(12),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_11\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(13),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_13\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(13),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_12\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(14),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_14\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(14),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_13\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(15),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_15\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(15),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_14\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(16),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_16\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(16),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_15\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(17),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_17\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(17),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_16\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(18),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_18\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(18),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_17\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(19),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_19\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(19),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_18\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(20),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_20\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(20),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_19\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(21),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_21\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(21),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_20\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(22),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_22\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(22),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_21\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(23),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_23\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(23),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_22\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(24),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_24\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(24),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_23\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(25),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_25\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(25),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_24\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_26: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(26),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(26),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_25\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(27),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_27\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(27),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_26\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_28: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(28),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_28\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(28),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_27\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_29: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(29),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_29\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(29),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_28\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_30: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(30),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_30\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(30),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_29\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_31: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(31),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_31\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(31),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_30\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_32: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(32),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_32\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(32),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_31\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_33: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(33),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_33\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(33),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_32\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_34: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(34),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_34\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(34),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_33\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_35: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(35),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_35\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(35),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_34\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_36: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(36),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_36\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(36),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_35\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_37: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(37),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_37\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(37),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_36\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_38: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(38),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_38\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(38),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_37\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_39: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(39),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_39\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(39),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_38\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_40: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(40),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_40\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(40),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_39\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_41: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(41),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_41\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(41),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_40\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_42: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(42),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_42\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(42),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_41\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_43: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(43),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_43\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(43),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_42\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_44: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(44),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_44\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(44),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_43\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_45: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(45),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_45\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(45),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_44\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_46: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(46),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_46\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(46),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_45\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_47: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(47),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_47\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(47),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_46\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_48: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(48),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_48\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(48),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_47\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_49: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(49),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_49\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(49),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_48\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_50: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(50),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_50\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(50),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_49\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_51: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(51),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_51\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(51),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_50\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_52: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(52),
cout => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_52\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(52),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_51\);
GRFPU0_GRFPU_X0_UN8_DIFF2_CARRY_53: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_DIFF2\(53),
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(53),
cin => \GRFPU0.GRFPU_X0.UN8_DIFF2_CARRY_52\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(0),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(29),
datac => N_80553,
datab => N_80552,
cin => GND);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(1),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_1\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(30),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_0\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(2),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(31),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_1\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(3),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_3\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(32),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_2\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(4),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_4\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(33),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_3\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(5),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_5\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(34),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_4\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(6),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_6\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(35),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_5\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(7),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_7\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(36),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_6\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(8),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_8\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(37),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_7\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(9),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_9\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(38),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_8\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(10),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_10\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(39),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_9\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(11),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_11\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(40),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_10\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(12),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_12\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(41),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_11\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(13),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_13\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(42),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_12\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(14),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_14\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(43),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_13\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(15),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_15\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(44),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_14\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(16),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_16\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(45),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_15\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(17),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_17\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(46),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_16\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(18),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_18\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(47),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_17\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(19),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_19\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(48),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_18\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(20),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_20\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(49),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_19\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(21),
cout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_21\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(50),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_20\);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX\(22),
cout => N_80126,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(51),
cin => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_21\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(0),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_0\,
dataf => N_82374,
datad => \GRFPU0.GRFPU_X0.N_14517\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(32),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => GND);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(1),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_1\,
datad => \GRFPU0.GRFPU_X0.N_14518\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(33),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_0\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(2),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_2\,
datad => \GRFPU0.GRFPU_X0.N_14519\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(34),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_1\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(3),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_3\,
datad => \GRFPU0.GRFPU_X0.N_14520\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(35),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_2\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(4),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_4\,
datad => \GRFPU0.GRFPU_X0.N_14521\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(36),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_3\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(5),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_5\,
datad => \GRFPU0.GRFPU_X0.N_14522\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(37),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_4\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(6),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_6\,
datad => \GRFPU0.GRFPU_X0.N_14523\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(38),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_5\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(7),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_7\,
datad => \GRFPU0.GRFPU_X0.N_14524\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(39),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_6\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(8),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_8\,
datad => \GRFPU0.GRFPU_X0.N_14525\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(40),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_7\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(9),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_9\,
datad => \GRFPU0.GRFPU_X0.N_14526\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(41),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_8\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(10),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_10\,
datad => \GRFPU0.GRFPU_X0.N_14527\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(42),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_9\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(11),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_11\,
datad => \GRFPU0.GRFPU_X0.N_14528\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(43),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_10\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(12),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_12\,
datad => \GRFPU0.GRFPU_X0.N_14529\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(44),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_11\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(13),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_13\,
datad => \GRFPU0.GRFPU_X0.N_14530\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(45),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_12\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(14),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_14\,
datad => \GRFPU0.GRFPU_X0.N_14531\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(46),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_13\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(15),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_15\,
datad => \GRFPU0.GRFPU_X0.N_14532\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(47),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_14\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(16),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_16\,
datad => \GRFPU0.GRFPU_X0.N_14533\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(48),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_15\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(17),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_17\,
datad => \GRFPU0.GRFPU_X0.N_14534\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(49),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_16\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(18),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_18\,
datad => \GRFPU0.GRFPU_X0.N_14535\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(50),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_17\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(19),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_19\,
datad => \GRFPU0.GRFPU_X0.N_14536\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(51),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_18\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(20),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_20\,
datad => \GRFPU0.GRFPU_X0.N_14537\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(52),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_19\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(21),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_21\,
datad => \GRFPU0.GRFPU_X0.N_14538\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(53),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_20\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f0cc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(22),
cout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_22\,
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datab => \GRFPU0.GRFPU_X0.N_14539\,
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_21\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(23),
cout => N_80124,
datad => VCC,
cin => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_22\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(1),
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datad => N_99660,
datac => N_99661,
datab => \GRFPU0.GRFPU_X0.N_3274\,
cin => GND);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(2),
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(53),
datad => N_99660,
datac => N_99661,
datab => \GRFPU0.GRFPU_X0.N_3274\,
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_0\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(3),
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(54),
datad => N_99660,
datac => N_99661,
datab => \GRFPU0.GRFPU_X0.N_3274\,
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_1\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(4),
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(55),
datad => N_99660,
datac => N_99661,
datab => \GRFPU0.GRFPU_X0.N_3274\,
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_2\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(5),
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datad => N_99660,
datac => N_99661,
datab => \GRFPU0.GRFPU_X0.N_3274\,
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_3\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(6),
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_5\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(57),
datad => N_99660,
datac => N_99661,
datab => \GRFPU0.GRFPU_X0.N_3274\,
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_4\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(7),
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_6\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datad => N_99660,
datac => N_99661,
datab => \GRFPU0.GRFPU_X0.N_3274\,
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_5\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(8),
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_7\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(59),
datad => N_99660,
datac => N_99661,
datab => \GRFPU0.GRFPU_X0.N_3274\,
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_6\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(9),
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_8\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datad => N_99660,
datac => N_99661,
datab => \GRFPU0.GRFPU_X0.N_3274\,
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_7\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(10),
cout => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_9\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(61),
datad => N_99660,
datac => N_99661,
datab => \GRFPU0.GRFPU_X0.N_3274\,
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_8\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000fc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(11),
cout => N_27,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(62),
datad => \GRFPU0.GRFPU_X0.N_3274\,
datac => N_99660,
datab => N_99661,
cin => \GRFPU0.GRFPU_X0.UN1_EXPDEC_CARRY_9\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(51),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
cin => GND);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(50),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_2\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_1\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(49),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_3\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(11),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_2\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(48),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_4\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_3\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(47),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_5\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_4\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(46),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_6\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_5\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(45),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_7\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_6\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(44),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_8\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_7\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(43),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_9\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_8\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(42),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_10\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_9\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(41),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_11\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(19),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_10\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(40),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_12\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_11\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(39),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_13\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_12\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(38),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_14\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_13\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(37),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_15\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_14\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(36),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_16\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_15\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(35),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_17\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_16\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(34),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_18\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_17\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(33),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_19\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_18\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(32),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_20\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_19\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(31),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_21\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_20\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(30),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_22\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_21\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(29),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_23\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_22\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(28),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_24\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_23\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(27),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_24\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_26: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(26),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_25\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(25),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_27\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_26\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_28: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(24),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_28\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_27\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_29: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(23),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_29\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_28\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_30: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(22),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_30\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_29\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_31: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(21),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_31\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_30\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_32: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(20),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_32\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_31\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_33: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(19),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_33\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_32\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_34: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(18),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_34\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_33\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_35: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(17),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_35\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_34\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_36: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(16),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_36\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_35\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_37: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(15),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_37\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_36\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_38: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(14),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_38\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_37\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_39: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(13),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_39\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_38\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_40: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(12),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_40\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_39\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_41: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(11),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_41\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_40\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_42: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(10),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_42\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_41\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_43: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(9),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_43\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_42\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_44: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(8),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_44\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_43\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_45: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(7),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_45\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_44\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_46: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(6),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_46\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_45\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_47: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(5),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_47\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_46\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_48: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(4),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_48\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_47\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_49: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(3),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_49\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_48\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_50: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(2),
cout => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_50\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_49\);
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_51: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN166_RNDOP\(1),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
cin => \GRFPU0.GRFPU_X0.UN166_RNDOP_CARRY_50\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff00000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(1),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(33),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
cin => GND);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(2),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_2\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(34),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_1\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(3),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_3\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(35),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_2\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(4),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_4\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_3\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(5),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_5\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(37),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_4\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(6),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_6\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(38),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_5\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(7),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_7\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(39),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_6\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(8),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_8\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(40),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_7\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(9),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_9\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(41),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_8\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(10),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_10\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(42),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_9\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(11),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_11\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(43),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_10\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(12),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_12\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(44),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_11\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(13),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_13\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(45),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_12\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(14),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_14\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(46),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_13\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(15),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_15\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(47),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_14\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(16),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_16\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(48),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_15\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(17),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_17\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_16\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(18),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_18\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(50),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_17\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(19),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_19\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(51),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_18\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(20),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_20\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(52),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_19\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(21),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_21\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(53),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_20\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(22),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_22\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(54),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_21\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(23),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_23\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(55),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_22\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(24),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_24\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(56),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_23\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(25),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_25\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(57),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_24\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_26: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(26),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(58),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_25\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(27),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_27\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_26\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_28: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(28),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_28\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_27\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_29: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(29),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_29\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(61),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_28\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_30: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(30),
cout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_30\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(62),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_29\);
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_31: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(31),
cout => N_28,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
cin => \GRFPU0.GRFPU_X0.INF_ABS0_A_0_CARRY_30\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000030")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(10),
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datad => \GRFPU0.GRFPU_X0.N_19750\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.DP\,
cin => GND);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000030")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(9),
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(1),
datad => \GRFPU0.GRFPU_X0.N_19750\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.DP\,
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_0\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000030")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(8),
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
datad => \GRFPU0.GRFPU_X0.N_19750\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.DP\,
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_1\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000030")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(7),
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(3),
datad => \GRFPU0.GRFPU_X0.N_19750\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.DP\,
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_2\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000030")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(6),
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(4),
datad => \GRFPU0.GRFPU_X0.N_19750\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.DP\,
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_3\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000030")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(5),
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_5\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datad => \GRFPU0.GRFPU_X0.N_19750\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.DP\,
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_4\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000000c")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(4),
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_6\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(6),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.N_19750\,
datab => \GRFPU0.GRFPU_X0.ITER.V\,
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_5\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(3),
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_7\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_6\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(2),
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_8\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_7\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(1),
cout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_9\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(9),
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_8\);
GRFPU0_GRFPU_X0_UN1_VITER_EXP_1_SQMUXA_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(10),
cin => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA_CARRY_9\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(52),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_0\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datab => VCC,
cin => GND);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(51),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_1\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_0\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(50),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_2\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_1\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(49),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_3\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(11),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_2\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(48),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_4\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_3\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(47),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_5\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_4\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(46),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_6\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_5\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(45),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_7\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_6\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(44),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_8\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_7\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(43),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_9\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_8\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(42),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_10\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_9\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(41),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_11\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(19),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_10\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(40),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_12\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_11\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(39),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_13\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_12\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(38),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_14\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_13\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(37),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_15\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_14\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(36),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_16\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_15\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(35),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_17\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_16\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(34),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_18\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_17\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(33),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_19\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_18\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(32),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_20\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_19\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(31),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_21\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_20\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(30),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_22\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_21\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(29),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_23\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_22\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(28),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_24\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_23\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(27),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_24\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_26: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(26),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_25\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(25),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_27\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_26\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_28: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(24),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_28\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_27\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_29: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(23),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_29\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_28\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_30: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(22),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_30\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_29\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_31: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(21),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_31\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_30\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_32: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(20),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_32\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_31\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_33: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(19),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_33\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_32\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_34: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(18),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_34\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_33\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_35: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(17),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_35\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_34\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_36: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(16),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_36\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_35\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_37: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(15),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_37\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_36\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_38: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(14),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_38\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_37\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_39: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(13),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_39\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_38\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_40: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(12),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_40\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_39\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_41: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(11),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_41\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_40\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_42: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(10),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_42\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_41\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_43: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(9),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_43\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_42\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_44: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(8),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_44\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_43\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_45: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(7),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_45\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_44\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_46: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(6),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_46\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_45\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_47: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(5),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_47\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_46\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_48: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(4),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_48\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_47\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_49: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(3),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_49\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_48\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_50: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(2),
cout => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_50\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_49\);
GRFPU0_GRFPU_X0_UN177_RNDOP_CARRY_51: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN177_RNDOP\(1),
cout => N_29,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN177_RNDOP_CARRY_50\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(1),
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datad => N_99625,
datac => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
cin => GND);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(2),
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(1),
datad => N_99625,
datac => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_0\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(3),
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
datad => N_99625,
datac => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_1\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(4),
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(3),
datad => N_99625,
datac => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_2\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(5),
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(4),
datad => N_99625,
datac => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_3\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(6),
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_5\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datad => N_99625,
datac => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_4\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(7),
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_6\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(6),
datad => N_99625,
datac => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_5\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(8),
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_7\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
datad => N_99625,
datac => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_6\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(9),
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_8\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
datad => N_99625,
datac => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_7\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00003330")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(10),
cout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_9\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(9),
datad => N_99625,
datac => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_8\);
GRFPU0_GRFPU_X0_UN1_ITER_SGNFEQ_2_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff000000fc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(11),
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(10),
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datac => N_99625,
datab => \GRFPU0.GRFPU_X0.COMB.EXP37\,
cin => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2_CARRY_9\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(1),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datad => N_80279,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => GND);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(2),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datad => N_80280,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_0\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(3),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datad => N_80281,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_1\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(4),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datad => N_80282,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_2\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(5),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datad => N_80283,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_3\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(6),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_5\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datad => N_80284,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_4\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(7),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_6\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datad => N_80285,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_5\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(8),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_7\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datad => N_80286,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_6\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(9),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_8\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datad => N_80287,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_7\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(10),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_9\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datad => N_80288,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_8\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(11),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_10\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datad => N_80289,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_9\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(12),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_11\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datad => N_80290,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_10\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(13),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_12\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datad => N_80291,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_11\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(14),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_13\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datad => N_80292,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_12\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(15),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_14\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datad => N_80293,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_13\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(16),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_15\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datad => N_80294,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_14\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(17),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_16\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datad => N_80295,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_15\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(18),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_17\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datad => N_80296,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_16\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(19),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_18\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datad => N_80297,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_17\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(20),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_19\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
datad => N_80298,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_18\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(21),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_20\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datad => N_80299,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_19\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(22),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_21\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datad => N_80300,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_20\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(23),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_22\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datad => N_80301,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_21\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(24),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_23\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datad => N_80302,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_22\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(25),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_24\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
datad => N_80303,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_23\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(26),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datad => N_80304,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_24\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_26: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(27),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_26\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datad => N_80305,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_25\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(28),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_27\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datad => N_80306,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_26\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_28: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(29),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_28\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datad => N_80307,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_27\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_29: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(30),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_29\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
datad => N_80308,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_28\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_30: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(31),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_30\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
datad => N_80309,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_29\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_31: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(32),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_31\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
datad => N_80310,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_30\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_32: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(33),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_32\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datad => N_80311,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_31\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_33: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(34),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_33\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datad => N_80312,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_32\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_34: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(35),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_34\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34),
datad => N_80313,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_33\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_35: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(36),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_35\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
datad => N_80314,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_34\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_36: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(37),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_36\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datad => N_80315,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_35\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_37: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(38),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_37\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datad => N_80316,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_36\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_38: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(39),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_38\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datad => N_80317,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_37\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_39: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(40),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_39\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datad => N_80318,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_38\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_40: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(41),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_40\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
datad => N_80319,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_39\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_41: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(42),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_41\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
datad => N_80320,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_40\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_42: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(43),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_42\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
datad => N_80321,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_41\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_43: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(44),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_43\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43),
datad => N_80322,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_42\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_44: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(45),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_44\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
datad => N_80323,
datac => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_43\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_45: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(46),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_45\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45),
datad => N_80324,
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_44\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_46: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(47),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_46\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
datad => N_80325,
datac => \GRFPU0.DIVROM0.RADDR\(2),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_45\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_47: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(48),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_47\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
datad => N_80326,
datac => \GRFPU0.DIVROM0.RADDR\(3),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_46\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_48: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(49),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_48\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48),
datad => N_80327,
datac => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_47\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_49: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(50),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_49\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datad => N_80328,
datac => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_48\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_50: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f000000ff")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(51),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_50\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
datad => N_80329,
datac => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_49\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_51: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f00000f00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(52),
cout => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_51\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datad => \GRFPU0.GRFPU_X0.N_3386\,
datac => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_50\);
GRFPU0_GRFPU_X0_UN2_DIFF1_CARRY_52: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000fff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN2_DIFF1\(53),
cout => N_30,
dataf => VCC,
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
cin => \GRFPU0.GRFPU_X0.UN2_DIFF1_CARRY_51\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(11),
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_0\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datab => VCC,
cin => GND);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(10),
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_1\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_0\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(9),
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_2\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_1\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(8),
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_3\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_2\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(7),
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_4\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_3\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(6),
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_5\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_4\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(5),
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_6\,
dataf => VCC,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(58),
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_5\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000cf0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(4),
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_7\,
dataf => N_80264,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(59),
datac => \GRFPU0.GRFPU_X0.N_162_I\,
datab => \GRFPU0.GRFPU_X0.N_19691\,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_6\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000030330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(3),
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_8\,
dataf => \GRFPU0.GRFPU_X0.N_162_I\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datac => \GRFPU0.GRFPU_X0.N_19691\,
datab => N_80264,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_7\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000030330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(2),
cout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_9\,
dataf => \GRFPU0.GRFPU_X0.N_162_I\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datac => \GRFPU0.GRFPU_X0.N_19691\,
datab => N_80264,
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_8\);
GRFPU0_GRFPU_X0_UN1_ST2_REG_1_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(1),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(62),
cin => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1_CARRY_9\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0c300000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(0),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_0\,
dataf => N_80261,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(20),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => N_80260,
cin => GND);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(1),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_1\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(21),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_0\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(2),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(22),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_1\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(3),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_3\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(23),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_2\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(4),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_4\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(24),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_3\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(5),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_5\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(25),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_4\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(6),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_6\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(26),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_5\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(7),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_7\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(27),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_6\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(8),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_8\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(28),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_7\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(9),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_9\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(29),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_8\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(10),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_10\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(30),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_9\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(11),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_11\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(31),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_10\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(12),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_12\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(32),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_11\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(13),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_13\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(33),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_12\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(14),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_14\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(34),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_13\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(15),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_15\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(35),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_14\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(16),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_16\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(36),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_15\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(17),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_17\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(37),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_16\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(18),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_18\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(38),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_17\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(19),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_19\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(39),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_18\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(20),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_20\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(40),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_19\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(21),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_21\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(41),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_20\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(22),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_22\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(42),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_21\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(23),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_23\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(43),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_22\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(24),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_24\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(44),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_23\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(25),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_25\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(45),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_24\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_26: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(26),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(46),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_25\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(27),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_27\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(47),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_26\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_28: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(28),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_28\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(48),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_27\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_29: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(29),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_29\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(49),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_28\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_30: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(30),
cout => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_30\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(50),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_29\);
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_31: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000ff0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN1_INTO\(31),
cout => N_31,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(51),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
cin => \GRFPU0.GRFPU_X0.UN1_INTO_CARRY_30\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_0\,
dataf => N_82253,
datad => N_80158,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(4),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => GND);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_1\,
datad => N_80159,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(5),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_0\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_2\,
datad => N_80163,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(6),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_1\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_3\,
datad => N_80164,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_2\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_4\,
datad => N_80167,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(8),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_3\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_5\,
datad => N_80168,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(9),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_4\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_6\,
datad => N_80171,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(10),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_5\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_7\,
datad => N_80172,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(11),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_6\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_8\,
datad => N_80175,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(12),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_7\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_9\,
datad => N_80176,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(13),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_8\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_10\,
datad => N_80179,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(14),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_9\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_11\,
datad => N_80180,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(15),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_10\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_12\,
datad => N_80183,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(16),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_11\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_13\,
datad => N_80184,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(17),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_12\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_14\,
datad => N_80187,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(18),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_13\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_15\,
datad => N_80188,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(19),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_14\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_16\,
datad => N_80191,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(20),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_15\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_17\,
datad => N_80192,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(21),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_16\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_18\,
datad => N_80195,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(22),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_17\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_19\,
datad => N_80196,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(23),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_18\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_20\,
datad => N_80199,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(24),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_19\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_21\,
datad => N_80200,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(25),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_20\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_22\,
datad => N_80203,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(26),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_21\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_23\,
datad => N_80204,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(27),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_22\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\,
datad => N_80207,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(28),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_23\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_25\,
datad => N_80208,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(29),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_24\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_26: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_26\,
datad => \GRFPU0.GRFPU_X0.N_14515\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(30),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_25\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_27\,
datad => \GRFPU0.GRFPU_X0.N_14516\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(31),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_26\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_28: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(29),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_28\,
datad => \GRFPU0.GRFPU_X0.N_14517\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(32),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_27\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_29: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(30),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_29\,
datad => \GRFPU0.GRFPU_X0.N_14518\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(33),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_28\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_30: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(31),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_30\,
datad => \GRFPU0.GRFPU_X0.N_14519\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(34),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_29\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_31: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(32),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_31\,
datad => \GRFPU0.GRFPU_X0.N_14520\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(35),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_30\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_32: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(33),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_32\,
datad => \GRFPU0.GRFPU_X0.N_14521\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(36),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_31\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_33: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(34),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_33\,
datad => \GRFPU0.GRFPU_X0.N_14522\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(37),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_32\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_34: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(35),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_34\,
datad => \GRFPU0.GRFPU_X0.N_14523\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(38),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_33\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_35: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(36),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_35\,
datad => \GRFPU0.GRFPU_X0.N_14524\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(39),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_34\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_36: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(37),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_36\,
datad => \GRFPU0.GRFPU_X0.N_14525\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(40),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_35\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_37: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(38),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_37\,
datad => \GRFPU0.GRFPU_X0.N_14526\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(41),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_36\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_38: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(39),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_38\,
datad => \GRFPU0.GRFPU_X0.N_14527\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(42),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_37\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_39: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(40),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_39\,
datad => \GRFPU0.GRFPU_X0.N_14528\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(43),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_38\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_40: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(41),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_40\,
datad => \GRFPU0.GRFPU_X0.N_14529\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(44),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_39\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_41: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(42),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_41\,
datad => \GRFPU0.GRFPU_X0.N_14530\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(45),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_40\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_42: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(43),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_42\,
datad => \GRFPU0.GRFPU_X0.N_14531\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(46),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_41\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_43: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(44),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_43\,
datad => \GRFPU0.GRFPU_X0.N_14532\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(47),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_42\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_44: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(45),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_44\,
datad => \GRFPU0.GRFPU_X0.N_14533\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(48),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_43\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_45: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(46),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_45\,
datad => \GRFPU0.GRFPU_X0.N_14534\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(49),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_44\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_46: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(47),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_46\,
datad => \GRFPU0.GRFPU_X0.N_14535\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(50),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_45\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_47: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(48),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_47\,
datad => \GRFPU0.GRFPU_X0.N_14536\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(51),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_46\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_48: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(49),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_48\,
datad => \GRFPU0.GRFPU_X0.N_14537\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(52),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_47\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_49: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f3c0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(50),
cout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_49\,
datad => \GRFPU0.GRFPU_X0.N_14538\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(53),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_48\);
GRFPU0_GRFPU_X0_UN5_S3ADDO2_CARRY_50: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f0cc")
port map (
sumout => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(51),
cout => N_32,
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datab => \GRFPU0.GRFPU_X0.N_14539\,
cin => \GRFPU0.GRFPU_X0.UN5_S3ADDO2_CARRY_49\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(0),
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(0),
cin => N_112293);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(1),
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_0\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(2),
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(2),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_1\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(3),
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(3),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_2\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(4),
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(4),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(4),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_3\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(5),
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_5\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(5),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(5),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_4\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(6),
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_6\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(6),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(6),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_5\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(7),
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_7\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(7),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(7),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_6\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(8),
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_8\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(8),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(8),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_7\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(9),
cout => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_9\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(9),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(9),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_8\);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(10),
cout => N_33,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
cin => \GRFPU0.GRFPU_X0.EXPDIFFN_1_CARRY_9\);
GRFPU0_GRFPU_X0_C_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(0),
cout => \GRFPU0.GRFPU_X0.C_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(0),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(0),
cin => N_112291);
GRFPU0_GRFPU_X0_C_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(1),
cout => \GRFPU0.GRFPU_X0.C_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(1),
cin => \GRFPU0.GRFPU_X0.C_CARRY_0\);
GRFPU0_GRFPU_X0_C_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(2),
cout => \GRFPU0.GRFPU_X0.C_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(2),
cin => \GRFPU0.GRFPU_X0.C_CARRY_1\);
GRFPU0_GRFPU_X0_C_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(3),
cout => \GRFPU0.GRFPU_X0.C_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(3),
cin => \GRFPU0.GRFPU_X0.C_CARRY_2\);
GRFPU0_GRFPU_X0_C_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(4),
cout => \GRFPU0.GRFPU_X0.C_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(4),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(4),
cin => \GRFPU0.GRFPU_X0.C_CARRY_3\);
GRFPU0_GRFPU_X0_C_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(5),
cout => \GRFPU0.GRFPU_X0.C_CARRY_5\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(5),
cin => \GRFPU0.GRFPU_X0.C_CARRY_4\);
GRFPU0_GRFPU_X0_C_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(6),
cout => \GRFPU0.GRFPU_X0.C_CARRY_6\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(6),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(6),
cin => \GRFPU0.GRFPU_X0.C_CARRY_5\);
GRFPU0_GRFPU_X0_C_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(7),
cout => \GRFPU0.GRFPU_X0.C_CARRY_7\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(7),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(7),
cin => \GRFPU0.GRFPU_X0.C_CARRY_6\);
GRFPU0_GRFPU_X0_C_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(8),
cout => \GRFPU0.GRFPU_X0.C_CARRY_8\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(8),
cin => \GRFPU0.GRFPU_X0.C_CARRY_7\);
GRFPU0_GRFPU_X0_C_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(9),
cout => \GRFPU0.GRFPU_X0.C_CARRY_9\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(9),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(9),
cin => \GRFPU0.GRFPU_X0.C_CARRY_8\);
GRFPU0_GRFPU_X0_C_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(10),
cout => \GRFPU0.GRFPU_X0.C_CARRY_10\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
cin => \GRFPU0.GRFPU_X0.C_CARRY_9\);
GRFPU0_GRFPU_X0_C_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.C\(11),
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
cin => \GRFPU0.GRFPU_X0.C_CARRY_10\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(0),
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ST3.LZCNT\(0),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(52),
cin => N_112289);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(1),
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ST3.LZCNT\(1),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(53),
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_0\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(2),
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ST3.LZCNT\(2),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(54),
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_1\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(3),
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ST3.LZCNT\(3),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(55),
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_2\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(4),
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ST3.LZCNT\(4),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(56),
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_3\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(5),
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_5\,
dataf => \GRFPU0.GRFPU_X0.ST3.LZCNT\(5),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(57),
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_4\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(6),
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_6\,
dataf => VCC,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(58),
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_5\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(7),
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_7\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(59),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_6\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(8),
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_8\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_7\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(9),
cout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_9\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(61),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_8\);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(10),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(62),
datab => VCC,
cin => \GRFPU0.GRFPU_X0.COMB.EXPCC_1_CARRY_9\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(0),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(0),
cin => N_112287);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(1),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_0\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2),
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(2),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_1\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(3),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_2\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4),
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(4),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(4),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_3\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataf => \GRFPU0.GRFPU_X0.ST1.EXP2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(5),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_CARRY_4\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_1_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(0),
cin => N_112285);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_1_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_0\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_1_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2),
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(2),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_1\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_1_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(3),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_2\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_1_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4),
cout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(4),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(4),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_3\);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_1_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(5),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(5),
cin => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1_CARRY_4\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(0),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(0),
cin => GND);
GRFPU0_GRFPU_X0_UN8_C_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(1),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_0\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(2),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_2\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(2),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_1\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(3),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_3\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(3),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_2\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(4),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_4\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(4),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(4),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_3\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(5),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_5\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(5),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(5),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_4\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(6),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_6\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(6),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(6),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_5\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(7),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_7\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(7),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(7),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_6\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(8),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_8\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(8),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(8),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_7\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(9),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_9\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(9),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(9),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_8\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000f0f0")
port map (
sumout => \GRFPU0.GRFPU_X0.UN8_C\(10),
cout => \GRFPU0.GRFPU_X0.UN8_C_CARRY_10\,
datac => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_9\);
GRFPU0_GRFPU_X0_UN8_C_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000033330000f0f0")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\,
cout => N_34,
datac => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
cin => \GRFPU0.GRFPU_X0.UN8_C_CARRY_10\);
GRFPU0_GRFPU_X0_UN4_S3ADDO3_CARRY_23_BUF: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_23\,
cin => N_80124);
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_22_BUF: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_22\,
cin => N_80126);
GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_A_0_CARRY_60_BUF: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_A_0\(97),
cin => N_80128);
\GRFPU0_GRFPU_X0_S3ADDI_0_0_RNIK2I461_0_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
cin => N_80134);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_63_BUF: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.GRFPU_X0.COMB.LESS2\,
cin => N_80138);
\GRFPC0_RFA2_RS2SEL_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"000c0031000c0000")
port map (
combout => \GRFPC0.FPUSEL_1\(3),
dataf => \GRFPC0.FP_PIPELINE.1.WRENX10\,
datae => N_37,
datad => \GRFPC0.FP_PIPELINE.1.EXEN7\,
datac => \GRFPC0.WR.RREG.RESV\,
datab => \GRFPC0.FP_PIPELINE.1.MEMEN10\,
dataa => \GRFPC0.N_24361\,
datag => \GRFPC0.N_24389\);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_8_0_M2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"ff55e4e4fa50e4e4")
port map (
combout => \GRFPC0.N_24723\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_8\(0),
datae => \GRFPC0.INST\(28),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60\(0),
datab => \GRFPC0.D.LDLCK_0_0_0__G3\,
dataa => \GRFPC0.INST\(26),
datag => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_9\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_0_M2_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"d955f0f00000f0f0")
port map (
combout => \GRFPC0.N_584_I\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datae => \GRFPC0.N_500\,
datad => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN2972_DEP\,
datac => \GRFPC0.N_462\,
datab => \GRFPC0.N_481\,
dataa => \GRFPC0.N_21943\,
datag => \GRFPC0.N_22173_I\);
GRFPC0_FP_PIPELINE_RSDEC_RS1D_IV_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"1000010000000000")
port map (
combout => \GRFPC0.N_23599_I_0\,
dataf => \GRFPC0.N_72_I\,
datae => \GRFPC0.INST\(19),
datad => \GRFPC0.N_23781\,
datac => \GRFPC0.INST\(9),
datab => \GRFPC0.N_23636\,
dataa => \GRFPC0.INST\(12),
datag => \GRFPC0.N_23795\);
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_O3_4_I_A3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"d0ddd0d0ddddd0d0")
port map (
combout => \GRFPC0.N_666\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datae => \GRFPC0.N_21725\,
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3628_DEP\,
datac => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.N_467\,
dataa => \GRFPC0.MEM.CTRL.RD\(2),
datag => \GRFPC0.N_74_I_I\);
\GRFPC0_INST_I_S_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"00cc05cd0fcf05cd")
port map (
combout => \GRFPC0.RFA.WRITE_RD_0_0_I1_I_1\,
dataf => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datae => \GRFPC0.N_23766\,
datad => N_91,
datac => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datab => \GRFPC0.N_24061\,
dataa => \GRFPC0.FIFO.INST_0\(13),
datag => \GRFPC0.FIFO.INST_1\(13));
\GRFPC0_FIFO_VCNT_0_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"00af001500000000")
port map (
combout => N_47282,
dataf => N_35,
datae => \GRFPC0.FIFO.VCNT_0\(0),
datad => N_47103,
datac => \GRFPC0.FP_PIPELINE.V.STATE6\,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
dataa => N_47071,
datag => N_47093);
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"3cf05f5f3cf0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(5),
dataf => \FPI.OP1\(60),
datae => \FPI.FLOP\(1),
datad => N_32594,
datac => \GRFPU0.GRFPU_X0.UN13_EXP_1_CO3\,
datab => \FPI.OP1\(56),
dataa => \FPI.OP1\(59),
datag => \FPI.OP1\(57));
GRFPC0_UN1_STDDEP_0_SQMUXA_101: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"aeaaeaaaaaaaaaaa")
port map (
combout => \GRFPC0.UN1_STDDEP_0_SQMUXA_101\,
dataf => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3956_DEP\,
datae => \GRFPC0.N_458\,
datad => \GRFPC0.FP_PIPELINE.12.STDEP_488_SEL0_1\,
datac => \GRFPC0.N_481\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
dataa => \GRFPC0.N_18739\,
datag => \GRFPC0.N_74_I_I\);
\GRFPC0_FIFO_VCNT_1_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"008a0002008a0022")
port map (
combout => N_47284,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FIFO.VCNT_1\(0),
datad => N_47157,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => N_47125,
dataa => N_35,
datag => N_47093);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNIC4C54_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"ffffffffa088a088")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(48),
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datac => \GRFPU0.MULO.MRES\(107),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(11),
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datag => \GRFPU0.MULO.MRES\(108));
\GRFPC0_FP_PIPELINE_7_STDEP_310_0_IV_I_M2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0c00f0f01d55f0f0")
port map (
combout => \GRFPC0.N_22360\,
dataf => \GRFPC0.N_21948_1\,
datae => \GRFPC0.N_22331\,
datad => \GRFPC0.N_470\,
datac => \GRFPC0.N_106_I\,
datab => \GRFPC0.N_690\,
dataa => \GRFPC0.N_21820\,
datag => \GRFPC0.N_21951_1\);
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"3ccc5a5a3ccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(5),
dataf => \GRFPU0.GRFPU_X0.N_10059_I\,
datae => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
datad => N_32406,
datac => \GRFPU0.GRFPU_X0.UN38_EXP_1_CO4\,
datab => \FPI.OP2\(57),
dataa => \FPI.OP2\(60),
datag => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafefafaaaaefafa")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(52),
dataf => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(11),
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datad => \GRFPU0.GRFPU_X0.N_5774\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(49),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(52),
dataa => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_3\,
datag => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"a5fff2ffa5ff02ff")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(55),
dataf => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(8),
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.UN1_VST3.EXC37\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datab => \GRFPU0.GRFPU_X0.N_5774\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datag => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M84_2_03_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"a5fff2ffa5ff02ff")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(56),
dataf => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(7),
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.UN1_VST3.EXC37\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datab => \GRFPU0.GRFPU_X0.N_5774\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datag => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M84_2_03\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0fff2fff0ff02ff")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(58),
dataf => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(5),
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.UN1_VST3.EXC37\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datab => \GRFPU0.GRFPU_X0.N_5774\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(58),
datag => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.OUT_1\(84));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0fff2fff0ff02ff")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(57),
dataf => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(6),
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.UN1_VST3.EXC37\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datab => \GRFPU0.GRFPU_X0.N_5774\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datag => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.OUT_1\(84));
GRFPC0_FIFO_FULL_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0a00a3a30000a3a3")
port map (
combout => \GRFPC0.FIFO.FULL_0_0_G1_1\,
dataf => \GRFPC0.FP_PIPELINE.UN1_FIFO.VCNT_1_1\,
datae => \GRFPC0.FP_PIPELINE.VFIFO.RD10\,
datad => \GRFPC0.FP_PIPELINE.CNTX14_0\,
datac => CPO_EXCZ,
datab => \GRFPC0.FP_PIPELINE.UN3_FIFO_CLR\,
dataa => \GRFPC0.FIFO.FULL\,
datag => \GRFPC0.FP_PIPELINE.UN4_CNTX\(1));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"ff0f606000f06060")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(2),
dataf => \FPI.OP2\(54),
datae => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.N_18882_1\,
datac => \GRFPU0.GRFPU_X0.N_10059_I\,
datab => \FPI.OP2\(57),
dataa => \GRFPU0.GRFPU_X0.UN38_EXP_1_CO1\,
datag => \FPI.FLOP\(1));
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_45_RNIVGFC7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"3b080f0f7f4c0f0f")
port map (
combout => D_N_5_4,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP\(7),
datae => \GRFPU0.GRFPU_X0.ITER.V\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(53),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(53),
datab => \GRFPU0.GRFPU_X0.N_18527\,
dataa => \GRFPU0.GRFPU_X0.N_11529\,
datag => \GRFPU0.GRFPU_X0.UN177_RNDOP\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_YY_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fafefafeaaeeaaee")
port map (
combout => N_93236,
dataf => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.GRFPU_X0.N_18664\,
datac => \GRFPU0.MULO.MRES\(109),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(50),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(50),
datag => \GRFPU0.MULO.MRES\(110));
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_48_RNIMPO87: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => N_82240,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP\(4),
datae => \GRFPU0.GRFPU_X0.ITER.V\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(56),
datac => \GRFPU0.GRFPU_X0.N_18386\,
datab => \GRFPU0.GRFPU_X0.N_18527\,
dataa => \GRFPU0.GRFPU_X0.N_11529\,
datag => \GRFPU0.GRFPU_X0.UN177_RNDOP\(4));
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_47_RNI71GC7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"3b080f0f7f4c0f0f")
port map (
combout => D_N_5_2,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP\(5),
datae => \GRFPU0.GRFPU_X0.ITER.V\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(55),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(55),
datab => \GRFPU0.GRFPU_X0.N_18527\,
dataa => \GRFPU0.GRFPU_X0.N_11529\,
datag => \GRFPU0.GRFPU_X0.UN177_RNDOP\(5));
\GRFPU0_GRFPU_X0_ST1_CCSEL_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"300c0000300c5a5a")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1_0_0_1__G1\,
dataf => \GRFPU0.GRFPU_X0.UN1_RAW1\(0),
datae => \FPI.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.N_18838\,
datac => \FPI.OP2\(55),
datab => \FPI.OP1\(52),
dataa => \FPI.OP1\(55),
datag => \FPI.OP2\(52));
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_50_RNI11HC7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"3b080f0f7f4c0f0f")
port map (
combout => D_N_5_1,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP\(2),
datae => \GRFPU0.GRFPU_X0.ITER.V\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(58),
datab => \GRFPU0.GRFPU_X0.N_18527\,
dataa => \GRFPU0.GRFPU_X0.N_11529\,
datag => \GRFPU0.GRFPU_X0.UN177_RNDOP\(2));
GRFPU0_GRFPU_X0_UN166_RNDOP_CARRY_49_RNIQTO87: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"3b080f0f7f4c0f0f")
port map (
combout => D_N_5_3,
dataf => \GRFPU0.GRFPU_X0.UN166_RNDOP\(3),
datae => \GRFPU0.GRFPU_X0.ITER.V\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(57),
datac => \GRFPU0.GRFPU_X0.N_18384\,
datab => \GRFPU0.GRFPU_X0.N_18527\,
dataa => \GRFPU0.GRFPU_X0.N_11529\,
datag => \GRFPU0.GRFPU_X0.UN177_RNDOP\(3));
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_I_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"000f808000008080")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_0\(0),
dataf => \GRFPC0.N_114\,
datae => \GRFPC0.N_73\,
datad => \GRFPC0.N_22000\,
datac => \GRFPC0.N_104\,
datab => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2024_DEP\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_54_0\,
datag => \GRFPC0.N_76\);
\GRFPU0_GRFPU_X0_COMB_IEXC5_ALTB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0aaf2b2b0a0a0a0a")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.IEXC5.ALTB\(1),
dataf => \GRFPU0.GRFPU_X0.ITER.TZR\(0),
datae => \GRFPU0.GRFPU_X0.L3_0_3\(5),
datad => \GRFPU0.GRFPU_X0.L3_1_1\(0),
datac => \GRFPU0.GRFPU_X0.L3_0_5\(1),
datab => \GRFPU0.GRFPU_X0.L3_0_5\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.TZR\(1),
datag => \GRFPU0.GRFPU_X0.L3_1_1\(1));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0fff4848f0004848")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(1),
dataf => \FPI.OP2\(53),
datae => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
datad => \FPI.OP2\(52),
datac => \FPI.OP2\(55),
datab => \GRFPU0.GRFPU_X0.N_10059_I\,
dataa => \FPI.OP2\(56),
datag => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"00c800c800400040")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(49),
dataf => \GRFPU0.MULO.MRES\(109),
datae => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => N_28196,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
dataa => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datag => N_28197);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"00c800c800400040")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(48),
dataf => \GRFPU0.MULO.MRES\(108),
datae => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => N_28194,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
dataa => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datag => N_28195);
\GRFPU0_GRFPU_X0_L4_7_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0fffacac0000acac")
port map (
combout => \GRFPU0.GRFPU_X0.L4_7\(3),
dataf => \GRFPU0.GRFPU_X0.L1_4_5\(3),
datae => \GRFPU0.GRFPU_X0.L3_0_3\(5),
datad => \GRFPU0.GRFPU_X0.L1_5_2_0\(3),
datac => \GRFPU0.GRFPU_X0.L2_0_5\(4),
datab => \GRFPU0.GRFPU_X0.N_9486\,
dataa => \GRFPU0.GRFPU_X0.L1_2_3\(3),
datag => \GRFPU0.GRFPU_X0.UN63_BCO_LSB\(15));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"8000800000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_270\,
dataf => \GRFPU0.GRFPU_X0.N_307\,
datae => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datad => \GRFPU0.GRFPU_X0.N_19546\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_A2_2_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0013010113133131")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_2\(18),
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(18),
datae => \GRFPU0.GRFPU_X0.N_19582\,
datad => \GRFPU0.GRFPU_X0.N_272\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.N_18983_I\,
dataa => \FPI.OP1_RETO\(18),
datag => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_2\);
GRFPU0_GRFPU_X0_COMB_SGNFINC_INC_2_M4_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"c0303232c0300000")
port map (
combout => N_82374,
dataf => \GRFPU0.GRFPU_X0.S3ADDI\(28),
datae => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datac => \GRFPU0.GRFPU_X0.COMB.S_SP_1_1\,
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
dataa => \GRFPU0.GRFPU_X0.S3ADDI\(29),
datag => \GRFPU0.GRFPU_X0.N_6041\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"c0cff5f5c0cfa0a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(0),
dataf => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(10),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datac => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
datab => \GRFPU0.GRFPU_X0.C\(0),
dataa => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datag => \GRFPU0.GRFPU_X0.N_18408\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"00c0000000c00080")
port map (
combout => \GRFPU0.GRFPU_X0.N_10096\,
dataf => \GRFPU0.GRFPU_X0.N_19690\,
datae => \GRFPU0.GRFPU_X0.N_18204_I\,
datad => \GRFPU0.GRFPU_X0.N_6736\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => N_35,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datag => \GRFPU0.GRFPU_X0.ITER.STATE\(13));
\GRFPU0_GRFPU_X0_L3_0_6_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_6\(2),
dataf => \GRFPU0.GRFPU_X0.N_9608\,
datae => \GRFPU0.GRFPU_X0.N_9548\,
datad => \GRFPU0.GRFPU_X0.N_9554\,
datac => \GRFPU0.GRFPU_X0.N_9595\,
datab => \GRFPU0.GRFPU_X0.N_9549\,
dataa => \GRFPU0.GRFPU_X0.N_9559\,
datag => \GRFPU0.GRFPU_X0.N_9547\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"00c0000000c00080")
port map (
combout => \GRFPU0.GRFPU_X0.N_10104\,
dataf => \GRFPU0.GRFPU_X0.N_19690\,
datae => \GRFPU0.GRFPU_X0.N_18204_I\,
datad => \GRFPU0.GRFPU_X0.N_6736\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => N_35,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(6),
datag => \GRFPU0.GRFPU_X0.ITER.STATE\(5));
\GRFPC0_OP1_5_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20239\,
dataf => \GRFPC0.DIV.RESULT\(51),
datae => N_99878,
datad => \GRFPU0.GRFPU_X0.N_20285_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(51),
datab => \GRFPC0.WR2.RREG.RES\(51),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP2_5_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19753\,
dataf => \GRFPC0.DIV.RESULT\(60),
datae => N_99881,
datad => \GRFPU0.GRFPU_X0.N_20288_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(60),
datab => \GRFPC0.WR2.RREG.RES\(60),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP1_5_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20231\,
dataf => \GRFPC0.DIV.RESULT\(43),
datae => N_99878,
datad => \GRFPU0.GRFPU_X0.N_20290_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(43),
datab => \GRFPC0.WR2.RREG.RES\(43),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP1_5_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20225\,
dataf => \GRFPC0.DIV.RESULT\(37),
datae => N_99878_1,
datad => \GRFPU0.GRFPU_X0.N_20275_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(37),
datab => \GRFPC0.WR2.RREG.RES\(37),
dataa => \GRFPC0.RFA2.RS1SEL_1\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP2_5_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19751\,
dataf => \GRFPC0.DIV.RESULT\(58),
datae => N_99881,
datad => \FPO.RES\(58),
datac => \GRFPC0.MEM.RREG.RES\(58),
datab => \GRFPC0.WR2.RREG.RES\(58),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"8ffff8ff8f8ff8f8")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(42),
dataf => N_99920,
datae => \GRFPU0.MULO.MRES\(102),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(42),
datac => \GRFPU0.GRFPU_X0.N_3560_I\,
datab => N_99921,
dataa => \GRFPU0.MULO.MRES\(103),
datag => \GRFPU0.GRFPU_X0.N_18663\);
\GRFPC0_OP1_6_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_20284\,
dataf => N_721,
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => \GRFPC0.OP1_4\,
datac => \GRFPC0.RFA2.RS1SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(30),
dataa => \GRFPC0.EX.RREG.RES\(30),
datag => N_657);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(9),
dataf => \GRFPC0.N_25233\,
datae => \GRFPC0.N_23670\,
datad => \FPI.FLOP\(4),
datac => \GRFPC0.EX.CTRL.PC\(9),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(9));
\GRFPC0_OP1_5_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20242\,
dataf => \GRFPC0.DIV.RESULT\(54),
datae => N_99878,
datad => \GRFPU0.GRFPU_X0.N_20286_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(54),
datab => \GRFPC0.WR2.RREG.RES\(54),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(4),
dataf => \GRFPC0.N_239\,
datae => \GRFPC0.N_23670\,
datad => \GRFPC0.N_227\,
datac => \GRFPC0.EX.CTRL.PC\(4),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(4));
\GRFPC0_OP2_5_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19750\,
dataf => \GRFPC0.DIV.RESULT\(57),
datae => N_99881,
datad => \GRFPU0.GRFPU_X0.N_20287_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(57),
datab => \GRFPC0.WR2.RREG.RES\(57),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(6),
dataf => \GRFPC0.N_241\,
datae => \GRFPC0.N_23670\,
datad => \FPI.FLOP\(1),
datac => \GRFPC0.EX.CTRL.PC\(6),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(6));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fff4ff4ff4f44f4f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(39),
dataf => N_99920,
datae => \GRFPU0.MULO.MRES\(99),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(39),
datac => \GRFPU0.GRFPU_X0.N_18663\,
datab => N_99921,
dataa => \GRFPU0.MULO.MRES\(100),
datag => \GRFPU0.GRFPU_X0.N_3560_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"8ffff8ff8f8ff8f8")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(47),
dataf => N_99920,
datae => \GRFPU0.MULO.MRES\(107),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(47),
datac => \GRFPU0.GRFPU_X0.N_3560_I\,
datab => N_99921,
dataa => \GRFPU0.MULO.MRES\(108),
datag => \GRFPU0.GRFPU_X0.N_18663\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"8ffff8ff8f8ff8f8")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(38),
dataf => N_99920,
datae => \GRFPU0.MULO.MRES\(98),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(38),
datac => \GRFPU0.GRFPU_X0.N_3560_I\,
datab => N_99921,
dataa => \GRFPU0.MULO.MRES\(99),
datag => \GRFPU0.GRFPU_X0.N_18663\);
\GRFPC0_OP2_5_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19746\,
dataf => \GRFPC0.DIV.RESULT\(53),
datae => N_99881,
datad => \FPO.RES\(53),
datac => \GRFPC0.MEM.RREG.RES\(53),
datab => \GRFPC0.WR2.RREG.RES\(53),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"8ffff8ff8f8ff8f8")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(57),
dataf => N_99920,
datae => \GRFPU0.MULO.MRES\(117),
datad => \GRFPU0.GRFPU_X0.N_18384\,
datac => \GRFPU0.GRFPU_X0.N_3560_I\,
datab => N_99921,
dataa => \GRFPU0.MULO.MRES\(118),
datag => \GRFPU0.GRFPU_X0.N_18663\);
\GRFPC0_OP2_5_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19748\,
dataf => \GRFPC0.DIV.RESULT\(55),
datae => N_99881,
datad => \FPO.RES\(55),
datac => \GRFPC0.MEM.RREG.RES\(55),
datab => \GRFPC0.WR2.RREG.RES\(55),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"8ffff8ff8f8ff8f8")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(44),
dataf => N_99920,
datae => \GRFPU0.MULO.MRES\(104),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(44),
datac => \GRFPU0.GRFPU_X0.N_3560_I\,
datab => N_99921,
dataa => \GRFPU0.MULO.MRES\(105),
datag => \GRFPU0.GRFPU_X0.N_18663\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(15),
dataf => \GRFPC0.N_246\,
datae => \GRFPC0.N_23670\,
datad => \GRFPC0.N_24487\,
datac => \GRFPC0.EX.CTRL.PC\(15),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(15));
\GRFPC0_OP1_5_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20235\,
dataf => \GRFPC0.DIV.RESULT\(47),
datae => N_99878,
datad => \GRFPU0.GRFPU_X0.N_19240_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(47),
datab => \GRFPC0.WR2.RREG.RES\(47),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP1_6_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_20280\,
dataf => N_717,
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => \GRFPC0.OP1_4\,
datac => \GRFPC0.RFA2.RS1SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(26),
dataa => \GRFPC0.EX.RREG.RES\(26),
datag => N_653);
\GRFPC0_OP2_5_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19747\,
dataf => \GRFPC0.DIV.RESULT\(54),
datae => N_99881,
datad => \GRFPU0.GRFPU_X0.N_20286_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(54),
datab => \GRFPC0.WR2.RREG.RES\(54),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP1_5_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20222\,
dataf => \GRFPC0.DIV.RESULT\(34),
datae => N_99878_1,
datad => \GRFPU0.GRFPU_X0.N_20274_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(34),
datab => \GRFPC0.WR2.RREG.RES\(34),
dataa => \GRFPC0.RFA2.RS1SEL_1\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(17),
dataf => \GRFPC0.N_248\,
datae => \GRFPC0.N_23670\,
datad => \GRFPC0.N_24489\,
datac => \GRFPC0.EX.CTRL.PC\(17),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(17));
\GRFPC0_OP1_5_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20230\,
dataf => \GRFPC0.DIV.RESULT\(42),
datae => N_99878,
datad => \GRFPU0.GRFPU_X0.N_20271_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(42),
datab => \GRFPC0.WR2.RREG.RES\(42),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_M3_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0a0a0cfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18674\,
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.UN166_RNDOP\(40),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
datab => \GRFPU0.GRFPU_X0.UN177_RNDOP\(40),
dataa => \GRFPU0.GRFPU_X0.N_128\,
datag => \GRFPU0.GRFPU_X0.N_11529\);
\GRFPC0_OP1_5_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20240\,
dataf => \GRFPC0.DIV.RESULT\(52),
datae => N_99878,
datad => \GRFPU0.GRFPU_X0.N_20293_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(52),
datab => \GRFPC0.WR2.RREG.RES\(52),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f000ccf0f0a0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(1),
dataf => \GRFPC0.N_23712\,
datae => N_99867,
datad => \GRFPC0.N_19\,
datac => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(1),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f000ccf0f0a0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(0),
dataf => \GRFPC0.N_23712\,
datae => N_99867,
datad => \GRFPC0.N_19\,
datac => \GRFPC0.WR.CTRL.INST\(0),
datab => \GRFPC0.WR2.CTRL.INST\(0),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.DIV.INST\(0));
\GRFPC0_OP1_5_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20226\,
dataf => \GRFPC0.DIV.RESULT\(38),
datae => N_99878_1,
datad => \GRFPU0.GRFPU_X0.N_20296_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(38),
datab => \GRFPC0.WR2.RREG.RES\(38),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"8ffff8ff8f8ff8f8")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(58),
dataf => N_99920,
datae => \GRFPU0.MULO.MRES\(118),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(58),
datac => \GRFPU0.GRFPU_X0.N_3560_I\,
datab => N_99921,
dataa => \GRFPU0.MULO.MRES\(119),
datag => \GRFPU0.GRFPU_X0.N_18663\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fff4ff4ff4f44f4f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(40),
dataf => N_99920,
datae => \GRFPU0.MULO.MRES\(100),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(40),
datac => \GRFPU0.GRFPU_X0.N_18663\,
datab => N_99921,
dataa => \GRFPU0.MULO.MRES\(101),
datag => \GRFPU0.GRFPU_X0.N_3560_I\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(13),
dataf => \GRFPC0.N_25235\,
datae => \GRFPC0.N_23670\,
datad => \FPI.FLOP\(8),
datac => \GRFPC0.EX.CTRL.PC\(13),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(13));
\GRFPU0_GRFPU_X0_ST2_EXC_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"5555555554444040")
port map (
combout => \GRFPU0.GRFPU_X0.N_10114\,
dataf => \GRFPU0.GRFPU_X0.UN1_VST2.EXC_0_SQMUXA_2_1\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datad => \GRFPU0.GRFPU_X0.N_4175\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datab => \GRFPU0.GRFPU_X0.N_3516\,
dataa => \GRFPU0.GRFPU_X0.UN1_VST2.EXC_1_SQMUXA\,
datag => \GRFPU0.GRFPU_X0.ST1.V\);
\GRFPC0_OP1_5_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20232\,
dataf => \GRFPC0.DIV.RESULT\(44),
datae => N_99878,
datad => \GRFPU0.GRFPU_X0.N_20298_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(44),
datab => \GRFPC0.WR2.RREG.RES\(44),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"8ffff8ff8f8ff8f8")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(55),
dataf => N_99920,
datae => \GRFPU0.MULO.MRES\(115),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(55),
datac => \GRFPU0.GRFPU_X0.N_3560_I\,
datab => N_99921,
dataa => \GRFPU0.MULO.MRES\(116),
datag => \GRFPU0.GRFPU_X0.N_18663\);
\GRFPC0_OP2_5_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19745\,
dataf => \GRFPC0.DIV.RESULT\(52),
datae => N_99881,
datad => \GRFPU0.GRFPU_X0.N_20293_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(52),
datab => \GRFPC0.WR2.RREG.RES\(52),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP1_5_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20236\,
dataf => \GRFPC0.DIV.RESULT\(48),
datae => N_99878,
datad => \GRFPU0.GRFPU_X0.N_20273_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(48),
datab => \GRFPC0.WR2.RREG.RES\(48),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP1_5_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20229\,
dataf => \GRFPC0.DIV.RESULT\(41),
datae => N_99878_1,
datad => \GRFPU0.GRFPU_X0.N_20297_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(41),
datab => \GRFPC0.WR2.RREG.RES\(41),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP1_5_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20247\,
dataf => \GRFPC0.DIV.RESULT\(59),
datae => N_99878,
datad => \FPO.RES\(59),
datac => \GRFPC0.MEM.RREG.RES\(59),
datab => \GRFPC0.WR2.RREG.RES\(59),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_FP_PIPELINE_DBGDATA_4_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0fcff5f50fcfa0a0")
port map (
combout => CPO_DBG_DATAZ(13),
dataf => N_640,
datae => N_425,
datad => \GRFPC0.N_23695\,
datac => N_704,
datab => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2\,
dataa => N_426,
datag => \GRFPC0.FP_PIPELINE.QNE2_I_A4_1\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(23),
dataf => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(23),
datae => \GRFPC0.N_23670\,
datad => \GRFPC0.N_24034\,
datac => \GRFPC0.EX.CTRL.PC\(23),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(23));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(19),
dataf => \GRFPC0.N_250\,
datae => \GRFPC0.N_23670\,
datad => \GRFPC0.N_236\,
datac => \GRFPC0.EX.CTRL.PC\(19),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(19));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(12),
dataf => \GRFPC0.N_244\,
datae => \GRFPC0.N_23670\,
datad => \FPI.FLOP\(7),
datac => \GRFPC0.EX.CTRL.PC\(12),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fff4ff4ff4f44f4f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(48),
dataf => N_99920,
datae => \GRFPU0.MULO.MRES\(108),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(48),
datac => \GRFPU0.GRFPU_X0.N_18663\,
datab => N_99921,
dataa => \GRFPU0.MULO.MRES\(109),
datag => \GRFPU0.GRFPU_X0.N_3560_I\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(16),
dataf => \GRFPC0.N_247\,
datae => \GRFPC0.N_23670\,
datad => \GRFPC0.N_24488\,
datac => \GRFPC0.EX.CTRL.PC\(16),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(16));
\GRFPC0_OP1_6_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_20285\,
dataf => N_722,
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => \GRFPC0.OP1_4\,
datac => \GRFPC0.RFA2.RS1SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(31),
dataa => \GRFPC0.EX.RREG.RES\(31),
datag => N_658);
\GRFPC0_OP1_5_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20234\,
dataf => \GRFPC0.DIV.RESULT\(46),
datae => N_99878,
datad => \GRFPU0.GRFPU_X0.N_20291_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(46),
datab => \GRFPC0.WR2.RREG.RES\(46),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(27),
dataf => \GRFPC0.N_25236\,
datae => \GRFPC0.N_23670\,
datad => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datac => \GRFPC0.EX.CTRL.PC\(27),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(27));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fff4ff4ff4f44f4f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(46),
dataf => N_99920,
datae => \GRFPU0.MULO.MRES\(106),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(46),
datac => \GRFPU0.GRFPU_X0.N_18663\,
datab => N_99921,
dataa => \GRFPU0.MULO.MRES\(107),
datag => \GRFPU0.GRFPU_X0.N_3560_I\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(14),
dataf => \GRFPC0.N_245\,
datae => \GRFPC0.N_23670\,
datad => \GRFPC0.N_235\,
datac => \GRFPC0.EX.CTRL.PC\(14),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(18),
dataf => \GRFPC0.N_249\,
datae => \GRFPC0.N_23670\,
datad => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.EX.CTRL.PC\(18),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(18));
\GRFPC0_OP2_5_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19755\,
dataf => \GRFPC0.DIV.RESULT\(62),
datae => N_99881,
datad => \FPO.RES\(62),
datac => \GRFPC0.MEM.RREG.RES\(62),
datab => \GRFPC0.WR2.RREG.RES\(62),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(29),
dataf => \GRFPC0.N_255\,
datae => \GRFPC0.N_23670\,
datad => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datac => \GRFPC0.EX.CTRL.PC\(29),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(29));
\GRFPC0_OP1_5_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20220\,
dataf => \GRFPC0.DIV.RESULT\(32),
datae => N_99878_1,
datad => \GRFPU0.GRFPU_X0.N_20294_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(32),
datab => \GRFPC0.WR2.RREG.RES\(32),
dataa => \GRFPC0.RFA2.RS1SEL_1\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP2_5_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19754\,
dataf => \GRFPC0.DIV.RESULT\(61),
datae => N_99881,
datad => \FPO.RES\(61),
datac => \GRFPC0.MEM.RREG.RES\(61),
datab => \GRFPC0.WR2.RREG.RES\(61),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(7),
dataf => \GRFPC0.N_242\,
datae => \GRFPC0.N_23670\,
datad => \FPI.FLOP\(2),
datac => \GRFPC0.EX.CTRL.PC\(7),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(7));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(26),
dataf => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(26),
datae => \GRFPC0.N_23670\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.PC\(26),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(26));
\GRFPC0_OP1_5_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20241\,
dataf => \GRFPC0.DIV.RESULT\(53),
datae => N_99878,
datad => \FPO.RES\(53),
datac => \GRFPC0.MEM.RREG.RES\(53),
datab => \GRFPC0.WR2.RREG.RES\(53),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(8),
dataf => \GRFPC0.N_23982\,
datae => \GRFPC0.N_23670\,
datad => \FPI.FLOP\(3),
datac => \GRFPC0.EX.CTRL.PC\(8),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(8));
\GRFPC0_OP1_5_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20227\,
dataf => \GRFPC0.DIV.RESULT\(39),
datae => N_99878_1,
datad => \GRFPU0.GRFPU_X0.N_19153_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(39),
datab => \GRFPC0.WR2.RREG.RES\(39),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fff4ff4ff4f44f4f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(51),
dataf => N_99920,
datae => \GRFPU0.MULO.MRES\(111),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(51),
datac => \GRFPU0.GRFPU_X0.N_18663\,
datab => N_99921,
dataa => \GRFPU0.MULO.MRES\(112),
datag => \GRFPU0.GRFPU_X0.N_3560_I\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(28),
dataf => \GRFPC0.N_254\,
datae => \GRFPC0.N_23670\,
datad => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.PC\(28),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(28));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_2_I_O2_RNO_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f00f93930f0f9393")
port map (
combout => N_40568,
dataf => \GRFPU0.GRFPU_X0.ITER.SIGN\,
datae => \GRFPU0.GRFPU_X0.COMB.UN13_ITER_OF\,
datad => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datag => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0));
\GRFPC0_OP1_5_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20228\,
dataf => \GRFPC0.DIV.RESULT\(40),
datae => N_99878_1,
datad => \GRFPU0.GRFPU_X0.N_20289_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(40),
datab => \GRFPC0.WR2.RREG.RES\(40),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP1_5_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20233\,
dataf => \GRFPC0.DIV.RESULT\(45),
datae => N_99878,
datad => \GRFPU0.GRFPU_X0.N_20272_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(45),
datab => \GRFPC0.WR2.RREG.RES\(45),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP1_5_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20223\,
dataf => \GRFPC0.DIV.RESULT\(35),
datae => N_99878_1,
datad => \GRFPU0.GRFPU_X0.N_20295_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(35),
datab => \GRFPC0.WR2.RREG.RES\(35),
dataa => \GRFPC0.RFA2.RS1SEL_1\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(5),
dataf => \GRFPC0.N_240\,
datae => \GRFPC0.N_23670\,
datad => \FPI.FLOP\(0),
datac => \GRFPC0.EX.CTRL.PC\(5),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(5));
\GRFPC0_OP2_5_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19749\,
dataf => \GRFPC0.DIV.RESULT\(56),
datae => N_99881,
datad => N_46771_3,
datac => \GRFPC0.MEM.RREG.RES\(56),
datab => \GRFPC0.WR2.RREG.RES\(56),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP1_5_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20237\,
dataf => \GRFPC0.DIV.RESULT\(49),
datae => N_99878,
datad => \GRFPU0.GRFPU_X0.N_20292_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(49),
datab => \GRFPC0.WR2.RREG.RES\(49),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(2),
dataf => \GRFPC0.N_237\,
datae => \GRFPC0.N_23670\,
datad => \GRFPC0.N_225\,
datac => \GRFPC0.EX.CTRL.PC\(2),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(2));
\GRFPC0_OP1_5_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20245\,
dataf => \GRFPC0.DIV.RESULT\(57),
datae => N_99878,
datad => \GRFPU0.GRFPU_X0.N_20287_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(57),
datab => \GRFPC0.WR2.RREG.RES\(57),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(11),
dataf => \GRFPC0.N_25234\,
datae => \GRFPC0.N_23670\,
datad => \FPI.FLOP\(6),
datac => \GRFPC0.EX.CTRL.PC\(11),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(11));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fff4ff4ff4f44f4f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(49),
dataf => N_99920,
datae => \GRFPU0.MULO.MRES\(109),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(49),
datac => \GRFPU0.GRFPU_X0.N_18663\,
datab => N_99921,
dataa => \GRFPU0.MULO.MRES\(110),
datag => \GRFPU0.GRFPU_X0.N_3560_I\);
\GRFPC0_OP1_5_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20243\,
dataf => \GRFPC0.DIV.RESULT\(55),
datae => N_99878,
datad => \FPO.RES\(55),
datac => \GRFPC0.MEM.RREG.RES\(55),
datab => \GRFPC0.WR2.RREG.RES\(55),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"8ffff8ff8f8ff8f8")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(53),
dataf => N_99920,
datae => \GRFPU0.MULO.MRES\(113),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(53),
datac => \GRFPU0.GRFPU_X0.N_3560_I\,
datab => N_99921,
dataa => \GRFPU0.MULO.MRES\(114),
datag => \GRFPU0.GRFPU_X0.N_18663\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(21),
dataf => \GRFPC0.N_252\,
datae => \GRFPC0.N_23670\,
datad => \GRFPC0.N_222\,
datac => \GRFPC0.EX.CTRL.PC\(21),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(21));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_M2_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0a0a0cfc0f5f5")
port map (
combout => \GRFPU0.GRFPU_X0.N_18338\,
dataf => \GRFPU0.GRFPU_X0.N_18663\,
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.UN166_RNDOP\(38),
datac => \GRFPU0.GRFPU_X0.N_3560_I\,
datab => \GRFPU0.GRFPU_X0.UN177_RNDOP\(38),
dataa => \GRFPU0.MULO.MRES\(82),
datag => \GRFPU0.GRFPU_X0.N_11529\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(25),
dataf => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(25),
datae => \GRFPC0.N_23670\,
datad => \GRFPC0.V.STDATA_14\(25),
datac => \GRFPC0.EX.CTRL.PC\(25),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f7c4f0f0b380f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(3),
dataf => \GRFPC0.N_238\,
datae => \GRFPC0.N_23670\,
datad => \GRFPC0.N_226\,
datac => \GRFPC0.EX.CTRL.PC\(3),
datab => N_25,
dataa => \GRFPC0.EX.CTRL.PEND\,
datag => \GRFPC0.EX.CTRL.INST\(3));
\GRFPC0_OP1_5_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20221\,
dataf => \GRFPC0.DIV.RESULT\(33),
datae => N_99878_1,
datad => \FPO.RES\(33),
datac => \GRFPC0.MEM.RREG.RES\(33),
datab => \GRFPC0.WR2.RREG.RES\(33),
dataa => \GRFPC0.RFA2.RS1SEL_1\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_OP2_5_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19744\,
dataf => \GRFPC0.DIV.RESULT\(51),
datae => N_99881,
datad => \GRFPU0.GRFPU_X0.N_20285_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(51),
datab => \GRFPC0.WR2.RREG.RES\(51),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fff4ff4ff4f44f4f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(45),
dataf => N_99920,
datae => \GRFPU0.MULO.MRES\(105),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(45),
datac => \GRFPU0.GRFPU_X0.N_18663\,
datab => N_99921,
dataa => \GRFPU0.MULO.MRES\(106),
datag => \GRFPU0.GRFPU_X0.N_3560_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_2_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fff4ff4ff4f44f4f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(56),
dataf => N_99920,
datae => \GRFPU0.MULO.MRES\(116),
datad => \GRFPU0.GRFPU_X0.N_18386\,
datac => \GRFPU0.GRFPU_X0.N_18663\,
datab => N_99921,
dataa => \GRFPU0.MULO.MRES\(117),
datag => \GRFPU0.GRFPU_X0.N_3560_I\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_0_A2_2_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"1000100000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19804\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datae => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.N_19547\,
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8));
\GRFPC0_OP1_5_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20248\,
dataf => \GRFPC0.DIV.RESULT\(60),
datae => N_99878,
datad => \GRFPU0.GRFPU_X0.N_20288_I_0\,
datac => \GRFPC0.MEM.RREG.RES\(60),
datab => \GRFPC0.WR2.RREG.RES\(60),
dataa => \GRFPC0.RFA2.RS1SEL\(2),
datag => \GRFPC0.RFA2.RS1SEL\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(11),
dataf => \GRFPC0.WR.CTRL.PC\(11),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(11),
datac => \GRFPC0.WR.CTRL.INST\(11),
datab => \GRFPC0.WR2.CTRL.INST\(11),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(9),
dataf => \GRFPC0.WR.CTRL.PC\(9),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(9),
datac => \GRFPC0.WR.CTRL.INST\(9),
datab => \GRFPC0.WR2.CTRL.INST\(9),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17187\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(5),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(4),
dataf => \GRFPC0.WR.CTRL.PC\(4),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(4),
datac => \GRFPC0.WR.CTRL.INST\(4),
datab => \GRFPC0.WR2.CTRL.INST\(4),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPC0_OP1_6_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20272\,
dataf => \GRFPC0.WR.RREG.RES\(18),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_709,
datac => \GRFPC0.EX.RREG.RES\(18),
datab => N_645,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17238\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(4),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(56),
datag => \GRFPU0.GRFPU_X0.ST1.EXP2\(4));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17207\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(25),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17199\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(17),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(10),
dataf => \GRFPC0.WR.CTRL.PC\(10),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(10),
datac => \GRFPC0.WR.CTRL.INST\(10),
datab => \GRFPC0.WR2.CTRL.INST\(10),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(3),
dataf => \GRFPC0.WR.CTRL.PC\(3),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(3),
datac => \GRFPC0.WR.CTRL.INST\(3),
datab => \GRFPC0.WR2.CTRL.INST\(3),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPC0_OP2_6_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19765\,
dataf => \GRFPC0.WR.RREG.RES\(6),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_729,
datac => \GRFPC0.EX.RREG.RES\(6),
datab => N_665,
dataa => \GRFPC0.RFA2.RS2SEL_0\(1),
datag => \GRFPC0.OP2_4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17240\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(6),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(58),
datag => \GRFPU0.GRFPU_X0.ST1.EXP2\(6));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fffffefefffcfefe")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_2_TZ\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M40_2_03\,
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_2_03\,
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M42_2_03\,
datag => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_2_03\);
\GRFPC0_OP2_6_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19764\,
dataf => \GRFPC0.WR.RREG.RES\(5),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_728,
datac => \GRFPC0.EX.RREG.RES\(5),
datab => N_664,
dataa => \GRFPC0.RFA2.RS2SEL_0\(1),
datag => \GRFPC0.OP2_4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17189\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(7),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17219\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(37),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(24),
dataf => \GRFPC0.WR.CTRL.PC\(24),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(24),
datac => \GRFPC0.WR.CTRL.INST\(24),
datab => \GRFPC0.WR2.CTRL.INST\(24),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17193\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(11),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(26),
dataf => \GRFPC0.WR.CTRL.PC\(26),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(26),
datac => \GRFPC0.WR.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(26),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPC0_OP2_6_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19778\,
dataf => \GRFPC0.WR.RREG.RES\(19),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_742,
datac => \GRFPC0.EX.RREG.RES\(19),
datab => N_678,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(2),
dataf => \GRFPC0.WR.CTRL.PC\(2),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(2),
datac => \GRFPC0.WR.CTRL.INST\(2),
datab => \GRFPC0.WR2.CTRL.INST\(2),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17198\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(16),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16));
\GRFPC0_OP2_6_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19763\,
dataf => \GRFPC0.WR.RREG.RES\(4),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_727,
datac => \GRFPC0.EX.RREG.RES\(4),
datab => N_663,
dataa => \GRFPC0.RFA2.RS2SEL_0\(1),
datag => \GRFPC0.OP2_4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17244\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(62),
datag => \GRFPU0.GRFPU_X0.ST1.EXP2\(10));
\GRFPC0_OP2_6_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19766\,
dataf => \GRFPC0.WR.RREG.RES\(7),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_730,
datac => \GRFPC0.EX.RREG.RES\(7),
datab => N_666,
dataa => \GRFPC0.RFA2.RS2SEL_0\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP2_6_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19790\,
dataf => \GRFPC0.WR.RREG.RES\(31),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_754,
datac => \GRFPC0.EX.RREG.RES\(31),
datab => N_690,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(25),
dataf => \GRFPC0.WR.CTRL.PC\(25),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(25),
datac => \GRFPC0.WR.CTRL.INST\(25),
datab => \GRFPC0.WR2.CTRL.INST\(25),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPC0_OP2_6_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19787\,
dataf => \GRFPC0.WR.RREG.RES\(28),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_751,
datac => \GRFPC0.EX.RREG.RES\(28),
datab => N_687,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17227\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(45),
datag => \GRFPU0.DIVROM0.RADDR\(1));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_0_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17233\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(51),
datag => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPC0_OP1_6_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20268\,
dataf => \GRFPC0.WR.RREG.RES\(14),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_705,
datac => \GRFPC0.EX.RREG.RES\(14),
datab => N_641,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP1_6_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20271\,
dataf => \GRFPC0.WR.RREG.RES\(17),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_708,
datac => \GRFPC0.EX.RREG.RES\(17),
datab => N_644,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP2_6_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19788\,
dataf => \GRFPC0.WR.RREG.RES\(29),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_752,
datac => \GRFPC0.EX.RREG.RES\(29),
datab => N_688,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_0_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17234\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(52),
datag => \GRFPU0.GRFPU_X0.ST1.EXP2\(0));
\GRFPC0_OP1_6_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_20304\,
dataf => N_645,
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => N_99879,
datac => \GRFPC0.RFA2.RS1SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(50),
dataa => \GRFPC0.EX.RREG.RES\(50),
datag => N_709);
\GRFPC0_OP2_6_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19772\,
dataf => \GRFPC0.WR.RREG.RES\(13),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_736,
datac => \GRFPC0.EX.RREG.RES\(13),
datab => N_672,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(18),
dataf => \GRFPC0.WR.CTRL.PC\(18),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(18),
datac => \GRFPC0.WR.CTRL.INST\(18),
datab => \GRFPC0.WR2.CTRL.INST\(18),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPC0_OP2_6_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19779\,
dataf => \GRFPC0.WR.RREG.RES\(20),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_743,
datac => \GRFPC0.EX.RREG.RES\(20),
datab => N_679,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(6),
dataf => \GRFPC0.WR.CTRL.PC\(6),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(6),
datac => \GRFPC0.WR.CTRL.INST\(6),
datab => \GRFPC0.WR2.CTRL.INST\(6),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17196\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(14),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17192\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(10),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(31),
dataf => \GRFPC0.WR.CTRL.PC\(31),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(31),
datac => \GRFPC0.WR.CTRL.INST\(31),
datab => \GRFPC0.WR2.CTRL.INST\(31),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPC0_OP1_6_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20278\,
dataf => \GRFPC0.WR.RREG.RES\(24),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_715,
datac => \GRFPC0.EX.RREG.RES\(24),
datab => N_651,
dataa => \GRFPC0.RFA2.RS1SEL\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP1_6_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20270\,
dataf => \GRFPC0.WR.RREG.RES\(16),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_707,
datac => \GRFPC0.EX.RREG.RES\(16),
datab => N_643,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(22),
dataf => \GRFPC0.WR.CTRL.PC\(22),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(22),
datac => \GRFPC0.WR.CTRL.INST\(22),
datab => \GRFPC0.WR2.CTRL.INST\(22),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPC0_OP1_6_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20269\,
dataf => \GRFPC0.WR.RREG.RES\(15),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_706,
datac => \GRFPC0.EX.RREG.RES\(15),
datab => N_642,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP1_6_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20261\,
dataf => \GRFPC0.WR.RREG.RES\(7),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_698,
datac => \GRFPC0.EX.RREG.RES\(7),
datab => N_634,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP1_6_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20258\,
dataf => \GRFPC0.WR.RREG.RES\(4),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_695,
datac => \GRFPC0.EX.RREG.RES\(4),
datab => N_631,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(7),
dataf => \GRFPC0.WR.CTRL.PC\(7),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(7),
datac => \GRFPC0.WR.CTRL.INST\(7),
datab => \GRFPC0.WR2.CTRL.INST\(7),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPC0_OP1_6_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20273\,
dataf => \GRFPC0.WR.RREG.RES\(19),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_710,
datac => \GRFPC0.EX.RREG.RES\(19),
datab => N_646,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP1_6_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20262\,
dataf => \GRFPC0.WR.RREG.RES\(8),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_699,
datac => \GRFPC0.EX.RREG.RES\(8),
datab => N_635,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP2_6_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19761\,
dataf => \GRFPC0.WR.RREG.RES\(2),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_725,
datac => \GRFPC0.EX.RREG.RES\(2),
datab => N_661,
dataa => \GRFPC0.RFA2.RS2SEL_0\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP2_6_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19789\,
dataf => \GRFPC0.WR.RREG.RES\(30),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_753,
datac => \GRFPC0.EX.RREG.RES\(30),
datab => N_689,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP2_6_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19771\,
dataf => \GRFPC0.WR.RREG.RES\(12),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_735,
datac => \GRFPC0.EX.RREG.RES\(12),
datab => N_671,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP1_6_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20255\,
dataf => \GRFPC0.WR.RREG.RES\(1),
datae => \GRFPC0.RFA2.RS1SEL_0\(7),
datad => N_692,
datac => \GRFPC0.EX.RREG.RES\(1),
datab => N_628,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP2_6_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19783\,
dataf => \GRFPC0.WR.RREG.RES\(24),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_747,
datac => \GRFPC0.EX.RREG.RES\(24),
datab => N_683,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP1_6_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20265\,
dataf => \GRFPC0.WR.RREG.RES\(11),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_702,
datac => \GRFPC0.EX.RREG.RES\(11),
datab => N_638,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP1_6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20254\,
dataf => \GRFPC0.WR.RREG.RES\(0),
datae => \GRFPC0.RFA2.RS1SEL_0\(7),
datad => N_691,
datac => \GRFPC0.EX.RREG.RES\(0),
datab => N_627,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP2_6_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19760\,
dataf => \GRFPC0.WR.RREG.RES\(1),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_724,
datac => \GRFPC0.EX.RREG.RES\(1),
datab => N_660,
dataa => \GRFPC0.RFA2.RS2SEL_0\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP2_6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19759\,
dataf => \GRFPC0.WR.RREG.RES\(0),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_723,
datac => \GRFPC0.EX.RREG.RES\(0),
datab => N_659,
dataa => \GRFPC0.RFA2.RS2SEL_0\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP1_6_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20257\,
dataf => \GRFPC0.WR.RREG.RES\(3),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_694,
datac => \GRFPC0.EX.RREG.RES\(3),
datab => N_630,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP2_6_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19774\,
dataf => \GRFPC0.WR.RREG.RES\(15),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_738,
datac => \GRFPC0.EX.RREG.RES\(15),
datab => N_674,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(13),
dataf => \GRFPC0.WR.CTRL.PC\(13),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(13),
datac => \GRFPC0.WR.CTRL.INST\(13),
datab => \GRFPC0.WR2.CTRL.INST\(13),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(16),
dataf => \GRFPC0.WR.CTRL.PC\(16),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(16),
datac => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(16),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(17),
dataf => \GRFPC0.WR.CTRL.PC\(17),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(17),
datac => \GRFPC0.WR.CTRL.INST\(17),
datab => \GRFPC0.WR2.CTRL.INST\(17),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17204\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(22),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22));
\GRFPC0_OP2_6_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19777\,
dataf => \GRFPC0.WR.RREG.RES\(18),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_741,
datac => \GRFPC0.EX.RREG.RES\(18),
datab => N_677,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17211\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(29),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(12),
dataf => \GRFPC0.WR.CTRL.PC\(12),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(12),
datac => \GRFPC0.WR.CTRL.INST\(12),
datab => \GRFPC0.WR2.CTRL.INST\(12),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPC0_OP1_6_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20282\,
dataf => \GRFPC0.WR.RREG.RES\(28),
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => N_719,
datac => \GRFPC0.EX.RREG.RES\(28),
datab => N_655,
dataa => \GRFPC0.RFA2.RS1SEL\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP2_6_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19786\,
dataf => \GRFPC0.WR.RREG.RES\(27),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_750,
datac => \GRFPC0.EX.RREG.RES\(27),
datab => N_686,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(20),
dataf => \GRFPC0.WR.CTRL.PC\(20),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(20),
datac => \GRFPC0.WR.CTRL.INST\(20),
datab => \GRFPC0.WR2.CTRL.INST\(20),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPC0_OP1_6_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20274\,
dataf => \GRFPC0.WR.RREG.RES\(20),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_711,
datac => \GRFPC0.EX.RREG.RES\(20),
datab => N_647,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP1_6_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20267\,
dataf => \GRFPC0.WR.RREG.RES\(13),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_704,
datac => \GRFPC0.EX.RREG.RES\(13),
datab => N_640,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP1_6_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20256\,
dataf => \GRFPC0.WR.RREG.RES\(2),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_693,
datac => \GRFPC0.EX.RREG.RES\(2),
datab => N_629,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17214\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32));
\GRFPC0_OP1_6_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20260\,
dataf => \GRFPC0.WR.RREG.RES\(6),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_697,
datac => \GRFPC0.EX.RREG.RES\(6),
datab => N_633,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17243\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(9),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(61),
datag => \GRFPU0.GRFPU_X0.ST1.EXP2\(9));
\GRFPC0_OP2_6_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19785\,
dataf => \GRFPC0.WR.RREG.RES\(26),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_749,
datac => \GRFPC0.EX.RREG.RES\(26),
datab => N_685,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP1_6_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20259\,
dataf => \GRFPC0.WR.RREG.RES\(5),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_696,
datac => \GRFPC0.EX.RREG.RES\(5),
datab => N_632,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP1_6_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20281\,
dataf => \GRFPC0.WR.RREG.RES\(27),
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => N_718,
datac => \GRFPC0.EX.RREG.RES\(27),
datab => N_654,
dataa => \GRFPC0.RFA2.RS1SEL\(1),
datag => \GRFPC0.OP1_4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17220\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(38),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38));
\GRFPC0_OP2_6_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_19818\,
dataf => N_686,
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_99882,
datac => \GRFPC0.RFA2.RS2SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(59),
dataa => \GRFPC0.EX.RREG.RES\(59),
datag => N_750);
\GRFPC0_OP1_6_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20264\,
dataf => \GRFPC0.WR.RREG.RES\(10),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_701,
datac => \GRFPC0.EX.RREG.RES\(10),
datab => N_637,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP2_6_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19770\,
dataf => \GRFPC0.WR.RREG.RES\(11),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_734,
datac => \GRFPC0.EX.RREG.RES\(11),
datab => N_670,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP2_6_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19762\,
dataf => \GRFPC0.WR.RREG.RES\(3),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_726,
datac => \GRFPC0.EX.RREG.RES\(3),
datab => N_662,
dataa => \GRFPC0.RFA2.RS2SEL_0\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(27),
dataf => \GRFPC0.WR.CTRL.PC\(27),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(27),
datac => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR2.CTRL.INST\(27),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(30),
dataf => \GRFPC0.WR.CTRL.PC\(30),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(30),
datac => \GRFPC0.WR.CTRL.INST\(30),
datab => \GRFPC0.WR2.CTRL.INST\(30),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPC0_OP2_6_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19775\,
dataf => \GRFPC0.WR.RREG.RES\(16),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_739,
datac => \GRFPC0.EX.RREG.RES\(16),
datab => N_675,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17186\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(4),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17188\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(6),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(28),
dataf => \GRFPC0.WR.CTRL.PC\(28),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(28),
datac => \GRFPC0.WR.CTRL.INST\(28),
datab => \GRFPC0.WR2.CTRL.INST\(28),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17218\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36));
\GRFPC0_OP1_6_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20283\,
dataf => \GRFPC0.WR.RREG.RES\(29),
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => N_720,
datac => \GRFPC0.EX.RREG.RES\(29),
datab => N_656,
dataa => \GRFPC0.RFA2.RS1SEL\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP2_6_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19784\,
dataf => \GRFPC0.WR.RREG.RES\(25),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_748,
datac => \GRFPC0.EX.RREG.RES\(25),
datab => N_684,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP2_6_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19768\,
dataf => \GRFPC0.WR.RREG.RES\(9),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_732,
datac => \GRFPC0.EX.RREG.RES\(9),
datab => N_668,
dataa => \GRFPC0.RFA2.RS2SEL_0\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP1_6_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_20290\,
dataf => N_631,
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => N_99879,
datac => \GRFPC0.RFA2.RS1SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(36),
dataa => \GRFPC0.EX.RREG.RES\(36),
datag => N_695);
\GRFPC0_OP1_6_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20263\,
dataf => \GRFPC0.WR.RREG.RES\(9),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_700,
datac => \GRFPC0.EX.RREG.RES\(9),
datab => N_636,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17224\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(42),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17242\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(8),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
datag => \GRFPU0.GRFPU_X0.ST1.EXP2\(8));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17217\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(35),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(15),
dataf => \GRFPC0.WR.CTRL.PC\(15),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(15),
datac => \GRFPC0.WR.CTRL.INST\(15),
datab => \GRFPC0.WR2.CTRL.INST\(15),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPC0_OP2_6_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19782\,
dataf => \GRFPC0.WR.RREG.RES\(23),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_746,
datac => \GRFPC0.EX.RREG.RES\(23),
datab => N_682,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP1_6_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_20315\,
dataf => N_656,
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => N_99879,
datac => \GRFPC0.RFA2.RS1SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(61),
dataa => \GRFPC0.EX.RREG.RES\(61),
datag => N_720);
\GRFPC0_OP2_6_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19776\,
dataf => \GRFPC0.WR.RREG.RES\(17),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_740,
datac => \GRFPC0.EX.RREG.RES\(17),
datab => N_676,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(5),
dataf => \GRFPC0.WR.CTRL.PC\(5),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(5),
datac => \GRFPC0.WR.CTRL.INST\(5),
datab => \GRFPC0.WR2.CTRL.INST\(5),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M3_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(29),
dataf => \GRFPC0.WR.CTRL.PC\(29),
datae => \GRFPC0.N_23712\,
datad => \GRFPC0.WR2.CTRL.PC\(29),
datac => \GRFPC0.WR.CTRL.INST\(29),
datab => \GRFPC0.WR2.CTRL.INST\(29),
dataa => \GRFPC0.N_23667\,
datag => \GRFPC0.N_19\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17194\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(12),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12));
\GRFPC0_OP2_6_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19780\,
dataf => \GRFPC0.WR.RREG.RES\(21),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_744,
datac => \GRFPC0.EX.RREG.RES\(21),
datab => N_680,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP2_6_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19781\,
dataf => \GRFPC0.WR.RREG.RES\(22),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_745,
datac => \GRFPC0.EX.RREG.RES\(22),
datab => N_681,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0000000000100010")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.R_I_33_M\(7),
dataf => \GRFPU0.GRFPU_X0.N_18664\,
datae => \GRFPU0.GRFPU_X0.N_4401\,
datad => \GRFPU0.GRFPU_X0.N_4481\,
datac => \GRFPU0.MULO.MRES\(67),
datab => \GRFPU0.GRFPU_X0.N_4482\,
dataa => \GRFPU0.GRFPU_X0.N_4664\,
datag => \GRFPU0.MULO.DRES_S\(66));
\GRFPC0_OP1_6_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20266\,
dataf => \GRFPC0.WR.RREG.RES\(12),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_703,
datac => \GRFPC0.EX.RREG.RES\(12),
datab => N_639,
dataa => \GRFPC0.RFA2.RS1SEL_1\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP1_6_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20275\,
dataf => \GRFPC0.WR.RREG.RES\(21),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_712,
datac => \GRFPC0.EX.RREG.RES\(21),
datab => N_648,
dataa => \GRFPC0.RFA2.RS1SEL\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP1_6_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20279\,
dataf => \GRFPC0.WR.RREG.RES\(25),
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => N_716,
datac => \GRFPC0.EX.RREG.RES\(25),
datab => N_652,
dataa => \GRFPC0.RFA2.RS1SEL\(1),
datag => \GRFPC0.OP1_4\);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_I_M2_RNI9OC35_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0000000001000100")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_3\(3),
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(18),
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.GRFPU_X0.UN128_BCO_LSB\(15),
datac => \GRFPU0.MULO.DRES_1S\(112),
datab => \GRFPU0.GRFPU_X0.N_18315\,
dataa => \GRFPU0.GRFPU_X0.N_18307\,
datag => \GRFPU0.MULO.DRES_1\(113));
\GRFPC0_OP2_6_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19769\,
dataf => \GRFPC0.WR.RREG.RES\(10),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_733,
datac => \GRFPC0.EX.RREG.RES\(10),
datab => N_669,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17184\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(2),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2));
\GRFPC0_OP1_6_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0ffacacf000acac")
port map (
combout => \GRFPC0.N_20310\,
dataf => N_651,
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => N_99879,
datac => \GRFPC0.RFA2.RS1SEL\(1),
datab => \GRFPC0.WR.RREG.RES\(56),
dataa => \GRFPC0.EX.RREG.RES\(56),
datag => N_715);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17239\,
dataf => \GRFPU0.GRFPU_X0.ST1.EXP1\(5),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(57),
datag => \GRFPU0.GRFPU_X0.ST1.EXP2\(5));
\GRFPC0_OP2_6_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19767\,
dataf => \GRFPC0.WR.RREG.RES\(8),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_731,
datac => \GRFPC0.EX.RREG.RES\(8),
datab => N_667,
dataa => \GRFPC0.RFA2.RS2SEL_0\(1),
datag => \GRFPC0.OP2_4\);
\GRFPC0_OP2_6_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19773\,
dataf => \GRFPC0.WR.RREG.RES\(14),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_737,
datac => \GRFPC0.EX.RREG.RES\(14),
datab => N_673,
dataa => \GRFPC0.RFA2.RS2SEL_1\(1),
datag => \GRFPC0.OP2_4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17191\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(9),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9));
\GRFPC0_OP1_6_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20276\,
dataf => \GRFPC0.WR.RREG.RES\(22),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_713,
datac => \GRFPC0.EX.RREG.RES\(22),
datab => N_649,
dataa => \GRFPC0.RFA2.RS1SEL\(1),
datag => \GRFPC0.OP1_4\);
\GRFPC0_OP1_6_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20277\,
dataf => \GRFPC0.WR.RREG.RES\(23),
datae => \GRFPC0.RFA2.RS1SEL_1\(7),
datad => N_714,
datac => \GRFPC0.EX.RREG.RES\(23),
datab => N_650,
dataa => \GRFPC0.RFA2.RS1SEL\(1),
datag => \GRFPC0.OP1_4\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"b8bba8a8b888a8a8")
port map (
combout => \GRFPU0.GRFPU_X0.N_17185\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datac => \GRFPU0.GRFPU_X0.N_4105\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(3),
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3));
\GRFPU0_GRFPU_X0_L1_1_1_5_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0a0f0b0b0a0a0a0a")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_5\(0),
dataf => \GRFPU0.GRFPU_X0.TZI2\(11),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
dataa => \GRFPU0.GRFPU_X0.TZI2\(9),
datag => \GRFPU0.GRFPU_X0.ITER.R_I\(16));
GRFPU0_GRFPU_X0_UN243_BCO_LSB_0_0_RNI37GK4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0000000002000200")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_6\(3),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_3\(26),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.N_13525\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3\(31),
dataa => \GRFPU0.GRFPU_X0.UN243_BCO_LSB_0\,
datag => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(27));
\GRFPC0_OP2_6_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19791\,
dataf => \GRFPC0.WR.RREG.RES\(32),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_659,
datac => \GRFPC0.EX.RREG.RES\(32),
datab => N_723,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => N_99882);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_42__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14530\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28254,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(45),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(42),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
\GRFPC0_OP2_6_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19806\,
dataf => \GRFPC0.WR.RREG.RES\(47),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_674,
datac => \GRFPC0.EX.RREG.RES\(47),
datab => N_738,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => N_99882);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_44__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14532\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28258,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(47),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(44),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_46__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14534\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28262,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(49),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(46),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_45__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14533\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28260,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(48),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(45),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNIPR9N3_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"ccccc8c8ccc00000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.REG_4_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datab => \GRFPU0.GRFPU_X0.N_3516\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datag => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8));
\GRFPC0_OP1_6_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20316\,
dataf => \GRFPC0.WR.RREG.RES\(62),
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => N_657,
datac => \GRFPC0.EX.RREG.RES\(62),
datab => N_721,
dataa => \GRFPC0.RFA2.RS1SEL\(1),
datag => N_99879);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_47__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14535\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28264,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(50),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(47),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_43__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14531\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28256,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(46),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(43),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_48__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14536\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28266,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(51),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(48),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_30__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14518\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28230,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(33),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(30),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_32__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14520\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28234,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(35),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(32),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_49__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14537\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28268,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(52),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(49),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
\GRFPU0_GRFPU_X0_L1_0_1_4_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0a0f0b0b0a0a0a0a")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1_4\(0),
dataf => \GRFPU0.GRFPU_X0.TZI2\(3),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
dataa => \GRFPU0.GRFPU_X0.TZI2\(1),
datag => \GRFPU0.GRFPU_X0.ITER.R_I\(8));
\GRFPU0_GRFPU_X0_L1_1_1_4_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0a0f0b0b0a0a0a0a")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_4\(0),
dataf => \GRFPU0.GRFPU_X0.TZI\(11),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(18),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(45),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(47),
dataa => \GRFPU0.GRFPU_X0.TZI\(9),
datag => \GRFPU0.GRFPU_X0.ITER.ND_I\(16));
\GRFPC0_OP2_6_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19804\,
dataf => \GRFPC0.WR.RREG.RES\(45),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_672,
datac => \GRFPC0.EX.RREG.RES\(45),
datab => N_736,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => N_99882);
\GRFPC0_OP2_6_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19799\,
dataf => \GRFPC0.WR.RREG.RES\(40),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_667,
datac => \GRFPC0.EX.RREG.RES\(40),
datab => N_731,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => N_99882);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_41__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14529\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28252,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(44),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(41),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_36__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14524\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28242,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(39),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(36),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_31__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14519\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28232,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(34),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(31),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
\GRFPC0_OP1_6_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20312\,
dataf => \GRFPC0.WR.RREG.RES\(58),
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => N_653,
datac => \GRFPC0.EX.RREG.RES\(58),
datab => N_717,
dataa => \GRFPC0.RFA2.RS1SEL\(1),
datag => N_99879);
\GRFPC0_OP2_6_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19802\,
dataf => \GRFPC0.WR.RREG.RES\(43),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_670,
datac => \GRFPC0.EX.RREG.RES\(43),
datab => N_734,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => N_99882);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_37__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14525\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28244,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(40),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(37),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
\GRFPU0_GRFPU_X0_L1_1_1_6_0_I_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"ff55ddddff05cdcd")
port map (
combout => \GRFPU0.GRFPU_X0.N_19772\,
dataf => \GRFPU0.GRFPU_X0.N_19566\,
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(23),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(52),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(55),
dataa => \GRFPU0.GRFPU_X0.INF_ABS0_3\(22),
datag => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(20));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_34__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14522\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28238,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(37),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(34),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_33__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14521\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28236,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(36),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(33),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
GRFPU0_GRFPU_X0_UN1_EXPT_3_SQMUXA_3_I_A2_0_2_RNIJMEI2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0000040004000400")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EMINM1_0_0_N_5\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\,
datae => \GRFPU0.GRFPU_X0.N_5226\,
datad => \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3_I_A2_0_2\,
datac => \GRFPU0.GRFPU_X0.N_17\,
datab => \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3_I_A2_0_3\,
dataa => \GRFPU0.GRFPU_X0.UN8_C\(10),
datag => \GRFPU0.GRFPU_X0.N_19\);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_38__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14526\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28246,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(41),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(38),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
\GRFPC0_OP2_6_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19795\,
dataf => \GRFPC0.WR.RREG.RES\(36),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_663,
datac => \GRFPC0.EX.RREG.RES\(36),
datab => N_727,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => N_99882);
\GRFPC0_OP2_6_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19798\,
dataf => \GRFPC0.WR.RREG.RES\(39),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_666,
datac => \GRFPC0.EX.RREG.RES\(39),
datab => N_730,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => N_99882);
\GRFPC0_OP2_6_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19808\,
dataf => \GRFPC0.WR.RREG.RES\(49),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_676,
datac => \GRFPC0.EX.RREG.RES\(49),
datab => N_740,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => N_99882);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_51__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14539\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28272,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(51),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_35__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14523\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28240,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(38),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(35),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_39__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14527\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28248,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(42),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(39),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
\GRFPC0_OP2_6_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19793\,
dataf => \GRFPC0.WR.RREG.RES\(34),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_661,
datac => \GRFPC0.EX.RREG.RES\(34),
datab => N_725,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => N_99882);
\GRFPC0_OP1_6_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_20317\,
dataf => \GRFPC0.WR.RREG.RES\(63),
datae => \GRFPC0.RFA2.RS1SEL\(7),
datad => N_658,
datac => \GRFPC0.EX.RREG.RES\(63),
datab => N_722,
dataa => \GRFPC0.RFA2.RS1SEL\(1),
datag => N_99879);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_50__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14538\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28270,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(53),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(50),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
\GRFPC0_OP2_6_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19800\,
dataf => \GRFPC0.WR.RREG.RES\(41),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_668,
datac => \GRFPC0.EX.RREG.RES\(41),
datab => N_732,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => N_99882);
\GRFPC0_OP2_6_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19807\,
dataf => \GRFPC0.WR.RREG.RES\(48),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_675,
datac => \GRFPC0.EX.RREG.RES\(48),
datab => N_739,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => N_99882);
\GRFPC0_OP2_6_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19801\,
dataf => \GRFPC0.WR.RREG.RES\(42),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_669,
datac => \GRFPC0.EX.RREG.RES\(42),
datab => N_733,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => N_99882);
\GRFPC0_OP2_6_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19805\,
dataf => \GRFPC0.WR.RREG.RES\(46),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_673,
datac => \GRFPC0.EX.RREG.RES\(46),
datab => N_737,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => N_99882);
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_40__G1\,
dataf => \GRFPU0.GRFPU_X0.N_14528\,
datae => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datad => N_28250,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(43),
datab => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(40),
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datag => N_28276);
\GRFPC0_OP2_6_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19796\,
dataf => \GRFPC0.WR.RREG.RES\(37),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_664,
datac => \GRFPC0.EX.RREG.RES\(37),
datab => N_728,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => N_99882);
\GRFPC0_OP2_6_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19797\,
dataf => \GRFPC0.WR.RREG.RES\(38),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_665,
datac => \GRFPC0.EX.RREG.RES\(38),
datab => N_729,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => N_99882);
\GRFPC0_OP2_6_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19794\,
dataf => \GRFPC0.WR.RREG.RES\(35),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_662,
datac => \GRFPC0.EX.RREG.RES\(35),
datab => N_726,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => N_99882);
\GRFPC0_OP2_6_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19809\,
dataf => \GRFPC0.WR.RREG.RES\(50),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_677,
datac => \GRFPC0.EX.RREG.RES\(50),
datab => N_741,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => N_99882);
\GRFPC0_OP2_6_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19803\,
dataf => \GRFPC0.WR.RREG.RES\(44),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_671,
datac => \GRFPC0.EX.RREG.RES\(44),
datab => N_735,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => N_99882);
\GRFPC0_OP2_6_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19792\,
dataf => \GRFPC0.WR.RREG.RES\(33),
datae => \GRFPC0.RFA2.RS2SEL\(7),
datad => N_660,
datac => \GRFPC0.EX.RREG.RES\(33),
datab => N_724,
dataa => \GRFPC0.RFA2.RS2SEL\(1),
datag => N_99882);
\GRFPU0_GRFPU_X0_COMB_EXPADDSUB_EXPT_0_A4_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0002000200000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_43\,
dataf => \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3_I_A2_0_3\,
datae => \GRFPU0.GRFPU_X0.N_5226\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\,
datac => \GRFPU0.GRFPU_X0.N_17\,
datab => \GRFPU0.GRFPU_X0.UN8_C\(10),
dataa => \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3_I_A2_0_2\,
datag => \GRFPU0.GRFPU_X0.N_19\);
\GRFPU0_GRFPU_X0_L1_0_1_5_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0a0f0b0b0a0a0a0a")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1_5\(0),
dataf => \GRFPU0.GRFPU_X0.TZI\(3),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(10),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(37),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(39),
dataa => \GRFPU0.GRFPU_X0.TZI\(1),
datag => \GRFPU0.GRFPU_X0.ITER.ND_I\(8));
\GRFPC0_STDATA_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(14),
dataf => \GRFPC0.R.FSR.FTT\(0),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(46),
datac => \GRFPC0.R.STDATA\(14),
datab => \GRFPC0.EX.RREG.RES\(14),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPU0_GRFPU_X0_L1_0_4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"ffccfafaffcffafa")
port map (
combout => N_82177,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
datae => \GRFPU0.GRFPU_X0.N_9732\,
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(53),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(52),
datag => \GRFPU0.GRFPU_X0.ST2.DIFF\(46));
\GRFPC0_STDATA_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(7),
dataf => \GRFPC0.R.FSR.AEXC\(2),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(39),
datac => \GRFPC0.R.STDATA\(7),
datab => \GRFPC0.EX.RREG.RES\(7),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(16),
dataf => \GRFPC0.R.FSR.FTT\(2),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(48),
datac => \GRFPC0.R.STDATA\(16),
datab => \GRFPC0.EX.RREG.RES\(16),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(30),
dataf => \FPI.RNDMODE\(0),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(62),
datac => \GRFPC0.R.STDATA\(30),
datab => \GRFPC0.EX.RREG.RES\(30),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(3),
dataf => \GRFPC0.R.FSR.CEXC\(3),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(35),
datac => \GRFPC0.R.STDATA\(3),
datab => \GRFPC0.EX.RREG.RES\(3),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(5),
dataf => \GRFPC0.R.FSR.AEXC\(0),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(37),
datac => \GRFPC0.R.STDATA\(5),
datab => \GRFPC0.EX.RREG.RES\(5),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(1),
dataf => \GRFPC0.R.FSR.CEXC\(1),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(33),
datac => \GRFPC0.R.STDATA\(1),
datab => \GRFPC0.EX.RREG.RES\(1),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(9),
dataf => \GRFPC0.R.FSR.AEXC\(4),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(41),
datac => \GRFPC0.R.STDATA\(9),
datab => \GRFPC0.EX.RREG.RES\(9),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPU0_GRFPU_X0_L1_3_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"ffccfafaffcffafa")
port map (
combout => N_82179,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(23),
datae => \GRFPU0.GRFPU_X0.N_9673\,
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(24),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datag => \GRFPU0.GRFPU_X0.ST2.DIFF\(22));
\GRFPC0_STDATA_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(2),
dataf => \GRFPC0.R.FSR.CEXC\(2),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(34),
datac => \GRFPC0.R.STDATA\(2),
datab => \GRFPC0.EX.RREG.RES\(2),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(23),
dataf => \GRFPC0.R.FSR.TEM\(0),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(55),
datac => \GRFPC0.R.STDATA\(23),
datab => \GRFPC0.EX.RREG.RES\(23),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(24),
dataf => \GRFPC0.R.FSR.TEM\(1),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(56),
datac => \GRFPC0.R.STDATA\(24),
datab => \GRFPC0.EX.RREG.RES\(24),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
GRFPU0_GRFPU_X0_INC_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"e00000a8000000a8")
port map (
combout => N_80261,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datae => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datad => \GRFPU0.GRFPU_X0.COMB.RNDM_1\(0),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(20),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(18),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(19),
datag => \GRFPU0.GRFPU_X0.ST3.FLOP\(8));
\GRFPC0_STDATA_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(6),
dataf => \GRFPC0.R.FSR.AEXC\(1),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(38),
datac => \GRFPC0.R.STDATA\(6),
datab => \GRFPC0.EX.RREG.RES\(6),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(0),
dataf => \GRFPC0.R.FSR.CEXC\(0),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(32),
datac => \GRFPC0.R.STDATA\(0),
datab => \GRFPC0.EX.RREG.RES\(0),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(15),
dataf => \GRFPC0.R.FSR.FTT\(1),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(47),
datac => \GRFPC0.R.STDATA\(15),
datab => \GRFPC0.EX.RREG.RES\(15),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_OP2_5_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => \GRFPC0.N_19756\,
dataf => \GRFPC0.DIV.RESULT\(63),
datae => N_99881,
datad => \FPO.RES\(63),
datac => \GRFPC0.MEM.RREG.RES\(63),
datab => \GRFPC0.WR2.RREG.RES\(63),
dataa => \GRFPC0.RFA2.RS2SEL\(2),
datag => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_STDATA_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(26),
dataf => \GRFPC0.R.FSR.TEM\(3),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(58),
datac => \GRFPC0.R.STDATA\(26),
datab => \GRFPC0.EX.RREG.RES\(26),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(31),
dataf => \FPI.RNDMODE\(1),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(63),
datac => \GRFPC0.R.STDATA\(31),
datab => \GRFPC0.EX.RREG.RES\(31),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(4),
dataf => \GRFPC0.R.FSR.CEXC\(4),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(36),
datac => \GRFPC0.R.STDATA\(4),
datab => \GRFPC0.EX.RREG.RES\(4),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(10),
dataf => \GRFPC0.R.FSR.FCC\(0),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(42),
datac => \GRFPC0.R.STDATA\(10),
datab => \GRFPC0.EX.RREG.RES\(10),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(22),
dataf => \FPI.NONSTD\,
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(54),
datac => \GRFPC0.R.STDATA\(22),
datab => \GRFPC0.EX.RREG.RES\(22),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(27),
dataf => \GRFPC0.R.FSR.TEM\(4),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(59),
datac => \GRFPC0.R.STDATA\(27),
datab => \GRFPC0.EX.RREG.RES\(27),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(8),
dataf => \GRFPC0.R.FSR.AEXC\(3),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(40),
datac => \GRFPC0.R.STDATA\(8),
datab => \GRFPC0.EX.RREG.RES\(8),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(25),
dataf => \GRFPC0.R.FSR.TEM\(2),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(57),
datac => \GRFPC0.R.STDATA\(25),
datab => \GRFPC0.EX.RREG.RES\(25),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
\GRFPC0_STDATA_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"cfc0f5f5cfc0a0a0")
port map (
combout => CPO_DATAZ(11),
dataf => \GRFPC0.R.FSR.FCC\(1),
datae => N_99884,
datad => \GRFPC0.EX.RREG.RES\(43),
datac => \GRFPC0.R.STDATA\(11),
datab => \GRFPC0.EX.RREG.RES\(11),
dataa => \GRFPC0.EX.CTRL.STDFQ\,
datag => \GRFPC0.FP_PIPELINE.UN1_CPI_2\);
GRFPC0_FP_PIPELINE_UN1_FIFO_VCNT_1_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"00000101000f0101")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_FIFO.VCNT_1_1\,
dataf => \GRFPC0.FIFO.VCNT_0\(0),
datae => \GRFPC0.FIFO.WR\(0),
datad => \GRFPC0.FIFO.VCNT_0\(1),
datac => \GRFPC0.FIFO.VCNT_1\(0),
datab => \GRFPC0.FIFO.VCNT_1\(1),
dataa => \GRFPC0.FIFO.VCNT_1\(2),
datag => \GRFPC0.FIFO.VCNT_0\(2));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_I_M4_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"afcfcacaa0c0caca")
port map (
combout => \GRFPU0.GRFPU_X0.N_19926\,
dataf => \GRFPU0.GRFPU_X0.N_17186\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(4),
dataa => \FPI.OP1_RETO\(4),
datag => \GRFPU0.GRFPU_X0.N_19547\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"afcfcacaa0c0caca")
port map (
combout => \GRFPU0.GRFPU_X0.N_15248\,
dataf => \GRFPU0.GRFPU_X0.N_17218\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(36),
datag => \GRFPU0.GRFPU_X0.N_19547\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"afcfcacaa0c0caca")
port map (
combout => \GRFPU0.GRFPU_X0.N_15219\,
dataf => \GRFPU0.GRFPU_X0.N_17189\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(7),
dataa => \FPI.OP1_RETO\(7),
datag => \GRFPU0.GRFPU_X0.N_19547\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"afcfcacaa0c0caca")
port map (
combout => \GRFPU0.GRFPU_X0.N_15223\,
dataf => \GRFPU0.GRFPU_X0.N_17193\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(11),
dataa => \FPI.OP1_RETO\(11),
datag => \GRFPU0.GRFPU_X0.N_19547\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"afcfcacaa0c0caca")
port map (
combout => \GRFPU0.GRFPU_X0.N_15226\,
dataf => \GRFPU0.GRFPU_X0.N_17196\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(14),
dataa => \FPI.OP1_RETO\(14),
datag => \GRFPU0.GRFPU_X0.N_19547\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"afcfcacaa0c0caca")
port map (
combout => \GRFPU0.GRFPU_X0.N_15237\,
dataf => \GRFPU0.GRFPU_X0.N_17207\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(25),
dataa => \FPI.OP1_RETO\(25),
datag => \GRFPU0.GRFPU_X0.N_19547\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"afcfcacaa0c0caca")
port map (
combout => \GRFPU0.GRFPU_X0.N_15222\,
dataf => \GRFPU0.GRFPU_X0.N_17192\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(10),
dataa => \FPI.OP1_RETO\(10),
datag => \GRFPU0.GRFPU_X0.N_19547\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"afcfcacaa0c0caca")
port map (
combout => \GRFPU0.GRFPU_X0.N_15229\,
dataf => \GRFPU0.GRFPU_X0.N_17199\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(17),
dataa => \FPI.OP1_RETO\(17),
datag => \GRFPU0.GRFPU_X0.N_19547\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"afcfcacaa0c0caca")
port map (
combout => \GRFPU0.GRFPU_X0.N_15228\,
dataf => \GRFPU0.GRFPU_X0.N_17198\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(16),
dataa => \FPI.OP1_RETO\(16),
datag => \GRFPU0.GRFPU_X0.N_19547\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"afcfcacaa0c0caca")
port map (
combout => \GRFPU0.GRFPU_X0.N_15221\,
dataf => \GRFPU0.GRFPU_X0.N_17191\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(9),
dataa => \FPI.OP1_RETO\(9),
datag => \GRFPU0.GRFPU_X0.N_19547\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"afcfcacaa0c0caca")
port map (
combout => \GRFPU0.GRFPU_X0.N_15241\,
dataf => \GRFPU0.GRFPU_X0.N_17211\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(29),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(29),
datag => \GRFPU0.GRFPU_X0.N_19547\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"afcfcacaa0c0caca")
port map (
combout => \GRFPU0.GRFPU_X0.N_15250\,
dataf => \GRFPU0.GRFPU_X0.N_17220\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(38),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(38),
datag => \GRFPU0.GRFPU_X0.N_19547\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"afcfcacaa0c0caca")
port map (
combout => \GRFPU0.GRFPU_X0.N_15257\,
dataf => \GRFPU0.GRFPU_X0.N_17227\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(45),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(45),
datag => \GRFPU0.GRFPU_X0.N_19547\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"afcfcacaa0c0caca")
port map (
combout => \GRFPU0.GRFPU_X0.N_15214\,
dataf => \GRFPU0.GRFPU_X0.N_17184\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(2),
dataa => \FPI.OP1_RETO\(2),
datag => \GRFPU0.GRFPU_X0.N_19547\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"afcfcacaa0c0caca")
port map (
combout => \GRFPU0.GRFPU_X0.N_15224\,
dataf => \GRFPU0.GRFPU_X0.N_17194\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(12),
dataa => \FPI.OP1_RETO\(12),
datag => \GRFPU0.GRFPU_X0.N_19547\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"afcfcacaa0c0caca")
port map (
combout => \GRFPU0.GRFPU_X0.N_15244\,
dataf => \GRFPU0.GRFPU_X0.N_17214\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(32),
datag => \GRFPU0.GRFPU_X0.N_19547\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"afcfcacaa0c0caca")
port map (
combout => \GRFPU0.GRFPU_X0.N_15217\,
dataf => \GRFPU0.GRFPU_X0.N_17187\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(5),
dataa => \FPI.OP1_RETO\(5),
datag => \GRFPU0.GRFPU_X0.N_19547\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"ffffffffeca0eca0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(20),
dataf => \GRFPU0.GRFPU_X0.N_270\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.N_18976\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datab => \FPI.OP1_RETO\(20),
dataa => \GRFPU0.GRFPU_X0.N_18983_I\,
datag => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_I_M4_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"afcfcacaa0c0caca")
port map (
combout => \GRFPU0.GRFPU_X0.N_19932\,
dataf => \GRFPU0.GRFPU_X0.N_17188\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(6),
dataa => \FPI.OP1_RETO\(6),
datag => \GRFPU0.GRFPU_X0.N_19547\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(17),
dataf => \GRFPC0.MEM.CTRL.PC\(17),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(17),
datac => \GRFPC0.MEM.CTRL.INST\(17),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(17),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(18),
dataf => \GRFPC0.MEM.CTRL.PC\(18),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(18),
datac => \GRFPC0.MEM.CTRL.INST\(18),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(18),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(13),
dataf => \GRFPC0.MEM.CTRL.PC\(13),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(13),
datac => \GRFPC0.MEM.CTRL.INST\(13),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(13),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(15),
dataf => \GRFPC0.MEM.CTRL.PC\(15),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(15),
datac => \GRFPC0.MEM.CTRL.INST\(15),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(15),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(3),
dataf => \GRFPC0.MEM.CTRL.PC\(3),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(3),
datac => \GRFPC0.MEM.CTRL.INST\(3),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(3),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(16),
dataf => \GRFPC0.MEM.CTRL.PC\(16),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(16),
datac => \GRFPC0.MEM.CTRL.INST\(16),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(16),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(20),
dataf => \GRFPC0.MEM.CTRL.PC\(20),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(20),
datac => \GRFPC0.MEM.CTRL.INST\(20),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(20),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(28),
dataf => \GRFPC0.MEM.CTRL.PC\(28),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(28),
datac => \GRFPC0.MEM.CTRL.INST\(28),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(28),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(2),
dataf => \GRFPC0.MEM.CTRL.PC\(2),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST\(2),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(2),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0f7c4f0f0b380")
port map (
combout => \GRFPU0.GRFPU_X0.N_15208\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(61),
datae => \GRFPU0.GRFPU_X0.N_5250\,
datad => \GRFPU0.GRFPU_X0.N_17243\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(61),
datab => \GRFPU0.GRFPU_X0.N_19547\,
dataa => \GRFPU0.GRFPU_X0.N_18969\,
datag => \GRFPU0.GRFPU_X0.UN8_C\(9));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0f7c4f0f0b380")
port map (
combout => \GRFPU0.GRFPU_X0.N_15203\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(56),
datae => \GRFPU0.GRFPU_X0.N_5250\,
datad => \GRFPU0.GRFPU_X0.N_17238\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(56),
datab => \GRFPU0.GRFPU_X0.N_19547\,
dataa => \GRFPU0.GRFPU_X0.N_18969\,
datag => \GRFPU0.GRFPU_X0.UN8_C\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(27),
dataf => \GRFPC0.MEM.CTRL.PC\(27),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(27),
datac => \GRFPC0.MEM.CTRL.INST\(27),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(27),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0800080808880808")
port map (
combout => \GRFPU0.GRFPU_X0.N_287\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(51),
datae => \GRFPU0.GRFPU_X0.N_19547\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.N_17233\,
datab => \GRFPU0.GRFPU_X0.N_19546\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datag => \GRFPU0.GRFPU_X0.ST1.RAW1\(51));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0f7c4f0f0b380")
port map (
combout => \GRFPU0.GRFPU_X0.N_15205\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(58),
datae => \GRFPU0.GRFPU_X0.N_5250\,
datad => \GRFPU0.GRFPU_X0.N_17240\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(58),
datab => \GRFPU0.GRFPU_X0.N_19547\,
dataa => \GRFPU0.GRFPU_X0.N_18969\,
datag => \GRFPU0.GRFPU_X0.UN8_C\(6));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(4),
dataf => \GRFPC0.MEM.CTRL.PC\(4),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(4),
datac => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(4),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(29),
dataf => \GRFPC0.MEM.CTRL.PC\(29),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(29),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(29),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(11),
dataf => \GRFPC0.MEM.CTRL.PC\(11),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(11),
datac => \GRFPC0.MEM.CTRL.INST\(11),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(11),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(5),
dataf => \GRFPC0.MEM.CTRL.PC\(5),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(5),
datac => \GRFPC0.MEM.CTRL.INST\(5),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(5),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0f7c4f0f0b380")
port map (
combout => \GRFPU0.GRFPU_X0.N_15209\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(62),
datae => \GRFPU0.GRFPU_X0.N_5250\,
datad => \GRFPU0.GRFPU_X0.N_17244\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(62),
datab => \GRFPU0.GRFPU_X0.N_19547\,
dataa => \GRFPU0.GRFPU_X0.N_18969\,
datag => \GRFPU0.GRFPU_X0.UN8_C\(10));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(7),
dataf => \GRFPC0.MEM.CTRL.PC\(7),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(7),
datac => \GRFPC0.MEM.CTRL.INST\(7),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(7),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(30),
dataf => \GRFPC0.MEM.CTRL.PC\(30),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(30),
datac => \GRFPC0.MEM.CTRL.INST\(30),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(30),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(6),
dataf => \GRFPC0.MEM.CTRL.PC\(6),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(6),
datac => \GRFPC0.MEM.CTRL.INST\(6),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(6),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(12),
dataf => \GRFPC0.MEM.CTRL.PC\(12),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(12),
datac => \GRFPC0.MEM.CTRL.INST\(12),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(12),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0f7c4f0f0b380")
port map (
combout => \GRFPU0.GRFPU_X0.N_15207\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
datae => \GRFPU0.GRFPU_X0.N_5250\,
datad => \GRFPU0.GRFPU_X0.N_17242\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(60),
datab => \GRFPU0.GRFPU_X0.N_19547\,
dataa => \GRFPU0.GRFPU_X0.N_18969\,
datag => \GRFPU0.GRFPU_X0.UN8_C\(8));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(9),
dataf => \GRFPC0.MEM.CTRL.PC\(9),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(9),
datac => \GRFPC0.MEM.CTRL.INST\(9),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(9),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f0f7c4f0f0b380")
port map (
combout => \GRFPU0.GRFPU_X0.N_15204\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(57),
datae => \GRFPU0.GRFPU_X0.N_5250\,
datad => \GRFPU0.GRFPU_X0.N_17239\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(57),
datab => \GRFPU0.GRFPU_X0.N_19547\,
dataa => \GRFPU0.GRFPU_X0.N_18969\,
datag => \GRFPU0.GRFPU_X0.UN8_C\(5));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(26),
dataf => \GRFPC0.MEM.CTRL.PC\(26),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(26),
datac => \GRFPC0.MEM.CTRL.INST\(26),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(26),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(25),
dataf => \GRFPC0.MEM.CTRL.PC\(25),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(25),
datac => \GRFPC0.MEM.CTRL.INST\(25),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(25),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fc0cf5f5fc0ca0a0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(22),
dataf => \GRFPC0.MEM.CTRL.PC\(22),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datad => \GRFPC0.DIV.INST\(22),
datac => \GRFPC0.MEM.CTRL.INST\(22),
datab => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(22),
dataa => \GRFPC0.N_23669\,
datag => N_99867);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"febafebaf0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(61),
dataf => \GRFPU0.GRFPU_X0.N_19546\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.N_15208\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(61),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
dataa => \GRFPU0.GRFPU_X0.N_18983_I\,
datag => \GRFPU0.GRFPU_X0.ST1.RAW2\(61));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"febafebaf0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(58),
dataf => \GRFPU0.GRFPU_X0.N_19546\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.N_15205\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(58),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
dataa => \GRFPU0.GRFPU_X0.N_18983_I\,
datag => \GRFPU0.GRFPU_X0.ST1.RAW2\(58));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"febafebaf0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(57),
dataf => \GRFPU0.GRFPU_X0.N_19546\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.N_15204\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(57),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
dataa => \GRFPU0.GRFPU_X0.N_18983_I\,
datag => \GRFPU0.GRFPU_X0.ST1.RAW2\(57));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"febafebaf0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(60),
dataf => \GRFPU0.GRFPU_X0.N_19546\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.N_15207\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(60),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
dataa => \GRFPU0.GRFPU_X0.N_18983_I\,
datag => \GRFPU0.GRFPU_X0.ST1.RAW2\(60));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"febafebaf0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(62),
dataf => \GRFPU0.GRFPU_X0.N_19546\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.N_15209\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(62),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
dataa => \GRFPU0.GRFPU_X0.N_18983_I\,
datag => \GRFPU0.GRFPU_X0.ST1.RAW2\(62));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"ffffffffb8f0b8f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(56),
dataf => \GRFPU0.GRFPU_X0.N_18983_I\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.N_19546\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(56),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
dataa => \GRFPU0.GRFPU_X0.N_15203\,
datag => \GRFPU0.GRFPU_X0.ST1.RAW2\(56));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_10_I_M2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"fffcfafa0030fafa")
port map (
combout => \GRFPC0.N_24730\,
dataf => \GRFPC0.FP_PIPELINE.11.REGDEPX2_359\(1),
datae => \GRFPC0.INST\(26),
datad => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.FP_PIPELINE.10.REGDEPX2_320\(1),
datab => \GRFPC0.DIV.VALID\,
dataa => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_3\(1),
datag => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355\(1));
GRFPC0_UN1_REGDEP173: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"aeabaeabeabaeaba")
port map (
combout => \GRFPC0.UN1_REGDEP173\,
dataf => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.EX.CTRL.RDD_0_0_G1\,
datac => \GRFPC0.RFA.RD\(0),
datab => \GRFPC0.N_23598_I_0\,
dataa => \GRFPC0.N_24011\,
datag => \GRFPC0.V.STDATA_14\(25));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0000080008008800")
port map (
combout => \GRFPU0.GRFPU_X0.N_18859_I_0_G0_2\,
dataf => \FPI.NONSTD\,
datae => \FPI.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.N_7241\,
datac => \FPI.FLOP\(0),
datab => \GRFPU0.GRFPU_X0.N_10059_I\,
dataa => \GRFPU0.GRFPU_X0.N_18867\,
datag => \GRFPU0.GRFPU_X0.N_18880\);
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0f0f000f0b0b000b")
port map (
combout => \GRFPC0.N_21674\,
dataf => \GRFPC0.N_21612\,
datae => \GRFPC0.N_860\,
datad => \GRFPC0.N_21610\,
datac => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.N_106_I\,
dataa => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datag => \GRFPC0.N_579\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"01000f0f01000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_22__G1\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(22),
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_0_03\,
datac => \GRFPU0.GRFPU_X0.N_5774\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datag => \GRFPU0.GRFPU_X0.ST2.REG\(56));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"01000f0f01000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_24__G1\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03\,
datac => \GRFPU0.GRFPU_X0.N_5774\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datag => \GRFPU0.GRFPU_X0.ST2.REG\(56));
\GRFPU0_GRFPU_X0_L1_0_6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"0eff0eff0e000e00")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_6\(0),
dataf => \GRFPU0.GRFPU_X0.L1_0_1_5\(0),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.N_9608\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(41),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_1_5_0_A4_0_0\(0),
dataa => \GRFPU0.GRFPU_X0.TZI\(5),
datag => \GRFPU0.GRFPU_X0.ITER.ND_I\(12));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"01000f0f01000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_23__G1\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03\,
datac => \GRFPU0.GRFPU_X0.N_5774\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datag => \GRFPU0.GRFPU_X0.ST2.REG\(56));
\GRFPU0_GRFPU_X0_L1_4_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"ffccfafaffcffafa")
port map (
combout => N_82180,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(15),
datae => \GRFPU0.GRFPU_X0.UN228_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datag => \GRFPU0.GRFPU_X0.ST2.DIFF\(14));
GRFPU0_FPMUL0_UN1_SIN_CARRY_27_BUF: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27_RETI\,
cin => N_80132);
GRFPU0_FPMUL0_UN1_SIN_CARRY_27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(93),
cout => N_80132,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(93),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_26\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_26: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(92),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_26\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(92),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_25\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(91),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_25\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(91),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_24\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(90),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_24\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(90),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_23\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(89),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_23\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(89),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_22\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(88),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_22\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(88),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_21\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(87),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_21\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(87),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_20\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(86),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_20\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(86),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_19\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(85),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_19\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(85),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_18\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(84),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_18\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(84),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_17\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(83),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_17\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(83),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_16\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(82),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_16\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(82),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_15\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(81),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_15\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(81),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_14\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(80),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_14\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(80),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_13\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(79),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_13\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(79),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_12\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(78),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_12\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(78),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_11\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(77),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_11\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(77),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_10\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(76),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_10\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(76),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_9\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(75),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_9\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(75),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_8\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(74),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_8\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(74),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_7\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(73),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_7\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(73),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_6\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(72),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_6\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(72),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_5\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(71),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_5\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(71),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_4\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(70),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_4\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(70),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_3\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(69),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_3\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(69),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_2\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(66),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_0\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(66),
datad => \GRFPU0.GRFPU_X0.N_13398_I\,
cin => GND);
GRFPU0_FPMUL0_UN1_SIN_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(67),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_1\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(67),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_0\);
GRFPU0_FPMUL0_UN1_SIN_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.MRES_RETI\(68),
cout => \GRFPU0.FPMUL0.UN1_SIN_CARRY_2\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(68),
cin => \GRFPU0.FPMUL0.UN1_SIN_CARRY_1\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_27_BUF: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_RETI\,
cin => N_80136);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(93),
cout => N_80136,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(93),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_26\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_26: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(92),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_26\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(92),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_25\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(91),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_25\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(91),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_24\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(90),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_24\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(90),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_23\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(89),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_23\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(89),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_22\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(88),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_22\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(88),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_21\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(87),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_21\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(87),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_20\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(86),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_20\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(86),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_19\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(85),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_19\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(85),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_18\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(84),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_18\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(84),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_17\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(83),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_17\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(83),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_16\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(82),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_16\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(82),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_15\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(81),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_15\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(81),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_14\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(80),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_14\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(80),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_13\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(79),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_13\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(79),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_12\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(78),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_12\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(78),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_11\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(77),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_11\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(77),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_10\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(76),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_10\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(76),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_9\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(75),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_9\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(75),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_8\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(74),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_8\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(74),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_7\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(73),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_7\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(73),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_6\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(72),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_6\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(72),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_5\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(71),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_5\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(71),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_4\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(70),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_4\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(70),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_3\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000c0c0")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(69),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_3\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(69),
datac => \GRFPU0.MULI.DP\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(68),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_2\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_0\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(66),
datad => \GRFPU0.GRFPU_X0.N_13398_I\,
cin => GND);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_1\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(67),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00003c3c")
port map (
sumout => \GRFPU0.MULO.DRES_1_RETI\(68),
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_2\,
datac => \GRFPU0.MULI.DP\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(68),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_1\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_27_0_BUF: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
sumout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0_RETI\,
cin => N_80130);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_27_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(92),
cout => N_80130,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(92),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_26_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_26_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(91),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_26_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(91),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_25_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_25_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(90),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_25_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(90),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_24_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_24_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(89),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_24_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(89),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_23_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_23_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(88),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_23_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(88),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_22_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_22_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(87),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_22_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(87),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_21_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_21_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(86),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_21_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(86),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_20_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_20_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(85),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_20_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(85),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_19_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_19_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(84),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_19_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(84),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_18_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_18_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(83),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_18_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(83),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_17_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_17_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(82),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_17_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(82),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_16_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_16_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(81),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_16_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(81),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_15_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_15_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(80),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_15_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(80),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_14_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_14_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(79),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_14_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(79),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_13_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_13_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(78),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_13_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(78),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_12_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_12_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(77),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_12_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(77),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_11_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_11_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(76),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_11_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(76),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_10_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_10_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(75),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_10_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(75),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_9_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_9_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(74),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_9_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(74),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_8_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_8_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(73),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_8_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(73),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_7_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_7_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(72),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_7_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(72),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_6_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_6_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(71),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_6_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(71),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_5_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_5_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(70),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_5_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(70),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_4_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_4_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(69),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_4_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(69),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_3\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000c0c0")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(68),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_3\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(68),
datac => \GRFPU0.MULI.DP\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(67),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_2\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_0\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(65),
datad => \GRFPU0.GRFPU_X0.N_13398_I\,
cin => GND);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_1\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(66),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_0\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00003c3c")
port map (
sumout => \GRFPU0.MULO.DRES_1S_RETI\(67),
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_2\,
datac => \GRFPU0.MULI.DP\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(67),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_1\);
GRFPU0_FPMUL0_R2_RET_82_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28107_RETI,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(121),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_26\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_26: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28105_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_26\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(120),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_25\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28103_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_25\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(119),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_24\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28101_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_24\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(118),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_23\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28099_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_23\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(117),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_22\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28097_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_22\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(116),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_21\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28095_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_21\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(115),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_20\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28093_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_20\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(114),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_19\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28091_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_19\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(113),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_18\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28089_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_18\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(112),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_17\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28087_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_17\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(111),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_16\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28085_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_16\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(110),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_15\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28083_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_15\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(109),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_14\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28081_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_14\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(108),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_13\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28079_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_13\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(107),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_12\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28077_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_12\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(106),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_11\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28075_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_11\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(105),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_10\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28073_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_10\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(104),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_9\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28071_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_9\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(103),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_8\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28069_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_8\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(102),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_7\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28067_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_7\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(101),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_6\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28065_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_6\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(100),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_5\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28063_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_5\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(99),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_4\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28061_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_4\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(98),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_3\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28059_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_3\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(97),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_2\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28057_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_2\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(96),
cin => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_1\);
GRFPU0_FPMUL0_UN1_SIN_0_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_28055_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_0_CARRY_1\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(95),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(94),
cin => GND);
GRFPU0_FPMUL0_R2_RET_109_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28221_RETI,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(121),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_26\);
GRFPU0_FPMUL0_R2_RET_109_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_26\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(120),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_25\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28217_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_25\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(119),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_24\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28215_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_24\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(118),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_23\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28213_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_23\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(117),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_22\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28211_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_22\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(116),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_21\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28209_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_21\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(115),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_20\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28207_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_20\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(114),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_19\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28205_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_19\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(113),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_18\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28203_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_18\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(112),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_17\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28201_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_17\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(111),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_16\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28199_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_16\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(110),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_15\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28197_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_15\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(109),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_14\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28195_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_14\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(108),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_13\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28193_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_13\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(107),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_12\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28191_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_12\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(106),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_11\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28189_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_11\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(105),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_10\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28187_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_10\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(104),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_9\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28185_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_9\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(103),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_8\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28183_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_8\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(102),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_7\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28181_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_7\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(101),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_6\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28179_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_6\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(100),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_5\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28177_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_5\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(99),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_4\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f3f30000ff00")
port map (
sumout => N_28175_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_4\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(98),
datac => \GRFPU0.MULI.DP\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(97),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_3\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_28169_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_1\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(95),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(94),
cin => GND);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28171_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_2\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(96),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_1\);
GRFPU0_FPMUL0_UN1_SIN_2_0_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000c3c3")
port map (
sumout => N_28173_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_3\,
datac => \GRFPU0.MULI.DP\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(97),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_0_CARRY_2\);
GRFPU0_FPMUL0_R2_RET_135_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28164_RETI,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(120),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_26\);
GRFPU0_FPMUL0_R2_RET_135_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_26\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(119),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_25\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28160_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_25\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(118),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_24\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28158_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_24\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(117),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_23\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28156_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_23\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(116),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_22\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28154_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_22\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(115),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_21\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28152_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_21\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(114),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_20\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28150_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_20\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(113),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_19\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28148_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_19\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(112),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_18\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28146_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_18\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(111),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_17\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28144_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_17\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(110),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_16\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28142_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_16\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(109),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_15\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28140_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_15\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(108),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_14\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28138_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_14\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(107),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_13\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28136_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_13\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(106),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_12\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28134_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_12\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(105),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_11\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28132_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_11\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(104),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_10\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28130_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_10\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(103),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_9\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28128_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_9\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(102),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_8\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28126_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_8\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(101),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_7\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28124_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_7\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(100),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_6\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28122_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_6\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(99),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_5\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28120_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_5\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(98),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_4\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f3f30000ff00")
port map (
sumout => N_28118_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_4\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(97),
datac => \GRFPU0.MULI.DP\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(96),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_3\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
sumout => N_28112_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_1\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(94),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(93),
cin => GND);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28114_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_2\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(95),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_1\);
GRFPU0_FPMUL0_UN1_SIN_3_0_CARRY_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000c3c3")
port map (
sumout => N_28116_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_3\,
datac => \GRFPU0.MULI.DP\,
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(96),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_0_CARRY_2\);
GRFPU0_FPMUL0_CS_DP_R_RET_1_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28220_RETI,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(121),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_26_0\);
GRFPU0_FPMUL0_CS_DP_R_RET_1_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_26_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(120),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_25_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_25_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28216_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_25_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(119),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_24_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_24_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28214_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_24_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(118),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_23_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_23_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28212_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_23_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(117),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_22_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_22_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28210_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_22_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(116),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_21_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_21_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28208_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_21_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(115),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_20_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_20_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28206_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_20_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(114),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_19_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_19_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28204_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_19_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(113),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_18_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_18_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28202_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_18_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(112),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_17_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_17_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28200_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_17_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(111),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_16_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_16_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28198_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_16_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(110),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_15_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_15_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28196_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_15_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(109),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_14_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_14_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28194_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_14_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(108),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_13_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_13_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28192_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_13_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(107),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_12_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_12_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28190_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_12_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(106),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_11_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_11_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28188_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_11_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(105),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_10_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_10_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28186_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_10_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(104),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_9_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_9_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28184_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_9_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(103),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_8_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_8_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28182_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_8_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(102),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_7_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_7_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28180_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_7_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(101),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_6_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_6_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28178_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_6_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(100),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_5_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_5_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28176_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_5_0\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(99),
cin => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_4_0\);
GRFPU0_FPMUL0_UN1_SIN_2_CARRY_4_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000ff00")
port map (
sumout => N_28174_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_4_0\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(97),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(98),
datac => \GRFPU0.MULI.DP\,
cin => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28163_RETI,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(120),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_26\);
GRFPU0_FPMUL0_CS_DP_R_RET_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_26\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(119),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_25\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28159_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_25\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(118),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_24\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28157_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_24\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(117),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_23\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28155_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_23\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(116),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_22\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28153_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_22\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(115),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_21\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28151_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_21\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(114),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_20\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28149_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_20\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(113),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_19\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28147_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_19\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(112),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_18\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28145_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_18\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(111),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_17\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28143_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_17\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(110),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_16\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28141_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_16\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(109),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_15\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28139_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_15\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(108),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_14\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28137_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_14\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(107),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_13\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28135_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_13\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(106),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_12\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28133_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_12\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(105),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_11\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28131_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_11\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(104),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_10\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28129_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_10\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(103),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_9\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28127_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_9\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(102),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_8\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28125_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_8\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(101),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_7\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28123_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_7\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(100),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_6\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28121_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_6\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(99),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_5\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
sumout => N_28119_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_5\,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(98),
cin => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_4\);
GRFPU0_FPMUL0_UN1_SIN_3_CARRY_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000ff00")
port map (
sumout => N_28117_RETI,
cout => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_4\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(96),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(97),
datac => \GRFPU0.MULI.DP\,
cin => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_MU_MULADD_0_60_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 multiplier_aclr0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "CLOCK0" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  61,
 width_b =>  36,
 width_a =>  25,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(24),
  result(25) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(25),
  result(26) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(26),
  result(27) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(27),
  result(28) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(28),
  result(29) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(29),
  result(30) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(30),
  result(31) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(31),
  result(32) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(32),
  result(33) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(33),
  result(34) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(34),
  result(35) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(35),
  result(36) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(36),
  result(37) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(37),
  result(38) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(38),
  result(39) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(39),
  result(40) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(40),
  result(41) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(41),
  result(42) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(42),
  result(43) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(43),
  result(44) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(44),
  result(45) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(45),
  result(46) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(46),
  result(47) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(47),
  result(48) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(48),
  result(49) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(49),
  result(50) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(50),
  result(51) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(51),
  result(52) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(52),
  result(53) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(53),
  result(54) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(54),
  result(55) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(55),
  result(56) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(56),
  result(57) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(57),
  result(58) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(58),
  result(59) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(59),
  result(60) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_MU\(60),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(36),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(37),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(38),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(39),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(40),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(41),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(42),
  dataa(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(43),
  dataa(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(44),
  dataa(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(45),
  dataa(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(46),
  dataa(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(47),
  dataa(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(48),
  dataa(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(49),
  dataa(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(50),
  dataa(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(51),
  dataa(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(52),
  dataa(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(53),
  dataa(18) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(54),
  dataa(19) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(55),
  dataa(20) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(56),
  dataa(21) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(57),
  dataa(22) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(58),
  dataa(23) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(59),
  dataa(24) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(60),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(0),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(1),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(2),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(3),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(4),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(5),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(6),
  datab(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(7),
  datab(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(8),
  datab(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(9),
  datab(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(10),
  datab(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(11),
  datab(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(12),
  datab(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(13),
  datab(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(14),
  datab(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(15),
  datab(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(16),
  datab(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(17),
  datab(18) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(18),
  datab(19) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(19),
  datab(20) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(20),
  datab(21) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(21),
  datab(22) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(22),
  datab(23) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(23),
  datab(24) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(24),
  datab(25) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(25),
  datab(26) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(26),
  datab(27) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(27),
  datab(28) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(28),
  datab(29) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(29),
  datab(30) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(30),
  datab(31) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(31),
  datab(32) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(32),
  datab(33) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(33),
  datab(34) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(34),
  datab(35) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(35),
  clock0 => N_36);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_MU_MULADD_0_49_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 multiplier_aclr0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "CLOCK0" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  50,
 width_b =>  25,
 width_a =>  25,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(24),
  result(25) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(25),
  result(26) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(26),
  result(27) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(27),
  result(28) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(28),
  result(29) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(29),
  result(30) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(30),
  result(31) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(31),
  result(32) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(32),
  result(33) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(33),
  result(34) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(34),
  result(35) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(35),
  result(36) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(36),
  result(37) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(37),
  result(38) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(38),
  result(39) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(39),
  result(40) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(40),
  result(41) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(41),
  result(42) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(42),
  result(43) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(43),
  result(44) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(44),
  result(45) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(45),
  result(46) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(46),
  result(47) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(47),
  result(48) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(48),
  result(49) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_MU\(49),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(36),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(37),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(38),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(39),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(40),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(41),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(42),
  dataa(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(43),
  dataa(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(44),
  dataa(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(45),
  dataa(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(46),
  dataa(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(47),
  dataa(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(48),
  dataa(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(49),
  dataa(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(50),
  dataa(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(51),
  dataa(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(52),
  dataa(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(53),
  dataa(18) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(54),
  dataa(19) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(55),
  dataa(20) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(56),
  dataa(21) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(57),
  dataa(22) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(58),
  dataa(23) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(59),
  dataa(24) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(60),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(36),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(37),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(38),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(39),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(40),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(41),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(42),
  datab(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(43),
  datab(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(44),
  datab(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(45),
  datab(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(46),
  datab(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(47),
  datab(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(48),
  datab(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(49),
  datab(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(50),
  datab(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(51),
  datab(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(52),
  datab(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(53),
  datab(18) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(54),
  datab(19) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(55),
  datab(20) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(56),
  datab(21) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(57),
  datab(22) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(58),
  datab(23) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(59),
  datab(24) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(60),
  clock0 => N_36);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_ML_ML_MULADD_0_71_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 multiplier_aclr0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "CLOCK0" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  72,
 width_b =>  36,
 width_a =>  36,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(24),
  result(25) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(25),
  result(26) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(26),
  result(27) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(27),
  result(28) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(28),
  result(29) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(29),
  result(30) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(30),
  result(31) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(31),
  result(32) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(32),
  result(33) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(33),
  result(34) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(34),
  result(35) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(35),
  result(36) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(36),
  result(37) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(37),
  result(38) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(38),
  result(39) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(39),
  result(40) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(40),
  result(41) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(41),
  result(42) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(42),
  result(43) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(43),
  result(44) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(44),
  result(45) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(45),
  result(46) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(46),
  result(47) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(47),
  result(48) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(48),
  result(49) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(49),
  result(50) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(50),
  result(51) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(51),
  result(52) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(52),
  result(53) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(53),
  result(54) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(54),
  result(55) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(55),
  result(56) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(56),
  result(57) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(57),
  result(58) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(58),
  result(59) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(59),
  result(60) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(60),
  result(61) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(61),
  result(62) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(62),
  result(63) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(63),
  result(64) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(64),
  result(65) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(65),
  result(66) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(66),
  result(67) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(67),
  result(68) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(68),
  result(69) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(69),
  result(70) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(70),
  result(71) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_ML_ML\(71),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(0),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(1),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(2),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(3),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(4),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(5),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(6),
  dataa(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(7),
  dataa(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(8),
  dataa(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(9),
  dataa(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(10),
  dataa(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(11),
  dataa(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(12),
  dataa(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(13),
  dataa(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(14),
  dataa(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(15),
  dataa(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(16),
  dataa(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(17),
  dataa(18) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(18),
  dataa(19) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(19),
  dataa(20) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(20),
  dataa(21) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(21),
  dataa(22) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(22),
  dataa(23) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(23),
  dataa(24) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(24),
  dataa(25) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(25),
  dataa(26) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(26),
  dataa(27) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(27),
  dataa(28) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(28),
  dataa(29) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(29),
  dataa(30) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(30),
  dataa(31) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(31),
  dataa(32) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(32),
  dataa(33) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(33),
  dataa(34) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(34),
  dataa(35) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(35),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(0),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(1),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(2),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(3),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(4),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(5),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(6),
  datab(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(7),
  datab(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(8),
  datab(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(9),
  datab(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(10),
  datab(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(11),
  datab(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(12),
  datab(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(13),
  datab(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(14),
  datab(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(15),
  datab(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(16),
  datab(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(17),
  datab(18) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(18),
  datab(19) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(19),
  datab(20) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(20),
  datab(21) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(21),
  datab(22) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(22),
  datab(23) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(23),
  datab(24) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(24),
  datab(25) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(25),
  datab(26) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(26),
  datab(27) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(27),
  datab(28) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(28),
  datab(29) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(29),
  datab(30) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(30),
  datab(31) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(31),
  datab(32) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(32),
  datab(33) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(33),
  datab(34) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(34),
  datab(35) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(35),
  clock0 => N_36);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R1IN_MU_ML_MULADD_0_60_0_\: altmult_add  generic map(
 input_source_b0 =>  "DATAB" ,
 input_aclr_b0 =>  "ACLR0" ,
 input_source_a0 =>  "DATAA" ,
 input_aclr_a0 =>  "ACLR0" ,
 multiplier_aclr0 =>  "ACLR0" ,
 chainout_register =>  "UNREGISTERED" ,
 output_register =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_register3 =>  "UNREGISTERED" ,
 addnsub_multiplier_pipeline_register1 =>  "UNREGISTERED" ,
 addnsub_multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register3 =>  "UNREGISTERED" ,
 multiplier_register2 =>  "UNREGISTERED" ,
 multiplier_register1 =>  "UNREGISTERED" ,
 multiplier_register0 =>  "CLOCK0" ,
 signed_pipeline_register_b =>  "UNREGISTERED" ,
 signed_register_b =>  "UNREGISTERED" ,
 input_register_b3 =>  "UNREGISTERED" ,
 input_register_b2 =>  "UNREGISTERED" ,
 input_register_b1 =>  "UNREGISTERED" ,
 input_register_b0 =>  "CLOCK0" ,
 signed_pipeline_register_a =>  "UNREGISTERED" ,
 signed_register_a =>  "UNREGISTERED" ,
 input_register_a3 =>  "UNREGISTERED" ,
 input_register_a2 =>  "UNREGISTERED" ,
 input_register_a1 =>  "UNREGISTERED" ,
 input_register_a0 =>  "CLOCK0" ,
 representation_b =>  "UNSIGNED" ,
 representation_a =>  "UNSIGNED" ,
 width_result =>  61,
 width_b =>  25,
 width_a =>  36,
 number_of_multipliers =>  1,
 multiplier3_direction =>  "ADD" ,
 multiplier1_direction =>  "ADD" )
port map (
  result(0) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(0),
  result(1) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(1),
  result(2) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(2),
  result(3) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(3),
  result(4) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(4),
  result(5) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(5),
  result(6) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(6),
  result(7) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(7),
  result(8) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(8),
  result(9) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(9),
  result(10) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(10),
  result(11) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(11),
  result(12) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(12),
  result(13) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(13),
  result(14) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(14),
  result(15) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(15),
  result(16) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(16),
  result(17) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(17),
  result(18) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(18),
  result(19) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(19),
  result(20) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(20),
  result(21) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(21),
  result(22) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(22),
  result(23) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(23),
  result(24) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(24),
  result(25) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(25),
  result(26) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(26),
  result(27) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(27),
  result(28) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(28),
  result(29) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(29),
  result(30) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(30),
  result(31) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(31),
  result(32) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(32),
  result(33) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(33),
  result(34) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(34),
  result(35) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(35),
  result(36) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(36),
  result(37) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(37),
  result(38) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(38),
  result(39) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(39),
  result(40) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(40),
  result(41) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(41),
  result(42) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(42),
  result(43) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(43),
  result(44) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(44),
  result(45) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(45),
  result(46) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(46),
  result(47) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(47),
  result(48) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(48),
  result(49) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(49),
  result(50) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(50),
  result(51) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(51),
  result(52) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(52),
  result(53) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(53),
  result(54) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(54),
  result(55) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(55),
  result(56) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(56),
  result(57) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(57),
  result(58) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(58),
  result(59) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(59),
  result(60) => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1IN_MU_ML\(60),
  dataa(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(0),
  dataa(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(1),
  dataa(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(2),
  dataa(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(3),
  dataa(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(4),
  dataa(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(5),
  dataa(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(6),
  dataa(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(7),
  dataa(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(8),
  dataa(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(9),
  dataa(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(10),
  dataa(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(11),
  dataa(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(12),
  dataa(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(13),
  dataa(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(14),
  dataa(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(15),
  dataa(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(16),
  dataa(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(17),
  dataa(18) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(18),
  dataa(19) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(19),
  dataa(20) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(20),
  dataa(21) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(21),
  dataa(22) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(22),
  dataa(23) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(23),
  dataa(24) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(24),
  dataa(25) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(25),
  dataa(26) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(26),
  dataa(27) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(27),
  dataa(28) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(28),
  dataa(29) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(29),
  dataa(30) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(30),
  dataa(31) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(31),
  dataa(32) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(32),
  dataa(33) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(33),
  dataa(34) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(34),
  dataa(35) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(35),
  datab(0) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(36),
  datab(1) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(37),
  datab(2) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(38),
  datab(3) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(39),
  datab(4) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(40),
  datab(5) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(41),
  datab(6) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(42),
  datab(7) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(43),
  datab(8) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(44),
  datab(9) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(45),
  datab(10) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(46),
  datab(11) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(47),
  datab(12) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(48),
  datab(13) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(49),
  datab(14) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(50),
  datab(15) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(51),
  datab(16) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(52),
  datab(17) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(53),
  datab(18) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(54),
  datab(19) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(55),
  datab(20) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(56),
  datab(21) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(57),
  datab(22) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(58),
  datab(23) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(59),
  datab(24) => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(60),
  clock0 => N_36);
\GRFPC0_FPUSEL_6_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "on",
    lut_mask => X"f0f00400f0f00000")
port map (
combout => \GRFPC0.FPUSEL_6\(2),
dataf => \GRFPC0.FPUSEL_6_0_3__G0_E_2\,
datae => \GRFPC0.FP_PIPELINE.0.EXEN2\,
datad => \GRFPC0.FPUSEL_6_0_3__G0_E_0\,
datac => N_37,
datab => \GRFPC0.FPUSEL_6_0_3__G0_E_1\,
dataa => \GRFPC0.N_24389\,
datag => \GRFPC0.EXSEL_1\(2));
GRFPU0_GRFPU_X0_COMB_SHR_POSI_1_CARRY_0_BUF: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
cout => N_112285,
datad => VCC,
cin => GND);
GRFPU0_GRFPU_X0_COMB_SHR_POSI_CARRY_0_BUF: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
cout => N_112287,
datad => VCC,
cin => GND);
GRFPU0_GRFPU_X0_COMB_EXPCC_1_CARRY_0_BUF: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
cout => N_112289,
datad => VCC,
cin => GND);
GRFPU0_GRFPU_X0_C_CARRY_0_BUF: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
cout => N_112291,
datad => VCC,
cin => GND);
GRFPU0_GRFPU_X0_EXPDIFFN_1_CARRY_0_BUF: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
cout => N_112293,
datad => VCC,
cin => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10092\,
dataf => \GRFPU0.GRFPU_X0.N_10088_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(18));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10089\,
dataf => \GRFPU0.GRFPU_X0.N_10088_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(21));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10088\,
dataf => \GRFPU0.GRFPU_X0.N_10088_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(22));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10102\,
dataf => \GRFPU0.GRFPU_X0.N_10088_1\,
datae => \GRFPU0.GRFPU_X0.N_19707\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10103\,
dataf => \GRFPU0.GRFPU_X0.N_10088_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(7));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10100\,
dataf => \GRFPU0.GRFPU_X0.N_10088_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(10));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10094\,
dataf => \GRFPU0.GRFPU_X0.N_10088_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(16));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10095\,
dataf => \GRFPU0.GRFPU_X0.N_10088_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(15));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10090\,
dataf => \GRFPU0.GRFPU_X0.N_10088_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(20));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10097\,
dataf => \GRFPU0.GRFPU_X0.N_10088_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(13));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10107\,
dataf => \GRFPU0.GRFPU_X0.N_10088_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(3));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10105\,
dataf => \GRFPU0.GRFPU_X0.N_10088_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(5));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10099\,
dataf => \GRFPU0.GRFPU_X0.N_10088_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(11));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10106\,
dataf => \GRFPU0.GRFPU_X0.N_10088_1\,
datae => \GRFPU0.GRFPU_X0.N_3560_I\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(0),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37_1\(9),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(0));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(1),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37_1\(9),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(1));
\GRFPU0_GRFPU_X0_ST2_REG_RNIVL6L1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(2),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37_1\(9),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(2));
\GRFPU0_GRFPU_X0_ST2_REG_RNI0Q6L1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(3),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37_1\(9),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(3));
\GRFPU0_GRFPU_X0_ST2_REG_RNI1U6L1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(4),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37_1\(9),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(4));
\GRFPU0_GRFPU_X0_ST2_REG_RNI227L1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(5),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37_1\(9),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(5));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(6),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37_1\(9),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(6));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(7),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37_1\(9),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(7));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(8),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37_1\(9),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(8));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(9),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37_1\(9),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(9));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(10),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37_1\(9),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(10));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(11),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37_1\(9),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(11));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(12),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37_1\(9),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(12));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(13),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37_1\(9),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(13));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(14),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37_1\(9),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(14));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(15),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37_1\(9),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(15));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(16),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37_1\(9),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(16));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(17),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37_1\(9),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(17));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_RNO_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00dddddd00dfdfdf")
port map (
combout => N_111219,
dataf => \GRFPC0.N_25273\,
datae => \GRFPC0.N_261_2\,
datad => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4193_REGDEPX2\,
datac => N_111753,
datab => \GRFPC0.WR2.RREG.RESV\,
dataa => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_45_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff2220ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_45\(0),
dataf => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_I_1\(0),
datae => \GRFPC0.N_24611\,
datad => N_111229,
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_8\(0),
datab => \GRFPC0.MEM.RREG.RESV\,
dataa => \GRFPC0.MEM.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_445_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff0fff2")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440\(1),
dataf => \GRFPC0.FP_PIPELINE.14.REGDEPX2_425\(1),
datae => N_1_0,
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_2\(1),
datac => N_110352,
datab => \GRFPC0.MEM.RREG.RESV\,
dataa => \GRFPC0.MEM.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_15_I_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffdfffffffc")
port map (
combout => \GRFPC0.N_25384_RETI\,
dataf => \GRFPC0.MEM.CTRL.INSTI\(25),
datae => \GRFPC0.MEM.CTRL.INSTI\(26),
datad => \GRFPC0.MEM.CTRL.INSTI\(27),
datac => \GRFPC0.MEM.CTRL.INSTI\(29),
datab => \GRFPC0.MEM.CTRL.INSTI\(28),
dataa => \GRFPC0.N_579I\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_138_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0cfff3ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_138\(1),
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX2_128\(1),
datae => \GRFPC0.FP_PIPELINE.4.REGDEPX2_125\(1),
datad => N_111787,
datac => \GRFPC0.EX.RREG.RESV\,
datab => \GRFPC0.EX.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_138_SUB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00002000")
port map (
combout => N_111787,
dataf => N_111247,
datae => \GRFPC0.N_705\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN334_REGDEPX2_1\,
datac => \GRFPC0.WR.CTRL.RS1V\,
datab => \GRFPC0.WR.CTRL.INST\(18),
dataa => \GRFPC0.WR.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffefffdfffc")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55\(1),
dataf => \GRFPC0.FP_PIPELINE.1.REGDEPX2_48\(1),
datae => \GRFPC0.FP_PIPELINE.1.REGDEPX2_45\(1),
datad => N_111783,
datac => \GRFPC0.N_25566\,
datab => \GRFPC0.N_25568\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_0_SUB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"11f1111100f00000")
port map (
combout => N_111783,
dataf => \GRFPC0.N_25632\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datad => \GRFPC0.N_703\,
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN800_REGDEPX2\,
datab => \GRFPC0.WR2.CTRL.INST\(2),
dataa => \GRFPC0.WR2.CTRL.INST\(3));
GRFPC0_FP_PIPELINE_0_REGDEP90_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"d8d850fa2727af05")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_0\,
dataf => N_111781,
datae => \GRFPC0.FP_PIPELINE.VRFA.ST_1\,
datad => N_108596,
datac => \GRFPC0.RFA.RS1\(1),
datab => N_104,
dataa => N_37);
GRFPC0_FP_PIPELINE_0_REGDEP90_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0f0f0f0f0f0f")
port map (
combout => N_111781,
dataf => N_47178_2,
datae => \FPI.START\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.RFA.RD\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_M2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0c00ffff0000")
port map (
combout => \GRFPC0.N_25223\,
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => N_111773,
datad => \GRFPC0.N_24657_2\,
datac => \GRFPC0.N_25658\,
datab => \GRFPC0.N_25221\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_M2_SUB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff22222000")
port map (
combout => N_111773,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_O2_3\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_14_0_0\(1),
datad => \GRFPC0.N_25746\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN285_REGDEPX2\,
datab => \GRFPC0.MEM.RREG.RESV\,
dataa => \GRFPC0.MEM.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_RNO_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => N_111753,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(1),
datae => \GRFPC0.N_25226\,
datad => \GRFPC0.WR2.CTRL.INST\(1),
datac => \GRFPC0.WR2.CTRL.INST\(4));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_245_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000cfff")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_245\(0),
dataf => N_108572,
datae => N_111747,
datad => \GRFPC0.FPEXC_0_SQMUXA_D\,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => N_44718_1);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_245_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000cffffffffff")
port map (
combout => N_111747,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datae => \GRFPC0.FP_PIPELINE.8.REGDEPX2_243\(0),
datad => \GRFPC0.N_264\,
datac => \FPI.FLOP\(1),
datab => \GRFPC0.N_223\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_345_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cccc0000efff")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345\(1),
dataf => N_108572,
datae => N_111741,
datad => \GRFPC0.FPEXC_0_SQMUXA_D\,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => N_111207,
dataa => N_44718_1);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_345_SUB_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300ff00ff")
port map (
combout => N_111741,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datae => \GRFPC0.FP_PIPELINE.11.REGDEPX2_334_0_0\(1),
datad => N_111207,
datac => \GRFPC0.N_24502\,
datab => \GRFPC0.N_24501\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_125_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000cfff")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_125\(0),
dataf => N_108572,
datae => N_111737,
datad => \GRFPC0.FPEXC_0_SQMUXA_D\,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => N_44718_1);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_125_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0013005fffffffff")
port map (
combout => N_111737,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datae => \GRFPC0.FP_PIPELINE.4.REGDEPX2_125_0_A2_1_0\(1),
datad => \GRFPC0.N_25663\,
datac => \GRFPC0.N_25662_2\,
datab => \GRFPC0.N_25649\,
dataa => \GRFPC0.N_261_1\);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_305_0_A2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000cfff")
port map (
combout => \GRFPC0.N_24504\,
dataf => N_108572,
datae => N_111727,
datad => \GRFPC0.FPEXC_0_SQMUXA_D\,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => N_44718_1);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_305_0_A2_0_SUB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000fffffffffffff")
port map (
combout => N_111727,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datae => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_9_0\(0),
datad => \FPI.FLOP\(1),
datac => \GRFPC0.V.STDATA_14\(25));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_275_0_A2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000cfff")
port map (
combout => \GRFPC0.N_23995\,
dataf => N_108572,
datae => N_111725,
datad => \GRFPC0.FPEXC_0_SQMUXA_D\,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => N_44718_1);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_275_0_A2_1_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fffffffffffff")
port map (
combout => N_111725,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datae => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.N_24611_1\,
datab => \GRFPC0.N_25649\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_100_0_A2_SUB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff73ff33ffffffff")
port map (
combout => N_111153,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datae => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\,
datad => N_111691,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_9_5\(0),
dataa => N_44718_1);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_100_0_A2_SUB_SUB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c3c3c3c3c3c3d7ff")
port map (
combout => N_111691,
dataf => \GRFPC0.N_25179\,
datae => \GRFPC0.N_25178\,
datad => \GRFPC0.FP_PIPELINE.3.REGDEPX2_100_0_A2_4_1\(1),
datac => \FPI.FLOP\(1),
datab => \FPI.FLOP\(0),
dataa => \GRFPC0.N_260_2\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_A2_0_RNIHM7D5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0307030f00000000")
port map (
combout => \GRFPC0.N_24061\,
dataf => N_111689,
datae => \GRFPC0.N_21933\,
datad => \GRFPC0.N_21984\,
datac => \GRFPC0.N_21108\,
datab => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_0\,
dataa => N_99);
GRFPC0_FP_PIPELINE_FPUSTART_7_RNITVNP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000ff00000f00f")
port map (
combout => N_111689,
dataf => \FPI.START\,
datae => N_110261,
datad => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.FIFO.RD_3\(0));
\GRFPC0_R_FSR_TEM_RNIRUTE4_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"efcfaf0f00000000")
port map (
combout => \GRFPC0.FPEXC_0_SQMUXA_D\,
dataf => N_111673,
datae => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
datad => \FPO.EXC\(2),
datac => N_111405,
datab => \GRFPC0.R.FSR.TEM\(3),
dataa => \GRFPC0.R.FSR.TEM\(2));
GRFPC0_FP_PIPELINE_UN86_HOLDN_NE_RNIQLTF: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff000000")
port map (
combout => N_111673,
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datae => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datad => \GRFPC0.FPR.RDY\);
\GRFPC0_OP2_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffff3ff")
port map (
combout => \FPI.OP2\(41),
dataf => N_111665,
datae => \GRFPU0.GRFPU_X0.N_20297_I_0\,
datad => N_99880_1,
datac => \GRFPC0.RFA2.RS2SEL\(4),
datab => N_99881);
\GRFPC0_OP2_SUB_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"407300004073ffff")
port map (
combout => N_111665,
dataf => \GRFPC0.N_19800\,
datae => N_99880,
datad => \GRFPC0.N_19537\,
datac => \GRFPC0.RFA2.RS2SEL\(4),
datab => N_99881,
dataa => \GRFPC0.WR2.RREG.RES\(41));
GRFPC0_FP_PIPELINE_UN25_HOLDN_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0f0ff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN25_HOLDN_1\,
dataf => N_111537,
datae => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_3\,
datad => N_108530,
datac => \GRFPC0.WR2.RREG.RESV\);
GRFPC0_FP_PIPELINE_UN25_HOLDN_1_SUB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0101ffff0101ff01")
port map (
combout => N_111537,
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_0\,
datae => \GRFPC0.WR2.RREG.RESV\,
datad => \GRFPC0.R.STATE\(0),
datac => \GRFPC0.WR2.CTRL.LD\,
datab => \GRFPC0.WR2.CTRL.CCWR\,
dataa => \GRFPC0.WR2.CTRL.RDWR\);
\GRFPC0_DIV_RESULT_0_0_50__G3_0\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ccf000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_50__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(50),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(50));
\GRFPC0_OP2_RNO_0_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1000ffffffffffff")
port map (
combout => N_110951,
dataf => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(44),
datae => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(44),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(0),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(1),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(41));
\GRFPC0_OP2_RNO_0_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000dfff")
port map (
combout => N_110955,
dataf => \GRFPC0.DIV.RESULT_0_0_36__G3_1\,
datae => \GRFPC0.DIV.RESULT_0_0_36__G3_0\,
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(33));
\GRFPC0_OP2_RNO_0_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1000ffffffffffff")
port map (
combout => N_110947,
dataf => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(34),
datae => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(34),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datab => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(31));
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_3_2\,
dataf => \FPO.EXC\(2),
datae => N_111405,
datad => \GRFPC0.R.FSR.TEM\(2));
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_13_RNIRSK91_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f00ff")
port map (
combout => N_111405,
dataf => \GRFPC0.FPO_I_6_I_0\(69),
datae => \GRFPU0.GRFPU_X0.N_18289_I_0\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\(1),
datac => \GRFPC0.R.FSR.TEM\(4));
\GRFPC0_R_FSR_TEM_RNIT8ALF_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000454500004555")
port map (
combout => N_47178_2,
dataf => \GRFPC0.FPEXC_0_SQMUXA_D\,
datae => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datad => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => N_44718_1,
dataa => N_39);
\GRFPC0_FIFO_INST_0_RNI5D0H6_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"550f33550f0f3333")
port map (
combout => N_108596,
dataf => \GRFPC0.VFIFO.WR_0_SQMUXA_3\,
datae => \GRFPC0.N_23766\,
datad => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.FIFO.INST_1\(15),
datab => \GRFPC0.FIFO.INST_0\(15),
dataa => N_93);
\GRFPC0_D_STLCK_RNO_4_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_31__G1_N_4\,
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_24900\,
datab => \GRFPC0.FIFO.INST_0\(29));
\GRFPC0_D_STLCK_RNO_0_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f000ff0fffff")
port map (
combout => \GRFPC0.D.STLCK_0_0_31__G1_N_6\,
dataf => \GRFPC0.FP_PIPELINE.15.STDEP_612\(1),
datae => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_20\(0),
datad => \GRFPC0.N_18394_1\,
datac => \GRFPC0.EX.CTRL.RDWR\);
\GRFPC0_D_STLCK_RNO_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff51ffffffff")
port map (
combout => \GRFPC0.D.STLCK_0_0_31__G1\,
dataf => \GRFPC0.D.STLCK_0_0_31__G1_N_6\,
datae => \GRFPC0.N_23091\,
datad => \GRFPC0.D.STLCK_0_0_31__G1_3\,
datac => \GRFPC0.N_23059\,
datab => N_110366,
dataa => \GRFPC0.D.STLCK_0_0_31__G1_N_4\);
\GRFPC0_D_STLCK_RNO_1_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_17__G1_N_3\,
dataf => \GRFPC0.N_810\,
datae => \GRFPC0.FP_PIPELINE.8.STDEP_332_SEL0_1\);
\GRFPC0_D_STLCK_RNO_2_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0c0f000f000f000")
port map (
combout => \GRFPC0.D.STLCK_0_0_17__G1_N_7\,
dataf => \GRFPC0.N_62\,
datae => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O2_1\(1),
datad => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_0_0\(1),
datac => \GRFPC0.N_21182\,
datab => \GRFPC0.N_9481\);
\GRFPC0_D_STLCK_RNO_0_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000003")
port map (
combout => \GRFPC0.D.STLCK_0_0_17__G1_N_8\,
dataf => \GRFPC0.D.STLCK_0_0_17__G1_N_7\,
datae => \GRFPC0.N_21208\,
datad => \GRFPC0.N_63\,
datac => \GRFPC0.N_21205\,
datab => \GRFPC0.D.STLCK_0_0_17__G1_0\);
\GRFPC0_D_STLCK_RNO_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"2020ffff20feffff")
port map (
combout => \GRFPC0.D.STLCK_0_0_17__G1\,
dataf => \GRFPC0.N_22291\,
datae => \GRFPC0.D.STLCK_0_0_17__G1_N_8\,
datad => \GRFPC0.D.STLCK_0_0_17__G1_N_3\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datab => \GRFPC0.N_55\,
dataa => \GRFPC0.N_106_I\);
\GRFPC0_D_STLCK_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff7fffff8000ffff")
port map (
combout => \GRFPC0.D.STLCK_0_0_8__G1\,
dataf => \GRFPC0.FP_PIPELINE.4.STDEP_172\(0),
datae => N_111371,
datad => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1386_DEP\,
dataa => \GRFPC0.EX.CTRL.RDWR\);
\GRFPC0_D_STLCK_RNO_0_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff00f0")
port map (
combout => N_111371,
dataf => \GRFPC0.N_22633\,
datae => \GRFPC0.STDDEP_0_SQMUXA_131_I_1\,
datad => \GRFPC0.D.STLCK_0_0_8__G1_3\,
datac => N_103);
\GRFPC0_D_STLCK_RNO_1_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0f2f000000000")
port map (
combout => \GRFPC0.N_21329\,
dataf => N_111369,
datae => \GRFPC0.N_21253\,
datad => \GRFPC0.FP_PIPELINE.13.STDEP_558_I_M_I_A3_14_0\(1),
datac => \GRFPC0.N_21269\,
datab => \GRFPC0.N_53\,
dataa => \GRFPC0.N_482\);
\GRFPC0_D_STLCK_RNO_7_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => N_111369,
dataf => \GRFPC0.N_21307\,
datae => \GRFPC0.N_122\,
datad => \GRFPC0.N_121\,
datac => N_40557);
\GRFPC0_D_STLCK_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0ffffff0000")
port map (
combout => \GRFPC0.D.STLCK_0_0_1__G1\,
dataf => \GRFPC0.N_557\,
datae => N_111365,
datad => \GRFPC0.N_507\,
datac => \GRFPC0.N_569\);
\GRFPC0_D_STLCK_RNO_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffa2")
port map (
combout => N_111365,
dataf => \GRFPC0.N_751\,
datae => \GRFPC0.N_762\,
datad => \GRFPC0.D.STLCK_0_0_1__G1_2\,
datac => \GRFPC0.N_730\,
datab => \GRFPC0.N_507\,
dataa => \GRFPC0.N_569\);
\GRFPC0_D_STLCK_RNO_11_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"02000f0d0f0d0f0d")
port map (
combout => \GRFPC0.N_21307\,
dataf => \GRFPC0.N_742_1\,
datae => \GRFPC0.N_21327\,
datad => \GRFPC0.N_114\,
datac => N_111363,
datab => \GRFPC0.N_21241\,
dataa => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_D_STLCK_RNO_15_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0cffffffff")
port map (
combout => N_111363,
dataf => \GRFPC0.N_21246\,
datae => \GRFPC0.N_21257\,
datad => N_111351,
datac => N_99872,
datab => \GRFPC0.N_505\);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_8_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00fb00cc00c8")
port map (
combout => \GRFPC0.N_17410\,
dataf => \GRFPC0.N_24723\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90\(0),
datad => N_111361,
datac => \GRFPC0.INST\(26),
datab => \GRFPC0.INST\(27),
dataa => \GRFPC0.INST\(28));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_8_0_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000880884048c0c8")
port map (
combout => N_111361,
dataf => \GRFPC0.N_24712\,
datae => \GRFPC0.N_24709\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210\(0),
datac => \GRFPC0.INST\(26),
datab => \GRFPC0.INST\(27),
dataa => \GRFPC0.INST\(28));
\GRFPC0_D_STLCK_RNO_4_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000e000e000e")
port map (
combout => \GRFPC0.N_21297\,
dataf => \GRFPC0.N_742_1\,
datae => \GRFPC0.N_21327\,
datad => N_111359,
datac => \GRFPC0.N_21241\,
datab => \GRFPC0.WR.CTRL.RDD\,
dataa => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_D_STLCK_RNO_10_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000a333b00003333")
port map (
combout => N_111359,
dataf => \GRFPC0.N_114\,
datae => \GRFPC0.N_53\,
datad => \GRFPC0.N_21241\,
datac => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.N_579\,
dataa => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_12_STDEP_492_3_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"4f04ffb40404b4b4")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_488\(1),
dataf => N_111357,
datae => \GRFPC0.N_114\,
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3956_DEP\,
datac => \GRFPC0.N_18739\,
datab => \GRFPC0.N_494\,
dataa => \GRFPC0.FP_PIPELINE.12.STDEP_488_SEL0_1\);
\GRFPC0_FP_PIPELINE_12_STDEP_492_3_RNO_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00ff000000ff00")
port map (
combout => N_111357,
dataf => \GRFPC0.N_16_I\,
datae => \GRFPC0.N_362\,
datad => \GRFPC0.N_458\,
datac => \GRFPC0.N_74_I_I\);
\GRFPC0_D_STLCK_RNO_17_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff00fcfcfffc")
port map (
combout => N_111351,
dataf => \GRFPC0.N_53\,
datae => \GRFPC0.N_21241\,
datad => \GRFPC0.WR.CTRL.RDD\,
datac => \GRFPC0.N_579\,
datab => \GRFPC0.MEM.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_O3_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000d0000ffff")
port map (
combout => \GRFPC0.N_165\,
dataf => \GRFPC0.N_666\,
datae => N_111349,
datad => \GRFPC0.N_114\,
datac => \GRFPC0.N_21725\,
datab => \GRFPC0.N_467\,
dataa => \GRFPC0.MEM.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_O3_1_SUB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => N_111349,
dataf => \GRFPC0.N_104\,
datae => \GRFPC0.N_467\,
datad => \GRFPC0.N_579\,
datac => \GRFPC0.MEM.CTRL.RD\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_SUB_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0f0000000c")
port map (
combout => N_111347,
dataf => N_93117,
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datad => \GRFPU0.GRFPU_X0.N_18527\,
datac => \GRFPU0.GRFPU_X0.N_5673_0\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_SUB_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000f0fc")
port map (
combout => N_111345,
dataf => N_93111,
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datad => \GRFPU0.GRFPU_X0.N_18527\,
datac => \GRFPU0.GRFPU_X0.N_5673_0\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_SUB_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000f0c")
port map (
combout => N_111343,
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => N_93115,
datac => \GRFPU0.GRFPU_X0.N_5673_0\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_SUB_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000f0c")
port map (
combout => N_111341,
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => N_93121,
datac => \GRFPU0.GRFPU_X0.N_5673_0\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPC0_FP_PIPELINE_12_STDEP_488_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff004400f40044")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_488\(0),
dataf => \GRFPC0.N_22173_I\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datad => N_111337,
datac => \GRFPC0.N_458\,
datab => \GRFPC0.N_494\,
dataa => \GRFPC0.FP_PIPELINE.12.STDEP_488_SEL0_1\);
\GRFPC0_FP_PIPELINE_12_STDEP_488_3_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"40fbfbfb00bbbbbb")
port map (
combout => N_111337,
dataf => \GRFPC0.N_114\,
datae => \GRFPC0.N_481\,
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3956_DEP\,
datac => \GRFPC0.N_18739\,
datab => \GRFPC0.N_494\,
dataa => \GRFPC0.FP_PIPELINE.12.STDEP_488_SEL0_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_SUB_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000f000f0000")
port map (
combout => N_111335,
dataf => N_93110,
datae => N_93122,
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \GRFPU0.GRFPU_X0.N_5673_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_SUB_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0f00000f00")
port map (
combout => N_111333,
dataf => N_93110,
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datad => N_93116,
datac => \GRFPU0.GRFPU_X0.N_5673_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_0_SUB_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff000000c0")
port map (
combout => N_111331,
dataf => N_108652,
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datad => \GRFPU0.GRFPU_X0.N_18527\,
datac => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_SUB_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000f0c")
port map (
combout => N_111329,
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => N_93114,
datac => \GRFPU0.GRFPU_X0.N_5673_0\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_SUB_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0f0000000c")
port map (
combout => N_111327,
dataf => N_93112,
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datad => \GRFPU0.GRFPU_X0.N_18527\,
datac => \GRFPU0.GRFPU_X0.N_5673_0\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_0_SUB_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff000000c0")
port map (
combout => N_111325,
dataf => N_108648,
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datad => \GRFPU0.GRFPU_X0.N_18527\,
datac => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_SUB_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0f0000000c")
port map (
combout => N_111323,
dataf => N_93123,
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datad => \GRFPU0.GRFPU_X0.N_18527\,
datac => \GRFPU0.GRFPU_X0.N_5673_0\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_SUB_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0f0000000c")
port map (
combout => N_111321,
dataf => N_93120,
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datad => \GRFPU0.GRFPU_X0.N_18527\,
datac => \GRFPU0.GRFPU_X0.N_5673_0\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_SUB_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0f0000000c")
port map (
combout => N_111319,
dataf => N_93113,
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datad => \GRFPU0.GRFPU_X0.N_18527\,
datac => \GRFPU0.GRFPU_X0.N_5673_0\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPC0_FP_PIPELINE_4_STDEP_164_0_IV_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_164\(0),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datae => N_111315,
datad => \GRFPC0.N_10567_2\,
datac => \GRFPC0.STDEP_2_SQMUXA_133\);
\GRFPC0_FP_PIPELINE_4_STDEP_164_0_IV_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000b3ffffff")
port map (
combout => N_111315,
dataf => \GRFPC0.STDEP_2_SQMUXA_133\,
datae => \GRFPC0.N_481\,
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1660_DEP_2\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\,
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1332_DEP_0\,
dataa => \GRFPC0.DIV.EXEC\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_358_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffdfffefffc")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_358\(0),
dataf => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345\(0),
datae => \GRFPC0.FP_PIPELINE.11.REGDEPX2_348\(0),
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355_1\(0),
datac => N_111309,
datab => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_7\(0),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_358_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffaeaa0c00")
port map (
combout => N_111309,
dataf => N_1_3,
datae => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_6\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datac => \GRFPC0.N_702\,
datab => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5210_REGDEPX2\,
dataa => \GRFPC0.DIV.RS1V\);
GRFPC0_RFA2_RS1DEP_RNO_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"81a5000000000000")
port map (
combout => N_110364,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_0_3\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEP78\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEP90\,
datac => \GRFPC0.N_22829\,
datab => N_111307,
dataa => \GRFPC0.EX.CTRL.RD\(0));
GRFPC0_RFA2_RS1DEP_RNO_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00ff00ff")
port map (
combout => N_111307,
dataf => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datae => \GRFPC0.V.STDATA_14\(25),
datad => \GRFPC0.RFA.RD\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_25_RNIP6F92_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_0__G3\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_25\(0),
datae => N_111301,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_16\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datab => \GRFPC0.DIV.RS1V\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_26_0_A2_1_0_A2_RNI0DJH1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f1f0110000000000")
port map (
combout => N_111301,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
datad => \GRFPC0.N_24242\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN447_REGDEPX2\,
datab => \GRFPC0.DIV.RD\(2),
dataa => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_10_STDEP_412_3_0_I_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000ff0000")
port map (
combout => \GRFPC0.N_742\,
dataf => \GRFPC0.N_10567_2\,
datae => \GRFPC0.N_24455_I\,
datad => N_111299,
datac => \GRFPC0.N_481\);
\GRFPC0_FP_PIPELINE_10_STDEP_412_3_0_I_A2_SUB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0cffffae0cffff")
port map (
combout => N_111299,
dataf => \GRFPC0.N_481\,
datae => \GRFPC0.N_458\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\,
datac => \GRFPC0.N_491\,
datab => \GRFPC0.WR.CTRL.RD\(0),
dataa => \GRFPC0.DIV.EXEC\);
\GRFPC0_FP_PIPELINE_3_STDEP_128_3_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000003f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_31\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datae => \GRFPC0.N_10567_2\,
datad => N_111297,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\,
datab => \GRFPC0.DIV.EXEC\);
\GRFPC0_FP_PIPELINE_3_STDEP_128_3_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffffffff")
port map (
combout => N_111297,
dataf => \GRFPC0.N_481\,
datae => \GRFPC0.N_458\,
datad => \GRFPC0.N_525\,
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
\GRFPC0_FP_PIPELINE_3_STDEP_128_3_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000c000f000f")
port map (
combout => \GRFPC0.N_805\,
dataf => \GRFPC0.FP_PIPELINE.UN29_WREN_1\,
datae => CPO_EXCZ,
datad => \GRFPC0.VDIV.EXEC_0_SQMUXA\,
datac => N_111269,
datab => \GRFPC0.DIV.EXEC_0_0_G0_2_0\);
\GRFPC0_FP_PIPELINE_3_STDEP_128_3_0_A2_SUB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffaaccafcf")
port map (
combout => N_111269,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.DIV.EXEC_0_0_G0_2_0\,
datad => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datac => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F1_A0_C\,
datab => \GRFPC0.DIV.RD\(4),
dataa => \GRFPC0.WR2.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_348_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff2ffff2ff22")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_348\(0),
dataf => \GRFPC0.FP_PIPELINE.11.REGDEPX2_340\(0),
datae => \GRFPC0.FP_PIPELINE.11.REGDEPX2_343\(0),
datad => N_111267,
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datab => \GRFPC0.N_706\,
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5181_REGDEPX2\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_348_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aa00eac00000c0c0")
port map (
combout => N_111267,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.N_704\,
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5165_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5195_REGDEPX2\,
datab => \GRFPC0.WR.CTRL.RS1V\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0));
\GRFPC0_FP_PIPELINE_13_STDEP_536_3_I_A3_6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000c000f000f")
port map (
combout => \GRFPC0.N_21327\,
dataf => \GRFPC0.FP_PIPELINE.UN29_WREN_1\,
datae => CPO_EXCZ,
datad => \GRFPC0.VDIV.EXEC_0_SQMUXA\,
datac => N_111259,
datab => \GRFPC0.DIV.EXEC_0_0_G0_2_0\);
\GRFPC0_FP_PIPELINE_13_STDEP_536_3_I_A3_6_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f1ffffffffffffff")
port map (
combout => N_111259,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.DIV.EXEC_0_0_G0_2_0\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F1_A0_C\);
GRFPC0_FP_PIPELINE_UN29_WREN_1_RNI9SD65: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000c000f000f")
port map (
combout => \GRFPC0.N_24455_I\,
dataf => \GRFPC0.FP_PIPELINE.UN29_WREN_1\,
datae => CPO_EXCZ,
datad => \GRFPC0.VDIV.EXEC_0_SQMUXA\,
datac => N_111257,
datab => \GRFPC0.DIV.EXEC_0_0_G0_2_0\);
GRFPC0_FP_PIPELINE_VDIV_VALID_7_F1_A0_C_RNICF3G2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff1fffff")
port map (
combout => N_111257,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.DIV.EXEC_0_0_G0_2_0\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F1_A0_C\);
GRFPC0_STDEP_2_SQMUXA_133: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000c000f000f")
port map (
combout => \GRFPC0.STDEP_2_SQMUXA_133\,
dataf => \GRFPC0.FP_PIPELINE.UN29_WREN_1\,
datae => CPO_EXCZ,
datad => N_111255,
datac => \GRFPC0.VDIV.EXEC_0_SQMUXA\,
datab => \GRFPC0.DIV.EXEC_0_0_G0_2_0\);
GRFPC0_STDEP_2_SQMUXA_133_SUB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1fffffffffffffff")
port map (
combout => N_111255,
dataf => \GRFPC0.N_481\,
datae => \GRFPC0.N_458\,
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1660_DEP_2\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1332_DEP_0\,
datab => \GRFPC0.DIV.EXEC_0_0_G0_2_0\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F1_A0_C\);
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_A3_4_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000c000f000f")
port map (
combout => \GRFPC0.N_23818_2\,
dataf => \GRFPC0.FP_PIPELINE.UN29_WREN_1\,
datae => CPO_EXCZ,
datad => \GRFPC0.VDIV.EXEC_0_SQMUXA\,
datac => N_111253,
datab => \GRFPC0.DIV.EXEC_0_0_G0_2_0\);
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_A3_4_2_SUB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff1ffff")
port map (
combout => N_111253,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.DIV.EXEC_0_0_G0_2_0\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F1_A0_C\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_411_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ff2fff20")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_411\(0),
dataf => \GRFPC0.FP_PIPELINE.13.REGDEPX2_408\(0),
datae => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405\(0),
datad => N_111251,
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datab => \GRFPC0.N_702\,
dataa => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6092_REGDEPX2\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_411_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => N_111251,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(0),
datae => \GRFPC0.N_25550\,
datad => \GRFPC0.WR2.CTRL.INST\(29),
datac => \GRFPC0.WR2.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_3_STDEP_128_3_0_A2_3_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000c000f000f")
port map (
combout => \GRFPC0.N_644_2\,
dataf => \GRFPC0.FP_PIPELINE.UN29_WREN_1\,
datae => CPO_EXCZ,
datad => \GRFPC0.VDIV.EXEC_0_SQMUXA\,
datac => N_111249,
datab => \GRFPC0.DIV.EXEC_0_0_G0_2_0\);
\GRFPC0_FP_PIPELINE_3_STDEP_128_3_0_A2_3_2_SUB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff1fff")
port map (
combout => N_111249,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.DIV.EXEC_0_0_G0_2_0\,
dataa => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F1_A0_C\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_136_SUB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0020")
port map (
combout => N_111247,
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_1\(1),
datae => \GRFPC0.FP_PIPELINE.4.REGDEPX2_0\(1),
datad => \GRFPC0.N_707\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_1\,
datab => \GRFPC0.WR.CTRL.INST\(29),
dataa => \GRFPC0.WR.CTRL.INST\(28));
GRFPC0_STDEP_2_SQMUXA_129: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fff00000ffff")
port map (
combout => \GRFPC0.STDEP_2_SQMUXA_129\,
dataf => \GRFPC0.FP_PIPELINE.UN29_WREN_1\,
datae => N_111245,
datad => CPO_EXCZ,
datac => \GRFPC0.DIV.EXEC_0_0_G0_2_0\);
GRFPC0_STDEP_2_SQMUXA_129_SUB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffeffff")
port map (
combout => N_111245,
dataf => \GRFPC0.VDIV.EXEC_0_SQMUXA\,
datae => \GRFPC0.N_458\,
datad => \GRFPC0.N_525\,
datac => N_110360,
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
dataa => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
\GRFPC0_FP_PIPELINE_3_STDEP_128_3_0_O2_2_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f3ff0000f3f3")
port map (
combout => \GRFPC0.N_737_2\,
dataf => \GRFPC0.FP_PIPELINE.UN29_WREN_1\,
datae => N_111243,
datad => \GRFPC0.PENDEXC_0_SQMUXA\,
datac => \GRFPC0.VDIV.EXEC_0_SQMUXA\,
datab => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F1_A0_C\);
\GRFPC0_FP_PIPELINE_3_STDEP_128_3_0_O2_2_RNO_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"bbbb3333fbbbf333")
port map (
combout => N_111243,
dataf => \GRFPC0.VDIV.EXEC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\,
datad => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datac => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F1_A0_C\,
datab => \GRFPC0.FP_PIPELINE.3.STDEP_128_SEL0_1\,
dataa => \GRFPC0.DIV.EXEC\);
GRFPU0_GRFPU_X0_SGNF_2_SQMUXA_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000070ff77ff")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
dataf => N_111241,
datae => \GRFPU0.GRFPU_X0.N_18948\,
datad => \GRFPU0.GRFPU_X0.N_7241\,
datac => \GRFPU0.GRFPU_X0.N_18870\,
datab => \GRFPU0.GRFPU_X0.N_18871\,
dataa => \FPI.NONSTD\);
GRFPU0_GRFPU_X0_SGNF_2_SQMUXA_1_SUB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000fffffffff")
port map (
combout => N_111241,
dataf => \GRFPU0.GRFPU_X0.N_10059_I\,
datae => \FPI.FLOP\(1),
datad => \FPI.FLOP\(6),
datac => \FPI.FLOP\(5));
\GRFPC0_FP_PIPELINE_5_STDEP_230_0_IV_I_I2_6_I4_0_A3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000030")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
dataf => CPO_EXCZ,
datae => \GRFPC0.N_21965\,
datad => \GRFPC0.N_21108\,
datac => N_108,
datab => N_111239);
\GRFPC0_FP_PIPELINE_5_STDEP_230_0_IV_I_I2_6_I4_0_A3_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefefeffffffffff")
port map (
combout => N_111239,
dataf => N_109,
datae => \GRFPC0.N_313\,
datad => \GRFPC0.N_9203\,
datac => N_113,
datab => N_112,
dataa => \GRFPC0.FP_PIPELINE.UN205_HOLDN_0\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff8000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435\(0),
dataf => N_111231,
datae => \GRFPC0.N_23933\,
datad => \GRFPC0.N_23994_1\,
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6767_REGDEPX2_2\,
datab => \GRFPC0.N_23975\,
dataa => \GRFPC0.N_23941_1\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff080")
port map (
combout => N_111231,
dataf => \GRFPC0.N_23932\,
datae => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_1\(0),
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_429_0\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6428_REGDEPX2\,
dataa => \GRFPC0.N_25162_1\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_43_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff75ff55f0300000")
port map (
combout => N_111229,
dataf => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_10_1\(0),
datae => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN740_REGDEPX2\,
datad => \GRFPC0.N_579\,
datac => \GRFPC0.MEM.CTRL.RS1V\,
datab => \GRFPC0.MEM.CTRL.INST\(14),
dataa => \GRFPC0.MEM.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_160_RNI0G2L2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff8000ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165\(0),
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160\(0),
datae => N_111225,
datad => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(0),
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2504_REGDEPX2\,
dataa => \GRFPC0.MEM.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_12_0_A2_RNIASFB1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000fff0000ffff")
port map (
combout => N_111225,
dataf => \GRFPC0.N_24193\,
datae => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_12\(0),
datad => \GRFPC0.MEM.CTRL.INST\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_343_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_343\(0),
dataf => \GRFPC0.N_24528\,
datae => \GRFPC0.N_24527\,
datad => \GRFPC0.N_24526\,
datac => N_111221);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_343_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffefc")
port map (
combout => N_111221,
dataf => \GRFPC0.N_24525\,
datae => \GRFPC0.N_24516\,
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_16\(0),
datac => \GRFPC0.N_24518\,
datab => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_17\(0),
dataa => \GRFPC0.MEM.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff00ffffffff")
port map (
combout => \GRFPC0.N_25228\,
dataf => N_111219,
datae => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_O2_3_1\(1),
datad => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_O2_3\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_128_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffeac0ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_128\(1),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => N_111215,
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_125_0_A2_1_0\(1),
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_125_0_A2_0\(1),
datab => \GRFPC0.N_25221\,
dataa => \GRFPC0.N_24484\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_128_SUB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => N_111215,
dataf => \GRFPC0.N_261\,
datae => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2004_REGDEPX2\,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_11\(1),
datac => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_408_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffeccc")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_408\(0),
dataf => N_110346,
datae => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_5\(0),
datad => \GRFPC0.N_25169_2\,
datac => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5885_REGDEPX2\,
datab => N_111213,
dataa => \FPI.FLOP\(6));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_408_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000003000")
port map (
combout => N_111213,
dataf => \GRFPC0.N_704\,
datae => \GRFPC0.N_25498\,
datad => \GRFPC0.WR.CTRL.RS1V\,
datac => \GRFPC0.WR.CTRL.INST\(15),
datab => \GRFPC0.WR.CTRL.INST\(16));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_345_SUB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8800f8f0ff00fff0")
port map (
combout => N_111207,
dataf => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_N_6\,
datae => \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_I_A4_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5165_REGDEPX2\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_48_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcfcfcff")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_48\(1),
dataf => \GRFPC0.N_25416\,
datae => N_110295,
datad => N_111133,
datac => N_111193,
datab => \GRFPC0.N_25415\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_48_SUB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff08")
port map (
combout => N_111193,
dataf => \GRFPC0.FP_PIPELINE.1.REGDEPX2_45_0_1\(1),
datae => \GRFPC0.N_25421\,
datad => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_7\(1),
datac => \GRFPC0.N_705\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN785_REGDEPX2\,
dataa => \GRFPC0.WR.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0ff0000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220\(0),
dataf => \GRFPC0.N_24554\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datad => N_111189,
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_1\(0),
datab => \GRFPC0.EX.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_RNO_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0f0f00ffffff")
port map (
combout => N_111189,
dataf => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3356_REGDEPX2\,
datae => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3327_REGDEPX2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_2_SUB_RNIOJBDA_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000b000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_155\(1),
dataf => N_108572,
datae => \GRFPC0.FPEXC_0_SQMUXA_D\,
datad => N_111179,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
dataa => N_44718_1);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_153_RNI9LDS1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0fff")
port map (
combout => N_111179,
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_153\(1),
datae => \GRFPC0.V.STDATA_14_I_M_10\(0),
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2429_REGDEPX2_0\,
datac => \GRFPC0.N_24616\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_M2_SUB_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccccccefff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_O2_3\(1),
dataf => N_108572,
datae => N_111169,
datad => \GRFPC0.FPEXC_0_SQMUXA_D\,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_O2_1\(1),
dataa => N_44718_1);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_M2_SUB_RNO_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000fffffffffff")
port map (
combout => N_111169,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_A2_1_1\(1),
datad => \GRFPC0.N_23966\,
datac => \GRFPC0.N_24484\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_SUB_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000008c00cc00")
port map (
combout => \GRFPC0.N_23932\,
dataf => N_108572,
datae => \GRFPC0.FPEXC_0_SQMUXA_D\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => N_111161,
dataa => N_44718_1);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_SUB_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => N_111161,
dataf => \GRFPC0.N_23980\,
datae => \GRFPC0.N_225\,
datad => \GRFPC0.N_24039\,
datac => \GRFPC0.N_25120\);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_255_0_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000b000f00")
port map (
combout => \GRFPC0.N_25255\,
dataf => N_108572,
datae => \GRFPC0.FPEXC_0_SQMUXA_D\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datac => N_111157,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
dataa => N_44718_1);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_255_0_RNO_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f0ff")
port map (
combout => N_111157,
dataf => \GRFPC0.N_25301\,
datae => \GRFPC0.N_25299\,
datad => \GRFPC0.N_264\,
datac => \GRFPC0.V.STDATA_14_I_M_10\(0));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_100_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0ffffff")
port map (
combout => \GRFPC0.N_25156\,
dataf => N_111153,
datae => \GRFPC0.FPEXC_0_SQMUXA_D\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datac => N_44718_1);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0f00000fbff")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75\(1),
dataf => N_108572,
datae => N_111151,
datad => \GRFPC0.FPEXC_0_SQMUXA_D\,
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_3\(1),
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
dataa => N_44718_1);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_SUB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000007f0000ffff")
port map (
combout => N_111151,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datae => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_3\(1),
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_O2_2_1\(1),
datac => \GRFPC0.N_25727_1\,
datab => \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN824_REGDEPX\,
dataa => \GRFPC0.FIFO.RD_1\(0));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_215_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3000")
port map (
combout => \GRFPC0.N_24555\,
dataf => N_108572,
datae => N_111149,
datad => \GRFPC0.FPEXC_0_SQMUXA_D\,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => N_44718_1);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_215_I_SUB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55ff0030ffffffff")
port map (
combout => N_111149,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datae => \GRFPC0.FP_PIPELINE.7.REGDEPX2_215_I_A2_1\(1),
datad => \GRFPC0.N_24621\,
datac => \GRFPC0.N_24568\,
datab => \GRFPC0.N_24622\,
dataa => \GRFPC0.N_235\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_425_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000cfff")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_425\(1),
dataf => N_108572,
datae => N_111147,
datad => \GRFPC0.FPEXC_0_SQMUXA_D\,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => N_44718_1);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_425_SUB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffefffffffff")
port map (
combout => N_111147,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datae => \GRFPC0.FP_PIPELINE.14.REGDEPX2_423\(1),
datad => \GRFPC0.V.STDATA_14_I_M_10\(0),
datac => \GRFPC0.N_225\,
datab => \GRFPC0.N_24039\,
dataa => \GRFPC0.N_25120\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_I_A3_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0ffffff")
port map (
combout => \GRFPC0.N_24611\,
dataf => N_111143,
datae => \GRFPC0.FPEXC_0_SQMUXA_D\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datac => N_44718_1);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_I_A3_1_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff7ffff")
port map (
combout => N_111143,
dataf => N_108572,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datad => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datab => \GRFPC0.N_24611_1\,
dataa => \GRFPC0.N_25649\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_0_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffefefeff")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_45\(1),
dataf => \GRFPC0.N_25416\,
datae => N_110295,
datad => N_111133,
datac => \GRFPC0.N_25415\,
datab => \GRFPC0.FP_PIPELINE.1.REGDEPX2_45_0_1\(1),
dataa => \GRFPC0.N_25421\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_2_0_3_RNI25768_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00ffff0000ffff")
port map (
combout => N_111133,
dataf => \GRFPC0.FPEXC_0_SQMUXA_D\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datac => N_44718_1);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_305_0_A2_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0b0b00000b0f0000")
port map (
combout => \GRFPC0.N_23994_1\,
dataf => \GRFPC0.FPEXC_0_SQMUXA_D\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datad => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\,
datac => N_111131,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
dataa => N_44718_1);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_305_0_A2_3_SUB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ff0fffffffffff")
port map (
combout => N_111131,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_9_5\(0),
datae => \FPI.FLOP\(1),
datad => \FPI.FLOP\(6),
datac => \FPI.FLOP\(0));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_340_0_A2_1_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"dfcfcfcfffffffff")
port map (
combout => N_110293,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datae => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_9_5\(0),
datab => N_111113,
dataa => N_44718_1);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_340_0_A2_1_SUB_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdfffffff7ffffff")
port map (
combout => N_111113,
dataf => \FPI.FLOP\(1),
datae => \GRFPC0.N_23980\,
datad => \GRFPC0.N_225\,
datac => \GRFPC0.N_226\,
datab => \FPI.FLOP\(0),
dataa => \GRFPC0.FP_PIPELINE.11.REGDEPX2_334_0_A2_0_0_0\(1));
GRFPC0_VFIFO_INST_1_1_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000500070005000f")
port map (
combout => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
dataf => \GRFPC0.N_21933\,
datae => \GRFPC0.N_21984\,
datad => \GRFPC0.N_21108\,
datac => N_111101,
datab => N_99,
dataa => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_0\);
GRFPC0_VFIFO_INST_1_1_SQMUXA_SUB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fffffffffffffff")
port map (
combout => N_111101,
dataf => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6_4_0\,
datad => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.FP_PIPELINE.UN24_OP\,
datab => N_37);
GRFPC0_VFIFO_PC_0_1_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000500070005000f")
port map (
combout => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
dataf => \GRFPC0.N_21933\,
datae => \GRFPC0.N_21984\,
datad => \GRFPC0.N_21108\,
datac => N_111099,
datab => N_99,
dataa => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_0\);
GRFPC0_VFIFO_PC_0_1_SQMUXA_SUB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fffffffffffff")
port map (
combout => N_111099,
dataf => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6_4_0\,
datad => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.FP_PIPELINE.UN24_OP\,
datab => N_37);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_2_0_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000041000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
dataf => \FPI.START\,
datae => N_44718_1,
datad => \FPI.FLOP\(6),
datac => \FPI.FLOP\(5),
datab => \FPI.FLOP\(2),
dataa => N_111097);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_2_0_3_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0f00ffffffff")
port map (
combout => N_111097,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_0\(0),
datae => \GRFPC0.WR2.CTRL.SEQERR\,
datad => \GRFPC0.R.STATE\(0),
datac => \GRFPC0.R.STATE\(1));
\GRFPC0_OP2_RNO_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0cc00ccffccff")
port map (
combout => \GRFPC0.N_19466\,
dataf => N_110955,
datae => N_99904_2,
datad => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPU0.GRFPU_X0.ST4.REG\(36),
datab => \GRFPC0.WR2.RREG.RES\(36));
\GRFPC0_OP2_RNO_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000f0ccf0ff")
port map (
combout => \GRFPC0.N_19474\,
dataf => N_110951,
datae => N_99904_2,
datad => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.WR2.RREG.RES\(44),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(44));
\GRFPC0_OP2_RNO_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000f0ccf0ff")
port map (
combout => \GRFPC0.N_19464\,
dataf => N_110947,
datae => N_99904_2,
datad => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.WR2.RREG.RES\(34),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(34));
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNIU69N1_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000cc00f00000f0")
port map (
combout => \FPO.RES_1\(25),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.REG\(25),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(25));
GRFPC0_FP_PIPELINE_FPRDY_1_1_SUB_RNIIE702: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0c0c0c0c0c0d")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_3\,
datae => N_108530,
datad => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_0\,
datac => N_110874,
datab => \GRFPC0.WR2.RREG.RESV\,
dataa => \GRFPC0.R.STATE\(0));
GRFPC0_WR2_CTRL_RDWR_RNIGHLA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
combout => N_110874,
dataf => \GRFPC0.WR2.CTRL.LD\,
datae => \GRFPC0.WR2.CTRL.CCWR\,
datad => \GRFPC0.WR2.CTRL.RDWR\);
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf0ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(51),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(51),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(51));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0ccffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(60),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.MEXP\(8),
datab => \GRFPU0.GRFPU_X0.ST4.AEXP\(8));
\GRFPC0_DIV_RESULT_0_0_58__G3_0\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ccf000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_58__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(6),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(6));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf0ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(38),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(38),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(38));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0ccffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(49),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2\(1),
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(49),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(49));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_O2_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1f5f1f1f0f4f0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_18868\,
dataf => \GRFPU0.GRFPU_X0.N_7321\,
datae => N_110850,
datad => \GRFPU0.GRFPU_X0.N_18880\,
datac => \GRFPU0.GRFPU_X0.N_10059_I\,
datab => \FPI.FLOP\(1),
dataa => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN24_DP_I_O2_RNIEBHQ5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff000f000f000")
port map (
combout => N_110850,
dataf => \GRFPU0.GRFPU_X0.N_18954\,
datae => \GRFPU0.GRFPU_X0.N_18948\,
datad => \GRFPU0.GRFPU_X0.N_18871\,
datac => \FPI.NONSTD\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500f5a0dd88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(51),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(51),
datac => \FPI.OP1\(43),
datab => \FPI.OP1\(46),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(42),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(42),
datac => \FPI.OP1\(37),
datab => \FPI.OP1\(34),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(52),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(52),
datac => \FPI.OP1\(47),
datab => \FPI.OP1\(44),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(43),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(43),
datac => \FPI.OP1\(38),
datab => \FPI.OP1\(35),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(40),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(40),
datac => \FPI.OP1\(35),
datab => \FPI.OP1\(32),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(57),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(57),
datac => \FPI.OP1\(52),
datab => \FPI.OP1\(49),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500f5a0dd88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(55),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(55),
datac => \FPI.OP1\(47),
datab => \FPI.OP1\(50),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500f5a0dd88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(49),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(49),
datac => \FPI.OP1\(41),
datab => \FPI.OP1\(44),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(58),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(58),
datac => \FPI.OP1\(53),
datab => \FPI.OP1\(50),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(54),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.N_18336\,
datac => \FPI.OP1\(49),
datab => \FPI.OP1\(46),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500f5a0dd88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(41),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(41),
datac => \FPI.OP1\(33),
datab => \FPI.OP1\(36),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33003300bb88f3c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(37),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.N_18337\,
datac => \FPI.OP1\(32),
datab => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
dataa => \FPI.OP1\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500f5a0dd88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(48),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(48),
datac => \FPI.OP1\(40),
datab => \FPI.OP1\(43),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500f5a0dd88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(44),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(44),
datac => \FPI.OP1\(36),
datab => \FPI.OP1\(39),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500f5a0dd88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(46),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(46),
datac => \FPI.OP1\(38),
datab => \FPI.OP1\(41),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500f5a0dd88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(53),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(53),
datac => \FPI.OP1\(45),
datab => \FPI.OP1\(48),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33003300bb88f3c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(38),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(38),
datac => \FPI.OP1\(33),
datab => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
dataa => \FPI.OP1\(30));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500f5a0dd88")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(45),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(45),
datac => \FPI.OP1\(37),
datab => \FPI.OP1\(40),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(56),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(56),
datac => \FPI.OP1\(51),
datab => \FPI.OP1\(48),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(47),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(47),
datac => \FPI.OP1\(42),
datab => \FPI.OP1\(39),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33003300bb88f3c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(39),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(39),
datac => \FPI.OP1\(34),
datab => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
dataa => \FPI.OP1\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55005500dd88f5a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(50),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(50),
datac => \FPI.OP1\(45),
datab => \FPI.OP1\(42),
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPC0_R_FSR_TEM_RNICL2EF_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cfcf0000cfff")
port map (
combout => N_110356,
dataf => \GRFPC0.FPEXC_0_SQMUXA_D\,
datae => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datad => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => N_44718_1);
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNIJ78E1_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccfffffff0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(46),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(46),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(46));
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNIFV7E1_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccfffffff0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(44),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(44),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(44));
\GRFPC0_DIV_RESULT_0_0_36__G3_0\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc000000f00000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_36__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(36),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(36));
\GRFPC0_DIV_RESULT_0_0_33__G3_0\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000cc0000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_33__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(33),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(33));
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNIC7QA1_0_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf0ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0_0\(39),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(39),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(39));
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNIBN7E1_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccfffffff0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(42),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(42),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(42));
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNIEB8E1_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccfffffff0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(34),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(34),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(34));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffaffcfcfcacf")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(49),
dataf => \GRFPU0.GRFPU_X0.N_20301\,
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(46),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(46));
\GRFPC0_DIV_RESULT_0_0_50__G3_1\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000a0cccc00a0")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_50__G3_1\,
dataf => \GRFPU0.GRFPU_X0.N_20301\,
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(47),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(47));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcffafafacaf")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(51),
dataf => \GRFPU0.GRFPU_X0.N_20301\,
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(48),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(48));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcffafafacaf")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(60),
dataf => \GRFPU0.GRFPU_X0.N_20301\,
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(5),
dataa => \GRFPU0.GRFPU_X0.ST4.AEXP\(5));
\GRFPC0_DIV_RESULT_0_0_58__G3_1\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c0aaaa00c0")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_58__G3_1\,
dataf => \GRFPU0.GRFPU_X0.N_20301\,
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(3),
dataa => \GRFPU0.GRFPU_X0.ST4.AEXP\(3));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcffafafacaf")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(38),
dataf => \GRFPU0.GRFPU_X0.N_20301\,
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(35),
dataa => \GRFPU0.GRFPU_X0.ST4.SGNF\(35));
\GRFPC0_DIV_RESULT_0_0_59__G3_1\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c0aaaa00c0")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_59__G3_1\,
dataf => \GRFPU0.GRFPU_X0.N_20301\,
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(4),
dataa => \GRFPU0.GRFPU_X0.ST4.AEXP\(4));
\GRFPC0_DIV_RESULT_0_0_59__G3_0\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaeaaaaa00c00000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_59__G3_0\,
dataf => \GRFPU0.GRFPU_X0.N_401\,
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(7),
dataa => \GRFPU0.GRFPU_X0.ST4.AEXP\(7));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf0ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(41),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(41),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(41));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0ccffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(57),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2\(1),
datac => \GRFPU0.GRFPU_X0.ST4.MEXP\(5),
datab => \GRFPU0.GRFPU_X0.ST4.AEXP\(5));
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNI4JPA1_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffccfffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(46),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(43),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(43));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNIS6PA1_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffccfffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(34),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(31),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(31));
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNIC7QA1_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffffccff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(42),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(39),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(39));
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNI6RPA1_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffccfffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0_1\(39),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(36),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(36));
\GRFPU0_GRFPU_X0_ST4_MSGNF_RNI0BPA1_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffccfffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(44),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(41),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(41));
\GRFPC0_DIV_RESULT_0_0_36__G3_1\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000cc0000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_36__G3_1\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(33),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(33));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffccfffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(32),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(29),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(29));
\GRFPC0_DIV_RESULT_0_0_62__G3_1\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000cc0000f000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_62__G3_1\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datac => \GRFPU0.GRFPU_X0.ST4.MEXP\(7),
datab => \GRFPU0.GRFPU_X0.ST4.AEXP\(7));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccfffffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(57),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(2),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(54));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffccfffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(41),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(38),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(38));
\GRFPC0_DIV_RESULT_0_0_55__G3_1\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000cc0000f000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_55__G3_1\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datac => \GRFPU0.GRFPU_X0.ST4.MEXP\(0),
datab => \GRFPU0.GRFPU_X0.ST4.AEXP\(0));
GRFPC0_FP_PIPELINE_VMEM_RREG_RES_1_3_2735_I_A3_3_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff33ffff0fff")
port map (
combout => \GRFPC0.FP_PIPELINE.VMEM.RREG.RES_1_3_2735_I_A3_3_1\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datac => \GRFPU0.GRFPU_X0.ST4.MEXP\(1),
datab => \GRFPU0.GRFPU_X0.ST4.AEXP\(1));
\GRFPC0_DIV_RESULT_0_0_61__G3_1\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000cc0000f000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_61__G3_1\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datac => \GRFPU0.GRFPU_X0.ST4.MEXP\(6),
datab => \GRFPU0.GRFPU_X0.ST4.AEXP\(6));
GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_A2_4_REST_N_2L1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_4_REST_N_2\,
dataf => \FPI.OP2\(30),
datae => \FPI.OP2\(29),
datad => \FPI.OP2\(8),
datac => \FPI.OP2\(9));
GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_A2_4_REST_N_3L3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_4_REST_N_3\,
dataf => \FPI.OP2\(16),
datae => \FPI.OP2\(17),
datad => \FPI.OP2\(18),
datac => \FPI.OP2\(19));
GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_A2_4_REST_N_4L5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_4_REST_N_4\,
dataf => \FPI.OP2\(14),
datae => \FPI.OP2\(15),
datad => \FPI.OP2\(21),
datac => \FPI.OP2\(20));
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_A2_4_S_RNISN3L4_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000010000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18954\,
dataf => N_108695,
datae => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_4_REST_N_4\,
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_4_REST_N_3\,
datac => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_4_REST_N_2\,
datab => \FPI.OP2\(13),
dataa => \FPI.OP2\(12));
GRFPC0_FP_PIPELINE_FPUSTART_7_N_3L4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030003030")
port map (
combout => \GRFPC0.FP_PIPELINE.FPUSTART_7_N_3\,
dataf => \GRFPC0.RFA.ST\,
datae => \GRFPC0.RFA2.FOP\(0),
datad => \GRFPC0.FPR.ALLOW\(1),
datac => N_37,
datab => N_39);
GRFPC0_FP_PIPELINE_FPUSTART_7_N_4L6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.FPUSTART_7_N_4\,
dataf => \GRFPC0.R.STATE\(0),
datae => \GRFPC0.R.STATE\(1));
GRFPC0_FP_PIPELINE_FPUSTART_7_N_5L8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000fff0")
port map (
combout => \GRFPC0.FP_PIPELINE.FPUSTART_7_N_5\,
dataf => \GRFPC0.FIFO.WR\(0),
datae => \GRFPC0.RFA.LD\,
datad => \GRFPC0.FIFO.RD_2\(0),
datac => \GRFPC0.FIFO.FULL\);
GRFPC0_FP_PIPELINE_FPUSTART_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"4000000000000000")
port map (
combout => \FPI.START\,
dataf => \GRFPC0.FP_PIPELINE.FPUSTART_7_N_5\,
datae => \FPI.START_1\,
datad => \GRFPC0.FP_PIPELINE.FPUSTART_7_N_4\,
datac => \GRFPC0.FP_PIPELINE.FPUSTART_7_N_3\,
datab => \FPI.START_3\,
dataa => N_45196_1);
GRFPC0_FP_PIPELINE_11_REGDEPX2_345_N_2L1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_N_2\,
dataf => \GRFPC0.MEM.CTRL.INST\(26),
datae => \GRFPC0.MEM.CTRL.INST\(27),
datad => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(28));
GRFPC0_FP_PIPELINE_11_REGDEPX2_345_N_6L10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0f0f00ffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_N_6\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(1),
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_N_4\,
datac => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_N_2\);
\GRFPC0_MEM_RREG_EXCT_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccd888e444f000")
port map (
combout => N_27211,
dataf => \GRFPC0.N_82\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datac => \GRFPC0.DIV.EXCT_0_0_5__I1_I_1\,
datab => \GRFPC0.EX.RREG.EXCT\(5),
dataa => N_37);
\GRFPC0_MEM_RREG_EXCT_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccd888e444f000")
port map (
combout => N_27210,
dataf => \GRFPC0.N_82\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datac => \GRFPC0.DIV.EXCT_0_0_4__I1_I_2\,
datab => \GRFPC0.EX.RREG.EXCT\(4),
dataa => N_37);
\GRFPC0_MEM_RREG_EXCT_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccd888e444f000")
port map (
combout => N_27207,
dataf => \GRFPC0.N_82\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datac => \GRFPC0.DIV.EXCT_0_0_1__I1_I_3\,
datab => \GRFPC0.EX.RREG.EXCT\(1),
dataa => N_37);
GRFPC0_RFA2_RS1DEP_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdf0fffff0f0f0f0")
port map (
combout => \GRFPC0.N_10559\,
dataf => \GRFPC0.RFA2.RS1DEP_0_0_G1_1\,
datae => \GRFPC0.REGDEP_2_SQMUXA_3\,
datad => \GRFPC0.RFA2.RS1DEP_0_0_G1_4749_0\,
datac => \GRFPC0.REGDEP_0_SQMUXA_1\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEP26\,
dataa => N_110368);
GRFPC0_RFA2_RS1DEP_RNO_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000f00000000")
port map (
combout => N_110368,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEP30\,
datae => \GRFPC0.N_22829\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEP18\,
datac => \GRFPC0.WR2.CTRL.RD\(0));
\GRFPC0_D_STLCK_RNO_3_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000fffffff")
port map (
combout => N_110366,
dataf => \GRFPC0.N_23136\,
datae => \GRFPC0.N_594\,
datad => \GRFPC0.EX.CTRL.LD\,
datac => \GRFPC0.STDDEP_0_SQMUXA_I_I_A2_1\);
GRFPC0_RFA2_RS1DEP_RNO_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000006fffffff")
port map (
combout => \GRFPC0.RFA2.RS1DEP_0_0_G1_0\,
dataf => N_110364,
datae => \GRFPC0.REGDEP_2_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_0_3\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEP62\,
datab => \GRFPC0.N_22829\,
dataa => \GRFPC0.MEM.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_A3_3_1_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff3fff0fff0")
port map (
combout => \GRFPC0.N_362\,
dataf => \GRFPC0.FP_PIPELINE.UN29_WREN_1\,
datae => CPO_EXCZ,
datad => \GRFPC0.VDIV.EXEC_0_SQMUXA\,
datac => N_110360,
datab => \GRFPC0.DIV.EXEC_0_0_G0_2_0\);
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_A3_3_1_I_SUB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0faaccafcf")
port map (
combout => N_110360,
dataf => \GRFPC0.N_74_I_I\,
datae => \GRFPC0.DIV.EXEC_0_0_G0_2_0\,
datad => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datac => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F1_A0_C\,
datab => \GRFPC0.DIV.RD\(0),
dataa => \GRFPC0.WR2.CTRL.RD\(0));
GRFPC0_UN28_WREN_2_RNIAQ9NT: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"a0a00000a0800000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN29_WREN\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => N_110356,
datad => \GRFPC0.UN28_WREN_2\,
datac => \GRFPC0.DIV.VALID\,
datab => \GRFPC0.WR2.CTRL.SEQERR\,
dataa => N_37);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_445_RNO_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eca0cc0000000000")
port map (
combout => N_110352,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6428_REGDEPX2\,
datad => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6414_REGDEPX2\,
datac => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_18_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_18\(0),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.N_23946_2\,
datad => N_110348,
datac => \GRFPC0.N_25377\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_1_0\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_18_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaea00c0ffffffff")
port map (
combout => N_110348,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_I_2\(0),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_7\(0),
datad => \GRFPC0.N_706\,
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN771_REGDEPX2_1\,
datab => \GRFPC0.N_25294_1\,
dataa => \GRFPC0.WR.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_406_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000030")
port map (
combout => N_110346,
dataf => \GRFPC0.N_25170\,
datae => \GRFPC0.N_706\,
datad => \GRFPC0.N_25496\,
datac => \GRFPC0.WR.CTRL.INST\(26),
datab => \GRFPC0.WR.CTRL.INST\(27));
\GRFPU0_GRFPU_X0_UN38_EXP_M_RNIL6DE_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffeffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18880\,
dataf => \GRFPU0.GRFPU_X0.N_18870\,
datae => N_110093,
datad => \FPI.OP2\(55),
datac => \FPI.OP2\(56),
datab => \FPI.OP2\(61),
dataa => \FPI.OP2\(62));
GRFPC0_FP_PIPELINE_FPUSTART_7_RNIPAQ3J: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
dataf => \GRFPC0.FPEXC_0_SQMUXA_D\,
datae => N_110339,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datac => N_44718_1);
GRFPC0_FP_PIPELINE_FPUSTART_7_RNICLU7B: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffbfafafaf")
port map (
combout => N_110339,
dataf => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datae => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datac => \FPI.START\,
datab => N_44718_1,
dataa => N_39);
GRFPC0_FP_PIPELINE_UN205_HOLDN_X_RNI041AK: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00aa00aa00ef00ff")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.ST_1\,
dataf => N_108519,
datae => \GRFPC0.FPEXC_0_SQMUXA_D\,
datad => N_110337,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => N_44718_1,
dataa => \GRFPC0.FP_PIPELINE.UN1_CPI\);
GRFPC0_FP_PIPELINE_UN1_CPI_RNIHGOSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"bbbbbbbbabaaaaaa")
port map (
combout => N_110337,
dataf => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datae => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datac => N_44718_1,
datab => \GRFPC0.FP_PIPELINE.UN1_CPI\,
dataa => N_108517);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_2_SUB_RNIJGTTA_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000008c00cc00")
port map (
combout => \GRFPC0.N_25273\,
dataf => N_108572,
datae => \GRFPC0.FPEXC_0_SQMUXA_D\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => N_110331,
dataa => N_44718_1);
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_24_IV_I_A2_1_RNI4IVC2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => N_110331,
dataf => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datad => \GRFPC0.N_24611_1\,
datac => \GRFPC0.N_24484\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff4fff0fff")
port map (
combout => \GRFPC0.N_24554\,
dataf => N_108572,
datae => \GRFPC0.FPEXC_0_SQMUXA_D\,
datad => N_110323,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
dataa => N_44718_1);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_RNO_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffff0ff")
port map (
combout => N_110323,
dataf => \GRFPC0.N_24581\,
datae => \GRFPC0.N_24621\,
datad => \GRFPC0.N_24568\,
datac => \GRFPC0.N_24622\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_I_1_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000008c00cc00")
port map (
combout => \GRFPC0.N_24608\,
dataf => N_108572,
datae => \GRFPC0.FPEXC_0_SQMUXA_D\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => N_110317,
dataa => N_44718_1);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_I_1_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => N_110317,
dataf => \GRFPC0.N_23980\,
datae => \GRFPC0.N_24039\,
datad => \GRFPC0.N_227\,
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN665_REGDEPX2_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_1_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0b0b00000b0f0000")
port map (
combout => \GRFPC0.N_23946_2\,
dataf => \GRFPC0.FPEXC_0_SQMUXA_D\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datad => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\,
datac => N_110313,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
dataa => N_44718_1);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_1_2_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfff3fffffffffff")
port map (
combout => N_110313,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_9_5\(0),
datae => \FPI.FLOP\(1),
datad => \FPI.FLOP\(6),
datac => \GRFPC0.N_23975\,
datab => \FPI.FLOP\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_2_SUB_RNI2A3FA_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000b000f00")
port map (
combout => \GRFPC0.N_25416\,
dataf => N_108572,
datae => \GRFPC0.FPEXC_0_SQMUXA_D\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datac => N_110311,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
dataa => N_44718_1);
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_24_IV_I_A2_RNIJB5U1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0ffffff")
port map (
combout => N_110311,
dataf => \GRFPC0.N_24597\,
datae => \GRFPC0.FP_PIPELINE.1.REGDEPX2_33_0_A2_1\(1),
datad => \GRFPC0.N_25221\,
datac => \GRFPC0.V.STDATA_14\(18));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_2_SUB_RNI25SB9_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000008c00cc00")
port map (
combout => \GRFPC0.N_25170\,
dataf => N_108572,
datae => \GRFPC0.FPEXC_0_SQMUXA_D\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => N_110307,
dataa => N_44718_1);
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5516_REGDEPX2_2_I_O2_I_A3_I_O2_RNIJ6UQ: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => N_110307,
dataf => \GRFPC0.N_23980\,
datae => \GRFPC0.N_225\,
datad => \GRFPC0.N_24039\,
datac => \GRFPC0.N_25120\);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_160_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000b000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_155\(0),
dataf => N_108572,
datae => \GRFPC0.FPEXC_0_SQMUXA_D\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datac => N_110303,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
dataa => N_44718_1);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_160_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000fffffff")
port map (
combout => N_110303,
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_153\(0),
datae => \GRFPC0.N_23980\,
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2429_REGDEPX2_0\,
datac => \GRFPC0.N_24616\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_2_SUB_RNIE0F1A_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000008c00cc00")
port map (
combout => \GRFPC0.N_261\,
dataf => N_108572,
datae => \GRFPC0.FPEXC_0_SQMUXA_D\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => N_110299,
dataa => N_44718_1);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_124_0_A2_1_0_RNIV1HG1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => N_110299,
dataf => \GRFPC0.V.STDATA_14_I_M_10\(0),
datae => \GRFPC0.N_225\,
datad => \GRFPC0.N_24039\,
datac => \GRFPC0.N_261_1\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_45_0_A3_SUB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcccccccd")
port map (
combout => N_110295,
dataf => N_108572,
datae => \GRFPC0.N_24624\,
datad => \GRFPC0.N_25420\,
datac => \GRFPC0.N_25421\,
datab => \GRFPC0.V.STDATA_14_I_M_10\(0),
dataa => \GRFPC0.N_25419\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_340_0_A2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0ffffff")
port map (
combout => \GRFPC0.N_24525\,
dataf => N_110293,
datae => \GRFPC0.FPEXC_0_SQMUXA_D\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datac => N_44718_1);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_340_0_A2_2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0b0b00000b0f0000")
port map (
combout => \GRFPC0.N_177_2\,
dataf => \GRFPC0.FPEXC_0_SQMUXA_D\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datad => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\,
datac => N_110291,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
dataa => N_44718_1);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_340_0_A2_2_2_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff0fffffffff")
port map (
combout => N_110291,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_9_5\(0),
datae => \FPI.FLOP\(1),
datad => \GRFPC0.V.STDATA_14\(25),
datac => \FPI.FLOP\(0));
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_A2_2_16_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_2_16\(4),
dataf => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_2_10\(4),
datae => N_110289,
datad => \FPI.OP2\(32),
datac => \FPI.OP2\(33));
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_A2_2_16_SUB_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => N_110289,
dataf => \FPI.OP2\(37),
datae => \FPI.OP2\(45),
datad => \FPI.OP2\(47),
datac => \FPI.OP2\(36),
datab => \FPI.OP2\(34),
dataa => \FPI.OP2\(44));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_I_A3_0_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0b0b00000b0f0000")
port map (
combout => \GRFPC0.N_25169_2\,
dataf => \GRFPC0.FPEXC_0_SQMUXA_D\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datad => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\,
datac => N_110287,
datab => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
dataa => N_44718_1);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_I_A3_0_2_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff0fffffffff")
port map (
combout => N_110287,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_9_5\(0),
datae => \FPI.FLOP\(1),
datad => \GRFPC0.N_235\,
datac => \FPI.FLOP\(0));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_5_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000023003300")
port map (
combout => \GRFPC0.N_25171\,
dataf => N_108572,
datae => \GRFPC0.FPEXC_0_SQMUXA_D\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => N_110275,
dataa => N_44718_1);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_5_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffffffffffff")
port map (
combout => N_110275,
dataf => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.N_24611_1\,
datac => \GRFPC0.N_25649\);
\GRFPC0_OP2_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffff3ff")
port map (
combout => \FPI.OP2\(47),
dataf => N_110269,
datae => \GRFPU0.GRFPU_X0.N_19240_I_0\,
datad => N_99880_1,
datac => \GRFPC0.RFA2.RS2SEL\(4),
datab => N_99881);
\GRFPC0_OP2_SUB_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"407300004073ffff")
port map (
combout => N_110269,
dataf => \GRFPC0.N_19806\,
datae => N_99880,
datad => \GRFPC0.N_19543\,
datac => \GRFPC0.RFA2.RS2SEL\(4),
datab => N_99881,
dataa => \GRFPC0.WR2.RREG.RES\(47));
\GRFPC0_OP2_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffff3ff")
port map (
combout => \FPI.OP2\(37),
dataf => N_110267,
datae => \GRFPU0.GRFPU_X0.N_20275_I_0\,
datad => N_99880_1,
datac => \GRFPC0.RFA2.RS2SEL\(4),
datab => N_99881);
\GRFPC0_OP2_SUB_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"407300004073ffff")
port map (
combout => N_110267,
dataf => \GRFPC0.N_19796\,
datae => N_99880,
datad => \GRFPC0.N_19533\,
datac => \GRFPC0.RFA2.RS2SEL\(4),
datab => N_99881,
dataa => \GRFPC0.WR2.RREG.RES\(37));
\GRFPC0_OP2_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffff3ff")
port map (
combout => \FPI.OP2\(45),
dataf => N_110265,
datae => \GRFPU0.GRFPU_X0.N_20272_I_0\,
datad => N_99880_1,
datac => \GRFPC0.RFA2.RS2SEL\(4),
datab => N_99881);
\GRFPC0_OP2_SUB_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"407300004073ffff")
port map (
combout => N_110265,
dataf => \GRFPC0.N_19804\,
datae => N_99880,
datad => \GRFPC0.N_19541\,
datac => \GRFPC0.RFA2.RS2SEL\(4),
datab => N_99881,
dataa => \GRFPC0.WR2.RREG.RES\(45));
\GRFPC0_OP2_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffff3ff")
port map (
combout => \FPI.OP2\(32),
dataf => N_110263,
datae => \GRFPU0.GRFPU_X0.N_20294_I_0\,
datad => N_99880_1,
datac => \GRFPC0.RFA2.RS2SEL\(4),
datab => N_99881);
\GRFPC0_OP2_SUB_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"407300004073ffff")
port map (
combout => N_110263,
dataf => \GRFPC0.N_19791\,
datae => N_99880,
datad => \GRFPC0.N_19528\,
datac => \GRFPC0.RFA2.RS2SEL\(4),
datab => N_99881,
dataa => \GRFPC0.WR2.RREG.RES\(32));
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_A2_0_RNIEM575: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000500070005000f")
port map (
combout => \GRFPC0.VFIFO.WR_0_SQMUXA_3\,
dataf => \GRFPC0.N_21933\,
datae => \GRFPC0.N_21984\,
datad => \GRFPC0.N_21108\,
datac => N_110261,
datab => N_99,
dataa => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_0\);
GRFPC0_FP_PIPELINE_UN1_HOLDN_6_4_0_RNIQVLJ: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffffffffffff")
port map (
combout => N_110261,
dataf => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6_4_0\,
datad => \GRFPC0.FP_PIPELINE.UN24_OP\,
datac => N_37);
\GRFPC0_OP2_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffff3ff")
port map (
combout => \FPI.OP2\(43),
dataf => N_110257,
datae => \GRFPU0.GRFPU_X0.N_20290_I_0\,
datad => N_99880_1,
datac => \GRFPC0.RFA2.RS2SEL\(4),
datab => N_99881);
\GRFPC0_OP2_SUB_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"407300004073ffff")
port map (
combout => N_110257,
dataf => \GRFPC0.N_19802\,
datae => N_99880,
datad => \GRFPC0.N_19539\,
datac => \GRFPC0.RFA2.RS2SEL\(4),
datab => N_99881,
dataa => \GRFPC0.WR2.RREG.RES\(43));
\GRFPC0_OP2_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffff3ff")
port map (
combout => \FPI.OP2\(35),
dataf => N_110255,
datae => \GRFPU0.GRFPU_X0.N_20295_I_0\,
datad => N_99880_1,
datac => \GRFPC0.RFA2.RS2SEL\(4),
datab => N_99881);
\GRFPC0_OP2_SUB_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"407300004073ffff")
port map (
combout => N_110255,
dataf => \GRFPC0.N_19794\,
datae => N_99880,
datad => \GRFPC0.N_19531\,
datac => \GRFPC0.RFA2.RS2SEL\(4),
datab => N_99881,
dataa => \GRFPC0.WR2.RREG.RES\(35));
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_A3_RNIVEO81: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f000ff000000")
port map (
combout => \GRFPC0.N_21965\,
dataf => \GRFPC0.N_21933\,
datae => \GRFPC0.N_21984\,
datad => N_110253,
datac => N_99);
GRFPC0_FP_PIPELINE_UN1_CPI_RNIEP3O: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => N_110253,
dataf => N_102,
datae => N_100,
datad => N_113,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI\);
\GRFPC0_OP2_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffff3ff")
port map (
combout => \FPI.OP2\(40),
dataf => N_110249,
datae => \GRFPU0.GRFPU_X0.N_20289_I_0\,
datad => N_99880_1,
datac => \GRFPC0.RFA2.RS2SEL\(4),
datab => N_99881);
\GRFPC0_OP2_SUB_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"407300004073ffff")
port map (
combout => N_110249,
dataf => \GRFPC0.N_19799\,
datae => N_99880,
datad => \GRFPC0.N_19536\,
datac => \GRFPC0.RFA2.RS2SEL\(4),
datab => N_99881,
dataa => \GRFPC0.WR2.RREG.RES\(40));
\GRFPC0_OP2_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffff3ff")
port map (
combout => \FPI.OP2\(48),
dataf => N_110247,
datae => \GRFPU0.GRFPU_X0.N_20273_I_0\,
datad => N_99880_1,
datac => \GRFPC0.RFA2.RS2SEL\(4),
datab => N_99881);
\GRFPC0_OP2_SUB_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"407300004073ffff")
port map (
combout => N_110247,
dataf => \GRFPC0.N_19807\,
datae => N_99880,
datad => \GRFPC0.N_19544\,
datac => \GRFPC0.RFA2.RS2SEL\(4),
datab => N_99881,
dataa => \GRFPC0.WR2.RREG.RES\(48));
\GRFPC0_OP2_1_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fff0f0f0")
port map (
combout => \GRFPC0.N_19472\,
dataf => N_110223,
datae => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(42),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(42),
datac => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP2_1_SUB_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f770f330f550f00")
port map (
combout => N_110223,
dataf => \GRFPU0.GRFPU_X0.N_404_0\,
datae => N_99904,
datad => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.WR2.RREG.RES\(42),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(39),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(42));
\GRFPC0_OP2_1_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fff0f0f0")
port map (
combout => \GRFPC0.N_19476\,
dataf => N_110219,
datae => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(46),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(46),
datac => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP2_1_SUB_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f770f330f550f00")
port map (
combout => N_110219,
dataf => \GRFPU0.GRFPU_X0.N_404_0\,
datae => N_99904,
datad => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.WR2.RREG.RES\(46),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(43),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(46));
\GRFPC0_OP2_1_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fff0f0f0")
port map (
combout => \GRFPC0.N_19469\,
dataf => N_110215,
datae => \GRFPU0.GRFPU_X0.RES_1_6_I_0_0\(39),
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0_1\(39),
datac => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP2_1_SUB_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f770f330f550f00")
port map (
combout => N_110215,
dataf => \GRFPU0.GRFPU_X0.N_404_0\,
datae => N_99904,
datad => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.WR2.RREG.RES\(39),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(36),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(39));
\GRFPC0_OP2_1_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0f0f0f00")
port map (
combout => \GRFPC0.N_19463\,
dataf => N_110211,
datae => \GRFPC0.DIV.RESULT_0_0_33__G3_1\,
datad => \GRFPC0.DIV.RESULT_0_0_33__G3_0\,
datac => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP2_1_SUB_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccfaccf0ccaacc00")
port map (
combout => N_110211,
dataf => \GRFPU0.GRFPU_X0.N_404_0\,
datae => N_99904,
datad => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPU0.GRFPU_X0.ST4.REG\(30),
datab => \GRFPC0.WR2.RREG.RES\(33),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(33));
\GRFPC0_DIV_RESULT_0_0_62__G3_0\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ccf000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_62__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(10),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(10));
\GRFPC0_DIV_RESULT_0_0_61__G3_0\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ccf000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_61__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(9),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(9));
GRFPC0_FP_PIPELINE_VMEM_RREG_RES_1_3_2735_I_A3_3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff330fffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.VMEM.RREG.RES_1_3_2735_I_A3_3_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(4),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(4));
\GRFPC0_DIV_RESULT_0_0_55__G3_0\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ccf000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_55__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(3),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(3));
\GRFPC0_DIV_RESULT_0_0_33__G3_1\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaeaaaa000c0000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_33__G3_1\,
dataf => \GRFPU0.GRFPU_X0.N_403\,
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(30),
dataa => \GRFPU0.GRFPU_X0.ST4.MSGNF\(30));
\GRFPC0_DIV_RESULT_0_0_53__G3_0\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ccf000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_53__G3_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(1),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(1));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf0ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(54),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(2),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(2));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf0ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(37),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(37),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(37));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf0ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(45),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(45),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(45));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf0ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(32),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(32),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(32));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_RNO_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf0ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0_0\(47),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(47),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(47));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_0_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf0ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(52),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2\(1),
datac => \GRFPU0.GRFPU_X0.ST4.AEXP\(0),
datab => \GRFPU0.GRFPU_X0.ST4.MEXP\(0));
\GRFPC0_DIV_RESULT_0_0_53__G3_1\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000cc0000f000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_53__G3_1\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(50),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(50));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffccfffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(52),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(49),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(49));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffffccff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(54),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(51),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(51));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffccfffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(37),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(34),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(34));
\GRFPU0_GRFPU_X0_RES_1_6_I_RNO_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffccfffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(45),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(42),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(42));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_RNO_0_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffccfffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0_1\(47),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(44),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(44));
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC_2_1_RNIQKI92: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ec00ff00ff00ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
dataf => N_110109,
datae => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_2_1\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.R.FSR.TEM\(2),
datab => \GRFPC0.WR2.RREG.EXCT\(5),
dataa => \GRFPC0.WR2.RREG.EXCT\(2));
\GRFPC0_WR2_RREG_EXCT_RNI83LV_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f00ff0f0fffff")
port map (
combout => N_110109,
dataf => \GRFPC0.R.FSR.TEM\(3),
datae => \GRFPC0.R.FSR.TEM\(1),
datad => \GRFPC0.WR2.RREG.EXCT\(3),
datac => \GRFPC0.WR2.RREG.EXCT\(1));
\GRFPU0_GRFPU_X0_UN38_EXP_M_RNI2HO4_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => N_110093,
dataf => \FPI.OP2\(58),
datae => \FPI.OP2\(60),
datad => \FPI.OP2\(59),
datac => \FPI.OP2\(57));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000afcfa0c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(51),
dataf => \GRFPU0.GRFPU_X0.N_18868_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(51),
datad => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \FPI.OP2\(43),
dataa => \FPI.OP2\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0fafcf0000a0c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(41),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(41),
datae => \GRFPU0.GRFPU_X0.N_18868_0\,
datad => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \FPI.OP2\(33),
dataa => \FPI.OP2\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0fcfaf0000c0a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(54),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(54),
datae => \GRFPU0.GRFPU_X0.N_18868_0\,
datad => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \FPI.OP2\(49),
dataa => \FPI.OP2\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0000cfafc0a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(43),
dataf => \GRFPU0.GRFPU_X0.N_18868_0\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(43),
datad => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \FPI.OP2\(38),
dataa => \FPI.OP2\(35));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ff2fff20")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180\(0),
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_168\(0),
datae => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_2\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datab => \GRFPC0.N_702\,
dataa => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_6_0\(0));
GRFPC0_VDIV_EXEC_0_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"a8a0a8a0a8a0a0a0")
port map (
combout => \GRFPC0.VDIV.EXEC_0_SQMUXA\,
dataf => \GRFPC0.FPEXC_0_SQMUXA_D\,
datae => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datac => N_44718_1,
datab => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
dataa => N_37);
\GRFPU0_GRFPU_X0_RES_1_6_I_0_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0ffffffccff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(40),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2\(0),
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(40),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(40));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0ffffffccff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(48),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2\(0),
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(48),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(48));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0ffffffccff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(43),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2\(0),
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(43),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(43));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0ffffffccff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(35),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2\(0),
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(35),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(35));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(48),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(45),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(45));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(43),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(40),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(40));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(40),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(37),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(37));
\GRFPU0_GRFPU_X0_RES_1_6_I_1_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff0ccff")
port map (
combout => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(35),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(32),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(32));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_2_9_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003505300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_9_2\(0),
dataf => \GRFPC0.N_222\,
datae => \GRFPC0.FIFO.INST_1\(19),
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.RD_0\(0),
datab => \GRFPC0.FIFO.INST_0\(9),
dataa => \GRFPC0.FIFO.INST_1\(9));
\GRFPU0_GRFPU_X0_IDOUT_I_M2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccf0f0f0cc")
port map (
combout => \FPO.IDOUT\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.ID\(0),
datab => \GRFPU0.GRFPU_X0.ST3.ID\(0));
\GRFPU0_GRFPU_X0_IDOUT_I_M2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccf0f0f0cc")
port map (
combout => \FPO.IDOUT\(4),
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.ID\(4),
datab => \GRFPU0.GRFPU_X0.ST3.ID\(4));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNIQP3B1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000300000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_3\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(4));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_21\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(20),
datae => \GRFPU0.GRFPU_X0.ST3.REG\(23),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(27),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(25),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(26),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(22));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000c000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1\(7),
dataf => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_0_7__N_4\,
datae => \GRFPU0.GRFPU_X0.N_18768\,
datad => \GRFPU0.GRFPU_X0.N_10059_I\,
datac => \GRFPU0.GRFPU_X0.N_18754\,
datab => \FPI.NONSTD\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3cffffff3c00ffff")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(59),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_31\(59),
datae => \GRFPU0.GRFPU_X0.UN1_VST3.EXC37\,
datad => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.OUT_1\(84),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(2));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30ffffff3000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(60),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_8__N_5\,
datae => \GRFPU0.GRFPU_X0.UN1_VST3.EXC37\,
datad => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.OUT_1\(84),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(2));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30ffffff3000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(61),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_9__N_5\,
datae => \GRFPU0.GRFPU_X0.UN1_VST3.EXC37\,
datad => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.OUT_1\(84),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(2));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03ffffff0300ffff")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(62),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_31\(62),
datae => \GRFPU0.GRFPU_X0.UN1_VST3.EXC37\,
datad => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.OUT_1\(84),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(2));
GRFPU0_GRFPU_X0_ITER_NX_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffcc00000fcc")
port map (
combout => N_53554,
dataf => N_44701,
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_184\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.NX\);
\GRFPC0_FP_PIPELINE_15_CHECK_DEP_DEP_9_0_A2_0_I_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_25122\,
dataf => \GRFPC0.EX.CTRL.INST\(27),
datae => \GRFPC0.EX.CTRL.INST\(26));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN271_REGDEPX2_2_0_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_25376\,
dataf => \GRFPC0.MEM.CTRL.INST\(29),
datae => \GRFPC0.MEM.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_10_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => \GRFPC0.N_25710\,
dataf => \GRFPC0.MEM.CTRL.INST\(1),
datae => \GRFPC0.MEM.CTRL.INST\(4),
datad => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST\(3),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffffff00ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.DIFF_1\(51),
dataf => \GRFPU0.GRFPU_X0.UN8_DIFF2\(51),
datae => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3_0\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(51));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffffff00ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.DIFF_1\(52),
dataf => \GRFPU0.GRFPU_X0.UN8_DIFF2\(52),
datae => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3_0\,
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(52));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.DIFF_1\(50),
dataf => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3_0\,
datae => \GRFPU0.GRFPU_X0.UN8_DIFF2\(50),
datad => \GRFPU0.GRFPU_X0.UN2_DIFF1\(50));
GRFPU0_GRFPU_X0_UN208_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_9732\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(50),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(52),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(51),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(53));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000c00")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(53),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_1__G0_2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datad => \GRFPU0.GRFPU_X0.N_19079\,
datac => \GRFPU0.GRFPU_X0.N_5774\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(53));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000c00")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47\(54),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_2__G0_2\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datad => \GRFPU0.GRFPU_X0.N_19079\,
datac => \GRFPU0.GRFPU_X0.N_5774\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_7_3_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_25\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_22\,
datae => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_18\,
datad => \GRFPU0.MULO.MRES\(18),
datac => \GRFPU0.MULO.MRES\(17),
datab => \GRFPU0.MULO.MRES\(20),
dataa => \GRFPU0.MULO.MRES\(19));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_7_3_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_21\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_14\,
datae => \GRFPU0.MULO.MRES\(38),
datad => \GRFPU0.MULO.MRES\(37),
datac => \GRFPU0.MULO.MRES\(40),
datab => \GRFPU0.MULO.MRES\(39));
\GRFPU0_GRFPU_X0_COMB_RMND_7_I_M3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0ff00f0ff0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_13387\,
dataf => \GRFPU0.MULO.MRES\(68),
datae => \GRFPU0.MULO.MRES\(69),
datad => \GRFPU0.GRFPU_X0.ITER.NORM\,
datac => \GRFPU0.GRFPU_X0.ITER.BMLSB\(0));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_340_I_O2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff3fffffff")
port map (
combout => \GRFPC0.N_24278\,
dataf => \GRFPC0.EX.CTRL.INST\(3),
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN253_REGDEPX2_2_0_O2_0_I_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.N_25460\,
dataf => \GRFPC0.EX.CTRL.INST\(3),
datae => \GRFPC0.EX.CTRL.INST\(4));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14488\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(1),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(2));
GRFPU0_GRFPU_X0_COMB_G_DP_1_U: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.G_DP_1\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(2),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(1),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(0));
\GRFPU0_GRFPU_X0_ST3_FARRES_RNO_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(54),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(54),
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(2),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_S_DP_1_1_U: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfcfccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.S_DP_1_1\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(1),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(0),
datab => \GRFPU0.GRFPU_X0.ST3.STICKY\);
GRFPU0_GRFPU_X0_COMB_RNDOP22_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_9344\,
dataf => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datae => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1));
\GRFPU0_GRFPU_X0_ITER_R_I_RNO_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"2f2f2f2f2f2f2f0d")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(52),
dataf => \GRFPU0.GRFPU_X0.N_18342\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O2_1\(52),
datad => \GRFPU0.GRFPU_X0.N_18364\,
datac => D_N_6_1,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(52),
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_52_M3_0_A2_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M13_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(14),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(42),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M22_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(23),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(33),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M2_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(3),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(53),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_S_SP_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_13\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(23),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(14),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M0_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(55),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_S_SP_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_20\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(1),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(0),
datad => \GRFPU0.GRFPU_X0.ST3.STICKY\,
datac => \GRFPU0.GRFPU_X0.S_SP_14\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNO_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3302310033023302")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(45),
dataf => N_108632,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(45),
datad => N_93120,
datac => \GRFPU0.GRFPU_X0.N_18527\,
datab => \GRFPU0.GRFPU_X0.N_5673_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNO_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3100310031003302")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(42),
dataf => N_108630,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(42),
datad => N_93119,
datac => \GRFPU0.GRFPU_X0.N_18527\,
datab => \GRFPU0.GRFPU_X0.N_5673_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNO_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3100310031003302")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(47),
dataf => N_108636,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(47),
datad => N_93118,
datac => \GRFPU0.GRFPU_X0.N_18527\,
datab => \GRFPU0.GRFPU_X0.N_5673_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNO_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3302310033023302")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(49),
dataf => N_108634,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(49),
datad => N_93117,
datac => \GRFPU0.GRFPU_X0.N_18527\,
datab => \GRFPU0.GRFPU_X0.N_5673_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.V\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(1),
dataf => \GRFPU0.GRFPU_X0.N_8869_0\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(1),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(2),
dataf => \GRFPU0.GRFPU_X0.N_8869_0\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(2),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(3),
dataf => \GRFPU0.GRFPU_X0.N_8869_0\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(3),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(4),
dataf => \GRFPU0.GRFPU_X0.N_8869_0\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(4),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(0),
dataf => \GRFPU0.GRFPU_X0.N_8869_0\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(0),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(5),
dataf => \GRFPU0.GRFPU_X0.N_8869_0\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(5),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(6),
dataf => \GRFPU0.GRFPU_X0.N_8869_0\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(6),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(7),
dataf => \GRFPU0.GRFPU_X0.N_8869_0\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(7),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(8),
dataf => \GRFPU0.GRFPU_X0.N_8869_0\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(8),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(9),
dataf => \GRFPU0.GRFPU_X0.N_8869_0\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(9),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(10),
dataf => \GRFPU0.GRFPU_X0.N_8869_0\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(10),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(11),
dataf => \GRFPU0.GRFPU_X0.N_8869_0\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(11),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(12),
dataf => \GRFPU0.GRFPU_X0.N_8869_0\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(12),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(13),
dataf => \GRFPU0.GRFPU_X0.N_8869_0\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(13),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(14),
dataf => \GRFPU0.GRFPU_X0.N_8869_0\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(14),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(15),
dataf => \GRFPU0.GRFPU_X0.N_8869_0\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(15),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(16),
dataf => \GRFPU0.GRFPU_X0.N_8869\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(16),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(17),
dataf => \GRFPU0.GRFPU_X0.N_8869\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(17),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(18),
dataf => \GRFPU0.GRFPU_X0.N_8869\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(18),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(19),
dataf => \GRFPU0.GRFPU_X0.N_8869\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(19),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(20),
dataf => \GRFPU0.GRFPU_X0.N_8869\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(20),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(21),
dataf => \GRFPU0.GRFPU_X0.N_8869\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(21),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(22),
dataf => \GRFPU0.GRFPU_X0.N_8869\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(22),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(23),
dataf => \GRFPU0.GRFPU_X0.N_8869\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(23),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(24),
dataf => \GRFPU0.GRFPU_X0.N_8869\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(24),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(25),
dataf => \GRFPU0.GRFPU_X0.N_8869\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(25),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_26: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(26),
dataf => \GRFPU0.GRFPU_X0.N_8869\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(26),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(27),
dataf => \GRFPU0.GRFPU_X0.N_8869\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(27),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_28: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000fc000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(28),
dataf => \GRFPU0.GRFPU_X0.N_8869\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(28),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_15\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(15),
datae => \GRFPU0.GRFPU_X0.ST3.REG\(14),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(13),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(12));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M23_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(24),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(32),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M25_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(26),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(30),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M14_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(15),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(41),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M1_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(2),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(54),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_S_SP_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_19\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(15),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(26),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(24),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(2));
\GRFPU0_GRFPU_X0_COMB_UN58_FLUSH_ALTB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff0f0f000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.ALTB\(1),
dataf => \FPI.FLUSHID\(1),
datae => \FPI.FLUSHID\(0),
datad => \GRFPU0.GRFPU_X0.ST3.ID\(0),
datac => \GRFPU0.GRFPU_X0.ST3.ID\(1));
\GRFPU0_GRFPU_X0_COMB_UN74_FLUSH_ALTB_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"7f1f07015f0f0500")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.ALTB\(2),
dataf => \FPI.FLUSHID\(0),
datae => \FPI.FLUSHID\(2),
datad => \FPI.FLUSHID\(1),
datac => \GRFPU0.GRFPU_X0.ITER.ID\(2),
datab => \GRFPU0.GRFPU_X0.ITER.ID\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.ID\(1));
\GRFPU0_GRFPU_X0_TZI2_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(3),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(11));
GRFPU0_GRFPU_X0_NXX_1_48_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_48_9\,
dataf => \GRFPU0.MULO.MRES\(58),
datae => \GRFPU0.MULO.MRES\(49),
datad => \GRFPU0.MULO.MRES\(48),
datac => \GRFPU0.MULO.MRES\(45));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_19\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(17),
datae => \GRFPU0.GRFPU_X0.ST3.REG\(16),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(1),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(0),
datab => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_13\);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN236_REGDEPX2_2_0_A2_0_A2_0_A2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN695_REGDEPX2_2\,
dataf => \GRFPC0.EX.CTRL.INST\(17),
datae => \GRFPC0.EX.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_20_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(1),
dataf => \GRFPC0.N_579\,
datae => \GRFPC0.MEM.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_6_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
dataf => \GRFPC0.N_579\,
datae => \GRFPC0.MEM.CTRL.INST\(25));
\GRFPU0_GRFPU_X0_ITER_STATE_RNI9ASE1_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c00c000")
port map (
combout => \GRFPU0.GRFPU_X0.G_16_0_A2_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datac => \GRFPU0.GRFPU_X0.ITER.SIGN\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(9));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN285_REGDEPX2_0_A2_1_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN285_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(16),
datae => \GRFPC0.MEM.CTRL.INST\(15),
datad => \GRFPC0.MEM.CTRL.INST\(18),
datac => \GRFPC0.MEM.CTRL.INST\(17));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000c0f030000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(48),
datae => N_93123,
datad => \GRFPU0.GRFPU_X0.N_18527\,
datac => \GRFPU0.GRFPU_X0.N_5673_0\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0003000f000f0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(38),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV\(38),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => N_93114,
datac => \GRFPU0.GRFPU_X0.N_5673_0\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPC0_RFA2_RS2SEL_RNIHK61_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => N_99880,
dataf => \GRFPC0.RFA2.RS2SEL\(7),
datae => \GRFPC0.RFA2.RS2SEL\(1),
datad => \GRFPC0.RFA2.RS2SEL\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ccccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
dataf => \GRFPU0.GRFPU_X0.N_5673_RETO\,
datae => \GRFPU0.GRFPU_X0.N_18527_RETO\,
datad => \GRFPU0.GRFPU_X0.ITER.V_RETO\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_RETO\(46),
datab => N_93112_RETO);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ccccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
dataf => \GRFPU0.GRFPU_X0.N_5673_RETO\,
datae => \GRFPU0.GRFPU_X0.N_18527_RETO\,
datad => \GRFPU0.GRFPU_X0.ITER.V_RETO\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_RETO\(39),
datab => N_93121_RETO);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cccc0fcc")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
dataf => \GRFPU0.GRFPU_X0.N_5673_RETO\,
datae => \GRFPU0.GRFPU_X0.N_18527_RETO\,
datad => \GRFPU0.GRFPU_X0.ITER.V_RETO\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_RETO\(44),
datab => N_93113_RETO);
GRFPU0_GRFPU_X0_ITER_R_I_RET_23_RNIL16Q: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"bb88aaaa3f0c0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
dataf => \GRFPU0.GRFPU_X0.N_5673_RETO\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_57_M4_E_2_RETO\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_RETO\(55),
datac => D_N_5_2_RETO,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_RETO\(55),
dataa => \GRFPU0.DIVAPPR_RETO\(3));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A2_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_24183_RETI\,
dataf => \GRFPC0.EX.CTRL.INST\(3),
datae => \GRFPC0.EX.CTRL.INST\(2));
GRFPU0_GRFPU_X0_ITER_R_I_RET_12_RNIE16Q: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"bb88aaaa3f0c0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
dataf => \GRFPU0.GRFPU_X0.N_5673_RETO\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_57_M4_E_2_RETO\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_RETO\(53),
datac => D_N_5_4_RETO,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_RETO\(53),
dataa => \GRFPU0.DIVAPPR_RETO\(1));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M27_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(28),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(28),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M16_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(17),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(39),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M21_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(22),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(34),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M26_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(27),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(29),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_S_SP_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_22_RETI\,
dataf => \GRFPU0.GRFPU_X0.S_SP_17_RETI\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(22),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(28),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(27),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(17));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M5_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(6),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(50),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M18_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(19),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(37),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M19_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(20),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(36),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M4_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(5),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(51),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_S_SP_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_21_RETI\,
dataf => \GRFPU0.GRFPU_X0.S_SP_15_RETI\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(20),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(19),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(6),
datab => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(5));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(1));
GRFPU0_GRFPU_X0_ITER_R_I_RET_7_RNIJNUK: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"bb88aaaaf3c0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
dataf => \GRFPU0.GRFPU_X0.N_5673_RETO\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_57_M4_E_2_RETO\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_RETO\(56),
datac => N_82240_RETO,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_RETO\(56),
dataa => \GRFPU0.DIVAPPR_RETO\(4));
GRFPU0_GRFPU_X0_ITER_R_I_RET_3_RNI2CIN: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"bb88aaaa3f0c0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
dataf => \GRFPU0.GRFPU_X0.N_5673_RETO\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_57_M4_E_2_RETO\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_RETO\(58),
datac => D_N_5_1_RETO,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_RETO\(58),
dataa => \GRFPU0.DIVAPPR_RETO\(6));
GRFPU0_GRFPU_X0_ITER_R_I_RET_0_RNI5DNF: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"bb88aaaa3f0c0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
dataf => \GRFPU0.GRFPU_X0.N_5673_RETO\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_57_M4_E_2_RETO\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_RETO\(57),
datac => D_N_5_3_RETO,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_RETO\(57),
dataa => \GRFPU0.DIVAPPR_RETO\(5));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(2));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(3));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(4));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(5));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(6));
\GRFPC0_EX_CTRL_INST_RNIC52EG_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.MEM.CTRL.INSTI\(28),
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.MEM.CTRL.INST\(28),
datad => \GRFPC0.EX.CTRL.INST\(28));
\GRFPC0_EX_CTRL_INST_RNIE92EG_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.MEM.CTRL.INSTI\(29),
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.MEM.CTRL.INST\(29),
datad => \GRFPC0.EX.CTRL.INST\(29));
\GRFPC0_EX_CTRL_INST_RNIA12EG_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.MEM.CTRL.INSTI\(27),
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.MEM.CTRL.INST\(27),
datad => \GRFPC0.EX.CTRL.INST\(27));
\GRFPC0_EX_CTRL_INST_RNI8T1EG_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.MEM.CTRL.INSTI\(26),
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.MEM.CTRL.INST\(26),
datad => \GRFPC0.EX.CTRL.INST\(26));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(7));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(8));
GRFPU0_GRFPU_X0_NXX_1_48_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_48_11_RETI\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(65),
datae => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(54),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(52),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(51),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(47));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(9));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(10));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(11));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(12));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(13));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(14));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(15));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(0));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_7_3_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_18_RETI\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(24),
datae => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(23),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(22),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(21));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffccccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
dataf => \GRFPU0.GRFPU_X0.N_5673_RETO\,
datae => \GRFPU0.GRFPU_X0.N_18527_RETO\,
datad => \GRFPU0.GRFPU_X0.ITER.V_RETO\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_RETO\(59),
datab => N_93111_RETO);
GRFPU0_GRFPU_X0_COMB_ORV_TMP_7_3_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_14_RETI\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(44),
datae => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(43),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(42),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(41));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(17));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(18));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(19));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(20));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(21));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(22));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(23));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(24));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(25));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_26: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(26));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(27));
GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_28: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
dataf => \GRFPU0.GRFPU_X0.N_18750_RETO\,
datae => \FPI.OP1_RETO\(28));
GRFPC0_FP_PIPELINE_9_CHECK_DEP_UN4209_REGDEPX2_0_A2_0_A2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_24325_RETI\,
dataf => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(27),
datae => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(26));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_RETI\(0),
dataf => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(14),
datae => N_47178);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_RETI\(1),
dataf => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(14),
datae => N_47178);
GRFPU0_GRFPU_X0_COMB_ORV_TMP_7_3_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_22_RETI\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_16_RETI\,
datae => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(30),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(29),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(32),
datab => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(31));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_18_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_RETI\(0),
dataf => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(0),
datae => N_47178);
GRFPC0_RFA_READ_RS1_RNIJO1G: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.EX.CTRL.RS1V_0_0_G1\,
dataf => \GRFPC0.RFA.READ_RS1\,
datae => N_35);
\GRFPC0_FP_PIPELINE_15_REGDEPX2_460_I_A2_1_0_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff000000")
port map (
combout => \GRFPC0.N_24327_RETI\,
dataf => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(14),
datae => N_47178,
datad => \GRFPC0.EX.CTRL.RS1V_0_0_G1\);
\GRFPC0_FP_PIPELINE_3_CHECK_DEP_DEP_21_0_A2_1_A2_0_A2_0_A2_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.N_24322_RETI\,
dataf => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(29),
datae => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(28));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_RETI\(0),
dataf => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(25),
datae => N_47178);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_RETI\(1),
dataf => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(25),
datae => N_47178);
GRFPC0_RFA2_RS1SEL_RET_37_RNIE90O_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f3000000")
port map (
combout => \GRFPC0.RFA2.RS1SEL\(1),
dataf => HOLDN_RETO,
datae => \GRFPC0.FPUSEL_6_2_RETO\(1),
datad => \GRFPC0.FPUSEL_6_3_RETO\(1),
datac => \GRFPC0.EX.RREG.RESV_RETO\,
datab => \GRFPC0.N_82_RETO\);
GRFPU0_GRFPU_X0_ST1_OP2NX_RET_1_RNI49FO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.OP2NX\,
dataf => \GRFPU0.GRFPU_X0.N_10059_I_RETO\,
datae => \GRFPU0.GRFPU_X0.ST1.OP2NX_0_0_G0_I_MUX2_RETO\);
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_13_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_13_RETI\,
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37\(5),
datae => \GRFPU0.GRFPU_X0.VST3.REG_37\(4),
datad => \GRFPU0.GRFPU_X0.VST3.REG_37\(3),
datac => \GRFPU0.GRFPU_X0.VST3.REG_37\(2));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_9_RETI\,
dataf => \GRFPU0.MULO.MRES_RETI\(82),
datae => \GRFPU0.MULO.MRES_RETI\(76),
datad => \GRFPU0.MULO.MRES_RETI\(75),
datac => \GRFPU0.MULO.MRES_RETI\(74));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M11_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(12),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(44),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M3_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(4),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(52),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M12_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(13),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(43),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M10_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(11),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(45),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_S_SP_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_14_RETI\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(13),
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(12),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(11),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(4));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_18_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_RETI\(1),
dataf => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(0),
datae => N_47178);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_RETI\(1),
dataf => \GRFPC0.MEM.CTRL.INSTI\(0),
datae => \GRFPC0.N_579I\);
GRFPC0_RFA2_RS1SEL_RET_31_RNI290O: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f3f3f300000000")
port map (
combout => \GRFPC0.FPUSEL_6_0_3__G7_RETO\,
dataf => HOLDN_RETO,
datae => \GRFPC0.FPUSEL_6_2_RETO\(1),
datad => \GRFPC0.FPUSEL_6_3_RETO\(1),
datac => \GRFPC0.MEM.RREG.RESV_RETO\,
datab => \GRFPC0.N_24428_RETO\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M20_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(21),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(35),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M17_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(38),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M24_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(25),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(31),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M15_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(16),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(40),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_S_SP_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_17_RETI\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(21),
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(25),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(18),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(16));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M7_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(8),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(48),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M8_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(9),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(47),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M9_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(10),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(46),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M6_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(7),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_4_03_0_G1\,
datae => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(49),
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_S_SP_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP_15_RETI\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(10),
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(9),
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(8),
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(7));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000002")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_11_RETI\,
dataf => \GRFPU0.MULO.MRES_RETI\(79),
datae => \GRFPU0.MULO.MRES_RETI\(78),
datad => \GRFPU0.MULO.MRES_RETI\(77),
datac => \GRFPU0.MULO.MRES_RETI\(73),
datab => \GRFPU0.MULO.MRES_RETI\(72),
dataa => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_3_RETI\);
\GRFPC0_EX_CTRL_INST_RNIAE4DG_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.MEM.CTRL.INSTI\(0),
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.MEM.CTRL.INST\(0),
datad => \GRFPC0.EX.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_RETI\(0),
dataf => \GRFPC0.MEM.CTRL.INSTI\(0),
datae => \GRFPC0.N_579I\);
\GRFPC0_EX_CTRL_INST_RNI6P1EG_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.MEM.CTRL.INSTI\(25),
dataf => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
datae => \GRFPC0.MEM.CTRL.INST\(25),
datad => \GRFPC0.EX.CTRL.INST\(25));
GRFPC0_MEM_CTRL_RDD_RNIJUI51: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPC0.N_579I\,
dataf => \GRFPC0.MEM.CTRL.RDD_0_0_G1\,
datae => \GRFPC0.N_579\,
datad => N_37);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6_RETI\(0),
dataf => \GRFPC0.MEM.CTRL.INSTI\(25),
datae => \GRFPC0.N_579I\);
GRFPU0_GRFPU_X0_COMB_ORV_TMP_7_3_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_16_RETI\,
dataf => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(36),
datae => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(35),
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(34),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(33));
GRFPC0_RFA2_RS1SEL_RET_24_RNI7ICD: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000cf")
port map (
combout => \GRFPC0.FPUSEL_6_0_3__G1_RETO\,
dataf => \GRFPC0.N_21346_RETO\,
datae => HOLDN_RETO,
datad => \GRFPC0.FP_PIPELINE.0.EXEN2_RETO\,
datac => \GRFPC0.N_24361_RETO\,
datab => \GRFPC0.WR.RREG.RESV_RETO\);
GRFPC0_RFA2_RS1SEL_RET_20_RNISHCD: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000f0f00000000")
port map (
combout => \GRFPC0.RFA2.RS1SEL\(4),
dataf => \GRFPC0.FPUSEL_6_1_RETO\(7),
datae => \GRFPC0.N_21346_RETO\,
datad => \GRFPC0.FP_PIPELINE.0.WR2EN2_RETO\,
datac => \GRFPC0.N_24359_RETO\,
datab => \GRFPC0.WR2SEL_1_RETO\(4));
GRFPC0_UN1_WRENX2_2_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c30000000000")
port map (
combout => \GRFPC0.UN1_WRENX2_2_4_RETO\,
dataf => \GRFPC0.N_21346_RETO\,
datae => \GRFPC0.FP_PIPELINE.0.WR2EN2_RETO\,
datad => \GRFPC0.UN1_WRENX2_2_4_0_RETO\,
datac => \GRFPC0.N_22829_RETO\,
datab => \GRFPC0.DIV.RD_RETO\(0));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_3_RETI\,
dataf => \GRFPU0.MULO.MRES_RETI\(71),
datae => \GRFPU0.MULO.MRES_RETI\(70),
datad => \GRFPU0.MULO.MRES_RETI\(69),
datac => \GRFPU0.MULO.MRES_RETI\(68));
GRFPC0_RFA2_RS1SEL_RET_13_RNIGE2H_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8b000000bb000000")
port map (
combout => \GRFPC0.RFA2.RS1SEL\(7),
dataf => \GRFPC0.UN1_WRENX2_2_4_RETO\,
datae => \GRFPC0.FPUSEL_6_1_RETO\(7),
datad => \GRFPC0.N_21346_RETO\,
datac => \GRFPC0.UN1_WRENX2_2_3_0_RETO\,
datab => \GRFPC0.FP_PIPELINE.0.WR2EN2_RETO\,
dataa => \GRFPC0.WR2SEL_1_RETO\(7));
GRFPC0_RFA2_RS1SEL_RET_2_RNIM02F2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffc0003fff0000")
port map (
combout => \GRFPC0.RFA2.RS1SEL\(3),
dataf => \GRFPC0.FPUSEL_6_0_3__G7_RETO\,
datae => \GRFPC0.FPUSEL_6_0_3__G1_RETO\,
datad => \GRFPC0.FPUSEL_6_0_3__G0_E_1_RETO\,
datac => \GRFPC0.FPUSEL_6_0_3__G0_E_2_RETO\,
datab => \GRFPC0.FPUSEL_6_0_3__G0_E_0_RETO\);
GRFPU0_GRFPU_X0_ST2_DEFERNX_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.DEFERNX\,
dataf => \GRFPU0.GRFPU_X0.N_10059_I_RETO\,
datae => \GRFPU0.GRFPU_X0.ST1.DEFERNX_0_0_G0_I_MUX2_RETO\);
GRFPU0_FPMUL0_CS_DP_R_RET_41_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S_RETI\(100),
dataf => N_28124_RETI,
datae => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0_RETI\,
datad => N_28123_RETI);
GRFPU0_FPMUL0_CS_DP_R_RET_21_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.MULO.DRES_1_RETI\(100),
dataf => N_28179_RETI,
datae => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_RETI\,
datad => N_28178_RETI);
GRFPU0_FPMUL0_CS_DP_R_RET_19_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.MULO.DRES_1_RETI\(102),
dataf => N_28183_RETI,
datae => N_28182_RETI,
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_RETI\);
GRFPC0_RFA2_RS2SEL_RET_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => N_99881_RETI,
dataf => \GRFPC0.N_10562\,
datae => \GRFPC0.FPUSEL_1\(2));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f00000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_16_RETI\(0),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27_RETI\,
datae => \GRFPU0.MULO.MRES_RETI\(93),
datad => \GRFPU0.MULO.MRES_RETI\(87),
datac => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(94));
GRFPU0_FPMUL0_R2_RET_162_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(96),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27_RETI\,
datae => N_28057_RETI,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(96));
GRFPU0_FPMUL0_R2_RET_161_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.MRES_RETI\(95),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27_RETI\,
datae => N_28055_RETI,
datad => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(95));
\GRFPC0_EX_CTRL_RD_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_46970,
dataf => N_46865,
datae => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datad => \GRFPC0.RFA.RD\(4));
\GRFPC0_EX_CTRL_RD_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_46944,
dataf => N_46865,
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.RFA.RD\(3));
\GRFPC0_EX_CTRL_RD_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_46918,
dataf => N_46865,
datae => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datad => \GRFPC0.RFA.RD\(2));
\GRFPC0_EX_CTRL_RD_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_46892,
dataf => N_46865,
datae => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datad => \GRFPC0.RFA.RD\(1));
\GRFPC0_EX_CTRL_RD_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_46866,
dataf => N_46865,
datae => \GRFPC0.V.STDATA_14\(25),
datad => \GRFPC0.RFA.RD\(0));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(51),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_51__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(22),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(50),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_50__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(21),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(49),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_49__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(20),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(48),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_48__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(19),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(47),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_47__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(18),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(46),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_46__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(17),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(45),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_45__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(16),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(44),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_44__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(15),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(43),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_43__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(14),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(42),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_42__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(13),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(41),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_41__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(12),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(40),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_40__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(11),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(39),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_39__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(10),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(38),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_38__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(9),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(37),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_37__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(8),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(36),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_36__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(7),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(35),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_35__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(6),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(34),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_34__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(5),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(33),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_33__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(4),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(32),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_32__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(3),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(31),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_31__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(2),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(30),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_30__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(1),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(29),
dataf => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_29__G1\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(0),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(10),
dataf => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(11),
datae => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_10__N_7\,
datad => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(9),
dataf => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(10),
datae => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_7\,
datad => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(8),
dataf => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(9),
datae => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_8__N_7\,
datad => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(7),
dataf => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(8),
datae => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_7__N_7\,
datad => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(6),
dataf => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(7),
datae => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_6__N_7\,
datad => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(5),
dataf => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(6),
datae => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_5__N_7\,
datad => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(4),
dataf => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(5),
datae => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_4__N_7\,
datad => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(3),
dataf => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(4),
datae => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_3__N_7\,
datad => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(2),
dataf => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(3),
datae => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_2__N_7\,
datad => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(1),
dataf => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(2),
datae => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__N_7\,
datad => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(0),
dataf => \GRFPU0.GRFPU_X0.UN1_EXPDEC\(1),
datae => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_0__N_6\);
\GRFPC0_MEM_RREG_EXCT_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => N_27209,
dataf => \GRFPC0.EX.RREG.EXCT_0_0_3__N_6\,
datae => \GRFPC0.MEM.RREG.EXCT_0_0_3__N_6\,
datad => N_37);
\GRFPC0_WR2_RREG_EXCT_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => N_27218,
dataf => \GRFPC0.WR2.RREG.EXCT_0_0_0__G3\,
datae => \FPO.EXC\(0),
datad => N_37);
\GRFPC0_WR2_RREG_EXCT_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => N_27219,
dataf => \GRFPC0.WR2.RREG.EXCT_0_0_1__G3\,
datae => \GRFPU0.GRFPU_X0.N_18290_I_0\,
datad => N_37);
\GRFPC0_WR2_RREG_EXCT_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => N_27220,
dataf => \GRFPC0.WR2.RREG.EXCT_0_0_2__G3\,
datae => \FPO.EXC\(2),
datad => N_37);
\GRFPC0_WR2_RREG_EXCT_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => N_27221,
dataf => \GRFPC0.WR2.RREG.EXCT_0_0_3__G3\,
datae => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
datad => N_37);
\GRFPC0_WR2_RREG_EXCT_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => N_27222,
dataf => \GRFPC0.WR2.RREG.EXCT_0_0_4__G3\,
datae => \GRFPU0.GRFPU_X0.N_18289_I_0\,
datad => N_37);
\GRFPC0_WR2_RREG_EXCT_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => N_27223,
dataf => \GRFPC0.WR2.RREG.EXCT_0_0_5__G3\,
datae => \GRFPC0.FPO_I_6_I_0\(69),
datad => N_37);
\GRFPU0_GRFPU_X0_ST2_DIFF_RNIFU8J4_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_9672\,
dataf => \GRFPU0.GRFPU_X0.N_9683\,
datae => \GRFPU0.GRFPU_X0.L2_0_0_0\(4),
datad => \GRFPU0.GRFPU_X0.N_14025_1\,
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(42));
GRFPU0_GRFPU_X0_COMB_VST3_RDY8_RNIIJ17C: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003030003")
port map (
combout => \GRFPU0.GRFPU_X0.N_5758\,
dataf => \GRFPU0.GRFPU_X0.N_5775\,
datae => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_5\,
datad => \GRFPU0.GRFPU_X0.N_5790\,
datac => \GRFPU0.GRFPU_X0.N_5774\,
datab => \GRFPU0.GRFPU_X0.N_5773\);
GRFPU0_GRFPU_X0_COMB_VST3_REG59_0_RNIJGA68: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_5775\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6\,
datae => \GRFPU0.GRFPU_X0.N_5806\,
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\,
datac => \GRFPU0.GRFPU_X0.ST2.RDY\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0fffff0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_1__G0_2\,
dataf => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_1__G0_0\,
datad => \GRFPU0.GRFPU_X0.N_19079\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_3\,
datab => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(10));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0fffff0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_2__G0_2\,
dataf => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_2__G0_0\,
datad => \GRFPU0.GRFPU_X0.N_19079\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_3\,
datab => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(9));
GRFPU0_GRFPU_X0_COMB_VST3_REG59_2_RNID6JID: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
dataf => \GRFPU0.GRFPU_X0.N_5758\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.REG59_2\,
datad => \GRFPU0.GRFPU_X0.N_19700\,
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST2.RDY\);
GRFPU0_GRFPU_X0_UN208_BCO_LSB_RNIT3BR1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_9683\,
dataf => \GRFPU0.GRFPU_X0.N_9732\,
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(46));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000f000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_31\(59),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datae => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(4),
datad => \GRFPU0.GRFPU_X0.N_5774\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(59));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000f000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_31\(62),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datae => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(1),
datad => \GRFPU0.GRFPU_X0.N_5774\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(62));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000f000f0")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_9__N_5\,
dataf => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datae => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(2),
datad => \GRFPU0.GRFPU_X0.N_5774\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(61));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000f000f0")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_8__N_5\,
dataf => \GRFPU0.GRFPU_X0.VST3.REG_0_SQMUXA_5\,
datae => \GRFPU0.GRFPU_X0.UN1_ST2.REG_1\(3),
datad => \GRFPU0.GRFPU_X0.N_5774\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(60));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_10_RNI9FUB7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6\,
dataf => \GRFPU0.GRFPU_X0.N_9666\,
datae => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_16\,
datad => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_14\,
datac => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_11\,
datab => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_10\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff003f00ff00ffc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.UN9_CMPI1\,
datae => \GRFPU0.GRFPU_X0.N_13428\,
datad => D_N_7_0_I,
datac => N_67750,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_M4_0_A2_1\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_58_RNIJBT: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_53\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_70\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_69\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_1_RNI0SH4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_4\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_10\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_2\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.N_1\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_10_RNIGKT8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_13\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_21\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_4\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.N_14\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_11\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.N_4\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.N_3\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_11_RNICRU6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_12\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_20\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_12\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.N_9\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_8\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.N_6\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.N_5\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_21_RNIDMLH: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_26\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_34\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_33\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.N_32\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_13\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.N_24\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_12\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_31_RNIJUTJ: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_38\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_48\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_26\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.N_46\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_45\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.N_44\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.N_36\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_47_RNI5V6M: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_52\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_60\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_38\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_58\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.N_57\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.N_56\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_13_RNIA5L2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_17\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_23\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_22\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.N_18\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_17\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.N_16\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.N_15\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_24_RNI3204: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_25\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_17\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_30\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.N_29\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_28\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_22_RNI6GP5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_30\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_25\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_40\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.N_35\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_27\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.N_26\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_32_RNI2O18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_37\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_30\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_47\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.N_42\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_41\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.N_39\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.N_38\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_42_RNIMOB1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_44\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_59\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_51\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.N_50\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_44_RNICR7B: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_50\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.N_64\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_44\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_37\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_54\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.N_53\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.N_52\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_52_RNIIBHD: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_57\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_50\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.N_71\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.N_66\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_65\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.N_63\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.N_62\);
GRFPU0_GRFPU_X0_COMB_LESS2_COMB_LESS2_61_RNI63261: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN9_CMPI1\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_57\,
datae => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_53\,
datad => \GRFPU0.GRFPU_X0.COMB.LESS2.N_75\,
datac => \GRFPU0.GRFPU_X0.COMB.LESS2.N_74\,
datab => \GRFPU0.GRFPU_X0.COMB.LESS2.N_72\,
dataa => \GRFPU0.GRFPU_X0.COMB.LESS2.G0_11_52\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"7f00ff00ff80ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.UN9_CMPI1\,
datae => \GRFPU0.GRFPU_X0.N_13428\,
datad => D_N_7_I,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1__G1_1\,
datab => \GRFPU0.GRFPU_X0.N_394\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1__G0_I_M2_M5_E_1\);
GRFPC0_RFA2_RS2DEP_RNO_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0000ff00000000")
port map (
combout => \GRFPC0.G4_1_0_0\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_0_1\,
datae => \GRFPC0.N_23598_I_0\,
datad => \GRFPC0.N_106_I\);
GRFPC0_RFA2_RS2DEP_RNO_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000804000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_0\,
dataf => \GRFPC0.UN1_REGDEP173\,
datae => \GRFPC0.G1_3\,
datad => \GRFPC0.N_23598_I_0\,
datac => \GRFPC0.FP_PIPELINE.1.REGDEP146\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_0_0\,
dataa => \GRFPC0.N_579\);
GRFPC0_RFA2_RS2DEP_RNO_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccc8ffff3332ffff")
port map (
combout => \GRFPC0.G1_0_0_0\,
dataf => \GRFPC0.N_23598_I_0\,
datae => \GRFPC0.FP_PIPELINE.1.REGDEP104\,
datad => \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\,
datab => \GRFPC0.DIV.RDD\,
dataa => \GRFPC0.DIV.VALID\);
GRFPC0_RFA2_RS2DEP_RNO_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000200000000")
port map (
combout => \GRFPC0.G1_0_0\,
dataf => \GRFPC0.UN1_REGDEP173\,
datae => \GRFPC0.G1_3\,
datad => \GRFPC0.N_8_0\,
datac => \GRFPC0.G6\,
datab => \GRFPC0.G1_1\,
dataa => \GRFPC0.G1_0_0_0\);
GRFPC0_RFA2_RS2DEP_RNO_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00000000f000000")
port map (
combout => \GRFPC0.G0_4_1\,
dataf => \GRFPC0.N_23598_I_0\,
datae => \GRFPC0.FP_PIPELINE.1.REGDEP132\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEP34_I_M_0_0\,
datac => \GRFPC0.WR.CTRL.RDD\);
GRFPC0_FP_PIPELINE_1_REGDEP146_RNIQD4J2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cf3f0000fcf30000")
port map (
combout => \GRFPC0.N_8_0\,
dataf => \GRFPC0.N_23598_I_0\,
datae => \GRFPC0.FP_PIPELINE.1.REGDEP146\,
datad => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datac => \GRFPC0.N_579\,
datab => \GRFPC0.MEM.CTRL.RD\(0));
GRFPC0_RFA2_RS2DEP_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff31ffffffff")
port map (
combout => \GRFPC0.G1_2_1\,
dataf => \GRFPC0.UN1_REGDEP173\,
datae => \GRFPC0.G1_3\,
datad => \GRFPC0.N_8_0\,
datac => \GRFPC0.G6\,
datab => \GRFPC0.G0_4_1\,
dataa => \GRFPC0.FP_PIPELINE.0.REGDEP18_I_M_0_2\);
GRFPC0_RFA2_RS2DEP_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaaabfaaaaaaaa")
port map (
combout => \GRFPC0.N_10557\,
dataf => \GRFPC0.G1_2_1\,
datae => \GRFPC0.G1_0_0\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_0\,
datac => \GRFPC0.UN1_REGDEP173\,
datab => \GRFPC0.G4_1_0_0\,
dataa => \GRFPC0.REGDEP_0_SQMUXA_2\);
GRFPC0_RFA2_RS2DEP_RNO_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff0000f0ff0000")
port map (
combout => \GRFPC0.G1_1\,
dataf => \GRFPC0.N_23598_I_0\,
datae => \GRFPC0.FP_PIPELINE.1.REGDEP118\,
datad => \GRFPC0.FP_PIPELINE.1.UN1_WR2.CTRL.RD\,
datac => \GRFPC0.WR2.CTRL.RDD\);
GRFPC0_FP_PIPELINE_1_REGDEP160_RNIGOIQ2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cf3f0000fcf30000")
port map (
combout => \GRFPC0.G1_3\,
dataf => \GRFPC0.N_23598_I_0\,
datae => \GRFPC0.FP_PIPELINE.1.REGDEP160\,
datad => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datac => \GRFPC0.N_106_I\,
datab => \GRFPC0.EX.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_RSDEC_RS2D_IV_I_O3_1_RNIQJ0R: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"10400050b0c0a0f0")
port map (
combout => \GRFPC0.G0_7_2\,
dataf => \GRFPC0.N_93\,
datae => \GRFPC0.INST\(12),
datad => \GRFPC0.INST\(9),
datac => \GRFPC0.N_23618\,
datab => \GRFPC0.INST\(7),
dataa => \GRFPC0.INST\(19));
GRFPC0_FP_PIPELINE_RSDEC_RS2D_IV_I_O2_0_RNI27MM1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_23598_I_0\,
dataf => \GRFPC0.G0_7_2\,
datae => \GRFPC0.N_23636\,
datad => \GRFPC0.N_72_I\,
datac => \GRFPC0.N_23629\,
datab => \GRFPC0.RFA.WRITE_RD_0_0_I1_I_1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_1_S_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000001f")
port map (
combout => N_108693,
dataf => \GRFPC0.N_25840\,
datae => \GRFPC0.N_25841\,
datad => \GRFPC0.N_25842\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_3_0\(24),
datab => \GRFPC0.DIV.EXEC\,
dataa => \GRFPC0.DIV.VALID\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffd0")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_2\(0),
dataf => \GRFPC0.N_24163\,
datae => \GRFPC0.N_25147\,
datad => \GRFPC0.N_24162\,
datac => \GRFPC0.N_25154_1\,
datab => \GRFPC0.N_106_I\,
dataa => \GRFPC0.EX.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_10_REGDEPX_192_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffdc50cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX_192\(1),
dataf => \GRFPC0.FP_PIPELINE.10.REGDEPX_192_0_2\(1),
datae => \GRFPC0.N_23512\,
datad => \GRFPC0.N_21638_1\,
datac => \GRFPC0.N_23560\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_0\(20),
dataa => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_D_LDLCK_RNO_0_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffeffeefefeeeee")
port map (
combout => \GRFPC0.D.LDLCK_0_0_20__G1_3\,
dataf => N_108684,
datae => \GRFPC0.N_25051_1\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_0\(20),
datab => \GRFPC0.D.LDLCK_0_0_20__G1_0\,
dataa => \GRFPC0.N_23529\);
\GRFPC0_D_STLCK_RNO_0_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"02000000f3f10000")
port map (
combout => \GRFPC0.N_757\,
dataf => N_40689,
datae => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_A2_0_3\(1),
datad => \GRFPC0.N_114\,
datac => \GRFPC0.N_500\,
datab => \GRFPC0.WR.CTRL.RDD\,
dataa => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_D_LDLCK_RNO_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffefff1fff0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_23__G1\,
dataf => \GRFPC0.FP_PIPELINE.11.REGDEPX2_359\(1),
datae => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355\(1),
datad => \GRFPC0.D.LDLCK_0_0_23__G1_4\,
datac => \GRFPC0.N_23415\,
datab => \GRFPC0.DIV.EXEC\,
dataa => \GRFPC0.DIV.VALID\);
\GRFPC0_D_STLCK_RNO_3_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f003f00ffff7f55")
port map (
combout => \GRFPC0.D.STLCK_0_0_8__G1_0\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_14_I_1\,
datae => \GRFPC0.RFA.RDD\,
datad => \GRFPC0.N_22706\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_25_I\(0),
datab => \GRFPC0.N_59\,
dataa => N_172);
\GRFPC0_D_STLCK_RNO_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffe0")
port map (
combout => \GRFPC0.D.STLCK_0_0_1__G1_2\,
dataf => \GRFPC0.N_694\,
datae => \GRFPC0.N_730\,
datad => \GRFPC0.D.STLCK_0_0_1__G1_TZ\,
datac => \GRFPC0.N_22975_I\,
datab => \GRFPC0.RFA.RDD\,
dataa => N_172);
\GRFPC0_FP_PIPELINE_9_STDEP_376_3_I_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff40")
port map (
combout => \GRFPC0.N_21916\,
dataf => \GRFPC0.N_21947\,
datae => \GRFPC0.N_21951\,
datad => \GRFPC0.N_21954\,
datac => \GRFPC0.N_114\,
datab => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_I_A2_0_1\(0),
dataa => \GRFPC0.WR.CTRL.RDD\);
\GRFPC0_D_STLCK_RNO_1_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff3030ff75")
port map (
combout => \GRFPC0.D.STLCK_0_0_16__G1_1\,
dataf => \GRFPC0.N_21192\,
datae => \GRFPC0.N_60\,
datad => \GRFPC0.N_106_I\,
datac => \GRFPC0.N_120\,
datab => \GRFPC0.N_61_I\,
dataa => N_241);
\GRFPC0_D_LDLCK_RNO_2_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fef0ee00f0f00000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_5__G1_3\,
dataf => \GRFPC0.N_22593_1\,
datae => \GRFPC0.N_25356_1\,
datad => \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.UN720_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.UN735_REGDEPX\,
datab => \GRFPC0.FIFO.INST_0\(6),
dataa => \GRFPC0.FIFO.INST_0\(14));
GRFPC0_D_FSTLCK_RNO_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffefffffefe")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1_7\,
dataf => \GRFPC0.WR.CTRL.LD\,
datae => \GRFPC0.MEM.CTRL.CCWR\,
datad => \GRFPC0.WR.CTRL.AFSR\,
datac => \GRFPC0.MEM.CTRL.STDFQ\,
datab => \GRFPC0.WR.CTRL.STDFQ\,
dataa => \GRFPC0.CCWR_0_SQMUXA\);
\GRFPC0_D_STDLCK_RNO_3_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0f0f8f0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_12__G1_3\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_13\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datad => \GRFPC0.N_102\,
datac => \GRFPC0.D.STDLCK_0_0_12__G1_1\,
datab => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_13_1_A2_1\,
dataa => \GRFPC0.FP_PIPELINE.12.STDEP_496_SEL0_1\);
\GRFPC0_D_STDLCK_RNO_0_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffccec")
port map (
combout => \GRFPC0.D.STDLCK_0_0_4__G1_7\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_5\,
datae => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_5\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datac => \GRFPC0.N_102\,
datab => \GRFPC0.D.STDLCK_0_0_4__G1_4\,
dataa => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_5_7_2\);
\GRFPC0_D_STDLCK_RNO_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffdfffff3f1")
port map (
combout => \GRFPC0.D.STDLCK_0_0_9__G1\,
dataf => N_82245,
datae => \GRFPC0.N_528\,
datad => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datac => \GRFPC0.D.STDLCK_0_0_9__G1_1\,
datab => \GRFPC0.N_449\,
dataa => \GRFPC0.N_106_I\);
\GRFPC0_D_STDLCK_RNO_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc8c8c8")
port map (
combout => \GRFPC0.D.STDLCK_0_0_11__G1\,
dataf => \GRFPC0.D.STDLCK_0_0_11__G1_5\,
datae => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A2_0_0\,
datad => \GRFPC0.N_16_I\,
datac => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datab => \GRFPC0.N_9484\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP\);
\GRFPC0_D_STDLCK_RNO_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0080")
port map (
combout => \GRFPC0.D.STDLCK_0_0_3__G1_7\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_6\,
datae => \GRFPC0.D.STDLCK_0_0_3__G1_5\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datac => \GRFPC0.N_102\,
datab => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_6_7_1\,
dataa => \GRFPC0.FP_PIPELINE.3.STDEP_136_SEL0_1\);
\GRFPC0_D_STLCK_RNO_0_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffe2ff33ff22")
port map (
combout => \GRFPC0.D.STLCK_0_0_2__G1_5\,
dataf => \GRFPC0.N_22118\,
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datad => \GRFPC0.D.STLCK_0_0_2__G1_3\,
datac => \GRFPC0.FP_PIPELINE.0.STDEP_82_0_IV_I_A3_2_0\(0),
datab => \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL0\,
dataa => \GRFPC0.N_106_I\);
\GRFPC0_D_STLCK_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff0d")
port map (
combout => \GRFPC0.D.STLCK_0_0_0__G1_3\,
dataf => \GRFPC0.N_22982\,
datae => \GRFPC0.N_22983\,
datad => \GRFPC0.D.STLCK_0_0_0__G1_0\,
datac => \GRFPC0.N_22960\,
datab => \GRFPC0.N_106_I\,
dataa => N_241);
\GRFPC0_D_STDLCK_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcfff8")
port map (
combout => \GRFPC0.D.STDLCK_0_0_0__G1\,
dataf => \GRFPC0.N_21393\,
datae => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datad => \GRFPC0.N_21391\,
datac => \GRFPC0.D.STDLCK_0_0_0__G1_3\,
datab => \GRFPC0.N_9453\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP\);
\GRFPC0_D_STLCK_RNO_2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffdfdfdffcccccc")
port map (
combout => \GRFPC0.D.STLCK_0_0_4__G1_1\,
dataf => \GRFPC0.N_21521\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(0),
datad => \GRFPC0.N_21515\,
datac => \GRFPC0.N_106_I\,
datab => \GRFPC0.N_21474\,
dataa => N_241);
\GRFPC0_D_LDLCK_RNO_2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff444fffff000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_4__G1_1\,
dataf => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A5_1_0\(4),
datae => \GRFPC0.N_22742\,
datad => \GRFPC0.N_23184_2\,
datac => \GRFPC0.N_22740_1\,
datab => N_94,
dataa => N_93);
\GRFPU0_GRFPU_X0_COMB_EXPADDSUB_EXPT_1_A4_2_RNI5UVV3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff1000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EMINM1_0_0_G0_I_A4_1\,
dataf => \GRFPU0.GRFPU_X0.ST2.EMINM1_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.N_18275\,
datad => \GRFPU0.GRFPU_X0.N_28\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"b8f0bbffb8f08800")
port map (
combout => N_82235,
dataf => N_67751,
datae => N_67750,
datad => \GRFPU0.GRFPU_X0.REST_2\(5),
datac => \GRFPU0.GRFPU_X0.COMB.CCV_8_0_1\(0),
datab => \GRFPU0.GRFPU_X0.N_5250\,
dataa => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(0));
\GRFPU0_GRFPU_X0_COMB_RMND_7_I_M3_RNICTN83_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00cc00080000")
port map (
combout => \GRFPU0.GRFPU_X0.G_16_0_O2_0\,
dataf => \GRFPU0.GRFPU_X0.G_16_0_A2_0\,
datae => \GRFPU0.GRFPU_X0.N_9344\,
datad => \GRFPU0.GRFPU_X0.N_13387\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ITER.LOB\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(9));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A2_1_0_0_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1fff00001fff1fff")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A2_1_0_0\(13),
dataf => \GRFPC0.N_22468_1\,
datae => N_97,
datad => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2191_REGDEPX_1\,
datac => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2191_REGDEPX_0\,
datab => N_78,
dataa => N_84);
\GRFPC0_D_STLCK_RNO_5_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f100")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_A2_0_3\(1),
dataf => \GRFPC0.N_747\,
datae => \GRFPC0.N_735\,
datad => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_A2_0_0\(1),
datac => \GRFPC0.N_502\,
datab => \GRFPC0.N_579\,
dataa => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_STDATA_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffeefefe11001010")
port map (
combout => CPO_DATAZ(13),
dataf => \GRFPC0.N_17570\,
datae => \GRFPC0.FP_PIPELINE.UN1_CPI_2\,
datad => \GRFPC0.EX.RREG.RES\(13),
datac => \GRFPC0.EX.RREG.RES\(45),
datab => \GRFPC0.EX.CTRL.AFSR\,
dataa => \GRFPC0.EX.CTRL.STDFQ\);
GRFPC0_RFA2_RS1DEP_RNO_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffb700ed00")
port map (
combout => \GRFPC0.RFA2.RS1DEP_0_0_G1_4749_0\,
dataf => N_61113_TZ,
datae => \GRFPC0.N_23599_I_0\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEP30\,
datac => \GRFPC0.N_22829\,
datab => \GRFPC0.WR2.CTRL.RDD\,
dataa => \GRFPC0.WR2.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff04ff04ff04")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_92\(1),
dataf => \GRFPC0.N_742_1\,
datae => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_A2_1\(1),
datad => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datab => \GRFPC0.N_102\,
dataa => \GRFPC0.N_21438\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_0_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0fffffff2")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_2\(0),
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_I_A4_1\(0),
datae => \GRFPC0.N_24084\,
datad => \GRFPC0.N_24085\,
datac => \GRFPC0.N_24083\,
datab => \GRFPC0.WR2.RREG.RESV\,
dataa => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_9_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff2fff0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_9_2\(0),
dataf => \GRFPC0.N_24141\,
datae => \GRFPC0.N_24066\,
datad => \GRFPC0.N_24143\,
datac => \GRFPC0.N_24080\,
datab => \GRFPC0.WR2.RREG.RESV\,
dataa => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff000d")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_0_1\(0),
dataf => \GRFPC0.N_25399\,
datae => \GRFPC0.N_25401\,
datad => \GRFPC0.N_25383\,
datac => \GRFPC0.N_25535\,
datab => \GRFPC0.N_579\,
dataa => \GRFPC0.MEM.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_168_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffdccf500")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_168\(0),
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165\(0),
datae => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_7\(0),
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2535_REGDEPX2\,
datac => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.WR.CTRL.RS1V\,
dataa => \GRFPC0.WR.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_I_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffa2")
port map (
combout => \GRFPC0.N_40\,
dataf => \GRFPC0.N_22757\,
datae => \GRFPC0.N_22758\,
datad => \GRFPC0.N_21477\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datab => \GRFPC0.N_102\,
dataa => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_I_0_A5_1_0\(0));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_140_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"2222222222222220")
port map (
combout => \GRFPC0.N_24140\,
dataf => \GRFPC0.N_24143\,
datae => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_16\(0),
datad => \GRFPC0.N_24170\,
datac => \GRFPC0.N_24142\,
datab => \GRFPC0.WR.RREG.RESV\,
dataa => \GRFPC0.WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_15_REGDEPX2_475_0_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffe0e0ffe0")
port map (
combout => \GRFPC0.N_25781\,
dataf => \GRFPC0.N_25848\,
datae => \GRFPC0.N_705\,
datad => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_0_A2_5_0\(0),
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6945_REGDEPX2\,
datab => \GRFPC0.WR.CTRL.RDD\,
dataa => \GRFPC0.WR.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_445_RNO_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffe0")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_2\(1),
dataf => N_2_6,
datae => N_1_4,
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_1_N_12\,
datac => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_A2_0\(1),
datab => \GRFPC0.WR.CTRL.RDD\,
dataa => \GRFPC0.WR.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffe000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_2\(1),
dataf => \GRFPC0.N_25433\,
datae => \GRFPC0.N_25432\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_0_A3_0_1\(1),
datab => \GRFPC0.WR.CTRL.RDD\,
dataa => \GRFPC0.WR.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_175_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff20")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175\(1),
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160\(1),
datae => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_0_5\(1),
datad => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_0_4\(1),
datac => \GRFPC0.N_25632\,
datab => \GRFPC0.WR2.CTRL.INST\(2),
dataa => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_9_REGDEPX_179_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffdf0df0fdd00")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX_179\(0),
dataf => \GRFPC0.FP_PIPELINE.9.REGDEPX_177\(0),
datae => \GRFPC0.FP_PIPELINE.9.REGDEPX_176\(0),
datad => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3127_REGDEPX\,
datac => \GRFPC0.N_21627\,
datab => N_84,
dataa => N_78);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff2fffdfff0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60\(0),
dataf => \GRFPC0.FP_PIPELINE.1.REGDEPX2_49\(0),
datae => \GRFPC0.FP_PIPELINE.1.REGDEPX2_45\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_3\(0),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_2\(0),
datab => \GRFPC0.WR.RREG.RESV\,
dataa => \GRFPC0.WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_160_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff22222000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160\(0),
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_155\(0),
datae => \GRFPC0.FP_PIPELINE.5.REGDEPX2_159_0\(0),
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2459_REGDEPX2\,
datac => \GRFPC0.N_25162_1\,
datab => \GRFPC0.EX.RREG.RESV\,
dataa => \GRFPC0.EX.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff2220")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_1\(0),
dataf => \GRFPC0.N_24760\,
datae => \GRFPC0.N_25509\,
datad => \GRFPC0.N_25518\,
datac => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_O2_0\(0),
datab => \GRFPC0.MEM.RREG.RESV\,
dataa => \GRFPC0.MEM.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_375_0_A3_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"2222222222222220")
port map (
combout => \GRFPC0.N_25403\,
dataf => \GRFPC0.N_25409\,
datae => \GRFPC0.N_25410\,
datad => \GRFPC0.N_25407\,
datac => \GRFPC0.N_25442\,
datab => \GRFPC0.MEM.RREG.RESV\,
dataa => \GRFPC0.MEM.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_140_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff2fffdfff0")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135\(1),
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX2_128\(1),
datae => \GRFPC0.FP_PIPELINE.4.REGDEPX2_125\(1),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_1\(1),
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_0\(1),
datab => \GRFPC0.EX.RREG.RESV\,
dataa => \GRFPC0.EX.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffefff0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_4\(1),
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140\(1),
datae => \GRFPC0.N_25791\,
datad => \GRFPC0.N_25802\,
datac => \GRFPC0.N_25803\,
datab => \GRFPC0.DIV.EXEC\,
dataa => \GRFPC0.DIV.VALID\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_25_0_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff2f0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_25_0_2\(1),
dataf => \GRFPC0.N_25805\,
datae => \GRFPC0.N_25253\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_25_0_A2_0\(1),
datac => \GRFPC0.N_25806\,
datab => \GRFPC0.WR2.RREG.RESV\,
dataa => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_25_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff2220")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_25\(1),
dataf => \GRFPC0.N_25223\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_25_0_2\(1),
datad => \GRFPC0.N_25294\,
datac => \GRFPC0.N_25293\,
datab => \GRFPC0.WR.RREG.RESV\,
dataa => \GRFPC0.WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_8_REGDEPX_156_0_A2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffe000000000")
port map (
combout => \GRFPC0.N_22305\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22311\,
datad => \GRFPC0.N_22313\,
datac => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2607_REGDEPX\,
datab => \GRFPC0.FIFO.INST_0\(6),
dataa => \GRFPC0.FIFO.INST_0\(0));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff4f0")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_5\(1),
dataf => \GRFPC0.N_24504\,
datae => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_1\(1),
datad => \GRFPC0.N_25444_1\,
datac => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_2\(1),
datab => \GRFPC0.MEM.CTRL.INST\(18),
dataa => \GRFPC0.MEM.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffefffffff0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_3\(1),
dataf => \GRFPC0.N_24937\,
datae => \GRFPC0.N_24975\,
datad => \GRFPC0.N_24974\,
datac => \GRFPC0.N_24976\,
datab => \GRFPC0.DIV.EXEC\,
dataa => \GRFPC0.DIV.VALID\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff222f000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_4\(0),
dataf => \GRFPC0.N_25598\,
datae => \GRFPC0.N_24735\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datac => \GRFPC0.N_24736\,
datab => \GRFPC0.MEM.RREG.RESV\,
dataa => \GRFPC0.MEM.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff2220")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_2\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_2_0\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_2_1\(0),
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_7\(0),
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_5\(0),
datab => \GRFPC0.WR2.RREG.RESV\,
dataa => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_255_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff20")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_255\(1),
dataf => \GRFPC0.N_25255\,
datae => \GRFPC0.FP_PIPELINE.8.REGDEPX2_255_0_1\(1),
datad => \GRFPC0.N_25257\,
datac => \GRFPC0.FP_PIPELINE.8.REGDEPX2_250_0_O2_0\(1),
datab => \GRFPC0.EX.RREG.RESV\,
dataa => \GRFPC0.EX.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff20ff20ff20")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_1\(1),
dataf => \GRFPC0.N_23994_1\,
datae => \GRFPC0.FP_PIPELINE.9.REGDEPX2_275_0_A2_0_0\(1),
datad => \GRFPC0.N_25250\,
datac => \GRFPC0.N_25237\,
datab => \GRFPC0.MEM.RREG.RESV\,
dataa => \GRFPC0.MEM.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff2220")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295\(1),
dataf => \GRFPC0.N_25228\,
datae => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_1\(1),
datad => \GRFPC0.N_25296\,
datac => \GRFPC0.N_25295\,
datab => \GRFPC0.WR.RREG.RESV\,
dataa => \GRFPC0.WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffe0")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_2\(1),
dataf => \GRFPC0.N_24167\,
datae => \GRFPC0.N_24166\,
datad => \GRFPC0.N_25153\,
datac => \GRFPC0.N_25154_1\,
datab => \GRFPC0.N_106_I\,
dataa => \GRFPC0.EX.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_100_I_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ddfdddfdddfd")
port map (
combout => \GRFPC0.N_27\,
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.3.REGDEPX2_94\(0),
datad => \GRFPC0.N_24307\,
datac => \GRFPC0.FP_PIPELINE.3.REGDEPX2_100_I_A4_1_0\(0),
datab => \GRFPC0.EX.RREG.RESV\,
dataa => \GRFPC0.EX.CTRL.DIV\);
GRFPC0_RFA_WRITE_RD_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcc9cee9c")
port map (
combout => N_108843,
dataf => N_108686,
datae => \GRFPC0.N_23783\,
datad => \GRFPC0.N_23631\,
datac => \GRFPC0.INST\(12),
datab => \GRFPC0.INST\(9),
dataa => \GRFPC0.INST\(7));
GRFPC0_RFA_WRITE_RD_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000030")
port map (
combout => \GRFPC0.RFA.WRITE_RD_0_0_G1\,
dataf => N_108843,
datae => \GRFPC0.N_23636\,
datad => \GRFPC0.N_95\,
datac => \GRFPC0.RFA.WRITE_RD_0_0_I1_I_1\,
datab => \GRFPC0.INST\(19));
\GRFPU0_GRFPU_X0_ST2_FLOP_RNIQGR11_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00f00000000000")
port map (
combout => N_108842,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(0));
\GRFPU0_GRFPU_X0_ST2_FLOP_RNIMH3K2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_5\,
dataf => N_108842,
datae => N_108679,
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(4));
GRFPU0_GRFPU_X0_SGNF_0_SQMUXA_57_I_A2_28_REST_S: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000001")
port map (
combout => N_108841,
dataf => \FPI.OP1\(6),
datae => \FPI.OP1\(7),
datad => \FPI.OP1\(2),
datac => \FPI.OP1\(3),
datab => \FPI.OP1\(4),
dataa => \FPI.OP1\(5));
GRFPU0_GRFPU_X0_SGNF_0_SQMUXA_57_I_A2_28_REST_REST: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_28\,
dataf => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_24\,
datae => N_108841,
datad => \FPI.OP1\(1),
datac => \FPI.OP1\(0));
GRFPU0_GRFPU_X0_SGNF_0_SQMUXA_57_I_A2_REST_S: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => N_108840,
dataf => \FPI.OP1\(17),
datae => \FPI.OP1\(16),
datad => \FPI.OP1\(19),
datac => \FPI.OP1\(18),
datab => \FPI.OP1\(12),
dataa => \FPI.OP1\(13));
GRFPU0_GRFPU_X0_SGNF_0_SQMUXA_57_I_A2_REST_REST: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18831\,
dataf => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_28\,
datae => N_108694,
datad => N_108840,
datac => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_20\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_RNIU2PG2_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000088ffa0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(49),
dataf => N_108650,
datae => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datad => N_108832,
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(12),
datab => \GRFPU0.GRFPU_X0.N_15755\,
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNISRVV_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => N_108832,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(49),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datad => \GRFPU0.GRFPU_X0.N_18527\,
datac => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff000a000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(42),
dataf => N_108830,
datae => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datad => N_108652,
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(5),
dataa => \GRFPU0.GRFPU_X0.N_15748\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_RNI33A92_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000088ffa0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(45),
dataf => N_108654,
datae => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datad => N_108828,
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(8),
datab => \GRFPU0.GRFPU_X0.N_15751\,
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNIOBVV_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => N_108828,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(45),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datad => \GRFPU0.GRFPU_X0.N_18527\,
datac => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff000a000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(47),
dataf => N_108826,
datae => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datad => N_108648,
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(10),
dataa => \GRFPU0.GRFPU_X0.N_15753\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffbbfbfb")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(50),
dataf => N_108824,
datae => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datad => N_93236,
datac => N_93235,
datab => N_93110,
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fbfbffbb")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(40),
dataf => N_108822,
datae => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datad => N_93231,
datac => N_93232,
datab => N_93110,
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_A2_3_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000010000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18948\,
dataf => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_2_16\(4),
datae => \FPI.OP2\(51),
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_2_12\(4),
datac => \FPI.OP2\(38),
datab => \FPI.OP2\(49),
dataa => \FPI.OP2\(50));
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_A2_4_S_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"efffffffffffffff")
port map (
combout => N_108695,
dataf => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_4_17\(4),
datae => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_4_16\(4),
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_4_19\(4),
datac => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_4_18\(4),
datab => \FPI.OP2\(10),
dataa => \FPI.OP2\(11));
GRFPU0_GRFPU_X0_SGNF_0_SQMUXA_57_I_A2_S: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => N_108694,
dataf => \FPI.OP1\(21),
datae => \FPI.OP1\(20),
datad => \FPI.OP1\(23),
datac => \FPI.OP1\(22),
datab => \FPI.OP1\(14),
dataa => \FPI.OP1\(15));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_380_0_A2_0_RNIN60U_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff0f")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_1\(24),
dataf => \GRFPC0.N_25673\,
datae => \GRFPC0.N_25753\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_1_6\(24),
datac => N_108693);
GRFPU0_GRFPU_X0_COMB_VST1_V2_1_A3_S: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffbfffffda9ff8ff")
port map (
combout => N_108692,
dataf => \FPI.FLOP\(1),
datae => \FPI.FLOP\(6),
datad => \FPI.FLOP\(0),
datac => \FPI.FLOP\(7),
datab => \FPI.FLOP\(2),
dataa => \FPI.FLOP\(3));
GRFPU0_GRFPU_X0_COMB_VST1_V2_1_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_17542\,
dataf => N_108692,
datae => \FPI.FLOP\(5),
datad => \FPI.FLOP\(4),
datac => \FPI.FLOP\(8));
GRFPU0_GRFPU_X0_ST3_EMAX_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0180000001010000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1\,
dataf => \GRFPU0.GRFPU_X0.N_19694\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1_7\,
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(59),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(61));
GRFPU0_GRFPU_X0_COMB_UN63_BLSB_S: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcfffff0fffc")
port map (
combout => N_108691,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datae => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datad => \GRFPU0.GRFPU_X0.ITER.BMLSB\(0),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(7),
datab => \GRFPU0.GRFPU_X0.ITER.BMLSB\(1));
GRFPU0_GRFPU_X0_ITER_LOB_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000ff00ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_6151\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN55_BLSBLT5\,
datae => \GRFPU0.GRFPU_X0.L3_0\(5),
datad => N_108691);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_28: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"01030147010389cf")
port map (
combout => N_108690,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M46_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_20\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(33),
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(32),
datad => N_108690,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(28));
GRFPU0_GRFPU_X0_UN8_C_CARRY_0_RNIAM661: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffeeff11ff00f")
port map (
combout => N_108689,
dataf => \GRFPU0.GRFPU_X0.N_17\,
datae => \GRFPU0.GRFPU_X0.N_19\,
datad => \GRFPU0.GRFPU_X0.UN8_C\(1),
datac => \GRFPU0.GRFPU_X0.UN8_C\(0),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
\GRFPU0_GRFPU_X0_COMB_EXPADDSUB_EXPT_1_O2_2_RNIOP082_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => N_60909,
dataf => N_108689,
datae => \GRFPU0.GRFPU_X0.N_16\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\,
datac => \GRFPU0.GRFPU_X0.UN8_C\(10));
GRFPU0_GRFPU_X0_VITER_DBUF_1_SQMUXA_3_I_S: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"efcffbfbffffffff")
port map (
combout => N_108688,
dataf => \GRFPU0.GRFPU_X0.ITER.V\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(14));
GRFPU0_GRFPU_X0_VITER_DBUF_1_SQMUXA_3_I_A3_1_RNI8U5E2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff000ffff")
port map (
combout => N_99907,
dataf => \GRFPU0.GRFPU_X0.N_5673_0\,
datae => N_108688,
datad => \GRFPU0.GRFPU_X0.N_147_I\,
datac => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I_A3_1\);
\GRFPC0_R_FSR_CEXC_RNO_2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1f5f3fff5f5fffff")
port map (
combout => N_108687,
dataf => \GRFPC0.V.FSR.CEXC_3_SQMUXA\,
datae => \GRFPC0.V.FSR.CEXC_2_SQMUXA\,
datad => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datac => \GRFPC0.R.FSR.TEM\(4),
datab => \GRFPC0.DIV.EXCT_0_0_4__I1_I_2\,
dataa => \GRFPC0.WR2.RREG.EXCT\(4));
\GRFPC0_R_FSR_CEXC_RNO_0_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff00ffffffff")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_4__G1_3\,
dataf => N_108687,
datae => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
datad => \GRFPC0.R.FSR.CEXC_0_0_4__G1_0\,
datac => \GRFPC0.DIV.EXCT\(4));
GRFPC0_RFA_WRITE_RD_RNO_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ecc0ec11ecffecff")
port map (
combout => N_108686,
dataf => \GRFPC0.N_72_I\,
datae => \GRFPC0.N_23631\,
datad => \GRFPC0.INST\(5),
datac => \GRFPC0.INST\(12),
datab => \GRFPC0.N_23618\,
dataa => \GRFPC0.INST\(7));
\GRFPC0_D_STDLCK_RNO_0_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f0ff00fff0")
port map (
combout => N_108685,
dataf => \GRFPC0.N_440\,
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datad => \GRFPC0.N_546\,
datac => \GRFPC0.N_106_I\);
\GRFPC0_D_STDLCK_RNO_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ffffffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_6__G1\,
dataf => N_108685,
datae => \GRFPC0.N_749\,
datad => \GRFPC0.D.STDLCK_0_0_6__G1_1\,
datac => \GRFPC0.STDDEP_0_SQMUXA_118\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_S_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff8080ffff80ff")
port map (
combout => N_108684,
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.N_24880\,
datad => \GRFPC0.N_24821\,
datac => \GRFPC0.N_22429\,
datab => \GRFPC0.N_23887\,
dataa => \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.UN735_REGDEPX_1\);
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_I_O3_S_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => N_108683,
dataf => \FPI.OP1\(59),
datae => \FPI.OP1\(60),
datad => \FPI.OP1\(61),
datac => \FPI.OP1\(57));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_I_O3_S_RNI3H8F_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18768\,
dataf => N_108683,
datae => \FPI.OP1\(55),
datad => \FPI.OP1\(56),
datac => \FPI.OP1\(58),
datab => \FPI.OP1\(62));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_A2_0_13_S_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => N_108681,
dataf => \FPI.OP1\(38),
datae => \FPI.OP1\(43),
datad => \FPI.OP1\(44),
datac => \FPI.OP1\(42));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_A2_0_13_7_RNIGIOB1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18829_13\,
dataf => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_0_13_7\(4),
datae => N_108681,
datad => \FPI.OP1\(45),
datac => \FPI.OP1\(36),
datab => \FPI.OP1\(39));
GRFPC0_WR_CTRL_PEND_RNO_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"040000000c000000")
port map (
combout => N_108680,
dataf => \GRFPC0.WR.CTRL.VCNT\(0),
datae => \GRFPC0.WR.CTRL.INST\(24),
datad => \GRFPC0.WR.CTRL.INST\(23),
datac => \GRFPC0.WR.CTRL.INST\(20),
datab => \GRFPC0.WR.CTRL.INST\(31),
dataa => N_39);
GRFPC0_WR_CTRL_PEND_RNO_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.WR.CTRL.PEND_0_0_G2_7\,
dataf => N_108680,
datae => \GRFPC0.WR.CTRL.INST\(21),
datad => \GRFPC0.WR.CTRL.INST\(30),
datac => \GRFPC0.WR.CTRL.INST\(22),
datab => \GRFPC0.DIV.EXC_MB_2_I_0\);
\GRFPU0_GRFPU_X0_ST2_FLOP_RNI88A11_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => N_108679,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datad => \GRFPU0.GRFPU_X0.ST2.RDY\,
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fff3ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(37),
dataf => N_108672,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV\(37),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \GRFPU0.GRFPU_X0.N_18527\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffffffd")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(59),
dataf => N_108670,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(59),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \GRFPU0.GRFPU_X0.N_18527\,
datab => \GRFPU0.GRFPU_X0.N_5673_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0707000702020002")
port map (
combout => N_108668,
dataf => D_N_5_2,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(55),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_57_M4_E_2\,
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPU0.DIVAPPR\(3),
dataa => \GRFPU0.GRFPU_X0.N_5673_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00fb00550051")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(53),
dataf => \GRFPU0.DIVROMI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(53),
datad => N_108666,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(53),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_57_M4_E_2\,
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0707000702020002")
port map (
combout => N_108666,
dataf => D_N_5_4,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(53),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_57_M4_E_2\,
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPU0.DIVAPPR\(1),
dataa => \GRFPU0.GRFPU_X0.N_5673_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00fb00550051")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(58),
dataf => \GRFPU0.GRFPU_X0.N_18857_I\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(58),
datad => N_108664,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(58),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_57_M4_E_2\,
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0707000704040004")
port map (
combout => N_108664,
dataf => D_N_5_1,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_57_M4_E_2\,
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPU0.GRFPU_X0.N_5673_0\,
dataa => \GRFPU0.DIVAPPR\(6));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffffff3")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(39),
dataf => N_108662,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(39),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \GRFPU0.GRFPU_X0.N_18527\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffffff3")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(46),
dataf => N_108660,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(46),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \GRFPU0.GRFPU_X0.N_18527\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fff3ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(38),
dataf => N_108658,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV\(38),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \GRFPU0.GRFPU_X0.N_18527\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fff3ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(44),
dataf => N_108656,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV\(44),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \GRFPU0.GRFPU_X0.N_18527\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ce00ff00cc00fd")
port map (
combout => N_108652,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(42),
datae => N_93119,
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \GRFPU0.GRFPU_X0.N_18527\,
datab => \GRFPU0.GRFPU_X0.N_5673_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ce00ff00cc00fd")
port map (
combout => N_108648,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(47),
datae => N_93118,
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \GRFPU0.GRFPU_X0.N_18527\,
datab => \GRFPU0.GRFPU_X0.N_5673_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0202000207070007")
port map (
combout => N_108646,
dataf => N_82240,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(56),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_57_M4_E_2\,
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPU0.DIVAPPR\(4),
dataa => \GRFPU0.GRFPU_X0.N_5673_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00fb00550051")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(57),
dataf => \GRFPU0.GRFPU_X0.N_18856_I\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(57),
datad => N_108644,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(57),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_57_M4_E_2\,
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0707000702020002")
port map (
combout => N_108644,
dataf => D_N_5_3,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(57),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_57_M4_E_2\,
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPU0.DIVAPPR\(5),
dataa => \GRFPU0.GRFPU_X0.N_5673_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0455045504550051")
port map (
combout => N_108642,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O2_1\(52),
datae => \GRFPU0.GRFPU_X0.N_18364\,
datad => D_N_6_1,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(52),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_52_M3_0_A2_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNO_0_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000f00000f0f0")
port map (
combout => N_108636,
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(10),
datad => \GRFPU0.GRFPU_X0.N_15753\,
datac => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNO_0_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff0fff0f0fffff")
port map (
combout => N_108634,
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(12),
datad => \GRFPU0.GRFPU_X0.N_15755\,
datac => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNO_0_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff0fff0f0fffff")
port map (
combout => N_108632,
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(8),
datad => \GRFPU0.GRFPU_X0.N_15751\,
datac => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNO_0_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000f00000f0f0")
port map (
combout => N_108630,
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(5),
datad => \GRFPU0.GRFPU_X0.N_15748\,
datac => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_S_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0c0c0c0f0c")
port map (
combout => N_93189,
dataf => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB\(2),
datae => N_93108,
datad => N_93109,
datac => N_108618,
datab => \GRFPU0.GRFPU_X0.COMB.LOB2_I_M_1_I_0_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_S_SUB_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff8")
port map (
combout => N_108618,
dataf => \GRFPU0.GRFPU_X0.RNDOP_14\(0),
datae => \GRFPU0.GRFPU_X0.N_11529\,
datad => \GRFPU0.GRFPU_X0.N_18572\,
datac => \GRFPU0.GRFPU_X0.N_18570\,
datab => \GRFPU0.GRFPU_X0.COMB.RMND_13\(0),
dataa => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_A2_1_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_2_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_177\,
dataf => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB\(2),
datae => N_108608,
datad => N_93108,
datac => \GRFPU0.GRFPU_X0.RNDOP_14\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_2_SUB_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"77f777f777ff77f7")
port map (
combout => N_108608,
dataf => N_93108,
datae => N_93109,
datad => \GRFPU0.GRFPU_X0.RNDOP_14\(0),
datac => \GRFPU0.GRFPU_X0.COMB.LOB2_I_M_1_I_0_0\,
datab => \GRFPU0.GRFPU_X0.N_18307\,
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_6_0_5_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff5400ffff0400")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6_0_5\(43),
dataf => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB\(2),
datae => N_108606,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6_0_4\(43),
datac => N_93108,
datab => N_93109,
dataa => \GRFPU0.GRFPU_X0.RNDOP_14\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_6_0_5_SUB_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccffff00000000")
port map (
combout => N_108606,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6_0_4\(43),
datae => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP_0_0\,
datad => \GRFPU0.MULO.MRES\(120),
datac => \GRFPU0.MULO.DRES_1\(103),
datab => \GRFPU0.MULO.DRES_1S\(102));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_O2_1_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O2_1\(52),
dataf => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB\(2),
datae => N_108604,
datad => N_93108,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O2_0\(52),
datab => \GRFPU0.GRFPU_X0.RNDOP_14\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_O2_1_SUB_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"050f050f070f050f")
port map (
combout => N_108604,
dataf => N_93108,
datae => N_93109,
datad => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP_0_0\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O2_0\(52),
datab => \GRFPU0.GRFPU_X0.RNDOP_14\(0),
dataa => \GRFPU0.GRFPU_X0.N_18315\);
\GRFPC0_RFA_RS1_RNI0DFDR_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0cfc00f00fff0")
port map (
combout => \GRFPC0.FP_PIPELINE.RS1_6\(1),
dataf => \GRFPC0.FP_PIPELINE.VRFA.ST_1\,
datae => N_108596,
datad => \GRFPC0.RFA.RS1\(1),
datac => N_37,
datab => N_104);
\GRFPC0_RFA_RS1_RNINV64L_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0cfc00f00fff0")
port map (
combout => \GRFPC0.N_23714\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.ST_1\,
datae => N_108594,
datad => \GRFPC0.RFA.RS1\(2),
datac => N_37,
datab => N_105);
\GRFPC0_FP_PIPELINE_RS1_6_I_M2_2_RNIQRN7_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000ffffff")
port map (
combout => N_108594,
dataf => \GRFPC0.N_23705\,
datae => \GRFPC0.N_23706\,
datad => \GRFPC0.N_23766\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cf00ff00")
port map (
combout => \GRFPC0.DIVI_0_SQMUXA\,
dataf => N_108572,
datae => \GRFPC0.FPEXC_0_SQMUXA_D\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => N_44718_1);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_2_SUB_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"9fff99ff99ff99ff")
port map (
combout => N_108572,
dataf => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_9_5\(0),
datac => N_44718_1,
datab => \FPI.FLOP\(1),
dataa => \FPI.FLOP\(0));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_15_I_M2_RNID1OP3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00fc00cf0000")
port map (
combout => \GRFPC0.N_21108\,
dataf => \GRFPC0.N_22358\,
datae => \GRFPC0.N_206\,
datad => N_108536,
datac => N_103,
datab => N_98);
\GRFPC0_R_STATE_RNIJ9KJ2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3cff")
port map (
combout => N_108536,
dataf => \GRFPC0.R.STATE\(0),
datae => \GRFPC0.R.STATE\(1),
datad => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_642_0_A2_1\,
datac => N_97,
datab => N_98);
GRFPC0_FP_PIPELINE_FPRDY_1_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000003")
port map (
combout => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_3\,
datae => N_108530,
datad => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_0\,
datac => \GRFPC0.WR2.RREG.RESV\,
datab => \GRFPC0.R.STATE\(0));
GRFPC0_FP_PIPELINE_FPRDY_1_1_SUB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff7bdeffff")
port map (
combout => N_108530,
dataf => \GRFPC0.R.STATE\(1),
datae => \GRFPC0.FPR.RDY\,
datad => \GRFPC0.FPR.ID\(1),
datac => \GRFPC0.FPR.ID\(3),
datab => \GRFPC0.WR2.CTRL.ID\(1),
dataa => \GRFPC0.WR2.CTRL.ID\(3));
GRFPC0_FP_PIPELINE_UN205_HOLDN_X: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => N_108519,
dataf => \GRFPC0.N_21965\,
datae => \GRFPC0.N_21108\,
datad => \GRFPC0.FP_PIPELINE.UN205_HOLDN_0\,
datac => N_112,
datab => N_113);
GRFPC0_FP_PIPELINE_VRFA_ST_1_U_1_RNIMNQP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffffffffffffff")
port map (
combout => N_108517,
dataf => N_99,
datae => \GRFPC0.FP_PIPELINE.VRFA.ST_1_1\,
datad => N_102);
\GRFPC0_DIV_EXCT_0_0_0__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eeeeeeeeeeeeeeef")
port map (
combout => \FPO.EXC\(0),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datac => \GRFPU0.GRFPU_X0.ST4.RDY\,
datab => \GRFPU0.GRFPU_X0.ST4.DEFERNX\,
dataa => \GRFPU0.GRFPU_X0.ST4.EXC\(0));
GRFPC0_FP_PIPELINE_FPUSTART_7_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000004050504")
port map (
combout => \FPI.START_2\,
dataf => \GRFPC0.FP_PIPELINE.UN6_FIFOV\,
datae => \GRFPC0.FIFO.WR\(0),
datad => \GRFPC0.FIFO.RD_2\(0),
datac => \GRFPC0.R.STATE\(0),
datab => \GRFPC0.FIFO.FULL\,
dataa => \GRFPC0.R.STATE\(1));
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_13_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"a0a0a0a0a0a0a080")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\(1),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datac => \GRFPC0.R.FSR.TEM\(1),
datab => \GRFPU0.GRFPU_X0.ST4.RDY\,
dataa => \GRFPC0.DIV.EXCT_0_0_1__I1_I_3\);
\GRFPC0_D_STDLCK_RNO_3_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000800")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_10_7\,
dataf => \GRFPC0.N_104\,
datae => \GRFPC0.N_23088\,
datad => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4976_DEP\,
datac => \GRFPC0.FP_PIPELINE.STDDEP_1_4\,
datab => \GRFPC0.N_579\,
dataa => \GRFPC0.MEM.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_200_0_A2_5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff080000000000")
port map (
combout => \GRFPC0.N_24174\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.N_24171\,
datad => \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_0_A2_8_0\(0),
datac => \GRFPC0.EX.CTRL.INST\(15),
datab => \GRFPC0.EX.CTRL.INST\(17),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(0));
GRFPU0_GRFPU_X0_COMB_UN1_EXPCC_2_0_A2_3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_EXPCC_2_0_A2_3\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_EXPCC_2_0_A2_1\,
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(9),
datad => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(4),
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(2),
dataa => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(1));
\GRFPU0_GRFPU_X0_L1_2_1_5_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"330033ff220022f0")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_5\(0),
dataf => \GRFPU0.GRFPU_X0.L1_2_1_5_A4_0_0\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(25));
\GRFPU0_GRFPU_X0_BCO_MSB_3_5_0_TZ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f4f4f4f4ffff00ff")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_5_TZ\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(59),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(29),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(31),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(30));
GRFPC0_FP_PIPELINE_V_STDATA_1_M6S2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
dataf => \GRFPC0.DIV.PEND\,
datae => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.WR2.EXC\,
datac => \GRFPC0.WR.CTRL.PEND\,
datab => \GRFPC0.WR2.CTRL.PEND\);
\GRFPU0_GRFPU_X0_L1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff003300ff0030")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_1_2\(0),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(32),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(31));
\GRFPU0_GRFPU_X0_L2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0eef0ee")
port map (
combout => N_82199,
dataf => \GRFPU0.GRFPU_X0.L1_0_2\(3),
datae => N_82172,
datad => \GRFPU0.GRFPU_X0.UN73_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.N_14045\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(29));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNIQ0H91_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000f00")
port map (
combout => \GRFPU0.GRFPU_X0.N_3516\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(7));
\GRFPU0_GRFPU_X0_L1_3_1_5_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0505f5f50404f404")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_1_5\(0),
dataf => \GRFPU0.GRFPU_X0.L1_3_1_5_A4_0_0\(0),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(7),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(6),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(38),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(39));
\GRFPU0_GRFPU_X0_BCO_MSB_2_6_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"333300ff222200f0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_6\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_2_6_0_A4_0_0\(0),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(49),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(20),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(21));
\GRFPU0_GRFPU_X0_BCO_MSB_2_5_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"333300ff222200f0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_5\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_2_5_0_A4_0_0\(0),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(21));
\GRFPU0_GRFPU_X0_L1_3_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"44544454445f4450")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_2\(0),
dataf => \GRFPU0.GRFPU_X0.N_14255_1\,
datae => \GRFPU0.GRFPU_X0.BCO_MSB_4_1\(0),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(26),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(27),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(25),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(24));
\GRFPC0_FP_PIPELINE_9_1_REGDEPX_172_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff80000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.1.REGDEPX_172\(1),
dataf => \GRFPC0.FP_PIPELINE.9.1.REGDEPX_170\(1),
datae => \GRFPC0.N_21626\,
datad => \GRFPC0.N_22243\,
datac => \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.UN3008_REGDEPX_2\,
datab => \GRFPC0.FIFO.INST_1\(18),
dataa => \GRFPC0.FIFO.INST_1\(15));
\GRFPC0_D_STDLCK_RNO_6_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000200000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_6_3\,
dataf => \GRFPC0.FP_PIPELINE.3.STDEP_132_SEL0_1\,
datae => \GRFPC0.N_465\,
datad => \GRFPC0.WR.CTRL.RDD\,
datac => \GRFPC0.WR.CTRL.RDWR\,
datab => \GRFPC0.WR.CTRL.RD\(3),
dataa => \GRFPC0.WR.CTRL.RD\(2));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe0efffffe0e0000")
port map (
combout => N_82210,
dataf => N_82188,
datae => \GRFPU0.GRFPU_X0.L1_4\(3),
datad => \GRFPU0.GRFPU_X0.N_14065\,
datac => \GRFPU0.GRFPU_X0.UN163_BCO_LSB\(15),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(48));
\GRFPU0_GRFPU_X0_L1_3_4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eeefffffeeee0000")
port map (
combout => N_82204,
dataf => \GRFPU0.GRFPU_X0.N_13685\,
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(32));
\GRFPC0_D_STDLCK_RNO_5_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c000000cc000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_5_7_2\,
dataf => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1386_DEP\,
datae => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\,
datad => \GRFPC0.N_579\,
datac => \GRFPC0.EX.CTRL.RDWR\,
datab => \GRFPC0.MEM.CTRL.RDWR\);
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f1f0f1f0ffff0000")
port map (
combout => N_82207,
dataf => \GRFPU0.GRFPU_X0.L1_4_1\(3),
datae => N_82184,
datad => \GRFPU0.GRFPU_X0.N_14115\,
datac => \GRFPU0.GRFPU_X0.N_14205_1\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(42),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(43));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0eef0eeffff0000")
port map (
combout => N_82202,
dataf => \GRFPU0.GRFPU_X0.L1_4_2\(3),
datae => N_82180,
datad => \GRFPU0.GRFPU_X0.UN233_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.N_13945\,
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(12));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_159_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccceccc0000a000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_159_0\(0),
dataf => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2474_REGDEPX2\,
datae => \GRFPC0.EX.CTRL.INST\(29),
datad => \GRFPC0.EX.CTRL.INST\(28),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(0),
dataa => \GRFPC0.N_24325\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_290_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000800000")
port map (
combout => \GRFPC0.N_24749\,
dataf => \GRFPC0.N_702\,
datae => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN800_REGDEPX2_1\,
datad => \GRFPC0.WR.RREG.RESV\,
datac => \GRFPC0.WR.CTRL.INST\(4),
datab => \GRFPC0.WR.CTRL.INST\(1),
dataa => \GRFPC0.WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_2_STDEP_114_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffefffffffffffff")
port map (
combout => \GRFPC0.N_18150\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datae => \GRFPC0.RFA.LD\,
datad => N_173,
datac => N_174,
datab => N_176,
dataa => N_175);
\GRFPU0_GRFPU_X0_L1_1_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eeeeeeeeeeeefffe")
port map (
combout => N_82172,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(39),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(42),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(37));
\GRFPU0_GRFPU_X0_L1_4_6_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0f11ff11ff")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_6\(1),
dataf => \GRFPU0.GRFPU_X0.UN58_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(40));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffeac0ffffaa00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(15),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(15),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(15),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_4623_2\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
dataa => \GRFPU0.MULO.MRES\(75));
GRFPC0_FP_PIPELINE_VRFA_RDD_1_0_A2_0_A2_RNIDFDU1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000c000ffffc000")
port map (
combout => \GRFPC0.N_22633\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_131_I_1\,
datae => \GRFPC0.FP_PIPELINE.VRFA.RDD_1\,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1386_DEP\,
datac => \GRFPC0.N_106_I\,
datab => \GRFPC0.EX.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_13_STDEP_536_3_I_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7ffffffffffffff")
port map (
combout => \GRFPC0.N_21274\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datae => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.EX.CTRL.RD\(3),
datac => \GRFPC0.EX.CTRL.RD\(2),
datab => \GRFPC0.EX.CTRL.RD\(1),
dataa => \GRFPC0.EX.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_A2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000008000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440_A2_0\(1),
dataf => \GRFPC0.WR.RREG.RESV\,
datae => \GRFPC0.WR.CTRL.INST\(4),
datad => \GRFPC0.WR.CTRL.INST\(3),
datac => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR.CTRL.INST\(2),
dataa => \GRFPC0.WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_290_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000800000")
port map (
combout => \GRFPC0.N_24750\,
dataf => \GRFPC0.N_706\,
datae => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN771_REGDEPX2_1\,
datad => \GRFPC0.WR.RREG.RESV\,
datac => \GRFPC0.WR.CTRL.INST\(29),
datab => \GRFPC0.WR.CTRL.INST\(26),
dataa => \GRFPC0.WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfcfc0c0cfc0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(14),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(14),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(14),
datad => \GRFPC0.N_23712\,
datac => N_99867,
datab => \GRFPC0.DIV.INST\(14));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfcfc0c0cfc0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(19),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(19),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(19),
datad => \GRFPC0.N_23712\,
datac => N_99867,
datab => \GRFPC0.DIV.INST\(19));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfcfc0c0cfc0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(21),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(21),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(21),
datad => \GRFPC0.N_23712\,
datac => N_99867,
datab => \GRFPC0.DIV.INST\(21));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfcfc0c0cfc0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(23),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(23),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(23),
datad => \GRFPC0.N_23712\,
datac => N_99867,
datab => \GRFPC0.DIV.INST\(23));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfcfc0c0cfc0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(8),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(8),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(8),
datad => \GRFPC0.N_23712\,
datac => N_99867,
datab => \GRFPC0.DIV.INST\(8));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff2000002020")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_2\(1),
dataf => \GRFPC0.N_280\,
datae => \GRFPC0.N_25535\,
datad => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4664_REGDEPX2\,
datac => \GRFPC0.MEM.CTRL.INST\(4),
datab => \GRFPC0.MEM.CTRL.INST\(3),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_A4_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPC0.N_25561\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
datad => \GRFPC0.DIV.INST\(2),
datac => \GRFPC0.DIV.INST\(3),
datab => \GRFPC0.DIV.INST\(1),
dataa => \GRFPC0.DIV.INST\(4));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_250_0_O2_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccce000acccc0000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_250_0_O2_0\(1),
dataf => \GRFPC0.N_24160_1\,
datae => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3797_REGDEPX2\,
datad => \GRFPC0.EX.CTRL.INST\(27),
datac => \GRFPC0.EX.CTRL.INST\(26),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1));
GRFPU0_GRFPU_X0_C_CARRY_2_RNIOT3L2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003fff00001fff")
port map (
combout => N_60912_TZ,
dataf => \GRFPU0.GRFPU_X0.N_18220\,
datae => \GRFPU0.GRFPU_X0.C\(6),
datad => \GRFPU0.GRFPU_X0.C\(5),
datac => \GRFPU0.GRFPU_X0.C\(4),
datab => \GRFPU0.GRFPU_X0.C\(3),
dataa => \GRFPU0.GRFPU_X0.C\(2));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0100000000000000")
port map (
combout => \GRFPC0.N_25042\,
dataf => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN928_REGDEPX_2\,
datae => \GRFPC0.N_22892_1\,
datad => \GRFPC0.FP_PIPELINE.UN24_OP\,
datac => N_113,
datab => N_94,
dataa => N_93);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000aaa9aaa9")
port map (
combout => \GRFPU0.GRFPU_X0.N_81\,
dataf => \GRFPU0.GRFPU_X0.N_18408\,
datae => \GRFPU0.GRFPU_X0.C\(3),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(1),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(3));
\GRFPC0_D_LDLCK_RNO_0_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"baaaaaaaaaaaaaaa")
port map (
combout => \GRFPC0.D.LDLCK_0_0_27__G1_2\,
dataf => \GRFPC0.N_21638_1\,
datae => \GRFPC0.FIFO.INST_1\(17),
datad => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_1\(15),
datab => \GRFPC0.FIFO.INST_1\(16),
dataa => \GRFPC0.D.LDLCK_0_0_27__G1_1\);
\GRFPC0_FP_PIPELINE_15_0_REGDEPX_275_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff008080ff80")
port map (
combout => \GRFPC0.FP_PIPELINE.15.0.REGDEPX_275_0_0\(1),
dataf => \GRFPC0.N_23916\,
datae => \GRFPC0.N_23915\,
datad => \GRFPC0.N_24977_1\,
datac => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.INST_0\(16),
dataa => \GRFPC0.FIFO.INST_0\(15));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_68_IV_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"7300500073ff5fff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I\(63),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(63),
datae => \GRFPU0.GRFPU_X0.REST_2\(5),
datad => \GRFPU0.GRFPU_X0.N_3407\,
datac => \GRFPU0.GRFPU_X0.N_3413\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(63),
dataa => \GRFPU0.GRFPU_X0.N_3440\);
\GRFPC0_D_LDLCK_RNO_2_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f222f000f000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_15__G1_0\,
dataf => \GRFPC0.N_25355_2\,
datae => \GRFPC0.N_25037\,
datad => \GRFPC0.N_25793_1\,
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_25_I_I_0\(1),
datab => N_82,
dataa => N_81);
GRFPU0_GRFPU_X0_UN128_BCO_LSB_RNI9E9S1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fffe0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_2\(2),
dataf => \GRFPU0.GRFPU_X0.UN128_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.UN123_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(10),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(8),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(7),
dataa => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(9));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1450fafabefa5050")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(3),
dataf => N_32589,
datae => \FPI.OP1\(55),
datad => \FPI.OP1\(56),
datac => \FPI.OP1\(58),
datab => \FPI.OP1\(57),
dataa => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_11_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"2eee2eee2eeeeeee")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(5),
dataf => \GRFPU0.GRFPU_X0.L3_0_3\(0),
datae => \GRFPU0.GRFPU_X0.L3_0_3\(1),
datad => \GRFPU0.GRFPU_X0.L3_0_3\(2),
datac => \GRFPU0.GRFPU_X0.L2_0\(4),
datab => \GRFPU0.GRFPU_X0.N_19742\,
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(5));
GRFPC0_RFA_RDWR_RNIVU981: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5050505073507070")
port map (
combout => \GRFPC0.EX.CTRL.RDWR_0_0_G2\,
dataf => CPO_EXCZ,
datae => \FPI.START\,
datad => \GRFPC0.RFA.WRITE_RD\,
datac => \GRFPC0.RFA.RDWR\,
datab => N_39,
dataa => N_37);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"2ee22ee2e2e22ee2")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(3),
dataf => \GRFPU0.GRFPU_X0.L4_1\(0),
datae => \GRFPU0.GRFPU_X0.L4_1_I\(1),
datad => \GRFPU0.GRFPU_X0.L4_1\(2),
datac => \GRFPU0.GRFPU_X0.L4_1\(3),
datab => \GRFPU0.GRFPU_X0.N_4623_2\,
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(3));
\GRFPC0_D_STLCK_RNO_1_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000fc0000000000")
port map (
combout => \GRFPC0.N_23542\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => \GRFPC0.FP_PIPELINE.UN205_HOLDN\,
datad => \GRFPC0.N_9483\,
datac => N_103,
datab => \GRFPC0.N_22615\);
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_0_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0d0d0cfe0dff")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_332_1\(0),
dataf => \GRFPC0.N_21948_1\,
datae => \GRFPC0.N_104\,
datad => \GRFPC0.N_23808\,
datac => \GRFPC0.FP_PIPELINE.8.STDEP_332_SEL0_1\,
datab => \GRFPC0.N_579\,
dataa => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_0_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000011190000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18752_I_0_G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_18781\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \GRFPU0.GRFPU_X0.N_18772\,
datac => \FPI.OP1\(51),
datab => \FPI.OP1\(54),
dataa => \FPI.FLOP\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_A3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"2200000020000000")
port map (
combout => \GRFPC0.N_21285\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => N_106,
datad => N_107,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datab => N_105,
dataa => N_104);
GRFPU0_GRFPU_X0_SGNF_2_SQMUXA_I_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18833\,
dataf => \GRFPU0.GRFPU_X0.N_18829\,
datae => \GRFPU0.GRFPU_X0.N_18768\,
datad => \FPI.OP1\(51),
datac => \FPI.OP1\(52),
datab => \FPI.OP1\(53),
dataa => \FPI.OP1\(54));
\GRFPC0_FP_PIPELINE_13_STDEP_536_3_I_A3_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fa320000")
port map (
combout => \GRFPC0.N_21302\,
dataf => N_40688,
datae => \GRFPC0.N_21327\,
datad => \GRFPC0.N_53\,
datac => \GRFPC0.N_21241\,
datab => \GRFPC0.N_470\,
dataa => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_3_STDEP_128_3_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff3edd0c")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_128\(1),
dataf => \GRFPC0.N_644\,
datae => \GRFPC0.N_867\,
datad => \GRFPC0.STDEP_2_SQMUXA_129\,
datac => \GRFPC0.FP_PIPELINE.3.STDEP_128_SEL0_1\,
datab => \GRFPC0.WR.CTRL.RDD\,
dataa => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_RFA2_FOP_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0002000000000000")
port map (
combout => \GRFPC0.RFA2.FOP_0_0_A2_0_0__G0_3\,
dataf => \GRFPC0.RFA.WRITE_RD_0_0_I1_I_1\,
datae => \GRFPC0.N_23631\,
datad => \GRFPC0.INST\(12),
datac => \GRFPC0.INST\(9),
datab => \GRFPC0.INST\(7),
dataa => \GRFPC0.INST\(11));
\GRFPC0_FP_PIPELINE_11_0_REGDEPX_203_0_A2_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.0.REGDEPX_203_0_A4_0\(1),
dataf => \GRFPC0.FIFO.INST_0\(18),
datae => \GRFPC0.FIFO.INST_0\(17),
datad => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_FP_PIPELINE_9_REGDEPX_174_0_A2_0_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0003")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_A2_0_1\(0),
dataf => \GRFPC0.N_23923\,
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_0\(17),
datac => \GRFPC0.FIFO.INST_0\(16),
datab => \GRFPC0.FIFO.INST_0\(14));
\GRFPC0_FP_PIPELINE_9_0_REGDEPX_167_0_A2_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.9.0.REGDEPX_167_0_A2_0\(1),
dataf => \GRFPC0.FIFO.INST_0\(17),
datae => \GRFPC0.FIFO.INST_0\(16),
datad => \GRFPC0.FIFO.INST_0\(15));
\GRFPU0_GRFPU_X0_L1_0_1_4_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccffccfffff0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_13855_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(9));
\GRFPU0_GRFPU_X0_BCO_MSB_2_7_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc00fc")
port map (
combout => \GRFPU0.GRFPU_X0.N_13532_1\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(19),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(18),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(51),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(50));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(38),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(38),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(18),
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(50));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff003030ff000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(0),
dataf => \GRFPC0.N_223\,
datae => \GRFPC0.EX.CTRL.PEND\,
datad => \GRFPC0.EX.CTRL.INST\(0),
datac => N_248,
datab => N_249);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff003030ff000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(1),
dataf => \GRFPC0.N_24039\,
datae => \GRFPC0.EX.CTRL.PEND\,
datad => \GRFPC0.EX.CTRL.INST\(1),
datac => N_248,
datab => N_249);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M105_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000fc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datab => \GRFPU0.DIVROM0.RADDR\(7));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M102_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000003ff00000300")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M106_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcccfcfc0ccc0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(10),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(10),
datae => \GRFPC0.DIV.PEND\,
datad => \GRFPC0.WR2.EXC\,
datac => \GRFPC0.DIV.EXC\,
datab => \GRFPC0.DIV.INST\(10));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcccfcfc0ccc0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(24),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(24),
datae => \GRFPC0.DIV.PEND\,
datad => \GRFPC0.WR2.EXC\,
datac => \GRFPC0.DIV.EXC\,
datab => \GRFPC0.DIV.INST\(24));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M5_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcccfcfc0ccc0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(31),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M3\(31),
datae => \GRFPC0.DIV.PEND\,
datad => \GRFPC0.WR2.EXC\,
datac => \GRFPC0.DIV.EXC\,
datab => \GRFPC0.DIV.INST\(31));
GRFPC0_V_STDATA_0_SQMUXA_1_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cf00cfcfcf00cf00")
port map (
combout => N_99870,
dataf => \GRFPC0.DIV.PEND\,
datae => \GRFPC0.WR2.EXC\,
datad => \GRFPC0.DIV.EXC\,
datac => N_248,
datab => N_249);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M105_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000fc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M102_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000003ff00000300")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M106_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0));
GRFPC0_DIV_EXC_0_2_I_O4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0000000ffffffff")
port map (
combout => \GRFPC0.DIV.EXC_MB_2_I_0\,
dataf => N_35,
datae => N_425,
datad => N_424,
datac => N_423,
datab => N_459);
GRFPC0_EX_CTRL_CCWR_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000f000f0")
port map (
combout => \GRFPC0.EX.CTRL.CCWR_0_0_G1_0_1438_A2_1\,
dataf => \GRFPC0.RFA2.FOP\(0),
datae => \GRFPC0.FPR.ALLOW\(1),
datad => \GRFPC0.RFA.WRITE_RD\,
datac => N_35);
GRFPC0_FP_PIPELINE_FPUSTART_7_3_RNISC961: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcfccffffffff")
port map (
combout => \GRFPC0.EX.CTRL.RD_0_0_0__G1_0_3942_I_O4_2\,
dataf => \FPI.START_3\,
datae => N_45196_1,
datad => \GRFPC0.RFA2.FOP\(0),
datac => \GRFPC0.FPR.ALLOW\(1),
datab => N_39);
GRFPC0_FP_PIPELINE_UN24_FPUSTART: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff03030300")
port map (
combout => \GRFPC0.FP_PIPELINE.UN24_FPUSTART\,
dataf => \FPI.START\,
datae => \GRFPC0.RFA.LD\,
datad => \GRFPC0.RFA.ST\,
datac => N_179,
datab => N_180);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M0_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_2_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(20));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M83_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cf00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_2_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(51));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M84_4_03_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.OUT_1\(84),
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(52));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M84_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M84_2_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M80_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00c0000000c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_0_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(52));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M84_2_03_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M84_2_03_1\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(52));
GRFPC0_FP_PIPELINE_V_FSR_FCC_1_M2S2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fcf0cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_SM0\,
dataf => N_46992,
datae => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datad => \GRFPC0.WR2.CTRL.LD\,
datac => \GRFPC0.WR2.CTRL.CCWR\,
datab => \GRFPC0.WR2.CTRL.AFSR\);
\GRFPC0_FP_PIPELINE_V_FSR_FCC_1_M1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccfc0ccccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M1\(0),
dataf => N_46992,
datae => \GRFPC0.WR2.CTRL.LD\,
datad => \GRFPC0.WR2.RREG.RES\(10),
datac => \GRFPC0.WR2.CTRL.AFSR\,
datab => \FPO.CC\(0));
\GRFPC0_FP_PIPELINE_V_FSR_FCC_1_M1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccfc0ccccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M1\(1),
dataf => N_46992,
datae => \GRFPC0.WR2.CTRL.LD\,
datad => \GRFPC0.WR2.RREG.RES\(11),
datac => \GRFPC0.WR2.CTRL.AFSR\,
datab => \FPO.CC\(1));
GRFPC0_UN28_WREN_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffcf0ffffffff")
port map (
combout => \GRFPC0.UN28_WREN_2\,
dataf => \GRFPC0.FP_PIPELINE.UN25_HOLDN\,
datae => N_44718_1,
datad => \GRFPC0.WR2.CTRL.LD\,
datac => \GRFPC0.WR2.CTRL.CCWR\,
datab => \GRFPC0.WR2.CTRL.AFSR\);
GRFPC0_FP_PIPELINE_FIFOV2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030003300330030")
port map (
combout => \GRFPC0.FP_PIPELINE.FIFOV2\,
dataf => \GRFPC0.FIFO.WR\(0),
datae => \GRFPC0.FIFO.RD_2\(0),
datad => \GRFPC0.R.STATE\(0),
datac => \GRFPC0.FIFO.FULL\,
datab => \GRFPC0.R.STATE\(1));
\GRFPC0_EX_CTRL_ID_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffcff")
port map (
combout => N_45174_TZ,
dataf => \GRFPC0.EX.CTRL.ID_0_0_7__G1_0_1663_TZ_4\,
datae => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_1\,
datad => N_45188,
datac => \GRFPC0.R.STATE\(0),
datab => \GRFPC0.R.STATE\(1));
GRFPC0_EX_CTRL_PEND_RNO_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0c0000000000")
port map (
combout => \GRFPC0.EX.CTRL.PEND_0_0_G1_0_A3_1\,
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => \GRFPC0.R.STATE\(0),
datad => \GRFPC0.R.STATE\(1),
datac => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA\,
datab => N_35);
\GRFPC0_FIFO_VCNT_0_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => N_47071,
dataf => N_44718_1,
datae => \GRFPC0.FP_PIPELINE.0.UN78_PENDEXC\,
datad => \GRFPC0.WR2.CTRL.SEQERR\,
datac => \GRFPC0.R.STATE\(0),
datab => \GRFPC0.R.STATE\(1));
\GRFPC0_FIFO_VCNT_1_RNIGEE52_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => N_47153,
dataf => N_44718_1,
datae => \GRFPC0.WR2.CTRL.SEQERR\,
datad => \GRFPC0.R.STATE\(0),
datac => \GRFPC0.R.STATE\(1),
datab => \GRFPC0.FIFO.VCNT_1\(0));
\GRFPC0_FIFO_VCNT_1_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => N_47125,
dataf => N_44718_1,
datae => \GRFPC0.FP_PIPELINE.1.UN87_PENDEXC\,
datad => \GRFPC0.WR2.CTRL.SEQERR\,
datac => \GRFPC0.R.STATE\(0),
datab => \GRFPC0.R.STATE\(1));
\GRFPC0_R_STATE_RNIBIPV1_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => N_47098,
dataf => N_44718_1,
datae => \GRFPC0.WR2.CTRL.SEQERR\,
datad => \GRFPC0.R.STATE\(0),
datac => \GRFPC0.R.STATE\(1));
GRFPC0_FP_PIPELINE_0_0_FIFO_INST_V_TMP_IV: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030003300000030")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
dataf => \GRFPC0.FIFO.WR\(0),
datae => \GRFPC0.FIFO.RD_0\(0),
datad => \GRFPC0.R.STATE\(0),
datac => \GRFPC0.FIFO.FULL\,
datab => \GRFPC0.R.STATE\(1));
GRFPC0_FP_PIPELINE_0_1_FIFO_INST_V_TMP_IV: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000330030")
port map (
combout => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
dataf => \GRFPC0.FIFO.WR\(0),
datae => \GRFPC0.FIFO.RD_0\(0),
datad => \GRFPC0.R.STATE\(0),
datac => \GRFPC0.FIFO.FULL\,
datab => \GRFPC0.R.STATE\(1));
GRFPC0_FP_PIPELINE_VFIFO_RD10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.VFIFO.RD10\,
dataf => \GRFPC0.R.STATE\(0),
datae => \GRFPC0.R.STATE\(1),
datad => N_39);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_33_0_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfffff0ccf0")
port map (
combout => \GRFPC0.N_25221\,
dataf => \GRFPC0.FIFO.INST_0\(6),
datae => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.FIFO.RD_0\(0),
datac => \GRFPC0.FIFO.INST_0\(14),
datab => \GRFPC0.FIFO.INST_1\(14));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_I_O3_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff33ffff0f330f")
port map (
combout => \GRFPC0.N_23975\,
dataf => \GRFPC0.FIFO.INST_0\(6),
datae => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.FIFO.RD_0\(0),
datac => \GRFPC0.FIFO.INST_0\(14),
datab => \GRFPC0.FIFO.INST_1\(14));
\GRFPC0_FP_PIPELINE_12_CHECK_DEP_DEP_22_IV_0_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0ffffcccc")
port map (
combout => \GRFPC0.N_25658\,
dataf => \GRFPC0.FIFO.RD_1\(0),
datae => \GRFPC0.FIFO.INST_0\(16),
datad => \GRFPC0.FIFO.INST_1\(15),
datac => \GRFPC0.FIFO.INST_1\(16),
datab => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_425_0_A2_1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000f033330000")
port map (
combout => \GRFPC0.N_23941_1\,
dataf => \GRFPC0.FIFO.RD_1\(0),
datae => \GRFPC0.FIFO.INST_0\(16),
datad => \GRFPC0.FIFO.INST_1\(15),
datac => \GRFPC0.FIFO.INST_1\(16),
datab => \GRFPC0.FIFO.INST_0\(15));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1475_REGDEPX2_2_I_O4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff0fff3333ffff")
port map (
combout => \GRFPC0.N_24271\,
dataf => \GRFPC0.FIFO.RD_1\(0),
datae => \GRFPC0.FIFO.INST_0\(16),
datad => \GRFPC0.FIFO.INST_1\(15),
datac => \GRFPC0.FIFO.INST_1\(16),
datab => \GRFPC0.FIFO.INST_0\(15));
\GRFPU0_GRFPU_X0_ST3_FARRES_RNIBDTD2_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(28),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(30),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(31),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(29));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3680_REGDEPX2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030000cf03cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3680_REGDEPX2_0\,
dataf => \GRFPC0.FIFO.INST_1\(17),
datae => \GRFPC0.FIFO.INST_0\(18),
datad => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.RD_1\(0));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_125_0_A2_2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000ccf0cc")
port map (
combout => \GRFPC0.N_260_2\,
dataf => \GRFPC0.FIFO.INST_0\(18),
datae => \GRFPC0.FIFO.INST_1\(18),
datad => \GRFPC0.FIFO.RD_1\(0),
datac => \GRFPC0.FIFO.INST_1\(11),
datab => \GRFPC0.FIFO.INST_0\(11));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5444_REGDEPX2_2_0_0_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc30cc0030300000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6767_REGDEPX2_2\,
dataf => \GRFPC0.FIFO.INST_1\(17),
datae => \GRFPC0.FIFO.INST_0\(18),
datad => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.RD_1\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A4_1_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3f00000000")
port map (
combout => \GRFPC0.N_24657_2\,
dataf => \FPI.FLOP\(6),
datae => \GRFPC0.N_24489\,
datad => \GRFPC0.FIFO.INST_0\(18),
datac => \GRFPC0.FIFO.INST_1\(18),
datab => \GRFPC0.FIFO.RD_0\(0));
\GRFPC0_FIFO_RD_0_RNI4SSP_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.V.STDATA_14\(18),
dataf => \GRFPC0.FIFO.INST_0\(18),
datae => \GRFPC0.FIFO.INST_1\(18),
datad => \GRFPC0.FIFO.RD_0\(0));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_334_0_A2_2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_A2_3_0\(0),
dataf => \GRFPC0.FIFO.INST_0\(18),
datae => \GRFPC0.FIFO.INST_0\(17),
datad => \GRFPC0.FIFO.RD_1\(0),
datac => \GRFPC0.FIFO.INST_0\(16),
datab => \GRFPC0.FIFO.INST_0\(15));
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN5885_REGDEPX2_0_A2_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPC0.N_24551\,
dataf => \GRFPC0.FIFO.INST_0\(18),
datae => \GRFPC0.FIFO.INST_0\(17),
datad => \GRFPC0.FIFO.RD_1\(0));
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN5885_REGDEPX2_0_A2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPC0.N_24550\,
dataf => \GRFPC0.FIFO.INST_1\(17),
datae => \GRFPC0.FIFO.INST_1\(18),
datad => \GRFPC0.FIFO.RD_1\(0));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN593_REGDEPX2_1_0_A3_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0ccffccf0")
port map (
combout => \GRFPC0.N_24580\,
dataf => \GRFPC0.FIFO.INST_1\(17),
datae => \GRFPC0.FIFO.INST_0\(17),
datad => \GRFPC0.FIFO.RD_0\(0),
datac => \GRFPC0.FIFO.INST_0\(16),
datab => \GRFPC0.FIFO.INST_1\(16));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_I_A3_0_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000003cf00000000")
port map (
combout => \GRFPC0.N_23994_2\,
dataf => \GRFPC0.N_24487\,
datae => \GRFPC0.N_24488\,
datad => \GRFPC0.FIFO.INST_1\(17),
datac => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.RD_0\(0));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2357_REGDEPX2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fc3000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2357_REGDEPX2_1\,
dataf => \GRFPC0.N_24487\,
datae => \GRFPC0.N_24488\,
datad => \GRFPC0.FIFO.INST_1\(17),
datac => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.RD_1\(0));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_275_0_O3_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff33ffff0f330f")
port map (
combout => \GRFPC0.N_23980\,
dataf => \GRFPC0.FIFO.INST_0\(6),
datae => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.FIFO.RD_1\(0),
datac => \GRFPC0.FIFO.INST_0\(0),
datab => \GRFPC0.FIFO.INST_1\(0));
\GRFPC0_FIFO_INST_1_RNIEHKJ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003030000f303f")
port map (
combout => \GRFPC0.V.STDATA_14_I_M_10\(0),
dataf => \GRFPC0.FIFO.INST_0\(6),
datae => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.FIFO.INST_0\(0),
datac => \GRFPC0.FIFO.RD\(0),
datab => \GRFPC0.FIFO.INST_1\(0));
GRFPC0_OP2_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000f00000f0f")
port map (
combout => \GRFPC0.OP2_4\,
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.INST_0\(0),
datad => \GRFPC0.FIFO.INST_1\(0),
datac => \GRFPC0.RFA.RS2D\);
GRFPC0_RFA_RS2D_RNI5T1L: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f0f0000")
port map (
combout => N_99882,
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.INST_0\(0),
datad => \GRFPC0.FIFO.INST_1\(0),
datac => \GRFPC0.RFA.RS2D\);
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN6122_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6122_REGDEPX2\,
dataf => \GRFPC0.WR2.CTRL.INST\(15),
datae => \GRFPC0.WR2.CTRL.INST\(16),
datad => \GRFPC0.WR2.CTRL.INST\(18),
datac => \GRFPC0.WR2.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_10_I_A2_1_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000000f3333")
port map (
combout => \GRFPC0.N_24627_1\,
dataf => \GRFPC0.FIFO.INST_0\(1),
datae => \GRFPC0.FIFO.RD_0\(0),
datad => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.INST_1\(1),
datab => \GRFPC0.FIFO.INST_0\(4));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_334_0_A2_0_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000ccccf0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_334_0_A2_0_0_0\(1),
dataf => \GRFPC0.FIFO.INST_0\(1),
datae => \GRFPC0.FIFO.RD_1\(0),
datad => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.INST_1\(1),
datab => \GRFPC0.FIFO.INST_0\(4));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2429_REGDEPX2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0333300f00000")
port map (
combout => \GRFPC0.N_24616\,
dataf => \GRFPC0.FIFO.INST_0\(1),
datae => \GRFPC0.FIFO.RD_1\(0),
datad => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.INST_1\(1),
datab => \GRFPC0.FIFO.INST_0\(4));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN205_REGDEPX2_2_0_A2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030300ff0303")
port map (
combout => \GRFPC0.N_25450_1\,
dataf => \GRFPC0.FIFO.INST_1\(3),
datae => \GRFPC0.FIFO.RD_0\(0),
datad => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.INST_0\(3),
datab => \GRFPC0.FIFO.INST_0\(4));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5516_REGDEPX2_2_I_O2_I_A3_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff3f3fffff3f3f")
port map (
combout => \GRFPC0.N_25120\,
dataf => \GRFPC0.FIFO.INST_1\(3),
datae => \GRFPC0.FIFO.RD_1\(0),
datad => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.INST_0\(3),
datab => \GRFPC0.FIFO.INST_0\(4));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_124_0_A2_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff303000003030")
port map (
combout => \GRFPC0.N_261_1\,
dataf => \GRFPC0.FIFO.INST_1\(3),
datae => \GRFPC0.FIFO.RD_1\(0),
datad => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.INST_0\(3),
datab => \GRFPC0.FIFO.INST_0\(4));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN205_REGDEPX2_1_0_A2_0_A2_0_A2_0_A3_0_A2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03000300030003ff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_1\,
dataf => \GRFPC0.FIFO.INST_0\(2),
datae => \GRFPC0.FIFO.INST_0\(1),
datad => \GRFPC0.FIFO.RD_0\(0),
datac => \GRFPC0.FIFO.INST_1\(2),
datab => \GRFPC0.FIFO.INST_1\(1));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_334_0_A2_5_I_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcc0fccffff0fff")
port map (
combout => \GRFPC0.N_24642\,
dataf => \GRFPC0.FIFO.INST_0\(2),
datae => \GRFPC0.FIFO.INST_1\(3),
datad => \GRFPC0.FIFO.RD_1\(0),
datac => \GRFPC0.FIFO.INST_1\(2),
datab => \GRFPC0.FIFO.INST_0\(3));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN665_REGDEPX2_1_0_A3_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000330f33")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN665_REGDEPX2_1\,
dataf => \GRFPC0.FIFO.INST_0\(2),
datae => \GRFPC0.FIFO.INST_1\(3),
datad => \GRFPC0.FIFO.RD_0\(0),
datac => \GRFPC0.FIFO.INST_1\(2),
datab => \GRFPC0.FIFO.INST_0\(3));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2429_REGDEPX2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0000000fcc00cc")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2429_REGDEPX2_0\,
dataf => \GRFPC0.FIFO.INST_0\(2),
datae => \GRFPC0.FIFO.INST_1\(3),
datad => \GRFPC0.FIFO.RD_1\(0),
datac => \GRFPC0.FIFO.INST_1\(2),
datab => \GRFPC0.FIFO.INST_0\(3));
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_24_IV_I_A2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"300030ff30003000")
port map (
combout => \GRFPC0.N_24611_1\,
dataf => \GRFPC0.FIFO.INST_0\(26),
datae => \GRFPC0.FIFO.INST_0\(27),
datad => \GRFPC0.FIFO.RD_0\(0),
datac => \GRFPC0.FIFO.INST_1\(26),
datab => \GRFPC0.FIFO.INST_1\(27));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_64_0_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcfcffff0cfc0")
port map (
combout => \GRFPC0.N_24484\,
dataf => \GRFPC0.FIFO.INST_0\(6),
datae => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.FIFO.INST_0\(25),
datac => \GRFPC0.FIFO.RD_0\(0),
datab => \GRFPC0.FIFO.INST_1\(25));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_124_0_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3f3ff0ff303f")
port map (
combout => \GRFPC0.N_25649\,
dataf => \GRFPC0.FIFO.INST_0\(6),
datae => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.FIFO.INST_0\(25),
datac => \GRFPC0.FIFO.RD_1\(0),
datab => \GRFPC0.FIFO.INST_1\(25));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A2_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0000000000000")
port map (
combout => \GRFPC0.N_25613\,
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.N_25204\,
datad => \GRFPC0.FIFO.INST_0\(25),
datac => \GRFPC0.FIFO.RD_1\(0),
datab => \GRFPC0.FIFO.INST_1\(25));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_37: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8421000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_37\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_24\,
datae => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_15_I_A2_1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000003000")
port map (
combout => \GRFPC0.N_24765_1\,
dataf => \GRFPC0.N_106_I\,
datae => \GRFPC0.EX.RREG.RESV\,
datad => \GRFPC0.EX.CTRL.DIV\,
datac => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.EX.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_100_I_A2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000ff0000")
port map (
combout => \GRFPC0.N_25162_1\,
dataf => \GRFPC0.N_106_I\,
datae => \GRFPC0.EX.CTRL.RS1V\,
datad => \GRFPC0.EX.CTRL.INST\(14));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1592_REGDEPX2_0_O2_I_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.N_25197\,
dataf => \GRFPC0.EX.CTRL.INST\(3),
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_465_0_A2_7_I_O3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00fffffff0ff")
port map (
combout => \GRFPC0.N_25388\,
dataf => \GRFPC0.N_106_I\,
datae => \GRFPC0.EX.RREG.RESV\,
datad => \GRFPC0.EX.CTRL.DIV\,
datac => \GRFPC0.EX.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_11_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0003000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_11\(0),
dataf => \GRFPC0.N_25460\,
datae => \GRFPC0.N_106_I\,
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.EX.CTRL.INST\(0));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN681_REGDEPX2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN681_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(27),
datae => \GRFPC0.EX.CTRL.INST\(26),
datad => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.EX.CTRL.INST\(28));
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN3327_REGDEPX2_0_A4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3327_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(27),
datae => \GRFPC0.EX.CTRL.INST\(29),
datad => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.EX.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_325_0_A2_3_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000003000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_3_1\(0),
dataf => \GRFPC0.N_579\,
datae => \GRFPC0.MEM.CTRL.INST\(27),
datad => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(28),
datab => \GRFPC0.MEM.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_10_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_10_1\(0),
dataf => \GRFPC0.MEM.CTRL.INST\(27),
datae => \GRFPC0.MEM.CTRL.INST\(26),
datad => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_11_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_11\(0),
dataf => \GRFPC0.MEM.CTRL.INST\(27),
datae => \GRFPC0.MEM.CTRL.INST\(26),
datad => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(28),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(0));
\GRFPC0_FP_PIPELINE_3_CHECK_DEP_DEP_17_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_17\(0),
dataf => \GRFPC0.MEM.CTRL.INST\(27),
datae => \GRFPC0.MEM.CTRL.INST\(26),
datad => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(28),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(0));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_380_0_A2_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000003000")
port map (
combout => \GRFPC0.N_25676_1\,
dataf => \GRFPC0.N_579\,
datae => \GRFPC0.MEM.RREG.RESV\,
datad => \GRFPC0.MEM.CTRL.RS1V\,
datac => \GRFPC0.MEM.CTRL.DIV\,
datab => \GRFPC0.MEM.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_15_I_A2_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000f0000000000")
port map (
combout => \GRFPC0.N_25448\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN285_REGDEPX2\,
datae => \GRFPC0.N_579\,
datad => \GRFPC0.MEM.CTRL.RS1V\,
datac => \GRFPC0.MEM.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_325_0_A2_8_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000003000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_8_1\(0),
dataf => \GRFPC0.N_579\,
datae => \GRFPC0.MEM.CTRL.INST\(4),
datad => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST\(3),
datab => \GRFPC0.MEM.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_200_0_A2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00030")
port map (
combout => \GRFPC0.N_24177\,
dataf => \GRFPC0.N_25535\,
datae => \GRFPC0.N_579\,
datad => \GRFPC0.MEM.CTRL.INST\(4),
datac => \GRFPC0.MEM.CTRL.INST\(3),
datab => \GRFPC0.MEM.CTRL.INST\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15825\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(99),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(99),
datab => N_28063);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15876\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(99),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(99),
datab => N_28063);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15826\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(100),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(100),
datab => N_28065);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18620\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(100),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(100),
datab => N_28065);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_350_0_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffccfff00000")
port map (
combout => \GRFPC0.N_24280\,
dataf => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5210_REGDEPX2\,
datae => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5181_REGDEPX2\,
datad => \GRFPC0.WR.CTRL.RDD\,
datac => \GRFPC0.WR.CTRL.INST\(25),
datab => \GRFPC0.WR.CTRL.INST\(0));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN6945_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6945_REGDEPX2\,
dataf => \GRFPC0.WR.CTRL.INST\(26),
datae => \GRFPC0.WR.CTRL.INST\(29),
datad => \GRFPC0.WR.CTRL.INST\(27),
datac => \GRFPC0.WR.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_4\(1),
dataf => \GRFPC0.N_707\,
datae => \GRFPC0.WR.CTRL.INST\(26),
datad => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR.CTRL.INST\(28));
GRFPC0_FP_PIPELINE_5_0_CHECK_DEP_UN1656_REGDEPX_0_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffffffffff")
port map (
combout => \GRFPC0.N_22535\,
dataf => \GRFPC0.FIFO.INST_0\(17),
datae => \GRFPC0.FIFO.INST_0\(16),
datad => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O3_8_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3ffffffff")
port map (
combout => \GRFPC0.N_36\,
dataf => \GRFPC0.N_24921\,
datae => \GRFPC0.FIFO.INST_0\(18),
datad => \GRFPC0.FIFO.INST_0\(17),
datac => \GRFPC0.FIFO.INST_0\(16),
datab => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_45_0_A3_3_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f000")
port map (
combout => \GRFPC0.N_25406_1\,
dataf => \GRFPC0.N_579\,
datae => \GRFPC0.MEM.RREG.RESV\,
datad => \GRFPC0.MEM.CTRL.DIV\,
datac => \GRFPC0.MEM.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_465_0_A3_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f000")
port map (
combout => \GRFPC0.N_24403_1\,
dataf => \GRFPC0.N_579\,
datae => \GRFPC0.MEM.RREG.RESV\,
datad => \GRFPC0.MEM.CTRL.DIV\,
datac => \GRFPC0.MEM.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_135_A0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_A0_1\(1),
dataf => \GRFPC0.N_579\,
datae => \GRFPC0.MEM.RREG.RESV\,
datad => \GRFPC0.MEM.CTRL.DIV\,
datac => \GRFPC0.MEM.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_380_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0c0c0c0c0c00")
port map (
combout => \GRFPC0.N_25673\,
dataf => \GRFPC0.N_25753\,
datae => \GRFPC0.FP_PIPELINE.12.REGDEPX2_380_0_O2_1_1\(0),
datad => \GRFPC0.N_25680\,
datac => \GRFPC0.MEM.RREG.RESV\,
datab => \GRFPC0.MEM.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_140_0_A2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.N_24142\,
dataf => \GRFPC0.N_24194\,
datae => \GRFPC0.MEM.CTRL.INST\(26),
datad => \GRFPC0.MEM.RREG.RESV\,
datac => \GRFPC0.MEM.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(0));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_A2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPC0.N_24198\,
dataf => \GRFPC0.MEM.CTRL.INST\(1),
datae => \GRFPC0.MEM.RREG.RESV\,
datad => \GRFPC0.MEM.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_165_0_A2_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPC0.N_24199\,
dataf => \GRFPC0.MEM.CTRL.INST\(26),
datae => \GRFPC0.MEM.RREG.RESV\,
datad => \GRFPC0.MEM.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_A2_5_1_A2_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0fff")
port map (
combout => \GRFPC0.N_25535\,
dataf => \GRFPC0.MEM.CTRL.INST\(1),
datae => \GRFPC0.MEM.RREG.RESV\,
datad => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A2_1_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000c00000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_1_1\(1),
dataf => \GRFPC0.N_579\,
datae => \GRFPC0.MEM.CTRL.INST\(27),
datad => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(28),
datab => \GRFPC0.MEM.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_A2_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_A2_0_0\(1),
dataf => \GRFPC0.N_579\,
datae => \GRFPC0.MEM.CTRL.INST\(29),
datad => \GRFPC0.MEM.CTRL.INST\(28),
datac => \GRFPC0.MEM.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_105_0_A2_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f000c000")
port map (
combout => \GRFPC0.N_25717\,
dataf => \GRFPC0.N_25376\,
datae => \GRFPC0.N_579\,
datad => \GRFPC0.MEM.CTRL.INST\(27),
datac => \GRFPC0.MEM.CTRL.INST\(26),
datab => \GRFPC0.MEM.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f000c0")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_2\(1),
dataf => \GRFPC0.N_25122\,
datae => \GRFPC0.N_106_I\,
datad => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.EX.CTRL.INST\(28),
datab => \GRFPC0.EX.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_11_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cc000000c000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_11\(1),
dataf => \GRFPC0.N_106_I\,
datae => \GRFPC0.EX.CTRL.INST\(29),
datad => \GRFPC0.EX.CTRL.INST\(28),
datac => \GRFPC0.EX.CTRL.INST\(25),
datab => \GRFPC0.N_24325\);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_A2_3_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f000")
port map (
combout => \GRFPC0.N_25715_1\,
dataf => \GRFPC0.N_106_I\,
datae => \GRFPC0.EX.RREG.RESV\,
datad => \GRFPC0.EX.CTRL.DIV\,
datac => \GRFPC0.EX.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_460_I_A2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f000c000")
port map (
combout => \GRFPC0.N_24311\,
dataf => \GRFPC0.N_25122\,
datae => \GRFPC0.N_106_I\,
datad => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.EX.CTRL.INST\(28),
datab => \GRFPC0.EX.CTRL.INST\(25));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2519_REGDEPX2_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPC0.N_24193\,
dataf => \GRFPC0.MEM.CTRL.INST\(4),
datae => \GRFPC0.MEM.CTRL.INST\(2),
datad => \GRFPC0.MEM.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_380_0_A2_9_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c00000")
port map (
combout => \GRFPC0.N_25711\,
dataf => \GRFPC0.MEM.CTRL.INST\(1),
datae => \GRFPC0.MEM.CTRL.INST\(4),
datad => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST\(3),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0));
\GRFPC0_FP_PIPELINE_15_CHECK_DEP_DEP_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_1\(0),
dataf => \GRFPC0.MEM.CTRL.INST\(1),
datae => \GRFPC0.MEM.CTRL.INST\(4),
datad => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST\(3),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A2_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0000000c000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_0_1\(1),
dataf => \GRFPC0.N_579\,
datae => \GRFPC0.MEM.CTRL.INST\(4),
datad => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST\(3),
datab => \GRFPC0.MEM.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_A2_2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f000")
port map (
combout => \GRFPC0.N_25686_1\,
dataf => \GRFPC0.N_106_I\,
datae => \GRFPC0.EX.RREG.RESV\,
datad => \GRFPC0.EX.CTRL.DIV\,
datac => \GRFPC0.EX.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A2_1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.N_24168_1\,
dataf => \GRFPC0.MEM.CTRL.INST\(15),
datae => \GRFPC0.MEM.CTRL.INST\(16),
datad => \GRFPC0.MEM.CTRL.INST\(18),
datac => \GRFPC0.MEM.CTRL.INST\(17));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5591_REGDEPX2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5591_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(15),
datae => \GRFPC0.MEM.CTRL.INST\(16),
datad => \GRFPC0.MEM.CTRL.INST\(18),
datac => \GRFPC0.MEM.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_465_0_A2_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25137\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(0),
datad => \GRFPC0.FP_PIPELINE.15.REGDEPX2_465_0_A2_3_2_0\(0),
datac => \GRFPC0.MEM.CTRL.INST\(18),
datab => \GRFPC0.MEM.CTRL.INST\(17));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2504_REGDEPX2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2504_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(16),
datae => \GRFPC0.MEM.CTRL.INST\(15),
datad => \GRFPC0.MEM.CTRL.INST\(17),
datac => \GRFPC0.MEM.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN740_REGDEPX2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN740_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(16),
datae => \GRFPC0.MEM.CTRL.INST\(15),
datad => \GRFPC0.MEM.CTRL.INST\(17),
datac => \GRFPC0.MEM.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_105_0_A2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0c0000000000000")
port map (
combout => \GRFPC0.N_25693\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1622_REGDEPX2\,
datad => \GRFPC0.N_579\,
datac => \GRFPC0.MEM.CTRL.RS1V\,
datab => \GRFPC0.MEM.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_14_0_A2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff000000")
port map (
combout => \GRFPC0.N_25746\,
dataf => \GRFPC0.N_579\,
datae => \GRFPC0.MEM.CTRL.RS1V\,
datad => \GRFPC0.MEM.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_A2_1_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0000000c000")
port map (
combout => \GRFPC0.N_280\,
dataf => \GRFPC0.N_106_I\,
datae => \GRFPC0.EX.RREG.RESV\,
datad => \GRFPC0.EX.CTRL.DIV\,
datac => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.EX.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000c000000000")
port map (
combout => \GRFPC0.N_25823\,
dataf => \GRFPC0.N_25823_2\,
datae => \GRFPC0.WR.CTRL.RDD\,
datad => \GRFPC0.WR.RREG.RESV\,
datac => \GRFPC0.WR.CTRL.DIV\,
datab => \GRFPC0.WR.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_175_0_A4_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000c000000000")
port map (
combout => \GRFPC0.N_25576\,
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_0_A4_0_0\(1),
datae => \GRFPC0.WR.CTRL.RDD\,
datad => \GRFPC0.WR.RREG.RESV\,
datac => \GRFPC0.WR.CTRL.DIV\,
datab => \GRFPC0.WR.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_10_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c00000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_10\(1),
dataf => \GRFPC0.N_705\,
datae => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.INST\(18),
datab => \GRFPC0.WR.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_475_0_A2_4_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_0_A2_5_0\(0),
dataf => \GRFPC0.WR.CTRL.RS1V\,
datae => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.INST\(18),
datab => \GRFPC0.WR.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_17_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_17\(1),
dataf => \GRFPC0.N_703\,
datae => \GRFPC0.WR.CTRL.INST\(4),
datad => \GRFPC0.WR.CTRL.INST\(3),
datac => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR.CTRL.INST\(2));
\GRFPU0_GRFPU_X0_ST2_EXC_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.EXC_8\(0),
dataf => \GRFPU0.GRFPU_X0.ST1.OP2NX\,
datae => \GRFPU0.GRFPU_X0.ST1.V\,
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(6));
GRFPU0_GRFPU_X0_VALLOW_5_SQMUXA_0_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_128\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datae => \GRFPU0.GRFPU_X0.ST1.V\,
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(6));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNIFLIT_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_3638_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(6));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN873_REGDEPX2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN873_REGDEPX2\,
dataf => \GRFPC0.DIV.INST\(17),
datae => \GRFPC0.DIV.INST\(15),
datad => \GRFPC0.DIV.INST\(16),
datac => \GRFPC0.DIV.INST\(18));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_1_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000f00")
port map (
combout => \GRFPC0.N_24750_1\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR.RREG.RESV\,
datad => \GRFPC0.WR.CTRL.DIV\,
datac => \GRFPC0.WR.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_14_CHECK_DEP_DEP_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00030")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_3\(0),
dataf => \GRFPC0.N_25496\,
datae => \GRFPC0.WR.CTRL.RDD\,
datad => \GRFPC0.WR.CTRL.INST\(26),
datac => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR.CTRL.INST\(25));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(34),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(34),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(14),
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(46));
\GRFPU0_GRFPU_X0_L1_2_1_6_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc00fc")
port map (
combout => \GRFPU0.GRFPU_X0.N_13562_1\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(15),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(14),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(47),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(46));
GRFPU0_GRFPU_X0_COMB_VST3_EXC51: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0500010004000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_5820\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_1_2\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_3_2\,
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
dataa => \GRFPU0.GRFPU_X0.ST2.FLOP\(3));
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf0330f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(0),
dataf => \GRFPU0.MULO.DRES_1\(97),
datae => \GRFPU0.MULO.DRES_1S\(96),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(120),
datab => N_28105);
GRFPU0_GRFPU_X0_ITER_NORM_RNIN1591: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0fff0fff00ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_4401\,
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(120),
datad => \GRFPU0.GRFPU_X0.ITER.NORM\,
datac => N_28105);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15897\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(120),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(120),
datab => N_28105);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_1_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fc000000")
port map (
combout => \GRFPC0.N_24944\,
dataf => N_113,
datae => \GRFPC0.FP_PIPELINE.UN24_OP\,
datad => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4687_REGDEPX\,
datac => N_84,
datab => N_78);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_340_0_A2_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.N_24528\,
dataf => \GRFPC0.N_23946_2\,
datae => \GRFPC0.N_24643\,
datad => \GRFPC0.FIFO.INST_1\(17),
datac => \GRFPC0.FIFO.INST_1\(15),
datab => \GRFPC0.FIFO.INST_1\(16));
\GRFPC0_FP_PIPELINE_10_REGDEPX_192_0_A4_1_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_0\(20),
dataf => \GRFPC0.FIFO.INST_1\(17),
datae => \GRFPC0.FIFO.INST_1\(18),
datad => \GRFPC0.FIFO.INST_1\(15),
datac => \GRFPC0.FIFO.INST_1\(16));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_64_0_A2_1_3_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN824_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(17),
datae => \GRFPC0.FIFO.INST_1\(18),
datad => \GRFPC0.FIFO.INST_1\(15),
datac => \GRFPC0.FIFO.INST_1\(16));
\GRFPU0_GRFPU_X0_L1_1_1_6_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc00fc")
port map (
combout => \GRFPU0.GRFPU_X0.N_13572_1\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(23),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(22),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(55),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(54));
GRFPU0_GRFPU_X0_COMB_UN1_FLOP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0f00330033")
port map (
combout => \GRFPU0.GRFPU_X0.N_8835\,
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_1\(11),
datad => \GRFPC0.FIFO.INST_0\(11),
datac => \GRFPC0.FIFO.INST_1\(10),
datab => \GRFPC0.FIFO.INST_0\(10));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5165_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5165_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(1),
datae => \GRFPC0.MEM.CTRL.INST\(4),
datad => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_19_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_19\(0),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(0),
datae => \GRFPC0.MEM.CTRL.INST\(16),
datad => \GRFPC0.MEM.CTRL.INST\(15),
datac => \GRFPC0.MEM.CTRL.INST\(17),
datab => \GRFPC0.MEM.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_A2_4_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_25444_1\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(1),
datad => \GRFPC0.MEM.CTRL.RS1V\,
datac => \GRFPC0.MEM.CTRL.INST\(15),
datab => \GRFPC0.MEM.CTRL.INST\(16));
GRFPC0_FP_PIPELINE_8_0_CHECK_DEP_UN2607_REGDEPX_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2607_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(2),
datae => \GRFPC0.FIFO.INST_0\(1),
datad => \GRFPC0.FIFO.INST_0\(3),
datac => \GRFPC0.FIFO.INST_0\(4));
\GRFPC0_FP_PIPELINE_10_CHECK_DEP_DEP_9_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_9\(0),
dataf => \GRFPC0.EX.CTRL.INST\(3),
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(0));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_200_0_A2_7_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_24171\,
dataf => \GRFPC0.EX.CTRL.INST\(3),
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(0));
\GRFPC0_FP_PIPELINE_10_0_REGDEPX_185_I_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffcfffff")
port map (
combout => \GRFPC0.N_24821\,
dataf => \GRFPC0.FIFO.INST_0\(19),
datae => \GRFPC0.FIFO.INST_0\(29),
datad => \GRFPC0.FIFO.INST_0\(26),
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28));
\GRFPC0_FP_PIPELINE_12_0_REGDEPX_221_0_A2_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000c0000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.0.REGDEPX_221_0_A2_0\(1),
dataf => \GRFPC0.FIFO.INST_0\(19),
datae => \GRFPC0.FIFO.INST_0\(29),
datad => \GRFPC0.FIFO.INST_0\(26),
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28));
\GRFPC0_FIFO_INST_0_RNIBUKC2_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_23522_I\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_23522_I_1\,
datad => \GRFPC0.FIFO.INST_0\(26),
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28));
\GRFPC0_FP_PIPELINE_0_STDEP_442_0_IV_I_O3_0_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3ffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_442_0_IV_I_O3_0_1\(0),
dataf => \GRFPC0.FIFO.INST_0\(29),
datae => \GRFPC0.FIFO.INST_0\(26),
datad => \GRFPC0.FIFO.INST_0\(27),
datac => \GRFPC0.FIFO.INST_0\(28),
datab => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_DIV_RESULT_0_0_0__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_0__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(0));
\GRFPC0_DIV_RESULT_0_0_10__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_10__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(10));
\GRFPC0_DIV_RESULT_0_0_11__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_11__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(11));
\GRFPC0_DIV_RESULT_0_0_12__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_12__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(12));
\GRFPC0_DIV_RESULT_0_0_13__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_13__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(13));
\GRFPC0_DIV_RESULT_0_0_14__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_14__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(14));
\GRFPC0_DIV_RESULT_0_0_15__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_15__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(15));
\GRFPC0_DIV_RESULT_0_0_16__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_16__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(16));
\GRFPC0_DIV_RESULT_0_0_17__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_17__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(17));
\GRFPC0_DIV_RESULT_0_0_18__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_18__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(18));
\GRFPC0_DIV_RESULT_0_0_19__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_19__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(19));
\GRFPC0_DIV_RESULT_0_0_1__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_1__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(1));
\GRFPC0_DIV_RESULT_0_0_20__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_20__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(20));
\GRFPC0_DIV_RESULT_0_0_21__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_21__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(21));
\GRFPC0_DIV_RESULT_0_0_22__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_22__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(22));
\GRFPC0_DIV_RESULT_0_0_23__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_23__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(23));
\GRFPC0_DIV_RESULT_0_0_24__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_24__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(24));
\GRFPC0_DIV_RESULT_0_0_26__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_26__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(26));
\GRFPC0_DIV_RESULT_0_0_27__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_27__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(27));
\GRFPC0_DIV_RESULT_0_0_28__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_28__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(28));
\GRFPC0_DIV_RESULT_0_0_29__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_29__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(29));
\GRFPC0_DIV_RESULT_0_0_2__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_2__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(2));
\GRFPC0_DIV_RESULT_0_0_31__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_31__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(31));
\GRFPC0_DIV_RESULT_0_0_3__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_3__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(3));
\GRFPC0_DIV_RESULT_0_0_4__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_4__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(4));
\GRFPC0_DIV_RESULT_0_0_5__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_5__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(5));
\GRFPC0_DIV_RESULT_0_0_6__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_6__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(6));
\GRFPC0_DIV_RESULT_0_0_7__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_7__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(7));
\GRFPC0_DIV_RESULT_0_0_8__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_8__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(8));
\GRFPC0_DIV_RESULT_0_0_9__G5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.DIV.RESULT_0_0_9__G5\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(9));
GRFPC0_FP_PIPELINE_VMEM_RREG_RES_1_10_2558_I_O3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0fffffffff")
port map (
combout => N_45853,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(30));
\GRFPU0_GRFPU_X0_RES_1_6_0_0_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff000c0000")
port map (
combout => \FPO.RES\(25),
dataf => \FPO.RES_1\(25),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(0),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(2),
datac => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(1),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(25));
\GRFPC0_FP_PIPELINE_4_CHECK_DEP_DEP_18_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_18\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datae => \GRFPC0.MEM.CTRL.INST\(26),
datad => \GRFPC0.MEM.CTRL.INST\(27),
datac => \GRFPC0.MEM.CTRL.INST\(29),
datab => \GRFPC0.MEM.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_12_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_12\(0),
dataf => \GRFPC0.MEM.CTRL.INST\(26),
datae => \GRFPC0.MEM.CTRL.INST\(27),
datad => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(28),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(0));
GRFPC0_FP_PIPELINE_VWR2_CTRL_PEND_1_IV_0_A4_0_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_23731_4\,
dataf => N_44718_1,
datae => \GRFPC0.FP_PIPELINE.VWR2.CTRL.PEND_1_IV_0_A4_0_4_4\,
datad => \GRFPC0.WR2.CTRL.INST\(20),
datac => \GRFPC0.WR2.CTRL.INST\(30),
datab => \GRFPC0.WR2.CTRL.INST\(24));
GRFPU0_GRFPU_X0_VITER_EXP_1_SQMUXA_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003303ffff")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.N_128\,
datae => \GRFPU0.GRFPU_X0.ITER.V\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
GRFPU0_GRFPU_X0_VITER_EXP_1_SQMUXA_1_0_I_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19750\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_I_O2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00fffffff0ff")
port map (
combout => \GRFPC0.N_25545\,
dataf => \GRFPC0.WR2.CTRL.RDD\,
datae => \GRFPC0.WR2.CTRL.INST\(29),
datad => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1\(0),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN369_REGDEPX2_1\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.CTRL.INST\(29),
datac => \GRFPC0.WR2.CTRL.INST\(28),
datab => \GRFPC0.WR2.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_175_I_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00030000000000")
port map (
combout => \GRFPC0.N_25621\,
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_I_A2_0_0\(0),
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.CTRL.INST\(1),
datac => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.WR2.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000300")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_3\(0),
dataf => \GRFPC0.N_25785\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.CTRL.INST\(1),
datac => \GRFPC0.WR2.CTRL.INST\(2),
datab => \GRFPC0.WR2.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_14_CHECK_DEP_DEP_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00030")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP\(0),
dataf => \GRFPC0.N_25785\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.CTRL.INST\(1),
datac => \GRFPC0.WR2.CTRL.INST\(2),
datab => \GRFPC0.WR2.CTRL.INST\(0));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3813_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3813_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(26),
datae => \GRFPC0.MEM.CTRL.INST\(27),
datad => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.N_24770\,
dataf => \GRFPC0.N_263\,
datae => \GRFPC0.DIV.INST\(17),
datad => \GRFPC0.DIV.INST\(15),
datac => \GRFPC0.DIV.INST\(18));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNIERF21_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_6050_6\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(4));
GRFPU0_GRFPU_X0_COMB_DPRES4_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6833\,
dataf => \GRFPU0.GRFPU_X0.N_6051_5\,
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(4));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNILSRP_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18500\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A2_8_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000f0f0f00")
port map (
combout => \GRFPC0.N_24796\,
dataf => \GRFPC0.DIV.RDD\,
datae => \GRFPC0.DIV.EXEC\,
datad => \GRFPC0.DIV.VALID\,
datac => \GRFPC0.DIV.INST\(0));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3975_REGDEPX2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3975_REGDEPX2\,
dataf => \GRFPC0.DIV.INST\(2),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(1),
datac => \GRFPC0.DIV.INST\(4));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_280_0_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00c00000")
port map (
combout => \GRFPC0.N_24736\,
dataf => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_11\(0),
datae => \GRFPC0.EX.CTRL.INST\(29),
datad => \GRFPC0.EX.CTRL.INST\(28),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(0),
datab => \GRFPC0.N_24325\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_A4_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25562\,
dataf => \GRFPC0.N_24222_1\,
datae => \GRFPC0.DIV.INST\(17),
datad => \GRFPC0.DIV.INST\(16),
datac => \GRFPC0.DIV.INST\(15),
datab => \GRFPC0.DIV.INST\(18));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_A2_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0c000000000")
port map (
combout => \GRFPC0.N_25803\,
dataf => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2168_REGDEPX2\,
datae => \GRFPC0.WR2.RREG.RESV\,
datad => \GRFPC0.WR2.CTRL.RDD\,
datac => \GRFPC0.WR2.CTRL.DIV\,
datab => \GRFPC0.WR2.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_A2_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f000")
port map (
combout => \GRFPC0.N_25244_1\,
dataf => \GRFPC0.WR2.RREG.RESV\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.CTRL.DIV\,
datac => \GRFPC0.WR2.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_12_CHECK_DEP_DEP_11_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f000c")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_11\(1),
dataf => \GRFPC0.N_25785\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.CTRL.INST\(1),
datac => \GRFPC0.WR2.CTRL.INST\(2),
datab => \GRFPC0.WR2.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000c00")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_3\(1),
dataf => \GRFPC0.N_25785\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.CTRL.INST\(1),
datac => \GRFPC0.WR2.CTRL.INST\(2),
datab => \GRFPC0.WR2.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_14_CHECK_DEP_DEP_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f000c0")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP\(1),
dataf => \GRFPC0.N_25785\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.CTRL.INST\(1),
datac => \GRFPC0.WR2.CTRL.INST\(2),
datab => \GRFPC0.WR2.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_8_CHECK_DEP_DEP_5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000003000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_5\(0),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(0),
datae => \GRFPC0.WR2.CTRL.INST\(1),
datad => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_O2_3_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0c00")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_O2_3\(1),
dataf => \GRFPC0.N_25273\,
datae => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_O2_1\(1),
datad => \GRFPC0.N_25421_1\,
datac => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.EX.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN4664_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4664_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(16),
datae => \GRFPC0.EX.CTRL.INST\(15),
datad => \GRFPC0.EX.CTRL.INST\(17),
datac => \GRFPC0.EX.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5105_REGDEPX2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5105_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(15),
datae => \GRFPC0.EX.CTRL.INST\(16),
datad => \GRFPC0.EX.CTRL.INST\(17),
datac => \GRFPC0.EX.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_3_0_A2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000f0000000")
port map (
combout => \GRFPC0.N_25871\,
dataf => \GRFPC0.WR2.CTRL.RDD\,
datae => \GRFPC0.WR2.CTRL.INST\(26),
datad => \GRFPC0.WR2.CTRL.INST\(27),
datac => \GRFPC0.WR2.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_0_A4_1_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f000")
port map (
combout => \GRFPC0.N_25592_1\,
dataf => \GRFPC0.WR2.RREG.RESV\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.CTRL.DIV\,
datac => \GRFPC0.WR2.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_25_0_A2_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000c00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_25_0_A2_0\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN369_REGDEPX2_1\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.CTRL.INST\(29),
datac => \GRFPC0.WR2.CTRL.INST\(28),
datab => \GRFPC0.WR2.CTRL.INST\(25));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M39_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M39_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0));
\GRFPC0_FP_PIPELINE_8_CHECK_DEP_DEP_7_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_7\(0),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(0),
datae => \GRFPC0.WR2.CTRL.INST\(29),
datad => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(27));
GRFPC0_FP_PIPELINE_9_CHECK_DEP_UN4344_REGDEPX2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4344_REGDEPX2\,
dataf => \GRFPC0.WR2.CTRL.INST\(29),
datae => \GRFPC0.WR2.CTRL.INST\(28),
datad => \GRFPC0.WR2.CTRL.INST\(26),
datac => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_325_0_A4_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0c000000000")
port map (
combout => \GRFPC0.N_24976\,
dataf => \GRFPC0.N_24976_2\,
datae => \GRFPC0.WR2.RREG.RESV\,
datad => \GRFPC0.WR2.CTRL.RDD\,
datac => \GRFPC0.WR2.CTRL.DIV\,
datab => \GRFPC0.WR2.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_0_A2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f000c000")
port map (
combout => \GRFPC0.N_25635\,
dataf => \GRFPC0.WR2.RREG.RESV\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.CTRL.DIV\,
datac => \GRFPC0.WR2.CTRL.INST\(15),
datab => \GRFPC0.WR2.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_18_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000c00")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_18\(1),
dataf => \GRFPC0.N_25784\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.CTRL.INST\(15),
datac => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_14_CHECK_DEP_DEP_8_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f000c0")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_8\(1),
dataf => \GRFPC0.N_25784\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.CTRL.INST\(15),
datac => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(14));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3917_REGDEPX2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3917_REGDEPX2\,
dataf => \GRFPC0.WR2.CTRL.INST\(15),
datae => \GRFPC0.WR2.CTRL.INST\(16),
datad => \GRFPC0.WR2.CTRL.INST\(17),
datac => \GRFPC0.WR2.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_A2_3_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.N_24404_1\,
dataf => \GRFPC0.MEM.CTRL.RS1V\,
datae => \GRFPC0.MEM.CTRL.INST\(16),
datad => \GRFPC0.MEM.CTRL.INST\(15),
datac => \GRFPC0.MEM.CTRL.INST\(17),
datab => \GRFPC0.MEM.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_A2_3_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A2_0_2_0\(0),
dataf => \GRFPC0.MEM.CTRL.RS1V\,
datae => \GRFPC0.MEM.CTRL.INST\(17),
datad => \GRFPC0.MEM.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_11_CHECK_DEP_DEP_16_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_16\(0),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(0),
datae => \GRFPC0.MEM.CTRL.INST\(15),
datad => \GRFPC0.MEM.CTRL.INST\(16),
datac => \GRFPC0.MEM.CTRL.INST\(17),
datab => \GRFPC0.MEM.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_A2_10_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000300000")
port map (
combout => \GRFPC0.N_25295\,
dataf => \GRFPC0.N_703\,
datae => \GRFPC0.WR.CTRL.INST\(4),
datad => \GRFPC0.WR.CTRL.INST\(3),
datac => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_A2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000003")
port map (
combout => \GRFPC0.N_25293\,
dataf => \GRFPC0.N_703\,
datae => \GRFPC0.WR.CTRL.INST\(4),
datad => \GRFPC0.WR.CTRL.INST\(3),
datac => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN800_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN800_REGDEPX2\,
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(3),
datad => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_385_0_A3_3_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_385_0_A3_3_0\(1),
dataf => \GRFPC0.N_25498\,
datae => \GRFPC0.WR.RREG.RESV\,
datad => \GRFPC0.WR.CTRL.INST\(15),
datac => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR.CTRL.DIV\);
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3872_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3872_REGDEPX2\,
dataf => \GRFPC0.WR.CTRL.INST\(15),
datae => \GRFPC0.WR.CTRL.INST\(18),
datad => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_A2_11_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003000000")
port map (
combout => \GRFPC0.N_25296\,
dataf => \GRFPC0.N_707\,
datae => \GRFPC0.WR.CTRL.INST\(29),
datad => \GRFPC0.WR.CTRL.INST\(26),
datac => \GRFPC0.WR.CTRL.INST\(27),
datab => \GRFPC0.WR.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_A2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000003")
port map (
combout => \GRFPC0.N_25294\,
dataf => \GRFPC0.N_707\,
datae => \GRFPC0.WR.CTRL.INST\(26),
datad => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.WR.CTRL.INST\(28),
datab => \GRFPC0.WR.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_7_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_7\(0),
dataf => \GRFPC0.N_706\,
datae => \GRFPC0.WR.CTRL.INST\(26),
datad => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.WR.CTRL.INST\(28),
datab => \GRFPC0.WR.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_7_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_7\(1),
dataf => \GRFPC0.N_707\,
datae => \GRFPC0.WR.CTRL.INST\(26),
datad => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.WR.CTRL.INST\(28),
datab => \GRFPC0.WR.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0003000000000")
port map (
combout => \GRFPC0.N_24784\,
dataf => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4769_REGDEPX2\,
datae => \GRFPC0.WR.CTRL.RDD\,
datad => \GRFPC0.WR.RREG.RESV\,
datac => \GRFPC0.WR.CTRL.DIV\,
datab => \GRFPC0.WR.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_246_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff000c0000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_246\(0),
dataf => \GRFPC0.FP_PIPELINE.8.REGDEPX2_245\(0),
datae => \GRFPC0.N_24160_1\,
datad => \GRFPC0.EX.CTRL.INST\(27),
datac => \GRFPC0.EX.CTRL.INST\(26),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_0_A2_8_1_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff000f000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_78_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(2),
datae => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(1),
datad => \GRFPU0.GRFPU_X0.ST3.RDY\,
datac => \GRFPU0.GRFPU_X0.ST3.QSNAN\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0ffffc0c0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(56),
dataf => \GRFPU0.GRFPU_X0.N_15546\,
datae => N_99909_I_0,
datad => \GRFPU0.GRFPU_X0.N_15611\,
datac => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.ST3.QSNAN\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0ffffc0c0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(57),
dataf => \GRFPU0.GRFPU_X0.N_15547\,
datae => N_99909_I_0,
datad => \GRFPU0.GRFPU_X0.N_15611\,
datac => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.ST3.QSNAN\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0ffffc0c0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(58),
dataf => \GRFPU0.GRFPU_X0.N_15548\,
datae => N_99909_I_0,
datad => \GRFPU0.GRFPU_X0.N_15611\,
datac => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.ST3.QSNAN\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0ffffc0c0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(59),
dataf => \GRFPU0.GRFPU_X0.N_15549\,
datae => N_99909_I_0,
datad => \GRFPU0.GRFPU_X0.N_15611\,
datac => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.ST3.QSNAN\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0ffffc0c0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(60),
dataf => \GRFPU0.GRFPU_X0.N_15550\,
datae => N_99909_I_0,
datad => \GRFPU0.GRFPU_X0.N_15611\,
datac => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.ST3.QSNAN\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0ffffc0c0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(61),
dataf => \GRFPU0.GRFPU_X0.N_15551\,
datae => N_99909_I_0,
datad => \GRFPU0.GRFPU_X0.N_15611\,
datac => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.ST3.QSNAN\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0ffffc0c0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(62),
dataf => \GRFPU0.GRFPU_X0.N_15552\,
datae => N_99909_I_0,
datad => \GRFPU0.GRFPU_X0.N_15611\,
datac => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.ST3.QSNAN\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_0_A2_5_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_53\,
dataf => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
datae => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(2),
datad => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(1),
datac => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.ST3.QSNAN\);
\GRFPU0_GRFPU_X0_COMB_TMP3_1_1_0_IV_RNIFHOQ1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003f0000003fc0")
port map (
combout => N_99909_I,
dataf => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
datae => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(2),
datad => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(1),
datac => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.ST3.QSNAN\);
\GRFPU0_GRFPU_X0_COMB_TMP3_1_1_0_IV_RNIDGUH1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff000ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_14\,
dataf => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(2),
datae => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(1),
datad => \GRFPU0.GRFPU_X0.ST3.RDY\,
datac => \GRFPU0.GRFPU_X0.ST3.QSNAN\);
GRFPU0_GRFPU_X0_COMB_VST4_REG30_RNI1A1P1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000003f0000c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15611\,
dataf => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(2),
datae => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(1),
datad => \GRFPU0.GRFPU_X0.N_5661\,
datac => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.ST3.QSNAN\);
GRFPU0_GRFPU_X0_UN23_EXP_ANC4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => N_32654,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(1),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(4),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(3));
GRFPU0_GRFPU_X0_UN1_ITER_EXP_C4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => N_32463,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(1),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(4),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(3));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccc3ccc3")
port map (
combout => \GRFPU0.GRFPU_X0.N_18234\,
dataf => \GRFPU0.GRFPU_X0.N_18408\,
datae => \GRFPU0.GRFPU_X0.C\(2),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(1),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(2));
GRFPU0_GRFPU_X0_UN1_ITER_EXP_C3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => N_32458,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(1),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(3));
\GRFPC0_DIV_EXCT_0_0_2__G4\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccccccccc0")
port map (
combout => N_45232_1,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
datac => \GRFPU0.GRFPU_X0.ST4.RDY\,
datab => \GRFPU0.GRFPU_X0.ST4.EXC\(2));
GRFPU0_GRFPU_X0_COMB_VEXC_5_1_I_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccccccccc0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18290_I_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(0),
datac => \GRFPU0.GRFPU_X0.ST4.RDY\,
datab => \GRFPC0.DIV.EXCT_0_0_1__I1_I_3\);
GRFPU0_GRFPU_X0_COMB_VEXC_5_4_I_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccccccccc0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18289_I_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(0),
datac => \GRFPU0.GRFPU_X0.ST4.RDY\,
datab => \GRFPC0.DIV.EXCT_0_0_4__I1_I_2\);
GRFPU0_GRFPU_X0_COMB_VEXC_5_5_I_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccccccccc0")
port map (
combout => \GRFPC0.FPO_I_6_I_0\(69),
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(0),
datac => \GRFPU0.GRFPU_X0.ST4.RDY\,
datab => \GRFPC0.DIV.EXCT_0_0_5__I1_I_1\);
GRFPU0_GRFPU_X0_COMB_VEXC_5_5_I_0_O7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(0),
datac => \GRFPU0.GRFPU_X0.ST4.RDY\);
\GRFPC0_R_FSR_AEXC_RNO_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.CPI_M\(399),
dataf => N_35,
datae => N_438,
datad => N_425,
datac => N_424,
datab => N_423);
\GRFPC0_R_FSR_AEXC_RNO_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.CPI_M\(401),
dataf => N_35,
datae => N_440,
datad => N_425,
datac => N_424,
datab => N_423);
GRFPC0_V_FSR_AEXC_0_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.V.FSR.AEXC_0_SQMUXA\,
dataf => N_35,
datae => N_425,
datad => N_424,
datac => N_423);
GRFPC0_V_FSR_AEXC_1_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffff00000000")
port map (
combout => \GRFPC0.V.FSR.AEXC_1_SQMUXA\,
dataf => N_35,
datae => N_425,
datad => N_424,
datac => N_423);
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_15_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_15\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(1),
datae => \GRFPC0.WR2.CTRL.INST\(29),
datad => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_2_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f00000f000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_0\(0),
dataf => \GRFPC0.FIFO.RD_0\(0),
datae => \GRFPC0.FIFO.INST_1\(23),
datad => \GRFPC0.FIFO.INST_0\(23),
datac => N_39);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN24_DP_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0ffffccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.N_18871\,
dataf => \GRFPC0.FIFO.INST_0\(6),
datae => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.FIFO.RD\(0),
datac => \GRFPC0.FIFO.INST_1\(5),
datab => \GRFPC0.FIFO.INST_0\(5));
GRFPC0_DIVI_0_SQMUXA_1_0_A4_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003333000f000f")
port map (
combout => \GRFPC0.DIVI_0_SQMUXA_1_2\,
dataf => \GRFPC0.FIFO.RD_0\(0),
datae => \GRFPC0.FIFO.INST_1\(12),
datad => \GRFPC0.FIFO.INST_0\(12),
datac => \GRFPC0.FIFO.INST_0\(13),
datab => \GRFPC0.FIFO.INST_1\(13));
\GRFPU0_GRFPU_X0_ITER_ALLOW_RNI9HTV_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cc00c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_4415_M_0_A3_1\,
dataf => \FPI.FLOP\(7),
datae => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.FIFO.INST_1\(8),
datac => \GRFPC0.FIFO.INST_0\(8),
datab => \GRFPU0.GRFPU_X0.ITER.ALLOW\(0));
GRFPU0_GRFPU_X0_COMB_VST1_V2_1_A3_0_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f3300000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.V2_1_A3_0_1\,
dataf => \FPI.FLOP\(6),
datae => \FPI.FLOP\(5),
datad => \GRFPC0.FIFO.RD\(0),
datac => \GRFPC0.FIFO.INST_1\(8),
datab => \GRFPC0.FIFO.INST_0\(8));
GRFPC0_DEP_1_SQMUXA_87_0_A4_I_O3_I_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000300")
port map (
combout => \GRFPC0.N_23897\,
dataf => \GRFPC0.FIFO.INST_0\(19),
datae => \GRFPC0.FIFO.INST_0\(29),
datad => \GRFPC0.FIFO.INST_0\(26),
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28));
GRFPC0_STDDEP_0_SQMUXA_108_0_A2_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000003")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_108_0_A2_0_A2_0\,
dataf => \GRFPC0.FIFO.INST_0\(19),
datae => \GRFPC0.FIFO.INST_0\(29),
datad => \GRFPC0.FIFO.INST_0\(26),
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28));
GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_UN61_REGDEPX_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(29),
datae => \GRFPC0.FIFO.INST_0\(26),
datad => \GRFPC0.FIFO.INST_0\(27),
datac => \GRFPC0.FIFO.INST_0\(28));
GRFPC0_FP_PIPELINE_1_0_CHECK_DEP_UN391_REGDEPX_I_O3_I_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.N_128\,
dataf => \GRFPC0.FIFO.INST_0\(29),
datae => \GRFPC0.FIFO.INST_0\(26),
datad => \GRFPC0.FIFO.INST_0\(27),
datac => \GRFPC0.FIFO.INST_0\(28));
GRFPC0_FP_PIPELINE_3_0_CHECK_DEP_UN1015_REGDEPX_I_0_O3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0ffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1015_REGDEPX_I_1\,
dataf => \GRFPC0.FIFO.INST_0\(29),
datae => \GRFPC0.FIFO.INST_0\(26),
datad => \GRFPC0.FIFO.INST_0\(27),
datac => \GRFPC0.FIFO.INST_0\(28));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0c0000fc0cffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(22),
dataf => \GRFPU0.GRFPU_X0.N_71\,
datae => \GRFPU0.GRFPU_X0.N_3476\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(2),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(34));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(23),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(23),
datae => \GRFPU0.GRFPU_X0.N_3476\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(3),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(35));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(27),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(27),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(7),
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(39));
\GRFPU0_GRFPU_X0_L1_3_1_5_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc00fc")
port map (
combout => \GRFPU0.GRFPU_X0.N_13552_1\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(7),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(6),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(38),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(39));
\GRFPU0_GRFPU_X0_L1_0_7_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f0fcf0f0f0")
port map (
combout => N_82194,
dataf => \GRFPU0.GRFPU_X0.N_13522\,
datae => \GRFPU0.GRFPU_X0.N_13441\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(31),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3\(30),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(50),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(50),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(30),
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(62));
GRFPU0_GRFPU_X0_UN243_BCO_LSB_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000fff0f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN243_BCO_LSB_0\,
dataf => \GRFPU0.GRFPU_X0.N_13441\,
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(30),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(62));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_375_0_A3_5_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_380_0_A2_3_1\(0),
dataf => \GRFPC0.EX.CTRL.INST\(3),
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3797_REGDEPX2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3797_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(3),
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_6_CHECK_DEP_UN2976_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2976_REGDEPX2\,
dataf => \GRFPC0.WR.CTRL.INST\(29),
datae => \GRFPC0.WR.CTRL.INST\(26),
datad => \GRFPC0.WR.CTRL.INST\(27),
datac => \GRFPC0.WR.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A2_6_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000ff0000")
port map (
combout => \GRFPC0.N_25516_2\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR.CTRL.RS1V\,
datad => \GRFPC0.WR.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_14_CHECK_DEP_DEP_19_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00030")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_19\(0),
dataf => \GRFPC0.N_25498\,
datae => \GRFPC0.WR.CTRL.RDD\,
datad => \GRFPC0.WR.CTRL.INST\(15),
datac => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_296_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0f0c0000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_296\(1),
dataf => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295\(1),
datae => \GRFPC0.N_24118\,
datad => \GRFPC0.DIV.RDD\,
datac => \GRFPC0.DIV.RD\(3),
datab => \GRFPC0.DIV.RD\(0));
\GRFPC0_FP_PIPELINE_10_CHECK_DEP_DEP_16_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_16\(1),
dataf => \GRFPC0.N_275\,
datae => \GRFPC0.DIV.RDD\,
datad => \GRFPC0.DIV.RD\(3),
datac => \GRFPC0.DIV.RD\(0));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_356_0_A2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
combout => \GRFPC0.N_24115\,
dataf => \GRFPC0.DIV.RDD\,
datae => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.DIV.RD\(0));
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_2_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_2\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datae => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_A2_1_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f000c0c0c000")
port map (
combout => \GRFPC0.N_24215_1\,
dataf => \GRFPC0.DIV.RDD\,
datae => \GRFPC0.DIV.EXEC\,
datad => \GRFPC0.DIV.VALID\,
datac => \GRFPC0.DIV.RS1V\,
datab => \GRFPC0.DIV.INST\(14));
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_8_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000c0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_8\(1),
dataf => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN873_REGDEPX2_2\,
datae => \GRFPC0.DIV.RDD\,
datad => \GRFPC0.DIV.INST\(16),
datac => \GRFPC0.DIV.INST\(15),
datab => \GRFPC0.DIV.INST\(14));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_16_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000c00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_16\(1),
dataf => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN873_REGDEPX2_2\,
datae => \GRFPC0.DIV.RDD\,
datad => \GRFPC0.DIV.INST\(15),
datac => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.INST\(14));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_A0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff000000")
port map (
combout => \GRFPC0.N_25624_1\,
dataf => \GRFPC0.DIV.RDD\,
datae => \GRFPC0.DIV.RS1V\,
datad => \GRFPC0.DIV.INST\(14));
\GRFPC0_FP_PIPELINE_11_CHECK_DEP_DEP_6_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f000c0")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_6\(1),
dataf => \GRFPC0.N_24201\,
datae => \GRFPC0.DIV.RDD\,
datad => \GRFPC0.DIV.INST\(17),
datac => \GRFPC0.DIV.INST\(18),
datab => \GRFPC0.DIV.INST\(14));
\GRFPC0_FP_PIPELINE_3_CHECK_DEP_DEP_11_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000c00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_11\(1),
dataf => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN873_REGDEPX2_2\,
datae => \GRFPC0.DIV.RDD\,
datad => \GRFPC0.DIV.INST\(16),
datac => \GRFPC0.DIV.INST\(15),
datab => \GRFPC0.DIV.INST\(14));
\GRFPU0_GRFPU_X0_BCO_MSB_3_7_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffc0c")
port map (
combout => \GRFPU0.GRFPU_X0.N_13512\,
dataf => \GRFPU0.GRFPU_X0.N_13515\,
datae => \GRFPU0.GRFPU_X0.INF_ABS0_3\(10),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(11),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(43));
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_I_A2_2_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffffffffffff")
port map (
combout => \GRFPC0.N_100\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR.CTRL.LD\,
datad => N_386,
datac => N_387,
datab => N_37);
GRFPC0_WR2_CTRL_CCWR_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030f00000")
port map (
combout => N_47182,
dataf => N_44831,
datae => \GRFPC0.WR.CTRL.CCWR\,
datad => \GRFPC0.WR.CTRL.VCNT\(0),
datac => N_35,
datab => N_39);
GRFPC0_WR2_CTRL_DIV_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030f00000")
port map (
combout => N_47181,
dataf => N_44831,
datae => \GRFPC0.WR.CTRL.DIV\,
datad => \GRFPC0.WR.CTRL.VCNT\(0),
datac => N_35,
datab => N_39);
GRFPC0_WR2_CTRL_RDWR_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030f00000")
port map (
combout => N_47180,
dataf => N_44831,
datae => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.WR.CTRL.VCNT\(0),
datac => N_35,
datab => N_39);
GRFPC0_RFA_LD_RNIL6ET_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_854\,
dataf => \GRFPC0.RFA.LD\,
datae => N_176,
datad => N_175,
datac => N_174,
datab => N_173);
GRFPC0_RFA_LD_RNIL6ET: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3ffffffff")
port map (
combout => \GRFPC0.N_22820\,
dataf => \GRFPC0.RFA.LD\,
datae => N_175,
datad => N_176,
datac => N_174,
datab => N_173);
GRFPU0_GRFPU_X0_UN228_BCO_LSB_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN228_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(18),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(19));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15830\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(104),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(104),
datab => N_28073);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18624\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(104),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(104),
datab => N_28073);
GRFPC0_STDDEP_0_SQMUXA_19_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => \GRFPC0.N_22819\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_242,
datad => N_243,
datac => N_245,
datab => N_244);
GRFPC0_STDDEP_0_SQMUXA_31_I_O4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffffffff")
port map (
combout => \GRFPC0.N_22960\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_242,
datad => N_243,
datac => N_245,
datab => N_244);
GRFPC0_EX_CTRL_LD_RNIA6811: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPC0.N_21521\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_242,
datad => N_243,
datac => N_245,
datab => N_244);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_140_0_A2_7_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c000000")
port map (
combout => \GRFPC0.N_24170\,
dataf => \GRFPC0.N_704\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN334_REGDEPX2_1\,
datad => \GRFPC0.WR.CTRL.RS1V\,
datac => \GRFPC0.WR.CTRL.INST\(18),
datab => \GRFPC0.WR.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_200_0_A2_6_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_0_A2_6_0\(0),
dataf => \GRFPC0.WR.CTRL.INST\(15),
datae => \GRFPC0.WR.CTRL.INST\(16),
datad => \GRFPC0.WR.CTRL.INST\(18),
datac => \GRFPC0.WR.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_200_0_A3_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_0_A3_0_1\(1),
dataf => \GRFPC0.WR.CTRL.RS1V\,
datae => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.INST\(18),
datab => \GRFPC0.WR.CTRL.INST\(17));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15821\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(95),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(95),
datab => N_28055);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15872\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(95),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(95),
datab => N_28055);
\GRFPU0_GRFPU_X0_UN1_INC_SP_I_A2_0_15_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"330f000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_15\(0),
dataf => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_12\(0),
datae => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_13\(0),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(95),
datab => N_28055);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_375_0_A3_4_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_380_0_A2_2_1\(0),
dataf => \GRFPC0.EX.CTRL.INST\(27),
datae => \GRFPC0.EX.CTRL.INST\(29),
datad => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.EX.CTRL.INST\(28));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN2004_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2004_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(27),
datae => \GRFPC0.EX.CTRL.INST\(29),
datad => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.EX.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_14_0_REGDEPX_257_0_A2_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0000000f000")
port map (
combout => \GRFPC0.N_24902\,
dataf => \GRFPC0.FIFO.INST_0\(6),
datae => \GRFPC0.FIFO.INST_0\(0),
datad => \GRFPC0.FIFO.INST_0\(4),
datac => \GRFPC0.FIFO.INST_0\(3));
GRFPC0_FP_PIPELINE_UN30_OP_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000030")
port map (
combout => \GRFPC0.N_313\,
dataf => N_45119_I,
datae => N_100,
datad => N_101,
datac => N_102,
datab => N_99);
\GRFPC0_FP_PIPELINE_5_STDEP_230_0_IV_I_I2_6_I4_0_A3_RNII4M61_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.N_22910\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => N_107,
datad => N_106,
datac => N_105,
datab => N_104);
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_25_IV_I_A4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_25_I_I_0\(1),
dataf => N_106,
datae => \GRFPC0.N_59\,
datad => N_107,
datac => N_105,
datab => N_104);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_5_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.N_9478\,
dataf => N_106,
datae => N_107,
datad => N_105,
datac => N_104);
\GRFPC0_FP_PIPELINE_5_STDEP_230_0_IV_I_I2_6_I4_0_A3_RNII4M61_5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_21281\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => N_106,
datad => N_107,
datac => N_105,
datab => N_104);
\GRFPC0_D_STLCK_RNO_2_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_21331\,
dataf => N_106,
datae => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datad => N_107,
datac => N_105,
datab => N_104);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_13_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPC0.N_23298\,
dataf => N_106,
datae => N_105,
datad => N_104);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_1_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.N_9474\,
dataf => N_106,
datae => N_107,
datad => N_105,
datac => N_104);
\GRFPC0_FP_PIPELINE_5_STDEP_230_0_IV_I_I2_6_I4_0_A3_RNII4M61_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_598_I_M_I_A3_0\(1),
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => N_107,
datad => N_106,
datac => N_104,
datab => N_105);
\GRFPC0_FP_PIPELINE_5_STDEP_230_0_IV_I_I2_6_I4_0_A3_RNII4M61_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_A2_3_0\(1),
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => N_107,
datad => N_106,
datac => N_104,
datab => N_105);
\GRFPC0_FP_PIPELINE_2_STDEP_110_0_IV_0_O3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3ffffffff")
port map (
combout => \GRFPC0.N_22725\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => N_106,
datad => N_107,
datac => N_104,
datab => N_105);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_10_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPC0.N_9483\,
dataf => N_106,
datae => N_107,
datad => N_104,
datac => N_105);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.N_9467\,
dataf => N_106,
datae => N_107,
datad => N_104,
datac => N_105);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.N_9479\,
dataf => N_106,
datae => N_107,
datad => N_104,
datac => N_105);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_3_1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPC0.N_22740_1\,
dataf => N_106,
datae => N_107,
datad => N_97,
datac => N_104,
datab => N_105);
\GRFPC0_FP_PIPELINE_11_STDEP_474_0_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fffffffffffff")
port map (
combout => \GRFPC0.N_21737\,
dataf => \GRFPC0.RFA.LD\,
datae => N_176,
datad => N_175,
datac => N_174,
datab => N_173);
GRFPC0_RFA_LD_RNIL6ET_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_26\,
dataf => \GRFPC0.RFA.LD\,
datae => N_175,
datad => N_176,
datac => N_174,
datab => N_173);
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1233_DEP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1233_DEP\,
dataf => N_175,
datae => N_176,
datad => N_174,
datac => N_173);
GRFPC0_FP_PIPELINE_0_STDDEP_180_IV_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_21902\,
dataf => \GRFPC0.RFA.LD\,
datae => N_175,
datad => N_176,
datac => N_174,
datab => N_173);
\GRFPC0_FP_PIPELINE_11_0_CHECK_DEP_DEP_0_A4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000300000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.DEP\(0),
dataf => \GRFPC0.N_23887\,
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_0\(2),
datac => \GRFPC0.FIFO.INST_0\(1),
datab => \GRFPC0.FIFO.INST_0\(0));
GRFPC0_FP_PIPELINE_3_0_CHECK_DEP_UN1047_REGDEPX_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1047_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(2),
datae => \GRFPC0.FIFO.INST_0\(1),
datad => \GRFPC0.FIFO.INST_0\(3),
datac => \GRFPC0.FIFO.INST_0\(4));
\GRFPC0_FP_PIPELINE_11_0_REGDEPX_203_0_A4_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000c00000000000")
port map (
combout => \GRFPC0.N_23857\,
dataf => \GRFPC0.N_23887\,
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_0\(2),
datac => \GRFPC0.FIFO.INST_0\(1),
datab => \GRFPC0.FIFO.INST_0\(0));
\GRFPC0_FP_PIPELINE_15_0_REGDEPX_275_0_A2_1_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000f0000000")
port map (
combout => \GRFPC0.N_24977_1\,
dataf => \GRFPC0.FIFO.INST_0\(6),
datae => \GRFPC0.FIFO.INST_0\(2),
datad => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FIFO.INST_0\(0));
GRFPC0_FP_PIPELINE_0_UN1_OP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
dataf => \GRFPC0.CCWR_0_SQMUXA_1\,
datae => N_99,
datad => N_113,
datac => N_108,
datab => N_109);
GRFPC0_CCWR_0_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.CCWR_0_SQMUXA\,
dataf => N_97,
datae => N_99,
datad => \GRFPC0.CCWR_0_SQMUXA_1\,
datac => N_108,
datab => N_109);
GRFPC0_FP_PIPELINE_UN24_OP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN24_OP\,
dataf => N_99,
datae => \GRFPC0.CCWR_0_SQMUXA_1\,
datad => N_108,
datac => N_109);
GRFPC0_FP_PIPELINE_0_STDDEP_180_IV_0_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_580\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.N_106_I\);
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN2698_DEP_2_RNIF6811: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_21225\,
dataf => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2698_DEP_1\,
datae => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3026_DEP_2\,
datad => \GRFPC0.N_106_I\,
datac => \GRFPC0.EX.CTRL.RDWR\,
datab => \GRFPC0.EX.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_1_STDEP_56_SEL1_I_0_A2_I_RNI47Q31: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00f00000ff0f")
port map (
combout => \GRFPC0.N_35_I\,
dataf => \GRFPC0.N_26\,
datae => \GRFPC0.N_570\,
datad => \GRFPC0.N_106_I\,
datac => \GRFPC0.EX.CTRL.RD\(0));
\GRFPC0_D_STLCK_RNO_3_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPC0.N_22779\,
dataf => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN730_DEP\,
datae => \GRFPC0.N_106_I\,
datad => \GRFPC0.EX.CTRL.RDWR\);
\GRFPC0_D_STLCK_RNO_4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_762\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP\,
datad => \GRFPC0.N_106_I\,
datac => \GRFPC0.EX.CTRL.RDWR\,
datab => \GRFPC0.EX.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_A2_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f030000000000000")
port map (
combout => \GRFPC0.N_21502\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN730_DEP\,
datad => \GRFPC0.N_106_I\,
datac => \GRFPC0.EX.CTRL.RDWR\,
datab => \GRFPC0.EX.CTRL.RD\(0));
\GRFPC0_D_STLCK_RNO_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff00f0")
port map (
combout => \GRFPC0.D.STLCK_0_0_4__G1_3\,
dataf => \GRFPC0.N_22767\,
datae => \GRFPC0.D.STLCK_0_0_4__G1_1\,
datad => \GRFPC0.FP_PIPELINE.2.STDEP_110_0_IV_0_O3_2_0\(0),
datac => \GRFPC0.N_106_I\);
\GRFPC0_D_STLCK_RNO_2_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_13__G1_2\,
dataf => \GRFPC0.D.STLCK_0_0_13__G1_1\,
datae => \GRFPC0.N_546\,
datad => \GRFPC0.N_106_I\);
\GRFPC0_D_STLCK_RNO_2_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.N_23551\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.N_490\,
datad => \GRFPC0.N_106_I\,
datac => \GRFPC0.EX.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_11_STDEP_456_SEL0_0_0_O2_0_O2_RNITN486: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fff00000ff00")
port map (
combout => \GRFPC0.N_23389\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.N_21721\,
datad => \GRFPC0.N_106_I\,
datac => \GRFPC0.EX.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_12_STDEP_496_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0c00f30000")
port map (
combout => \GRFPC0.N_18320\,
dataf => \GRFPC0.FP_PIPELINE.12.STDEP_492\(0),
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datad => \GRFPC0.FP_PIPELINE.12.STDEP_496_SEL0_1\,
datac => \GRFPC0.N_106_I\,
datab => \GRFPC0.EX.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_12_STDEP_496_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ff0f")
port map (
combout => \GRFPC0.N_18322\,
dataf => \GRFPC0.FP_PIPELINE.12.STDEP_492\(0),
datae => \GRFPC0.FP_PIPELINE.12.STDEP_496_SEL0_1\,
datad => \GRFPC0.N_106_I\,
datac => \GRFPC0.EX.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN4666_DEP_2_RNICL541: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff3fffffffff")
port map (
combout => \GRFPC0.N_23152\,
dataf => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2698_DEP_1\,
datae => \GRFPC0.N_473_1\,
datad => \GRFPC0.N_106_I\,
datac => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_3_STDEP_136_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00f0ff0f0000")
port map (
combout => \GRFPC0.N_18500\,
dataf => \GRFPC0.FP_PIPELINE.3.STDEP_132\(0),
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datad => \GRFPC0.N_106_I\,
datac => \GRFPC0.EX.CTRL.RD\(0));
\GRFPC0_D_STLCK_RNO_1_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPC0.N_22583\,
dataf => \GRFPC0.N_169\,
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datad => \GRFPC0.N_21612\,
datac => \GRFPC0.N_106_I\,
datab => \GRFPC0.EX.CTRL.RD\(0));
\GRFPC0_D_STLCK_RNO_6_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff000000ff")
port map (
combout => \GRFPC0.N_92_I\,
dataf => \GRFPC0.N_21612\,
datae => \GRFPC0.N_106_I\,
datad => \GRFPC0.EX.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_6_STDEP_256_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f300f0fffffffc")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_256\(0),
dataf => \GRFPC0.N_28\,
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datad => \GRFPC0.N_546\,
datac => \GRFPC0.N_106_I\,
datab => \GRFPC0.EX.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_8_STDEP_350_0_IV_I_O4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffc00f300f0")
port map (
combout => \GRFPC0.N_22259\,
dataf => \GRFPC0.FP_PIPELINE.8.STDEP_332\(0),
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datad => \GRFPC0.N_55\,
datac => \GRFPC0.N_106_I\,
datab => \GRFPC0.EX.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_9_STDEP_376_3_I_A2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.N_21954\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.N_449\,
datad => \GRFPC0.N_106_I\,
datac => \GRFPC0.EX.CTRL.RD\(0));
\GRFPU0_GRFPU_X0_ITER_IDCST_RNI4THU3_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3c000000c3000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6736\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH\,
datae => \GRFPU0.GRFPU_X0.ITER.V\,
datad => \FPI.FLUSH\,
datac => \GRFPU0.GRFPU_X0.ITER.ID\(5),
datab => \FPI.FLUSHID\(5));
\GRFPC0_D_STLCK_RNO_0_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_856\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => N_104,
datad => N_107,
datac => N_105,
datab => N_106);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN300_REGDEPX_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN300_REGDEPX\,
dataf => N_95,
datae => N_96,
datad => N_94,
datac => N_93);
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN4048_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4048_REGDEPX\,
dataf => N_95,
datae => N_96,
datad => N_94,
datac => N_93);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_1_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0303030300030300")
port map (
combout => \GRFPC0.N_25357_1\,
dataf => N_97,
datae => N_90,
datad => N_89,
datac => N_96,
datab => N_95);
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN616_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN616_REGDEPX\,
dataf => N_93,
datae => N_94,
datad => N_96,
datac => N_95);
GRFPC0_FP_PIPELINE_3_STDEP_132_SEL0_0_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_132_SEL0_1\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(2),
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1040_DEP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1040_DEP\,
dataf => \GRFPC0.MEM.CTRL.RD\(2),
datae => \GRFPC0.MEM.CTRL.RD\(4),
datad => \GRFPC0.MEM.CTRL.RD\(1),
datac => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPC0_MEM_CTRL_RD_RNIBEDQ_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffffffff")
port map (
combout => \GRFPC0.N_477\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(2),
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(3));
GRFPC0_UN1_STDDEP_0_SQMUXA_108: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3f000c000c000c")
port map (
combout => \GRFPC0.UN1_STDDEP_0_SQMUXA_108\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datae => \GRFPC0.UN1_STDEP2530\,
datad => \GRFPC0.N_25889\,
datac => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.WR.CTRL.RDWR\);
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN4375_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4375_REGDEPX\,
dataf => N_82,
datae => N_80,
datad => N_81,
datac => N_79);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1567_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1567_REGDEPX\,
dataf => N_79,
datae => N_81,
datad => N_82,
datac => N_80);
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN1864_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1864_REGDEPX\,
dataf => N_93,
datae => N_95,
datad => N_96,
datac => N_94);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1552_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1552_REGDEPX\,
dataf => N_93,
datae => N_95,
datad => N_96,
datac => N_94);
\GRFPC0_D_STLCK_RNO_2_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0003000")
port map (
combout => \GRFPC0.D.STLCK_0_0_28__G1_1\,
dataf => \GRFPC0.D.STLCK_0_0_28__G1_0\,
datae => \GRFPC0.N_106_I\,
datad => \GRFPC0.EX.CTRL.LD\,
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4855_DEP\,
datab => N_241);
\GRFPC0_FP_PIPELINE_0_STDEP_282_0_IV_I_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff00000000")
port map (
combout => \GRFPC0.N_22453\,
dataf => \GRFPC0.N_22406_I\,
datae => \GRFPC0.N_106_I\,
datad => N_241);
\GRFPC0_FP_PIPELINE_9_STDEP_398_0_IV_TZ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff00ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_TZ\(0),
dataf => \GRFPC0.N_680\,
datae => \GRFPC0.N_106_I\,
datad => N_241);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15845\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(119),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(119),
datab => N_28103);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15896\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(119),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(119),
datab => N_28103);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M39_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M39_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0));
\GRFPU0_GRFPU_X0_REST_2_IV_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffeaeaeae0")
port map (
combout => \GRFPU0.GRFPU_X0.REST_2\(2),
dataf => \GRFPU0.GRFPU_X0.REST_2_IV_0\(2),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(4));
\GRFPC0_EX_CTRL_RD_RNIVL8L_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff3fffffffff")
port map (
combout => \GRFPC0.N_449\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_13_STDEP_536_3_I_O3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fffffffffffff")
port map (
combout => N_99872,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_5_STDEP_216_SEL1_I_0_A2_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffffffffffff")
port map (
combout => \GRFPC0.N_21612\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_O2_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffcfffffffff")
port map (
combout => \GRFPC0.N_22126\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_3_STDEP_128_3_0_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcfffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_128_SEL0_1\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4));
GRFPC0_STDDEP_0_SQMUXA_52_I_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffffffffffff")
port map (
combout => \GRFPC0.N_21610\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4));
GRFPU0_GRFPU_X0_COMB_UN1_EXPCC_1_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18472\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_EXPCC_1_0_A2_0_0\,
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(4),
datac => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(2),
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(1));
GRFPC0_FP_PIPELINE_4_1_CHECK_DEP_UN1448_REGDEPX_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1448_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(17),
datae => \GRFPC0.FIFO.INST_1\(18),
datad => \GRFPC0.FIFO.INST_1\(15),
datac => \GRFPC0.FIFO.INST_1\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_M2_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ffff0000330f")
port map (
combout => \GRFPU0.GRFPU_X0.N_18318\,
dataf => \GRFPU0.GRFPU_X0.N_18311\,
datae => \GRFPU0.GRFPU_X0.N_18663\,
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(114),
datab => N_28093);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_I_M2_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18616\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(114),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(114),
datab => N_28093);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15891\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(114),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(114),
datab => N_28093);
GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_UN80_REGDEPX_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN80_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(18),
datae => \GRFPC0.FIFO.INST_0\(17),
datad => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.INST_0\(15));
GRFPC0_FP_PIPELINE_0_UN1_DEP_RNI3QFS: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_22706\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datae => N_106,
datad => N_107,
datac => N_104,
datab => N_105);
\GRFPC0_FP_PIPELINE_5_STDEP_230_0_IV_I_I2_6_I4_0_A3_RNII4M61_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_131_I_1\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => N_106,
datad => N_107,
datac => N_104,
datab => N_105);
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_EQ_EXPT63_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000003")
port map (
combout => \GRFPU0.GRFPU_X0.N_18258\,
dataf => \GRFPU0.GRFPU_X0.C\(11),
datae => \GRFPU0.GRFPU_X0.C\(10),
datad => \GRFPU0.GRFPU_X0.C\(9),
datac => \GRFPU0.GRFPU_X0.C\(7),
datab => \GRFPU0.GRFPU_X0.C\(8));
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_EQ_EXPT67_0_A5_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT67_0_A5_0\,
dataf => \GRFPU0.GRFPU_X0.C\(9),
datae => \GRFPU0.GRFPU_X0.C\(7),
datad => \GRFPU0.GRFPU_X0.C\(8),
datac => \GRFPU0.GRFPU_X0.C\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A5_2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A5_2_1\(0),
dataf => \GRFPU0.GRFPU_X0.C\(9),
datae => \GRFPU0.GRFPU_X0.C\(7),
datad => \GRFPU0.GRFPU_X0.C\(8),
datac => \GRFPU0.GRFPU_X0.C\(1),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18216\,
dataf => \GRFPU0.GRFPU_X0.C\(9),
datae => \GRFPU0.GRFPU_X0.C\(7),
datad => \GRFPU0.GRFPU_X0.C\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_O3_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcfff0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18238\,
dataf => \GRFPU0.GRFPU_X0.C\(9),
datae => \GRFPU0.GRFPU_X0.C\(7),
datad => \GRFPU0.GRFPU_X0.C\(8),
datac => \GRFPU0.GRFPU_X0.C\(1),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_I_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_25618\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(0),
datae => \GRFPC0.WR2.CTRL.INST\(1),
datad => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_A2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.N_24213_2\,
dataf => \GRFPC0.DIV.RD\(3),
datae => \GRFPC0.DIV.RD\(4),
datad => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.DIV.RD\(1));
\GRFPU0_GRFPU_X0_UN4_S3ADDO3_M_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.S3ADDI\(29),
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(30),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(31),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(32));
GRFPC0_FP_PIPELINE_14_1_CHECK_DEP_UN4583_REGDEPX_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4583_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(3),
datae => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.INST_1\(1));
GRFPC0_FP_PIPELINE_8_1_CHECK_DEP_UN2711_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2711_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(3),
datae => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.INST_1\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_0_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2_0\(20),
dataf => \GRFPC0.FIFO.INST_1\(3),
datae => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.INST_1\(1));
GRFPC0_FP_PIPELINE_11_1_CHECK_DEP_UN3647_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3647_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(3),
datae => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.INST_1\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_0_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2_0\(14),
dataf => \GRFPC0.FIFO.INST_1\(3),
datae => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.INST_1\(1));
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_6\(0),
dataf => \GRFPC0.N_704\,
datae => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(18),
datac => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfcfcf00cfcf00")
port map (
combout => \GRFPC0.N_22892_1\,
dataf => N_97,
datae => N_90,
datad => N_89,
datac => N_92,
datab => N_84);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cf000000")
port map (
combout => \GRFPC0.N_25795_1\,
dataf => N_113,
datae => \GRFPC0.FP_PIPELINE.UN24_OP\,
datad => \GRFPC0.N_21627\,
datac => N_92,
datab => N_84);
\GRFPC0_FP_PIPELINE_9_REGDEPX_177_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcf000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX_177\(0),
dataf => \GRFPC0.FP_PIPELINE.9.REGDEPX_176\(0),
datae => N_96,
datad => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3112_REGDEPX_0\,
datac => N_92,
datab => N_84);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_7_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3c000000000")
port map (
combout => \GRFPC0.N_25727_1\,
dataf => \FPI.FLOP\(6),
datae => \GRFPC0.N_235\,
datad => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6),
datab => \GRFPC0.FIFO.RD_1\(0));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_454_0_A2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3c000000000")
port map (
combout => \GRFPC0.N_25130\,
dataf => \GRFPC0.FP_PIPELINE.15.REGDEPX2_465_0_A2_4_0\(0),
datae => \GRFPC0.V.STDATA_14\(25),
datad => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6),
datab => \GRFPC0.FIFO.RD_2\(0));
GRFPU0_GRFPU_X0_COMB_MULBP_1_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f3c000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_3\,
dataf => \FPI.FLOP\(6),
datae => \FPI.FLOP\(2),
datad => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6),
datab => \GRFPC0.FIFO.RD\(0));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c3ff3c0ffff")
port map (
combout => N_82234,
dataf => \FPI.OP1\(52),
datae => \FPI.OP1\(55),
datad => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_1\(6),
datab => \GRFPC0.FIFO.RD\(0));
\GRFPC0_FP_PIPELINE_4_REGDEPX_84_0_A4_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0c0000000000000")
port map (
combout => \GRFPC0.N_22656\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_25085\,
datad => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O3_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff3ffffffff")
port map (
combout => \GRFPC0.N_22813\,
dataf => \GRFPC0.N_25010\,
datae => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.FIFO.INST_1\(3),
datac => \GRFPC0.FIFO.INST_1\(2),
datab => \GRFPC0.FIFO.INST_1\(0));
\GRFPC0_FP_PIPELINE_15_REGDEPX_282_0_A2_2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcccc0ff00cc0")
port map (
combout => \GRFPC0.N_22899_1\,
dataf => \GRFPC0.FIFO.INST_1\(19),
datae => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.FIFO.INST_1\(12),
datac => \GRFPC0.FIFO.INST_1\(11),
datab => \GRFPC0.FIFO.INST_1\(14));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O2_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03ffffffffffff")
port map (
combout => \GRFPC0.N_22957\,
dataf => \GRFPC0.N_21626\,
datae => \GRFPC0.N_25083\,
datad => \GRFPC0.FIFO.INST_1\(17),
datac => \GRFPC0.FIFO.INST_1\(6),
datab => \GRFPC0.FIFO.INST_1\(14));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_4_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc00000000000000")
port map (
combout => \GRFPC0.N_24948\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_21626\,
datad => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4568_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1\(6),
datab => \GRFPC0.FIFO.INST_1\(14));
\GRFPC0_FP_PIPELINE_0_STDEP_362_0_IV_I_A3_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.N_120\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datae => N_104,
datad => N_105,
datac => N_106,
datab => N_107);
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_O2_2_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3ffffffff")
port map (
combout => \GRFPC0.N_22231\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => N_104,
datad => N_105,
datac => N_106,
datab => N_107);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15750\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.MRES\(104),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(103),
datab => N_28071);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15829\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(103),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(103),
datab => N_28071);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18623\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(103),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(103),
datab => N_28071);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_3_0_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030003000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_3_0\(14),
dataf => \GRFPC0.N_23854_I_0\,
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_0\(0),
datac => \GRFPC0.FIFO.INST_0\(3),
datab => \GRFPC0.FIFO.INST_0\(4));
\GRFPC0_FP_PIPELINE_12_0_REGDEPX_221_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0003")
port map (
combout => \GRFPC0.N_24836\,
dataf => \GRFPC0.N_23915\,
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_0\(2),
datac => \GRFPC0.FIFO.INST_0\(1),
datab => \GRFPC0.FIFO.INST_0\(0));
\GRFPC0_FP_PIPELINE_13_0_REGDEPX_240_I_A2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00030000000000")
port map (
combout => \GRFPC0.N_22587\,
dataf => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4167_REGDEPX_0_A2_0\,
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(0));
\GRFPC0_FP_PIPELINE_9_0_REGDEPX_168_0_A4_0_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00030000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.0.REGDEPX_168_0_A4_0_1\(0),
dataf => \GRFPC0.N_23887\,
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(0));
GRFPC0_FP_PIPELINE_6_0_CHECK_DEP_UN1983_REGDEPX_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.0.CHECK_DEP.UN1983_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(1),
datae => \GRFPC0.FIFO.INST_0\(2),
datad => \GRFPC0.FIFO.INST_0\(3),
datac => \GRFPC0.FIFO.INST_0\(4));
GRFPC0_FP_PIPELINE_2_0_CHECK_DEP_UN735_REGDEPX_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.UN735_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(1),
datae => \GRFPC0.FIFO.INST_0\(2),
datad => \GRFPC0.FIFO.INST_0\(3),
datac => \GRFPC0.FIFO.INST_0\(4));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_3_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f000c0")
port map (
combout => \GRFPC0.N_24979\,
dataf => \GRFPC0.N_23915\,
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_0_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff3c3c003c")
port map (
combout => \GRFPC0.N_23986_1\,
dataf => \GRFPC0.FIFO.INST_0\(19),
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_0\(14),
datac => \GRFPC0.FIFO.INST_0\(11),
datab => \GRFPC0.FIFO.INST_0\(12));
\GRFPC0_FP_PIPELINE_4_0_REGDEPX_77_0_A2_1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f030000000000000")
port map (
combout => \GRFPC0.N_24837_1\,
dataf => \GRFPC0.N_24921\,
datae => \GRFPC0.N_24892\,
datad => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_0\(17),
datab => \GRFPC0.FIFO.INST_0\(14));
\GRFPC0_FP_PIPELINE_10_0_REGDEPX_185_I_A2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f030000000000000")
port map (
combout => \GRFPC0.N_24880\,
dataf => \GRFPC0.N_24921\,
datae => \GRFPC0.N_24539\,
datad => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_0\(18),
datab => \GRFPC0.FIFO.INST_0\(14));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f300000000000000")
port map (
combout => \GRFPC0.N_25062\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_24921\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN80_REGDEPX\,
datac => \GRFPC0.FIFO.INST_0\(6),
datab => \GRFPC0.FIFO.INST_0\(14));
\GRFPC0_FP_PIPELINE_3_0_REGDEPX_59_0_A3_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff003c3c3c00")
port map (
combout => \GRFPC0.N_25016\,
dataf => \GRFPC0.FIFO.INST_0\(19),
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_0\(14),
datac => \GRFPC0.FIFO.INST_0\(11),
datab => \GRFPC0.FIFO.INST_0\(12));
\GRFPC0_FP_PIPELINE_4_0_REGDEPX_77_0_A2_3_I_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffc3ffffffffff")
port map (
combout => \GRFPC0.N_25021\,
dataf => \GRFPC0.N_22427\,
datae => \GRFPC0.FIFO.INST_0\(19),
datad => \GRFPC0.FIFO.INST_0\(17),
datac => \GRFPC0.FIFO.INST_0\(11),
datab => \GRFPC0.FIFO.INST_0\(12));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_2_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3c000000000000")
port map (
combout => \GRFPC0.N_22445_1\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22427\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0\(11),
datab => \GRFPC0.FIFO.INST_0\(12));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6428_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6428_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(16),
datae => \GRFPC0.EX.CTRL.INST\(15),
datad => \GRFPC0.EX.CTRL.INST\(18),
datac => \GRFPC0.EX.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_4_CHECK_DEP_DEP_11_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000c0")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_11\(0),
dataf => \GRFPC0.EX.CTRL.INST\(16),
datae => \GRFPC0.EX.CTRL.INST\(15),
datad => \GRFPC0.EX.CTRL.INST\(18),
datac => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(0));
\GRFPC0_FP_PIPELINE_4_CHECK_DEP_DEP_11_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000c0")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_11\(1),
dataf => \GRFPC0.EX.CTRL.INST\(16),
datae => \GRFPC0.EX.CTRL.INST\(15),
datad => \GRFPC0.EX.CTRL.INST\(18),
datac => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_0_A2_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_0_A2_0\(1),
dataf => \GRFPC0.EX.CTRL.INST\(16),
datae => \GRFPC0.EX.CTRL.INST\(15),
datad => \GRFPC0.EX.CTRL.INST\(18),
datac => \GRFPC0.EX.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_135_A0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_A0_0\(1),
dataf => \GRFPC0.MEM.CTRL.RS1V\,
datae => \GRFPC0.MEM.CTRL.INST\(15),
datad => \GRFPC0.MEM.CTRL.INST\(16),
datac => \GRFPC0.MEM.CTRL.INST\(18),
datab => \GRFPC0.MEM.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_9_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_9\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(1),
datae => \GRFPC0.MEM.CTRL.INST\(15),
datad => \GRFPC0.MEM.CTRL.INST\(16),
datac => \GRFPC0.MEM.CTRL.INST\(18),
datab => \GRFPC0.MEM.CTRL.INST\(17));
GRFPC0_FP_PIPELINE_UN11_SHARE: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc00fcfcfc00fc00")
port map (
combout => \GRFPC0.FP_PIPELINE.UN11_SHARE\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.LD\,
datad => \GRFPC0.MEM.CTRL.CCWR\,
datac => \GRFPC0.MEM.CTRL.VCNT\(1),
datab => \GRFPC0.MEM.CTRL.VCNT\(0));
GRFPC0_FP_PIPELINE_UN1_CPI_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0f0f000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_CPI_6\,
dataf => \GRFPC0.MEM.CTRL.LD\,
datae => \GRFPC0.MEM.CTRL.VCNT\(1),
datad => \GRFPC0.MEM.CTRL.VCNT\(0),
datac => N_39);
\GRFPU0_GRFPU_X0_COMB_EXPADDSUB_EXPT_0_M2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffffffff03")
port map (
combout => \GRFPU0.GRFPU_X0.N_30\,
dataf => \GRFPU0.GRFPU_X0.UN8_C\(9),
datae => \GRFPU0.GRFPU_X0.UN8_C\(8),
datad => \GRFPU0.GRFPU_X0.UN8_C\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
\GRFPU0_GRFPU_X0_COMB_EXPADDSUB_EXPT_0_O4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fff0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18264\,
dataf => \GRFPU0.GRFPU_X0.UN8_C\(10),
datae => \GRFPU0.GRFPU_X0.UN8_C\(7),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
GRFPU0_GRFPU_X0_UN1_EXPT_3_SQMUXA_3_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcfcfcff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18262\,
dataf => N_60914,
datae => \GRFPU0.GRFPU_X0.N_18269\,
datad => \GRFPU0.GRFPU_X0.N_19\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
\GRFPC0_R_STATE_RNI5E3AG_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f300")
port map (
combout => \GRFPC0.DIV.PC_0_0_9__G2\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datad => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datac => \GRFPC0.R.STATE\(0),
datab => \GRFPC0.R.STATE\(1));
\GRFPC0_R_STATE_RNI86TTF_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000cc0c")
port map (
combout => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datad => \GRFPC0.R.STATE\(0),
datac => \GRFPC0.R.STATE\(1),
datab => N_37);
GRFPC0_RFA_SEQERR_RNO_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc0c0000cccc0000")
port map (
combout => N_45055,
dataf => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2\,
datae => \GRFPC0.FP_PIPELINE.QNE2_I_A4_1\,
datad => \GRFPC0.R.STATE\(0),
datac => \GRFPC0.R.STATE\(1),
datab => N_45055_1);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_375_0_A3_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_25406\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datad => \GRFPC0.N_25380\,
datac => \GRFPC0.MEM.CTRL.INST\(29),
datab => \GRFPC0.MEM.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_14_CHECK_DEP_DEP_15_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_15\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datae => \GRFPC0.MEM.CTRL.INST\(27),
datad => \GRFPC0.MEM.CTRL.INST\(26),
datac => \GRFPC0.MEM.CTRL.INST\(29),
datab => \GRFPC0.MEM.CTRL.INST\(28));
GRFPC0_V_STDATA_0_SQMUXA_3_I_O4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPC0.N_23699\,
dataf => \GRFPC0.DIV.PEND\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.WR2.CTRL.PEND\);
GRFPC0_V_STDATA_0_SQMUXA_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff30ffff")
port map (
combout => \GRFPC0.N_23667\,
dataf => \GRFPC0.DIV.PEND\,
datae => \GRFPC0.WR.CTRL.PEND\,
datad => \GRFPC0.WR2.CTRL.PEND\,
datac => N_248,
datab => N_249);
GRFPC0_DIV_EXC_RNO_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00fffc")
port map (
combout => \GRFPC0.DIV.EXC_0_0_G0_I_O4_0\,
dataf => N_44718_1,
datae => \GRFPC0.N_23694\,
datad => \GRFPC0.WR2.CTRL.SEQERR\,
datac => \GRFPC0.WR2.EXC\,
datab => \GRFPC0.DIV.EXC\);
GRFPC0_VDIV_EXC_1_SQMUXA_0_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPC0.N_23696\,
dataf => \GRFPC0.N_23694\,
datae => \GRFPC0.WR2.CTRL.SEQERR\,
datad => \GRFPC0.WR2.EXC\,
datac => \GRFPC0.DIV.EXC\);
GRFPU0_GRFPU_X0_UN73_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN73_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(32));
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_4\(0),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(0),
datae => \GRFPC0.WR2.CTRL.INST\(29),
datad => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP\(1),
dataf => \GRFPC0.EX.CTRL.INST\(3),
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_200_0_A2_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_0_A2_1_0\(0),
dataf => \GRFPC0.EX.CTRL.INST\(27),
datae => \GRFPC0.EX.CTRL.INST\(26),
datad => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.EX.CTRL.INST\(28));
GRFPU0_GRFPU_X0_UN78_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN78_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(39),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(37));
\GRFPU0_GRFPU_X0_L1_4_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_1\(3),
dataf => \GRFPU0.GRFPU_X0.UN108_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(39),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(37));
GRFPC0_RFA_LD_RNIL6ET_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fffffffffffff")
port map (
combout => \GRFPC0.N_23234\,
dataf => \GRFPC0.RFA.LD\,
datae => N_176,
datad => N_174,
datac => N_173,
datab => N_175);
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_20_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_20\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datae => \GRFPC0.MEM.CTRL.INST\(26),
datad => \GRFPC0.MEM.CTRL.INST\(27),
datac => \GRFPC0.MEM.CTRL.INST\(29),
datab => \GRFPC0.MEM.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_3_CHECK_DEP_DEP_9_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_9\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(1),
datae => \GRFPC0.WR2.CTRL.INST\(29),
datad => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_475_0_A2_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_25848\,
dataf => \GRFPC0.N_703\,
datae => \GRFPC0.WR.CTRL.INST\(4),
datad => \GRFPC0.WR.CTRL.INST\(3),
datac => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_475_0_A2_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_25846\,
dataf => \GRFPC0.N_702\,
datae => \GRFPC0.WR.CTRL.INST\(4),
datad => \GRFPC0.WR.CTRL.INST\(3),
datac => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.N_25633\,
dataf => \GRFPC0.WR2.CTRL.RS1V\,
datae => \GRFPC0.WR2.CTRL.INST\(16),
datad => \GRFPC0.WR2.CTRL.INST\(18),
datac => \GRFPC0.WR2.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_475_0_A2_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_0_A2_0_1\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13\(1),
datae => \GRFPC0.N_25784\,
datad => \GRFPC0.WR2.CTRL.RS1V\,
datac => \GRFPC0.WR2.CTRL.INST\(15),
datab => \GRFPC0.WR2.CTRL.INST\(16));
\GRFPC0_FP_PIPELINE_3_CHECK_DEP_DEP_8_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_8_0\(1),
dataf => \GRFPC0.WR2.CTRL.INST\(15),
datae => \GRFPC0.WR2.CTRL.INST\(16),
datad => \GRFPC0.WR2.CTRL.INST\(17),
datac => \GRFPC0.WR2.CTRL.INST\(18));
\GRFPU0_GRFPU_X0_L3_0_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"110f110f0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3\(1),
dataf => \GRFPU0.GRFPU_X0.L2_0\(4),
datae => N_82199,
datad => \GRFPU0.GRFPU_X0.UN83_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.N_14265_1\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(50),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(49));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_I_M2_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18615\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(113),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(113),
datab => N_28091);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15890\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(113),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(113),
datab => N_28091);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19264\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(0),
datad => N_391,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19274\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(10),
datad => N_401,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19275\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(11),
datad => N_402,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19276\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(12),
datad => N_403,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19277\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(13),
datad => N_404,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19278\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(14),
datad => N_405,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19279\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(15),
datad => N_406,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19280\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(16),
datad => N_407,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19281\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(17),
datad => N_408,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19282\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(18),
datad => N_409,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19283\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(19),
datad => N_410,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19265\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(1),
datad => N_392,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19284\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(20),
datad => N_411,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19285\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(21),
datad => N_412,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19286\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(22),
datad => N_413,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19287\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(23),
datad => N_414,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19288\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(24),
datad => N_415,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19289\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(25),
datad => N_416,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19290\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(26),
datad => N_417,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19291\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(27),
datad => N_418,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19292\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(28),
datad => N_419,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19293\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(29),
datad => N_420,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19266\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(2),
datad => N_393,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19294\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(30),
datad => N_421,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19295\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(31),
datad => N_422,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19267\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(3),
datad => N_394,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19268\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(4),
datad => N_395,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19269\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(5),
datad => N_396,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19270\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(6),
datad => N_397,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19271\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(7),
datad => N_398,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19272\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(8),
datad => N_399,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff03fc00ff00ff00")
port map (
combout => \GRFPC0.N_19273\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(9),
datad => N_400,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19296\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(32),
datad => N_391,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19297\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(33),
datad => N_392,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19298\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(34),
datad => N_393,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19299\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(35),
datad => N_394,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19300\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(36),
datad => N_395,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19301\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(37),
datad => N_396,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19302\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(38),
datad => N_397,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19303\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(39),
datad => N_398,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19304\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(40),
datad => N_399,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19305\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(41),
datad => N_400,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19306\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(42),
datad => N_401,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19307\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(43),
datad => N_402,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19308\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(44),
datad => N_403,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19309\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(45),
datad => N_404,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19310\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(46),
datad => N_405,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19311\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(47),
datad => N_406,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19312\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(48),
datad => N_407,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19313\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(49),
datad => N_408,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19314\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(50),
datad => N_409,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19315\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(51),
datad => N_410,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19316\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(52),
datad => N_411,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19317\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(53),
datad => N_412,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19318\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(54),
datad => N_413,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19319\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(55),
datad => N_414,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19320\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(56),
datad => N_415,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19321\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(57),
datad => N_416,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19322\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(58),
datad => N_417,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19323\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(59),
datad => N_418,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19324\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(60),
datad => N_419,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19325\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(61),
datad => N_420,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19326\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(62),
datad => N_421,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_2_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0300ff00ff00")
port map (
combout => \GRFPC0.N_19327\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR2.RREG.RES\(63),
datad => N_422,
datac => N_386,
datab => N_387);
\GRFPC0_FP_PIPELINE_REN1_1_IV_0_O3_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0000c0cfc0c0")
port map (
combout => \GRFPC0.N_25099\,
dataf => N_425,
datae => \GRFPC0.N_25098\,
datad => \GRFPC0.FP_PIPELINE.UN1_VRFA.ST\,
datac => N_423,
datab => N_424);
\GRFPC0_FP_PIPELINE_WREN_1_F0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00c03fff")
port map (
combout => RFI1_WRENZ,
dataf => N_425,
datae => \GRFPC0.FP_PIPELINE.WREN_17_I\(0),
datad => N_426,
datac => N_424,
datab => N_423);
\GRFPC0_FP_PIPELINE_WREN_1_F0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffc000ff3f")
port map (
combout => RFI2_WRENZ,
dataf => N_425,
datae => \GRFPC0.FP_PIPELINE.WREN_17_IV\(1),
datad => N_426,
datac => N_424,
datab => N_423);
\GRFPC0_FP_PIPELINE_REN1_1_IV_0_A3_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff000000")
port map (
combout => \GRFPC0.WREN_0_SQMUXA\,
dataf => N_425,
datae => N_424,
datad => N_423);
\GRFPC0_WRDATA_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(0),
dataf => N_431,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(32),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(1),
dataf => N_432,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(33),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(2),
dataf => N_433,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(34),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(3),
dataf => N_434,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(35),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(4),
dataf => N_435,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(36),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(5),
dataf => N_436,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(37),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(6),
dataf => N_437,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(38),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(7),
dataf => N_438,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(39),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(8),
dataf => N_439,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(40),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(9),
dataf => N_440,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(41),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(10),
dataf => N_441,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(42),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(11),
dataf => N_442,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(43),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(12),
dataf => N_443,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(44),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(13),
dataf => N_444,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(45),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(14),
dataf => N_445,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(46),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(15),
dataf => N_446,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(47),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(16),
dataf => N_447,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(48),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(17),
dataf => N_448,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(49),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(18),
dataf => N_449,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(50),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(19),
dataf => N_450,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(51),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(20),
dataf => N_451,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(52),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(21),
dataf => N_452,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(53),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(22),
dataf => N_453,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(54),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(23),
dataf => N_454,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(55),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(24),
dataf => N_455,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(56),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(25),
dataf => N_456,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(57),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(26),
dataf => N_457,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(58),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(27),
dataf => N_458,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(59),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(28),
dataf => N_459,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(60),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(29),
dataf => N_460,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(61),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(30),
dataf => N_461,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(62),
datad => N_424,
datac => N_423);
\GRFPC0_WRDATA_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => RFI1_WRDATAZ(31),
dataf => N_462,
datae => \GRFPC0.FP_PIPELINE.WRDATA_3\(63),
datad => N_424,
datac => N_423);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15842\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(116),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(116),
datab => N_28097);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15893\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(116),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(116),
datab => N_28097);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_0_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\(23),
dataf => N_97,
datae => N_104,
datad => N_105,
datac => N_106,
datab => N_107);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fcf33cc0f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(34),
dataf => \GRFPU0.GRFPU_X0.N_3560_I\,
datae => N_99921,
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.MULO.MRES\(95),
datab => \GRFPU0.FPMUL0.SX\(94));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00000ff00ff0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15820\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(94),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(94));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00000ff00ff0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15871\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(94),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(94));
\GRFPU0_GRFPU_X0_L1_1_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f000f040f04")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_3\(0),
dataf => \GRFPU0.GRFPU_X0.UN93_BCO_LSB_0\,
datae => \GRFPU0.GRFPU_X0.BCO_MSB_2\(0),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(9),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(8),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(11),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(10));
\GRFPU0_GRFPU_X0_RNDOP_14_IV_RNICV9L2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000c0000000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP_0_0\,
dataf => \GRFPU0.GRFPU_X0.RNDOP_14\(0),
datae => \GRFPU0.GRFPU_X0.COMB.LOB2_I_M_1_I_0_0\,
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_43_M2_E_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_43_M2_E_0\,
dataf => \GRFPU0.GRFPU_X0.N_3560_I\,
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_XX_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff000c0000")
port map (
combout => N_93231,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(40),
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(3),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_3_0_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_3_0\(41),
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.MRES\(100),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_6_1_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6_1\(41),
dataf => \GRFPU0.GRFPU_X0.RNDOP_14\(0),
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_6_S_0_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6_S_0\(43),
dataf => \GRFPU0.GRFPU_X0.RNDOP_14\(0),
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_11_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0fff0f0f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(0),
dataf => \GRFPU0.GRFPU_X0.L3_0_3\(0),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_11_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccc0cccfcccfccc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(1),
dataf => \GRFPU0.GRFPU_X0.L3_0_3\(0),
datae => \GRFPU0.GRFPU_X0.L3_0_3\(1),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(1));
GRFPU0_GRFPU_X0_VITER_EXPOP_1_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPC0_FIFO_VCNT_1_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f4ff00000000")
port map (
combout => N_47285,
dataf => \GRFPC0.FIFO.VCNT_1_0_0__G1_1_4304_I_1\,
datae => N_47157,
datad => N_47093,
datac => N_47153,
datab => \GRFPC0.FIFO.VCNT_1\(2),
dataa => \GRFPC0.FIFO.VCNT_1\(1));
\GRFPU0_GRFPU_X0_BCO_MSB_3_4_I_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffcfffcfffc00")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_4_I_0_0\(1),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(28));
\GRFPU0_GRFPU_X0_ITER_R_I_RNINCI12_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03000300030003ff")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1\(3),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(28));
\GRFPC0_FP_PIPELINE_14_STDEP_594_0_O2_I_A3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_661\,
dataf => \GRFPC0.RFA.LD\,
datae => N_176,
datad => N_173,
datac => N_175,
datab => N_174);
\GRFPC0_FIFO_INST_1_RNIEEFJ1_0_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff0ffff")
port map (
combout => \GRFPC0.N_22244\,
dataf => \GRFPC0.FIFO.INST_1\(28),
datae => \GRFPC0.FIFO.INST_1\(29),
datad => \GRFPC0.FIFO.INST_1\(26),
datac => \GRFPC0.FIFO.INST_1\(27));
GRFPC0_FP_PIPELINE_9_1_CHECK_DEP_UN2992_REGDEPX_I_0_O4_I_A2_0_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0ffffff")
port map (
combout => \GRFPC0.N_548\,
dataf => \GRFPC0.FIFO.INST_1\(28),
datae => \GRFPC0.FIFO.INST_1\(29),
datad => \GRFPC0.FIFO.INST_1\(26),
datac => \GRFPC0.FIFO.INST_1\(27));
\GRFPC0_D_STLCK_RNO_8_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000c0000000")
port map (
combout => \GRFPC0.N_23431\,
dataf => \GRFPC0.N_106_I\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => N_245,
datac => \GRFPC0.N_23478\,
datab => N_241);
\GRFPC0_D_STLCK_RNO_5_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000fff0")
port map (
combout => \GRFPC0.D.STLCK_0_0_17__G1_0\,
dataf => \GRFPC0.N_21203\,
datae => \GRFPC0.N_60\,
datad => \GRFPC0.N_106_I\,
datac => N_241);
\GRFPC0_D_STLCK_RNO_0_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00fc00ff")
port map (
combout => \GRFPC0.D.STLCK_0_0_25__G1_1\,
dataf => \GRFPC0.D.STLCK_0_0_25__G1_0\,
datae => \GRFPC0.N_23371\,
datad => \GRFPC0.STDDEP_0_SQMUXA_12_I_1\,
datac => \GRFPC0.N_106_I\,
datab => N_241);
\GRFPC0_D_STLCK_RNO_5_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000f0000000")
port map (
combout => \GRFPC0.N_23199\,
dataf => \GRFPC0.N_106_I\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4855_DEP\,
datac => N_241);
\GRFPC0_FP_PIPELINE_3_STDEP_158_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fffffff3ffffff")
port map (
combout => \GRFPC0.N_18122\,
dataf => \GRFPC0.N_106_I\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => \GRFPC0.N_23478\,
datac => N_245,
datab => N_241);
GRFPC0_FP_PIPELINE_9_0_CHECK_DEP_UN2887_REGDEPX_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2887_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(29),
datae => \GRFPC0.FIFO.INST_0\(26),
datad => \GRFPC0.FIFO.INST_0\(27),
datac => \GRFPC0.FIFO.INST_0\(28));
\GRFPC0_FP_PIPELINE_14_0_REGDEPX_257_0_A2_0_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c00000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_111_I_I_A2_0_A3_0\,
dataf => \GRFPC0.FIFO.INST_0\(19),
datae => \GRFPC0.FIFO.INST_0\(29),
datad => \GRFPC0.FIFO.INST_0\(26),
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28));
\GRFPU0_GRFPU_X0_L1_4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eeefeeefffff0000")
port map (
combout => N_82184,
dataf => \GRFPU0.GRFPU_X0.UN108_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.N_14235\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(39),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(37),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(36));
GRFPC0_STDDEP_0_SQMUXA_13_I_O4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3fffffffffff")
port map (
combout => \GRFPC0.N_23261\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_243,
datad => N_245,
datac => N_244,
datab => N_242);
GRFPC0_FP_PIPELINE_8_STDEP_336_SEL0_0_I_O3_0_O4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3ffffffff")
port map (
combout => \GRFPC0.N_55\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_A3_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffff00000000")
port map (
combout => \GRFPC0.N_123\,
dataf => \GRFPC0.FP_PIPELINE.8.STDEP_332_SEL0_1\,
datae => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2698_DEP_1\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(2));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(46),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(46),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(26),
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(58));
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_GT_EXPT18LTO11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_GT.EXPT18\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\,
datae => \GRFPU0.GRFPU_X0.UN8_C\(10),
datad => \GRFPU0.GRFPU_X0.UN8_C\(9),
datac => \GRFPU0.GRFPU_X0.UN8_C\(8),
datab => \GRFPU0.GRFPU_X0.UN8_C\(7));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(39),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(39),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(19),
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(51));
GRFPC0_RFA_LD_RNIL6ET_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPC0.N_22975_I\,
dataf => \GRFPC0.RFA.LD\,
datae => N_173,
datad => N_174,
datac => N_176,
datab => N_175);
GRFPC0_RFA_LD_RNIL6ET_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_21515\,
dataf => \GRFPC0.RFA.LD\,
datae => N_174,
datad => N_173,
datac => N_176,
datab => N_175);
GRFPU0_GRFPU_X0_UN233_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN233_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(10),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(11));
\GRFPU0_GRFPU_X0_COMB_UN43_FLUSH_ALTB_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff333f033f033300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH.ALTB\(2),
datae => \FPI.FLUSHID\(3),
datad => \FPI.FLUSHID\(4),
datac => \GRFPU0.GRFPU_X0.ST2.ID\(3),
datab => \GRFPU0.GRFPU_X0.ST2.ID\(4));
GRFPU0_GRFPU_X0_EXP_0_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datad => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0),
datac => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1));
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_I_O2_0_0_O3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffffffffff")
port map (
combout => \GRFPC0.N_474\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_A2_4_I_A3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPC0.N_655\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4));
\GRFPC0_WR_CTRL_RD_RNIVS202_0_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffffffff")
port map (
combout => \GRFPC0.N_21353\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_6_1_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.N_24978_1\,
dataf => \GRFPC0.FIFO.INST_0\(18),
datae => \GRFPC0.FIFO.INST_0\(17),
datad => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.INST_0\(15));
GRFPC0_FP_PIPELINE_3_STDEP_136_SEL0_0_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcfffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_136_SEL0_1\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1058_DEP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1058_DEP\,
dataf => \GRFPC0.EX.CTRL.RD\(3),
datae => \GRFPC0.EX.CTRL.RD\(2),
datad => \GRFPC0.EX.CTRL.RD\(1),
datac => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_A2_4_I_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPC0.N_21502_2\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_2_STDEP_110_0_IV_0_O3_2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_110_0_IV_0_O3_2_0\(0),
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN64_DEP_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP\,
dataf => \GRFPC0.EX.CTRL.RD\(3),
datae => \GRFPC0.EX.CTRL.RD\(2),
datad => \GRFPC0.EX.CTRL.RD\(1),
datac => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_A2_0_I_O3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffcfffffffff")
port map (
combout => \GRFPC0.N_570\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN730_DEP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN730_DEP\,
dataf => \GRFPC0.EX.CTRL.RD\(3),
datae => \GRFPC0.EX.CTRL.RD\(2),
datad => \GRFPC0.EX.CTRL.RD\(1),
datac => \GRFPC0.EX.CTRL.RD\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A5_1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A5_1_0\(0),
dataf => \GRFPU0.GRFPU_X0.C\(11),
datae => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT63_0_A2_0_2\,
datad => \GRFPU0.GRFPU_X0.C\(10),
datac => \GRFPU0.GRFPU_X0.C\(1),
datab => \GRFPU0.GRFPU_X0.C\(0));
GRFPC0_STDDEP_0_SQMUXA_25_I_0_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffffffffff")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_25_I_1\,
dataf => \GRFPC0.RFA.LD\,
datae => N_175,
datad => N_176,
datac => N_174,
datab => N_173);
\GRFPC0_FP_PIPELINE_5_STDEP_230_0_IV_I_I2_6_I4_0_A3_RNII4M61_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffffffffff")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_128_I_1\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => N_106,
datad => N_107,
datac => N_104,
datab => N_105);
\GRFPU0_GRFPU_X0_L1_4_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff3fff0fff0")
port map (
combout => N_82188,
dataf => \GRFPU0.GRFPU_X0.N_14145\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(42));
GRFPU0_GRFPU_X0_UN158_BCO_LSB_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN158_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(42));
GRFPU0_GRFPU_X0_UN58_BCO_LSB_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN58_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(42));
\GRFPU0_GRFPU_X0_ITER_R_I_RNIL3OC3_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5\(3),
dataf => \GRFPU0.GRFPU_X0.L1_1_2\(3),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(51));
GRFPU0_GRFPU_X0_UN163_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN163_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(51));
GRFPC0_FP_PIPELINE_6_STDEP_248_SEL1_I_0_A2_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3fff")
port map (
combout => \GRFPC0.N_22000\,
dataf => \GRFPC0.N_453\,
datae => \GRFPC0.WR.CTRL.RDD\,
datad => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(2));
\GRFPC0_FP_PIPELINE_14_CHECK_DEP_DEP_16_I_I2_0_O2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffffffffff")
port map (
combout => \GRFPC0.N_23806\,
dataf => \GRFPC0.WR.CTRL.RD\(3),
datae => \GRFPC0.WR.CTRL.RD\(2),
datad => \GRFPC0.WR.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN4958_DEP_I_S: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffffffffffff")
port map (
combout => \GRFPC0.N_25889\,
dataf => \GRFPC0.WR.CTRL.RD\(3),
datae => \GRFPC0.WR.CTRL.RD\(2),
datad => \GRFPC0.WR.CTRL.RD\(1),
datac => \GRFPC0.WR.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_I_O2_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0fcf")
port map (
combout => \GRFPC0.N_76\,
dataf => \GRFPC0.N_561\,
datae => \GRFPC0.N_453\,
datad => \GRFPC0.WR.CTRL.RDD\,
datac => \GRFPC0.WR.CTRL.RDWR\,
datab => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_7_STDEP_292_3_0_O2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00fff0ff")
port map (
combout => \GRFPC0.N_21820\,
dataf => \GRFPC0.N_21817\,
datae => \GRFPC0.WR.CTRL.RDD\,
datad => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_7_STDEP_292_3_I_O2_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0fff")
port map (
combout => \GRFPC0.N_21822\,
dataf => \GRFPC0.N_21817\,
datae => \GRFPC0.WR.CTRL.RDD\,
datad => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_14_STDEP_568_3_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f0000000fc")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_568_3_0_0\(1),
dataf => \GRFPC0.N_114\,
datae => \GRFPC0.N_23806\,
datad => \GRFPC0.N_23802\,
datac => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_14_STDEP_568_3_0_A2_0_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffffff3")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_568_3_0_A2_0_0\(1),
dataf => \GRFPC0.N_481\,
datae => \GRFPC0.N_23806\,
datad => \GRFPC0.N_23802\,
datac => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_11_STDEP_452_3_0_O3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ff00")
port map (
combout => \GRFPC0.N_21729\,
dataf => \GRFPC0.N_21725\,
datae => \GRFPC0.WR.CTRL.RDD\,
datad => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_D_STLCK_RNO_1_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A2_4_1\(1),
dataf => \GRFPC0.N_458\,
datae => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3628_DEP\,
datad => \GRFPC0.N_21725\,
datac => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_D_STLCK_RNO_3_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.N_23439\,
dataf => \GRFPC0.N_23495\,
datae => \GRFPC0.N_114\,
datad => \GRFPC0.N_21725\,
datac => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.WR.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_3_STDEP_132_SEL1_I_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_18634\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_2\,
datae => \GRFPC0.N_579\,
datad => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.MEM.CTRL.RD\(2),
datab => \GRFPC0.MEM.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_0_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0fffffffffff")
port map (
combout => \GRFPC0.N_74\,
dataf => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2024_DEP\,
datae => \GRFPC0.N_579\,
datad => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.MEM.CTRL.RD\(0));
GRFPC0_STDDEP_0_SQMUXA_179: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fff00000c000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_179\,
dataf => \GRFPC0.UN1_STDDEP_0_SQMUXA_102\,
datae => \GRFPC0.FP_PIPELINE.3.STDEP_136_SEL0_1\,
datad => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1040_DEP\,
datac => \GRFPC0.N_579\,
datab => \GRFPC0.MEM.CTRL.RDWR\);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15823\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(97),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(97),
datab => N_28059);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15874\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(97),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(97),
datab => N_28059);
GRFPU0_GRFPU_X0_UN1_INC_0_SQMUXA_0_M4_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff330000ff0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_18637\,
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datad => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
datac => \GRFPU0.FPMUL0.SX\(97),
datab => N_28059);
\GRFPC0_EX_CTRL_RD_RNIVL8L_0_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffffffffff")
port map (
combout => \GRFPC0.N_546\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_0_O2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3ffffffffff")
port map (
combout => \GRFPC0.N_490\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2_2_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003fffffff")
port map (
combout => \GRFPC0.N_21581_2\,
dataf => \GRFPC0.N_858\,
datae => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2698_DEP_1\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_14_STDEP_576_SEL0_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fffffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datae => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2698_DEP_1\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(2));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_0_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000f0000000")
port map (
combout => \GRFPC0.N_22370_2\,
dataf => N_84,
datae => N_92,
datad => N_94,
datac => N_93);
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3736_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3736_REGDEPX\,
dataf => N_96,
datae => N_95,
datad => N_94,
datac => N_93);
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN4984_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4984_REGDEPX\,
dataf => N_95,
datae => N_96,
datad => N_94,
datac => N_93);
GRFPC0_EX_RREG_RESV_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0000000f000f00")
port map (
combout => \GRFPC0.N_10577\,
dataf => \GRFPC0.N_82\,
datae => \GRFPC0.EX.RREG.RESV\,
datad => N_35,
datac => N_37);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_2_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.N_25344_1\,
dataf => N_79,
datae => N_80,
datad => N_82,
datac => N_81);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_15_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000300")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_15\(1),
dataf => N_79,
datae => N_80,
datad => \GRFPC0.N_23978\,
datac => N_82,
datab => N_81);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O3_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcffffff")
port map (
combout => \GRFPC0.N_22824\,
dataf => N_80,
datae => N_79,
datad => \GRFPC0.N_23978\,
datac => N_82,
datab => N_81);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_0_A4_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_25568\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13\(1),
datae => \GRFPC0.N_25568_1\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.CTRL.DIV\,
datab => \GRFPC0.WR2.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_8_0_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00f0ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90\(0),
dataf => \GRFPC0.FP_PIPELINE.2.REGDEPX2_83\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_2\(0),
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_A2_1_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_25805_1\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13\(1),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN383_REGDEPX2_1\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.CTRL.RS1V\,
datab => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_9_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0cff000c0c0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_9\(1),
dataf => \GRFPC0.N_25444_1\,
datae => \GRFPC0.N_25637_1\,
datad => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3386_REGDEPX2_2\,
datac => \GRFPC0.WR2.RREG.RESV\,
datab => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_O2_7_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00ff0c")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_O2_7\(0),
dataf => \GRFPC0.N_24775\,
datae => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_I_A4_1\(0),
datad => \GRFPC0.N_24177\,
datac => \GRFPC0.WR2.RREG.RESV\,
datab => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_A2_1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff000f00")
port map (
combout => \GRFPC0.N_24087_1\,
dataf => \GRFPC0.WR2.RREG.RESV\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.CTRL.DIV\,
datac => \GRFPC0.WR2.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_355_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000f000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355_1\(0),
dataf => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_20\(0),
datae => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_8\(0),
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_355_A0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f03000000000")
port map (
combout => N_1_3,
dataf => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355_A0_0\(0),
datae => \GRFPC0.WR2.RREG.RESV\,
datad => \GRFPC0.WR2.CTRL.RDD\,
datac => \GRFPC0.WR2.CTRL.DIV\,
datab => \GRFPC0.WR2.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0c0cfff30c00")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415\(0),
dataf => \GRFPC0.FP_PIPELINE.13.REGDEPX2_413\(0),
datae => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410\(0),
datad => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_3\(0),
datac => \GRFPC0.WR2.RREG.RESV\,
datab => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000300000000000")
port map (
combout => \GRFPC0.N_25632\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(1),
datae => \GRFPC0.WR2.RREG.RESV\,
datad => \GRFPC0.WR2.CTRL.INST\(1),
datac => \GRFPC0.WR2.CTRL.DIV\,
datab => \GRFPC0.WR2.CTRL.INST\(4));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_0_A2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0003000")
port map (
combout => \GRFPC0.N_25634\,
dataf => \GRFPC0.WR2.RREG.RESV\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.CTRL.DIV\,
datac => \GRFPC0.WR2.CTRL.INST\(15),
datab => \GRFPC0.WR2.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_5_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c000000")
port map (
combout => \GRFPC0.N_25842\,
dataf => \GRFPC0.N_25784\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN383_REGDEPX2_1\,
datad => \GRFPC0.N_25842_1\,
datac => \GRFPC0.WR2.RREG.RESV\,
datab => \GRFPC0.WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_7_RNIGEKJ1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcfcff03fc00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_18__G3\,
dataf => \GRFPC0.FP_PIPELINE.9.REGDEPX2_298\(0),
datae => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295\(0),
datad => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_7\(0),
datac => \GRFPC0.DIV.EXEC\,
datab => \GRFPC0.DIV.VALID\);
\GRFPC0_D_LDLCK_RNO_0_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0000f0000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_19__G3\,
dataf => \GRFPC0.FP_PIPELINE.9.REGDEPX2_299\(1),
datae => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295\(1),
datad => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.DIV.VALID\);
\GRFPC0_D_LDLCK_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcff03ff00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_1__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_29\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_25\(1),
datad => \GRFPC0.D.LDLCK_0_0_1__G1_TZ\,
datac => \GRFPC0.DIV.EXEC\,
datab => \GRFPC0.DIV.VALID\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_120_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120\(1),
dataf => \GRFPC0.FP_PIPELINE.3.REGDEPX2_119\(1),
datae => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115\(1),
datad => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.DIV.VALID\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60\(1),
dataf => \GRFPC0.FP_PIPELINE.1.REGDEPX2_59\(1),
datae => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55\(1),
datad => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.DIV.VALID\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00c000000000")
port map (
combout => \GRFPC0.N_24219\,
dataf => \GRFPC0.N_24242\,
datae => \GRFPC0.DIV.EXEC\,
datad => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.DIV.VALID\,
datab => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90\(1),
dataf => \GRFPC0.FP_PIPELINE.2.REGDEPX2_89\(1),
datae => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85\(1),
datad => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.DIV.VALID\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_A4_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f00030303000")
port map (
combout => \GRFPC0.N_24222_1\,
dataf => \GRFPC0.DIV.RDD\,
datae => \GRFPC0.DIV.EXEC\,
datad => \GRFPC0.DIV.VALID\,
datac => \GRFPC0.DIV.RS1V\,
datab => \GRFPC0.DIV.INST\(14));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_A4_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000f0f0f00")
port map (
combout => \GRFPC0.N_25560_2\,
dataf => \GRFPC0.DIV.RDD\,
datae => \GRFPC0.DIV.EXEC\,
datad => \GRFPC0.DIV.VALID\,
datac => \GRFPC0.DIV.RD\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_1_0_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffc000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_1_0\(24),
dataf => \GRFPC0.N_25760_2\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5739_REGDEPX2\,
datac => \GRFPC0.DIV.EXEC\,
datab => \GRFPC0.DIV.VALID\);
GRFPC0_FP_PIPELINE_3_STDEP_136_SEL0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fffffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_136_SEL0\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_2\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(2),
datab => \GRFPC0.EX.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_7_STDEP_296_SEL0_0_1_O4_0_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_1\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_11_STDEP_456_SEL0_0_0_O2_0_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3fffffffffff")
port map (
combout => \GRFPC0.N_21721\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_15_CHECK_DEP_DEP_20_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_20\(0),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_15_STDEP_616_SEL0_0_1_I_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_23088\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_15_STDEP_616_SEL1_I_0_A2_1_0_A3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_18394_1\,
dataf => \GRFPC0.N_106_I\,
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN2370_DEP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2370_DEP\,
dataf => \GRFPC0.EX.CTRL.RD\(3),
datae => \GRFPC0.EX.CTRL.RD\(2),
datad => \GRFPC0.EX.CTRL.RD\(1),
datac => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_15_STDEP_612_SEL1_I_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_18829\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_54_0\,
datae => \GRFPC0.MEM.CTRL.RD\(2),
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN4976_DEP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4976_DEP\,
dataf => \GRFPC0.MEM.CTRL.RD\(2),
datae => \GRFPC0.MEM.CTRL.RD\(4),
datad => \GRFPC0.MEM.CTRL.RD\(1),
datac => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff000f000f000")
port map (
combout => \GRFPU0.GRFPU_X0.DIFFIN2_4\(0),
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0));
GRFPU0_GRFPU_X0_ST2_DIFFN_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10083\,
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1\(53),
datae => \GRFPU0.GRFPU_X0.ST2.DIFFN_0_0_G0_0\,
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNO_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.DIFF_1\(53),
dataf => \GRFPU0.GRFPU_X0.UN8_DIFF2\(53),
datae => \GRFPU0.GRFPU_X0.UN2_DIFF1\(53),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datac => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1));
GRFPU0_GRFPU_X0_COMB_VST2_DIFF2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1\(53),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_80288,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_80289,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_80290,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffccf0cc00ccf0")
port map (
combout => N_80291,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_80292,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_80293,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_80294,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_80295,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_80296,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffccf0cc00ccf0")
port map (
combout => N_80279,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_80298,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffccf0cc00ccf0")
port map (
combout => N_80299,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_80300,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffccf0cc00ccf0")
port map (
combout => N_80301,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_80302,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_80303,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffccf0cc00ccf0")
port map (
combout => N_80304,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffccf0cc00ccf0")
port map (
combout => N_80306,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => N_80307,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffccf0cc00ccf0")
port map (
combout => N_80280,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_80308,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccf0f0ff00")
port map (
combout => N_80309,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => N_80310,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccf0f0ff00")
port map (
combout => N_80312,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => N_80313,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_80314,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_80315,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_80316,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_80317,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_80281,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_80319,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_80320,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccf0f0ff00")
port map (
combout => N_80321,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_80323,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_80324,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.DIVROM0.RADDR\(2),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_80325,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.DIVROM0.RADDR\(3),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_80327,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_80282,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccf0f0ff00")
port map (
combout => N_80328,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccf0f0ff00")
port map (
combout => N_80329,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.DIVROM0.RADDR\(6),
datac => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_80283,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_80284,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_80285,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6));
\GRFPU0_GRFPU_X0_DIFFIN2_4_1_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_80287,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_1_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_80322,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.DIVROM0.RADDR\(0),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M2_1_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_80326,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(3),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_0_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_80305,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_0_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_80311,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M3_0_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccff00f0f0")
port map (
combout => N_80318,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M4_0_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffccf0cc00ccf0")
port map (
combout => N_80297,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19));
\GRFPU0_GRFPU_X0_DIFFIN2_4_I_M4_0_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf000f0cc")
port map (
combout => N_80286,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7));
GRFPC0_FP_PIPELINE_0_UN1_DEP_RNI3QFS_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_23127\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datae => N_106,
datad => N_107,
datac => N_104,
datab => N_105);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_M2_0_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ffff0000330f")
port map (
combout => \GRFPU0.GRFPU_X0.N_18342\,
dataf => \GRFPU0.GRFPU_X0.N_18311\,
datae => \GRFPU0.GRFPU_X0.N_18663\,
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(112),
datab => N_28089);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15838\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(112),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(112),
datab => N_28089);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15889\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(112),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(112),
datab => N_28089);
\GRFPC0_FP_PIPELINE_9_STDEP_376_3_I_O3_I_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcfffffffffff")
port map (
combout => \GRFPC0.N_502\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(2),
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_7_0_CHECK_DEP_DEP_2_IV_0_O4_0_O4_I_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.N_25056\,
dataf => \GRFPC0.FIFO.INST_0\(29),
datae => \GRFPC0.FIFO.INST_0\(26),
datad => \GRFPC0.FIFO.INST_0\(27),
datac => \GRFPC0.FIFO.INST_0\(28));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN4999_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4999_REGDEPX\,
dataf => N_81,
datae => N_82,
datad => N_80,
datac => N_79);
GRFPC0_FP_PIPELINE_12_1_CHECK_DEP_UN3959_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3959_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(3),
datae => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.INST_1\(1));
\GRFPC0_D_STDLCK_RNO_1_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00fcffff0000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_11__G1_3\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.D.STDLCK_0_0_11__G1_2\,
datad => \GRFPC0.N_21721\,
datac => \GRFPC0.N_106_I\,
datab => \GRFPC0.EX.CTRL.RD\(0));
\GRFPC0_D_STDLCK_RNO_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffffff03ff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_0__G1_1\,
dataf => \GRFPC0.N_507\,
datae => \GRFPC0.N_22975_I\,
datad => \GRFPC0.N_22960\,
datac => \GRFPC0.N_106_I\,
datab => \GRFPC0.EX.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_13_0_CHECK_DEP_DEP_2_IV_0_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0fffffffffffff")
port map (
combout => \GRFPC0.N_22536\,
dataf => \GRFPC0.FIFO.INST_0\(29),
datae => \GRFPC0.FIFO.INST_0\(26),
datad => \GRFPC0.FIFO.INST_0\(27),
datac => \GRFPC0.FIFO.INST_0\(28));
\GRFPC0_D_STLCK_RNO_2_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000c00")
port map (
combout => \GRFPC0.N_168\,
dataf => \GRFPC0.N_22546\,
datae => \GRFPC0.FIFO.INST_0\(29),
datad => \GRFPC0.FIFO.INST_0\(26),
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28));
\GRFPC0_FIFO_INST_1_RNI2GB02_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffcfffff")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_123_I_I_A2_I_O2_0\,
dataf => \GRFPC0.FIFO.INST_1\(19),
datae => \GRFPC0.FIFO.INST_1\(28),
datad => \GRFPC0.FIFO.INST_1\(29),
datac => \GRFPC0.FIFO.INST_1\(26),
datab => \GRFPC0.FIFO.INST_1\(27));
\GRFPC0_FP_PIPELINE_4_REGDEPX_84_0_O2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => \GRFPC0.N_22639\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.FIFO.INST_1\(28),
datad => \GRFPC0.FIFO.INST_1\(29),
datac => \GRFPC0.FIFO.INST_1\(26),
datab => \GRFPC0.FIFO.INST_1\(27));
GRFPC0_FP_PIPELINE_13_1_CHECK_DEP_UN4240_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4240_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(29),
datae => \GRFPC0.FIFO.INST_1\(28),
datad => \GRFPC0.FIFO.INST_1\(26),
datac => \GRFPC0.FIFO.INST_1\(27));
GRFPC0_STDDEP_0_SQMUXA_10_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_10\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_245,
datad => N_242,
datac => N_243,
datab => N_244);
\GRFPU0_GRFPU_X0_L1_4_2_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_2\(3),
dataf => \GRFPU0.GRFPU_X0.UN228_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(15));
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(10),
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.DRES_1\(107),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datac => N_28136,
datab => N_28135);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_0_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0880000f088")
port map (
combout => \GRFPU0.GRFPU_X0.N_17110\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_47\(63),
datae => \GRFPU0.GRFPU_X0.VST2.REG_4_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.ADD_1_1\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN1\,
datab => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(0));
GRFPU0_GRFPU_X0_COMB_EXPINC_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf0ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
dataf => \GRFPU0.MULO.MRES_1\(121),
datae => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(121),
datab => N_28107);
\GRFPC0_FP_PIPELINE_14_CHECK_DEP_DEP_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_1\(0),
dataf => \GRFPC0.N_702\,
datae => \GRFPC0.WR.CTRL.INST\(4),
datad => \GRFPC0.WR.CTRL.INST\(3),
datac => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_200_0_A2_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A4_1_0\(1),
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(3),
datad => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(2));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNI5L6H1_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_5673\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datae => \GRFPU0.GRFPU_X0.ST1.V\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(3));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_O4_0_RNIE29D1_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_154\,
dataf => \GRFPU0.GRFPU_X0.N_19897\,
datae => \GRFPU0.GRFPU_X0.REST_2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(3));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNI7JHU_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19546\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.ST1.V\,
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(3));
GRFPU0_GRFPU_X0_ST2_QSNAN_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G0_0\,
dataf => \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G1\,
datae => \GRFPU0.GRFPU_X0.REST_1_2\(2),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(3));
GRFPU0_GRFPU_X0_VST2_EXC_0_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_3406\,
dataf => \GRFPU0.GRFPU_X0.ST1.V\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(3));
\GRFPC0_WR_CTRL_RD_RNIVS202_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3ffffffffff")
port map (
combout => \GRFPC0.N_491\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_12_STDEP_488_SEL0_0_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_488_SEL0_1\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_12_STDEP_488_SEL1_I_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_18739\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_58_0_A2_0\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000002")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_18\,
dataf => \GRFPU0.MULO.MRES\(88),
datae => \GRFPU0.MULO.MRES\(89),
datad => \GRFPU0.MULO.MRES\(86),
datac => \GRFPU0.MULO.MRES\(84),
datab => \GRFPU0.MULO.MRES\(83),
dataa => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_9\);
\GRFPC0_FP_PIPELINE_14_STDEP_568_3_0_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3ffffffffff")
port map (
combout => \GRFPC0.N_23807\,
dataf => \GRFPC0.N_494\,
datae => \GRFPC0.N_561\,
datad => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_14_STDEP_568_SEL1_I_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => \GRFPC0.N_19008\,
dataf => \GRFPC0.N_561\,
datae => \GRFPC0.WR.CTRL.RDD\,
datad => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_8_STDEP_328_SEL0_0_1_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3ffffffff")
port map (
combout => \GRFPC0.N_23810\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN4687_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4687_REGDEPX\,
dataf => N_82,
datae => N_79,
datad => N_81,
datac => N_80);
GRFPC0_FP_PIPELINE_13_1_CHECK_DEP_UN4271_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4271_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(3),
datae => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.INST_1\(1));
GRFPC0_FP_PIPELINE_2_1_CHECK_DEP_UN839_REGDEPX_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN839_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(3),
datae => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.INST_1\(1));
GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_UN207_REGDEPX_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN207_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(3),
datae => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.INST_1\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O2_1_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303ff0303ff")
port map (
combout => \GRFPC0.N_22433_1\,
dataf => N_97,
datae => N_90,
datad => N_89,
datac => N_92,
datab => N_84);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_1_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fc000000")
port map (
combout => \GRFPC0.N_23988_1\,
dataf => N_113,
datae => \GRFPC0.FP_PIPELINE.UN24_OP\,
datad => \GRFPC0.N_21627\,
datac => N_92,
datab => N_84);
\GRFPC0_FP_PIPELINE_4_REGDEPX_88_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffc000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX_88\(1),
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX_86\(1),
datae => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1552_REGDEPX\,
datad => \GRFPC0.N_21627\,
datac => N_92,
datab => N_84);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_5_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000cf00000000")
port map (
combout => \GRFPC0.N_25064\,
dataf => N_81,
datae => N_82,
datad => \GRFPC0.N_25037\,
datac => N_78,
datab => N_84);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_3_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cf000000")
port map (
combout => \GRFPC0.N_23529\,
dataf => N_113,
datae => \GRFPC0.FP_PIPELINE.UN24_OP\,
datad => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3439_REGDEPX\,
datac => N_78,
datab => N_84);
\GRFPC0_FP_PIPELINE_11_CHECK_DEP_DEP_12_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000cf00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_12\(0),
dataf => N_82,
datae => N_81,
datad => \GRFPC0.N_25037\,
datac => N_78,
datab => N_84);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000cf00")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\(0),
dataf => N_79,
datae => N_80,
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN943_REGDEPX_2\,
datac => N_78,
datab => N_84);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O3_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30ffffff")
port map (
combout => \GRFPC0.N_22823\,
dataf => N_80,
datae => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN943_REGDEPX_2\,
datad => N_79,
datac => N_78,
datab => N_84);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_1_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ffff0000330f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(50),
dataf => \GRFPU0.GRFPU_X0.N_3560_I\,
datae => \GRFPU0.GRFPU_X0.N_18663\,
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(110),
datab => N_28085);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15836\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(110),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(110),
datab => N_28085);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15887\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(110),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(110),
datab => N_28085);
GRFPU0_GRFPU_X0_UN108_BCO_LSB_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN108_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(33),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(32));
\GRFPU0_GRFPU_X0_L1_4_1_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0f0f0ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_14235\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(33),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(32));
\GRFPU0_GRFPU_X0_L1_0_2_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_2\(3),
dataf => \GRFPU0.GRFPU_X0.UN73_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(33),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(34));
\GRFPC0_FIFO_VCNT_0_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccceeeeccc3eeeb")
port map (
combout => \GRFPC0.FIFO.VCNT_0_0_0_2__G2\,
dataf => \GRFPC0.UN1_VFIFO.VCNT_0_1_SQMUXA\,
datae => \GRFPC0.VFIFO.INST_0_1_0_0\,
datad => \GRFPC0.FIFO.VCNT_0\(0),
datac => \GRFPC0.FIFO.VCNT_0\(1),
datab => \GRFPC0.FIFO.VCNT_0\(2),
dataa => N_35);
\GRFPC0_FP_PIPELINE_4_REGDEPX_84_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f030000000000000")
port map (
combout => \GRFPC0.N_25050\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_25085\,
datad => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f30000000000")
port map (
combout => \GRFPC0.N_24854\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_24911\,
datad => \GRFPC0.FP_PIPELINE.15.1.CHECK_DEP.UN4895_REGDEPX_2\,
datac => \GRFPC0.FIFO.INST_1\(6),
datab => \GRFPC0.FIFO.INST_1\(0));
\GRFPC0_FP_PIPELINE_3_1_REGDEPX_65_I_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0cff")
port map (
combout => \GRFPC0.FP_PIPELINE.3.1.REGDEPX_65_I_A2_0\(0),
dataf => \GRFPC0.N_24767\,
datae => \GRFPC0.N_24911\,
datad => \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN839_REGDEPX_2\,
datac => \GRFPC0.FIFO.INST_1\(6),
datab => \GRFPC0.FIFO.INST_1\(0));
\GRFPC0_FP_PIPELINE_5_1_CHECK_DEP_DEP_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.DEP_1\(0),
dataf => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1775_REGDEPX_1\,
datae => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.FIFO.INST_1\(2),
datac => \GRFPC0.FIFO.INST_1\(4),
datab => \GRFPC0.FIFO.INST_1\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O3_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fffcffffffff")
port map (
combout => \GRFPC0.N_22812\,
dataf => \GRFPC0.N_25010\,
datae => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.FIFO.INST_1\(3),
datac => \GRFPC0.FIFO.INST_1\(2),
datab => \GRFPC0.FIFO.INST_1\(0));
\GRFPC0_FP_PIPELINE_11_REGDEPX_210_0_A2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff33330ff00330")
port map (
combout => \GRFPC0.N_22902_1\,
dataf => \GRFPC0.FIFO.INST_1\(19),
datae => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.FIFO.INST_1\(12),
datac => \GRFPC0.FIFO.INST_1\(11),
datab => \GRFPC0.FIFO.INST_1\(14));
\GRFPC0_FP_PIPELINE_12_REGDEPX_228_0_A3_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f000000000000")
port map (
combout => \GRFPC0.N_23349\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_23349_1\,
datad => \GRFPC0.FIFO.INST_1\(6),
datac => \GRFPC0.FIFO.INST_1\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15745\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.MRES\(99),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(98),
datab => N_28061);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_I_M2_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_100\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.MRES\(97),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(98),
datab => N_28061);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15824\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(98),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(98),
datab => N_28061);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15875\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(98),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(98),
datab => N_28061);
\GRFPC0_FIFO_VCNT_1_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0fafaf0c3faeb")
port map (
combout => \GRFPC0.FIFO.VCNT_1_0_0_2__G2\,
dataf => \GRFPC0.UN1_VFIFO.VCNT_1_1_SQMUXA\,
datae => \GRFPC0.VFIFO.INST_1_1_0_0\,
datad => \GRFPC0.FIFO.VCNT_1\(0),
datac => \GRFPC0.FIFO.VCNT_1\(2),
datab => \GRFPC0.FIFO.VCNT_1\(1),
dataa => N_35);
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5739_REGDEPX2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5739_REGDEPX2\,
dataf => \GRFPC0.DIV.INST\(2),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(1),
datac => \GRFPC0.DIV.INST\(4));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN7062_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7062_REGDEPX2\,
dataf => \GRFPC0.DIV.INST\(2),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(1),
datac => \GRFPC0.DIV.INST\(4));
GRFPC0_FP_PIPELINE_7_STDEP_288_SEL0_0_1_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffffffffffffff")
port map (
combout => \GRFPC0.N_21818\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15827\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(101),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(101),
datab => N_28067);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18621\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(101),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(101),
datab => N_28067);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_A0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => N_1_2,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN873_REGDEPX2_2\,
datad => \GRFPC0.N_25839_1\,
datac => \GRFPC0.DIV.INST\(15),
datab => \GRFPC0.DIV.INST\(16));
GRFPU0_GRFPU_X0_UN1_EXPT_3_SQMUXA_3_I_A4_1_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3_I_A4_1_0\,
dataf => \GRFPU0.GRFPU_X0.N_17\,
datae => \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3_I_A2_0_3\,
datad => \GRFPU0.GRFPU_X0.UN8_C\(6),
datac => \GRFPU0.GRFPU_X0.UN8_C\(3),
datab => \GRFPU0.GRFPU_X0.UN8_C\(2));
GRFPU0_GRFPU_X0_COMB_UN1_VST4_ADDOF_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0fc000000cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_VST4.ADDOF_0\,
dataf => \GRFPU0.GRFPU_X0.N_13455\,
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datac => \GRFPU0.GRFPU_X0.ST3.DIFFV\,
datab => \GRFPU0.GRFPU_X0.ST3.EMIN\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_DP_1_SQMUXA_RNINNKC1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0f0f0f0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_7278\,
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datac => \GRFPU0.GRFPU_X0.ST3.DIFFV\);
\GRFPU0_GRFPU_X0_REST_1_2_IV_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffeaeaeae0")
port map (
combout => \GRFPU0.GRFPU_X0.REST_1_2\(2),
dataf => \GRFPU0.GRFPU_X0.REST_1_2_IV_0\(2),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(4));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_476_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_24067\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datae => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.DIV.RD\(4),
datac => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.DIV.RD\(1));
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN3505_REGDEPX2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3505_REGDEPX2\,
dataf => \GRFPC0.DIV.RD\(3),
datae => \GRFPC0.DIV.RD\(4),
datad => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.N_24779\,
dataf => \GRFPC0.N_25560_2\,
datae => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.DIV.RD\(4),
datac => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_4_REGDEPX_84_0_A2_1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3c000000000000")
port map (
combout => \GRFPC0.N_25051_1\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22250\,
datad => \GRFPC0.FIFO.INST_1\(19),
datac => \GRFPC0.FIFO.INST_1\(12),
datab => \GRFPC0.FIFO.INST_1\(11));
\GRFPC0_FP_PIPELINE_13_REGDEPX_246_0_A2_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3c000000000000")
port map (
combout => \GRFPC0.N_21638_1\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22243\,
datad => \GRFPC0.FIFO.INST_1\(19),
datac => \GRFPC0.FIFO.INST_1\(12),
datab => \GRFPC0.FIFO.INST_1\(11));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A2_2_0_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0ff000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A2_2_0\(13),
dataf => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2072_REGDEPX\,
datae => \GRFPC0.FIFO.INST_1\(19),
datad => \GRFPC0.FIFO.INST_1\(12),
datac => \GRFPC0.FIFO.INST_1\(11));
GRFPU0_GRFPU_X0_UN83_BCO_LSB_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN83_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(46),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(48));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_4_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_22773\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22429\,
datad => \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.UN735_REGDEPX_1\,
datac => \GRFPC0.FIFO.INST_0\(4),
datab => \GRFPC0.FIFO.INST_0\(3));
GRFPC0_FP_PIPELINE_1_0_CHECK_DEP_UN423_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.UN423_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(1),
datae => \GRFPC0.FIFO.INST_0\(2),
datad => \GRFPC0.FIFO.INST_0\(4),
datac => \GRFPC0.FIFO.INST_0\(3));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O3_5_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff00000fffcffcc")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O3_5_0\(3),
dataf => \GRFPC0.N_36\,
datae => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.UN423_REGDEPX\,
datad => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_0\(0),
datab => \GRFPC0.FIFO.INST_0\(14));
\GRFPC0_FP_PIPELINE_10_REGDEPX_192_0_A2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc00000000000000")
port map (
combout => \GRFPC0.N_24986\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_23887\,
datad => \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.UN735_REGDEPX_1\,
datac => \GRFPC0.FIFO.INST_0\(6),
datab => \GRFPC0.FIFO.INST_0\(0));
\GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_DEP_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000c00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_1\(1),
dataf => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN97_REGDEPX_2\,
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(0));
\GRFPC0_FP_PIPELINE_12_0_REGDEPX_221_0_A2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f000c")
port map (
combout => \GRFPC0.N_24839\,
dataf => \GRFPC0.N_23915\,
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(0));
\GRFPC0_FP_PIPELINE_13_0_CHECK_DEP_DEP_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000c0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.DEP_1\(1),
dataf => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4167_REGDEPX_0_A2_0\,
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(0));
\GRFPC0_FP_PIPELINE_4_0_CHECK_DEP_DEP_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000c00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.DEP\(1),
dataf => \GRFPC0.N_25011\,
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(0));
\GRFPC0_FP_PIPELINE_5_0_REGDEPX_95_0_A2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000c0000000000")
port map (
combout => \GRFPC0.N_24846\,
dataf => \GRFPC0.N_25011\,
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(0));
\GRFPC0_FP_PIPELINE_9_0_REGDEPX_167_0_A2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000c0000000000")
port map (
combout => \GRFPC0.N_23950\,
dataf => \GRFPC0.N_23887\,
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_0\(1),
datac => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(0));
GRFPU0_GRFPU_X0_VITER_EMAXP1_0_SQMUXA_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000ff00f30")
port map (
combout => \GRFPU0.GRFPU_X0.N_5987\,
dataf => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datad => \GRFPU0.GRFPU_X0.ITER.EXPT\(1),
datac => \GRFPU0.GRFPU_X0.ITER.EXPT\(0),
datab => \GRFPU0.GRFPU_X0.ITER.EXPT\(2));
\GRFPC0_FP_PIPELINE_4_CHECK_DEP_DEP_16_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000030")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_16\(0),
dataf => \GRFPC0.N_706\,
datae => \GRFPC0.WR.CTRL.INST\(29),
datad => \GRFPC0.WR.CTRL.INST\(26),
datac => \GRFPC0.WR.CTRL.INST\(28),
datab => \GRFPC0.WR.CTRL.INST\(27));
GRFPC0_FP_PIPELINE_0_STDDEP_180_IV_0_A2_4_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fff00000")
port map (
combout => \GRFPC0.N_149\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datae => \GRFPC0.N_102\,
datad => \GRFPC0.N_579\,
datac => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_1_STDEP_52_3_I_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ffffffffff")
port map (
combout => \GRFPC0.N_22125\,
dataf => \GRFPC0.N_675\,
datae => \GRFPC0.N_579\,
datad => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_I_A4_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff030300ff0003")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_I_A4_0\(1),
dataf => \GRFPC0.N_23808\,
datae => \GRFPC0.FP_PIPELINE.8.STDEP_332_SEL0_1\,
datad => \GRFPC0.WR.CTRL.RDD\,
datac => \GRFPC0.N_579\,
datab => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15834\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(108),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(108),
datab => N_28081);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15885\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(108),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(108),
datab => N_28081);
\GRFPC0_FP_PIPELINE_12_CHECK_DEP_DEP_14_0_A3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_14\(0),
dataf => \GRFPC0.N_702\,
datae => \GRFPC0.WR.CTRL.INST\(4),
datad => \GRFPC0.WR.CTRL.INST\(3),
datac => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN2123_REGDEPX2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2123_REGDEPX2\,
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(3),
datad => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3887_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3887_REGDEPX2\,
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(3),
datad => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(2));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15822\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(96),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(96),
datab => N_28057);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15873\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(96),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(96),
datab => N_28057);
\GRFPC0_FP_PIPELINE_7_1_CHECK_DEP_DEP_2_IV_0_I4_I_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.N_25013\,
dataf => \GRFPC0.FIFO.INST_1\(29),
datae => \GRFPC0.FIFO.INST_1\(28),
datad => \GRFPC0.FIFO.INST_1\(26),
datac => \GRFPC0.FIFO.INST_1\(27));
GRFPC0_FP_PIPELINE_3_1_CHECK_DEP_UN1120_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.1.CHECK_DEP.UN1120_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(28),
datae => \GRFPC0.FIFO.INST_1\(29),
datad => \GRFPC0.FIFO.INST_1\(26),
datac => \GRFPC0.FIFO.INST_1\(27));
\GRFPC0_FP_PIPELINE_9_REGDEPX_174_0_A4_2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000300000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_A4_2_1\(0),
dataf => \GRFPC0.N_22250\,
datae => \GRFPC0.FIFO.INST_1\(17),
datad => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_1\(15),
datab => \GRFPC0.FIFO.INST_1\(16));
\GRFPU0_GRFPU_X0_BCO_MSB_2_5_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfcffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_13695_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(21));
\GRFPC0_FP_PIPELINE_15_0_REGDEPX_275_0_O2_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0fffffffffff")
port map (
combout => \GRFPC0.N_23916\,
dataf => \GRFPC0.N_24921\,
datae => \GRFPC0.FIFO.INST_0\(6),
datad => \GRFPC0.FIFO.INST_0\(18),
datac => \GRFPC0.FIFO.INST_0\(14));
\GRFPC0_FP_PIPELINE_3_0_REGDEPX_59_0_A3_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0000000000000")
port map (
combout => \GRFPC0.N_23334\,
dataf => \GRFPC0.N_24921\,
datae => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1032_REGDEPX\,
datad => \GRFPC0.FIFO.INST_0\(6),
datac => \GRFPC0.FIFO.INST_0\(14));
\GRFPC0_FP_PIPELINE_8_REGDEPX_156_0_A2_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc00000000000000")
port map (
combout => \GRFPC0.N_22313\,
dataf => \GRFPC0.N_24921\,
datae => \GRFPC0.N_23963\,
datad => \GRFPC0.FP_PIPELINE.8.0.REGDEPX_149_0_A2_1_0_0\(0),
datac => \GRFPC0.FIFO.INST_0\(6),
datab => \GRFPC0.FIFO.INST_0\(14));
GRFPU0_GRFPU_X0_VST2_EXC_1_SQMUXA_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000d00")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_3\,
dataf => \GRFPU0.GRFPU_X0.VST2.EXC_0_SQMUXA_1\,
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(5));
GRFPU0_GRFPU_X0_UN53_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN53_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_42_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(50),
dataf => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datae => \GRFPU0.MULO.MRES\(110),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datac => N_28199,
datab => N_28198);
\GRFPU0_GRFPU_X0_L2_0_3_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000303ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_3\(2),
dataf => \GRFPU0.GRFPU_X0.N_9683\,
datae => \GRFPU0.GRFPU_X0.N_14025_1\,
datad => \GRFPU0.GRFPU_X0.N_9732\,
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(42));
GRFPU0_GRFPU_X0_UN113_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN113_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(42),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(43));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_340_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_24518\,
dataf => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5105_REGDEPX2\,
datae => \GRFPC0.EX.RREG.RESV\,
datad => \GRFPC0.EX.CTRL.RS1V\,
datac => \GRFPC0.EX.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(0));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_45_0_A3_4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_25419\,
dataf => \GRFPC0.EX.RREG.RESV\,
datae => \GRFPC0.EX.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1),
datac => \GRFPC0.N_24322\,
datab => \GRFPC0.N_24325\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_10_I_A2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_25291\,
dataf => \GRFPC0.N_25460\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN253_REGDEPX2_1\,
datad => \GRFPC0.EX.RREG.RESV\,
datac => \GRFPC0.EX.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_15_I_A2_0_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000c0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_I_A2_0_1\(0),
dataf => \GRFPC0.EX.RREG.RESV\,
datae => \GRFPC0.EX.CTRL.INST\(27),
datad => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.EX.CTRL.DIV\,
datab => \GRFPC0.N_24322\);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_A2_1_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff000000")
port map (
combout => \GRFPC0.N_25319\,
dataf => \GRFPC0.EX.RREG.RESV\,
datae => \GRFPC0.EX.CTRL.RS1V\,
datad => \GRFPC0.EX.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_400_0_A2_0_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_25154_1\,
dataf => \GRFPC0.EX.RREG.RESV\,
datae => \GRFPC0.EX.CTRL.INST\(29),
datad => \GRFPC0.EX.CTRL.INST\(28),
datac => \GRFPC0.EX.CTRL.DIV\,
datab => \GRFPC0.N_24325\);
\GRFPU0_GRFPU_X0_L1_0_1_5_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfcffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_13845_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(37),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(38),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(8),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(9));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15765\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.MRES\(119),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(118),
datab => N_28101);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15844\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(118),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(118),
datab => N_28101);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15895\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(118),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(118),
datab => N_28101);
\GRFPU0_GRFPU_X0_BCO_MSB_1_5_I_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfcffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_5_I_0\(1),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(41),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(42),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(12),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(13));
\GRFPC0_FP_PIPELINE_0_STDEP_82_0_IV_I_A3_3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3000000f30000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_82_0_IV_I_A3_3_0\(0),
dataf => \GRFPC0.N_570\,
datae => \GRFPC0.N_675\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datac => \GRFPC0.N_579\,
datab => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_0_STDEP_82_0_IV_I_A3_2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c000000ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_82_0_IV_I_A3_2_0\(0),
dataf => \GRFPC0.N_675\,
datae => \GRFPC0.N_22126\,
datad => \GRFPC0.N_494\,
datac => \GRFPC0.N_579\,
datab => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_9_STDEP_376_3_I_O3_I_A3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f0f000f")
port map (
combout => \GRFPC0.N_670\,
dataf => \GRFPC0.N_467\,
datae => \GRFPC0.N_579\,
datad => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.MEM.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_3_STDEP_132_SEL0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0fcfffff")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_132_SEL0\,
dataf => \GRFPC0.N_25886\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_2\,
datad => \GRFPC0.N_579\,
datac => \GRFPC0.MEM.CTRL.RDWR\,
datab => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_D_STLCK_RNO_5_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000c0000")
port map (
combout => \GRFPC0.N_21298\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datae => \GRFPC0.N_102\,
datad => \GRFPC0.N_53\,
datac => \GRFPC0.N_579\,
datab => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_D_STLCK_RNO_3_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0f0000ff00")
port map (
combout => \GRFPC0.N_21295\,
dataf => \GRFPC0.N_21253\,
datae => \GRFPC0.N_53\,
datad => \GRFPC0.N_579\,
datac => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_0_A2_1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0c000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_A2_1_1\(0),
dataf => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2644_DEP\,
datae => \GRFPC0.N_23808\,
datad => \GRFPC0.FP_PIPELINE.8.STDEP_332_SEL0_1\,
datac => \GRFPC0.N_579\,
datab => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_D_STLCK_RNO_16_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff0c0c000c")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_558_I_M_I_A3_10_0\(1),
dataf => \GRFPC0.N_53\,
datae => N_99872,
datad => \GRFPC0.N_505\,
datac => \GRFPC0.N_579\,
datab => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_7_STDEP_292_3_I_O2_1_I_A3_RNI8TJK_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c000c0000000c00")
port map (
combout => \GRFPC0.N_689\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datae => \GRFPC0.N_102\,
datad => \GRFPC0.N_690\,
datac => \GRFPC0.N_579\,
datab => \GRFPC0.MEM.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_A2_2_1_I_O3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00f0ffff")
port map (
combout => \GRFPC0.N_615\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datae => \GRFPC0.N_102\,
datad => \GRFPC0.N_579\,
datac => \GRFPC0.MEM.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_26_IV_0_A2_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f30000")
port map (
combout => \GRFPC0.N_21407\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datae => \GRFPC0.N_102\,
datad => \GRFPC0.N_477\,
datac => \GRFPC0.N_579\,
datab => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_I_A4_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000f0000000f0")
port map (
combout => \GRFPC0.N_810\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datae => \GRFPC0.N_102\,
datad => \GRFPC0.N_579\,
datac => \GRFPC0.MEM.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_26_IV_0_O2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0f0f0f0f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_O2_1\,
dataf => \GRFPC0.N_477\,
datae => \GRFPC0.N_21353\,
datad => \GRFPC0.WR.CTRL.RDD\,
datac => \GRFPC0.N_579\);
\GRFPC0_FP_PIPELINE_10_STDEP_416_3_0_A2_1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0c0000ff0cff0c")
port map (
combout => \GRFPC0.N_24463_2\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datae => \GRFPC0.N_490\,
datad => \GRFPC0.N_501\,
datac => \GRFPC0.N_579\,
datab => \GRFPC0.MEM.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_A3_1_I_O2_0_RNIV9QF: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0f0fff0f")
port map (
combout => \GRFPC0.N_23390\,
dataf => \GRFPC0.N_467\,
datae => \GRFPC0.N_579\,
datad => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.MEM.CTRL.RD\(2));
\GRFPC0_D_STLCK_RNO_3_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPC0.N_23208\,
dataf => \GRFPC0.N_23152\,
datae => \GRFPC0.N_858\,
datad => \GRFPC0.N_579\);
\GRFPC0_FP_PIPELINE_0_STDEP_82_0_IV_I_A3_1_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff00ffffffff")
port map (
combout => \GRFPC0.N_22120\,
dataf => \GRFPC0.N_675\,
datae => \GRFPC0.N_579\,
datad => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000f3f0f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_0\(1),
dataf => \GRFPC0.N_533\,
datae => \GRFPC0.N_655\,
datad => \GRFPC0.WR.CTRL.RDD\,
datac => \GRFPC0.N_579\,
datab => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_O2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff00ff")
port map (
combout => \GRFPC0.N_21438\,
dataf => \GRFPC0.N_533\,
datae => \GRFPC0.N_579\,
datad => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_I_0_A5_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_22758\,
dataf => \GRFPC0.N_22718\,
datae => \GRFPC0.N_104\,
datad => \GRFPC0.N_533\,
datac => \GRFPC0.N_579\,
datab => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_I_0_A5_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_I_0_A5_1_0\(0),
dataf => \GRFPC0.N_533\,
datae => \GRFPC0.N_579\,
datad => \GRFPC0.MEM.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_4_STDEP_172_SEL0_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fff0ffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_172_SEL0\,
dataf => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\,
datae => \GRFPC0.N_579\,
datad => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_5_STDEP_212_3_0_O3_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffffffffff")
port map (
combout => \GRFPC0.N_21615\,
dataf => \GRFPC0.N_860\,
datae => \GRFPC0.N_579\,
datad => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_5_STDEP_234_0_IV_I_O2_3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_234_0_IV_I_O2_3_0\(0),
dataf => \GRFPC0.N_860\,
datae => \GRFPC0.N_579\,
datad => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_I_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fff0ffffffffff")
port map (
combout => \GRFPC0.N_73\,
dataf => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2024_DEP\,
datae => \GRFPC0.N_579\,
datad => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_225_RNI6LSK2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0fffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5\(1),
dataf => \GRFPC0.FP_PIPELINE.7.REGDEPX2_225\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_4\(1),
datad => \GRFPC0.WR.RREG.RESV\,
datac => \GRFPC0.WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_A2_0_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.N_25250_3\,
dataf => \GRFPC0.WR.RREG.RESV\,
datae => \GRFPC0.WR.CTRL.INST\(16),
datad => \GRFPC0.WR.CTRL.INST\(17),
datac => \GRFPC0.WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0cfff3ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270\(1),
dataf => \GRFPC0.FP_PIPELINE.8.REGDEPX2_259\(1),
datae => \GRFPC0.FP_PIPELINE.8.REGDEPX2_255\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_4\(1),
datac => \GRFPC0.WR.RREG.RESV\,
datab => \GRFPC0.WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_A2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c000000")
port map (
combout => \GRFPC0.N_24401\,
dataf => \GRFPC0.N_704\,
datae => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3872_REGDEPX2\,
datad => \GRFPC0.WR.CTRL.RS1V\,
datac => \GRFPC0.WR.RREG.RESV\,
datab => \GRFPC0.WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPC0.N_25824_1\,
dataf => \GRFPC0.WR.RREG.RESV\,
datae => \GRFPC0.WR.CTRL.INST\(3),
datad => \GRFPC0.WR.CTRL.DIV\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15755\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.MRES\(108),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(109),
datab => N_28083);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15835\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(109),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(109),
datab => N_28083);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15886\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(109),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(109),
datab => N_28083);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15832\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(106),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(106),
datab => N_28077);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18626\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(106),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(106),
datab => N_28077);
\GRFPC0_FP_PIPELINE_8_REGDEPX_156_0_A2_1_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPC0.N_22273_1\,
dataf => \GRFPC0.N_21626\,
datae => \GRFPC0.FIFO.INST_1\(17),
datad => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_1\(15),
datab => \GRFPC0.FIFO.INST_1\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15751\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.MRES\(104),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(105),
datab => N_28075);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15752\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.MRES\(106),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(105),
datab => N_28075);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15831\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(105),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(105),
datab => N_28075);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18625\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(105),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(105),
datab => N_28075);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_I_M2_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18617\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(115),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(115),
datab => N_28095);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15892\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(115),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(115),
datab => N_28095);
\GRFPC0_FP_PIPELINE_14_CHECK_DEP_DEP_11_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_11\(0),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(0),
datae => \GRFPC0.WR2.CTRL.INST\(29),
datad => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_14_CHECK_DEP_DEP_11_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_11\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(1),
datae => \GRFPC0.WR2.CTRL.INST\(29),
datad => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_4_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25841\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN369_REGDEPX2_1\,
datac => \GRFPC0.WR2.CTRL.INST\(29),
datab => \GRFPC0.WR2.CTRL.INST\(28));
GRFPU0_GRFPU_X0_UN48_BCO_LSB_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030000030300ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_13805_I_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(25));
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN4360_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4360_REGDEPX\,
dataf => N_94,
datae => N_96,
datad => N_95,
datac => N_93);
GRFPC0_FP_PIPELINE_14_REGDEPX2_435TT_1_M3_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff3f00000000")
port map (
combout => N_1_0,
dataf => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435TT_1_M3_0_A2_0\,
datae => \GRFPC0.N_25383\,
datad => \GRFPC0.MEM.CTRL.INST\(1),
datac => \GRFPC0.MEM.CTRL.INST\(2),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1));
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(8),
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.DRES_1S\(104),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datac => N_28189,
datab => N_28188);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN2033_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2033_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(3),
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2474_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2474_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(3),
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15837\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(111),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(111),
datab => N_28087);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15888\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(111),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(111),
datab => N_28087);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15748\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.MRES\(101),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(102),
datab => N_28069);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15828\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(102),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(102),
datab => N_28069);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18622\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(102),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(102),
datab => N_28069);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNITNDT4_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c00000ffc0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19690\,
dataf => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.N_3407\,
datad => \GRFPU0.GRFPU_X0.N_5790\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8));
GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_SN_M4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cf0f0f0f00000000")
port map (
combout => N_99844,
dataf => \GRFPU0.GRFPU_X0.N_6\,
datae => \GRFPU0.GRFPU_X0.N_3407\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8));
GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_52_M3_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003f00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_52_M3_0_A2_0\,
dataf => \GRFPU0.GRFPU_X0.N_18527\,
datae => \GRFPU0.GRFPU_X0.N_3407\,
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8));
GRFPU0_GRFPU_X0_ITER_SQRT_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f00ff003f3fffff")
port map (
combout => N_26925,
dataf => \GRFPU0.GRFPU_X0.N_128\,
datae => \GRFPU0.GRFPU_X0.N_3407\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNI3FAG4_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_140\,
dataf => \GRFPU0.GRFPU_X0.N_5539\,
datae => \GRFPU0.GRFPU_X0.N_3407\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8));
GRFPU0_GRFPU_X0_VITER_DBUF_4_SQMUXA_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ff00ff00ff00ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_4\,
dataf => \GRFPU0.GRFPU_X0.N_3407\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8));
GRFPU0_GRFPU_X0_VITER_EXP_0_SQMUXA_1_I_0_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000ffff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18408_1\,
dataf => \GRFPU0.GRFPU_X0.N_3407\,
datae => \GRFPU0.GRFPU_X0.ITER.V\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNI4FQJ1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0__G0_0_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3));
\GRFPU0_GRFPU_X0_COMB_EXP_14_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3ff0c00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXP_14\(5),
dataf => N_32649,
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(4),
datac => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datab => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0));
\GRFPU0_GRFPU_X0_COMB_EXP_14_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f30cff00ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXP_14\(8),
dataf => N_32664,
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
datac => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datab => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0));
\GRFPU0_GRFPU_X0_COMB_EXP_14_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f00f0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXP_14\(1),
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(1),
datad => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datac => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0));
\GRFPU0_GRFPU_X0_COMB_EXP_14_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00f0ff0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXP_14\(3),
dataf => \GRFPU0.GRFPU_X0.UN23_EXP\(3),
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(3),
datad => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datac => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(41),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(41),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(21),
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(53));
GRFPU0_GRFPU_X0_COMB_ANDV_TMP_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ANDV.TMP_5\,
dataf => \GRFPU0.GRFPU_X0.C\(7),
datae => \GRFPU0.GRFPU_X0.C\(5),
datad => \GRFPU0.GRFPU_X0.C\(4),
datac => \GRFPU0.GRFPU_X0.C\(0),
datab => \GRFPU0.GRFPU_X0.C\(2));
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_EQ_EXPT63_0_A2_0_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT63_0_A2_0_2\,
dataf => \GRFPU0.GRFPU_X0.C\(6),
datae => \GRFPU0.GRFPU_X0.C\(5),
datad => \GRFPU0.GRFPU_X0.C\(4),
datac => \GRFPU0.GRFPU_X0.C\(3),
datab => \GRFPU0.GRFPU_X0.C\(2));
GRFPC0_FP_PIPELINE_FCC_1_M2S2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff000f000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_1_SM0\,
dataf => \GRFPC0.MEM.CTRL.CCWR\,
datae => \GRFPC0.MEM.RREG.RESV\,
datad => \GRFPC0.EX.RREG.RESV\,
datac => \GRFPC0.EX.CTRL.CCWR\);
GRFPC0_FP_PIPELINE_FCC_1_M2S4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffc0ffc0")
port map (
combout => N_38,
dataf => \GRFPC0.MEM.CTRL.CCWR\,
datae => \GRFPC0.MEM.RREG.RESV\,
datad => \GRFPC0.FP_PIPELINE.FCC_1_M2S4_0\,
datac => \GRFPC0.EX.RREG.RESV\,
datab => \GRFPC0.EX.CTRL.CCWR\);
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A5_6_1_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A5_6_1_0\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT63_0_A2_0_2\,
datae => \GRFPU0.GRFPU_X0.N_18220\,
datad => \GRFPU0.GRFPU_X0.C\(9),
datac => \GRFPU0.GRFPU_X0.C\(7),
datab => \GRFPU0.GRFPU_X0.C\(8));
GRFPU0_GRFPU_X0_COMB_VST2_ADD_1_1_U: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff00ff0f00f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.ADD_1_1\,
dataf => \GRFPU0.GRFPU_X0.N_4202\,
datae => \GRFPU0.GRFPU_X0.N_4201\,
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN1\);
GRFPU0_GRFPU_X0_COMB_VST2_QSNAN12_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f000f00f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_3504_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datac => \GRFPU0.GRFPU_X0.ST1.SIGN1\);
GRFPU0_GRFPU_X0_VST3_EXC_0_SQMUXA_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333333000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_0\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(59),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(62));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_16\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_12\,
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(9),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(7));
\GRFPC0_FP_PIPELINE_5_STDEP_230_0_IV_I_I2_6_I4_0_A3_RNII4M61_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_139\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => N_104,
datad => N_105,
datac => N_106,
datab => N_107);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_0_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003000000")
port map (
combout => \GRFPC0.N_25341_1\,
dataf => N_97,
datae => N_104,
datad => N_105,
datac => N_106,
datab => N_107);
\GRFPC0_D_STDLCK_RNO_10_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_15__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.STDDEP_1_4\,
datae => \GRFPC0.RFA.LD\,
datad => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1233_DEP_1\,
datac => N_176,
datab => N_175);
\GRFPC0_D_STLCK_RNO_5_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_23089\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datae => \GRFPC0.RFA.LD\,
datad => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1233_DEP_1\,
datac => N_176,
datab => N_175);
GRFPC0_STDEP_0_SQMUXA_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.STDEP_0_SQMUXA_9\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datae => \GRFPC0.RFA.LD\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN243_DEP_1\,
datac => N_176,
datab => N_175);
\GRFPC0_D_STDLCK_RNO_10_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_13_1\,
dataf => \GRFPC0.N_505\,
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_12_STDEP_496_SEL0_0_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_496_SEL0_1\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_12_STDEP_496_SEL1_I_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_18319\,
dataf => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A2_0\,
datae => \GRFPC0.EX.CTRL.RD\(3),
datad => \GRFPC0.EX.CTRL.RD\(2),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(4));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M17_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M17_2_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(0));
\GRFPU0_GRFPU_X0_VITER_ALLOW_CNST_I_A2_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f0fffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_76_2\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(1),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(9));
GRFPC0_STDDEP_0_SQMUXA_24_I_O4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff3fffffffff")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_24_I_1\,
dataf => \GRFPC0.RFA.LD\,
datae => N_174,
datad => N_176,
datac => N_173,
datab => N_175);
\GRFPU0_GRFPU_X0_L1_1_1_5_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfffffcfcff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_13825_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(17));
\GRFPU0_GRFPU_X0_L1_1_1_4_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfcffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_13835_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(45),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(46),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(16),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(17));
\GRFPU0_GRFPU_X0_L2_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000eef0eef0")
port map (
combout => N_82205,
dataf => \GRFPU0.GRFPU_X0.N_9804\,
datae => N_82187,
datad => \GRFPU0.GRFPU_X0.N_9856\,
datac => \GRFPU0.GRFPU_X0.N_14345_1\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_A2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_25802\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN369_REGDEPX2_1\,
datac => \GRFPC0.WR2.CTRL.INST\(29),
datab => \GRFPC0.WR2.CTRL.INST\(28));
GRFPU0_GRFPU_X0_IEXC_0_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_5505\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(8));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16463\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(8));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16475\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(20));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16476\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(21));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16477\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(22));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16480\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(25));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16481\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(26));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16464\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(9));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16483\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(28));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16484\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(29));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16485\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(30));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16486\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(31));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16487\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(32));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16488\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(33));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16489\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(34));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16490\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(35));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16491\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(36));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16465\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(10));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16495\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(40));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16498\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(43));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16500\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(45));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16501\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datae => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datad => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datac => \GRFPU0.GRFPU_X0.ITER.FLUSH0\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16502\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(47));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16466\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(11));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16503\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(48));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16504\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(49));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16505\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(50));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16506\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(51));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16507\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datad => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(52));
\GRFPU0_GRFPU_X0_ITER_ND_I_RNI6GTS_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_13638\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(31),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(30));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15843\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(117),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(117),
datab => N_28099);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15894\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(117),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(117),
datab => N_28099);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15753\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.MRES\(106),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(107),
datab => N_28079);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15833\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(107),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(107),
datab => N_28079);
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15884\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(107),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.SX\(107),
datab => N_28079);
GRFPU0_GRFPU_X0_ST4_RDY_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff0f3f00f00030")
port map (
combout => \GRFPU0.GRFPU_X0.N_10047\,
dataf => \GRFPU0.GRFPU_X0.N_5661\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datac => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(8));
\GRFPU0_GRFPU_X0_IDOUT_I_M2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccf0f0f0cc")
port map (
combout => \FPO.IDOUT\(1),
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.ID\(1),
datab => \GRFPU0.GRFPU_X0.ST3.ID\(1));
\GRFPU0_GRFPU_X0_IDOUT_I_M2_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccf0f0f0cc")
port map (
combout => \FPO.IDOUT\(2),
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.ID\(2),
datab => \GRFPU0.GRFPU_X0.ST3.ID\(2));
\GRFPU0_GRFPU_X0_IDOUT_I_M2_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccf0f0f0cc")
port map (
combout => \FPO.IDOUT\(3),
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.ID\(3),
datab => \GRFPU0.GRFPU_X0.ST3.ID\(3));
\GRFPU0_GRFPU_X0_IDOUT_I_M2_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccf0f0f0cc")
port map (
combout => \FPO.IDOUT\(5),
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ITER.ID\(5),
datab => \GRFPU0.GRFPU_X0.ST3.ID\(5));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_0_A2_3_1_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_A2_3_1\(52),
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(1),
datae => \GRFPU0.GRFPU_X0.N_5508\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(8));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_0_A2_7_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_73\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8));
\GRFPU0_GRFPU_X0_ITER_STATE_RNINUR11_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8));
GRFPU0_GRFPU_X0_VITER_FLUSH0_2_SQMUXA_0_A3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6071\,
dataf => \GRFPU0.GRFPU_X0.ITER.V\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datac => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(8));
GRFPU0_GRFPU_X0_UN88_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_9856\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(3),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(0));
GRFPU0_GRFPU_X0_UN13_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000330f")
port map (
combout => \GRFPU0.GRFPU_X0.N_9554\,
dataf => \GRFPU0.GRFPU_X0.TZI\(19),
datae => \GRFPU0.GRFPU_X0.N_13815_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(55),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(26));
\GRFPU0_GRFPU_X0_BCO_MSB_2_6_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfcffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_13675_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(49),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(50),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(20),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(21));
\GRFPU0_GRFPU_X0_L1_2_1_4_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfcffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_13815_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(53),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(25),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(24));
\GRFPU0_GRFPU_X0_VST3_REG_37_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffcf0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(18),
datad => \GRFPU0.GRFPU_X0.ST2.EXPT\(0),
datac => \GRFPU0.GRFPU_X0.ST2.EXPT\(1),
datab => \GRFPU0.GRFPU_X0.ST2.EXPT\(2));
\GRFPU0_GRFPU_X0_ST2_EXPT_RNIR6E71_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37_1\(9),
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.ST2.EXPT\(0),
datad => \GRFPU0.GRFPU_X0.ST2.EXPT\(1),
datac => \GRFPU0.GRFPU_X0.ST2.EXPT\(2));
GRFPU0_GRFPU_X0_UN1_RNDOP_2_I_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000cc000000c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18572\,
dataf => \GRFPU0.GRFPU_X0.COMB.RMND_13\(0),
datae => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datac => \GRFPU0.GRFPU_X0.ITER.LOB\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(1));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2535_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2535_REGDEPX2\,
dataf => \GRFPC0.WR.CTRL.INST\(29),
datae => \GRFPC0.WR.CTRL.INST\(26),
datad => \GRFPC0.WR.CTRL.INST\(27),
datac => \GRFPC0.WR.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_226_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000000c")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_226\(1),
dataf => \GRFPC0.FP_PIPELINE.7.REGDEPX2_225\(1),
datae => \GRFPC0.N_707\,
datad => \GRFPC0.N_25497\,
datac => \GRFPC0.WR.CTRL.INST\(29),
datab => \GRFPC0.WR.CTRL.INST\(26));
\GRFPU0_GRFPU_X0_L2_0_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03000300ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_1\(2),
dataf => \GRFPU0.GRFPU_X0.N_9804\,
datae => \GRFPU0.GRFPU_X0.N_9856\,
datad => \GRFPU0.GRFPU_X0.UN93_BCO_LSB_0\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(9),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(8));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccc3cccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_2__N_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(2),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(53),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(54));
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_3__N_16\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(53),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(55));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f00ff0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16067\,
dataf => \GRFPU0.GRFPU_X0.N_18195\,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(53),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(54));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccccccc3ccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16068\,
dataf => \GRFPU0.GRFPU_X0.N_18195\,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(53),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(55));
GRFPU0_GRFPU_X0_UN1_ST3_REG_ANC3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => N_32517,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST3.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(54),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(55));
GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0000000c000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
dataf => \GRFPU0.GRFPU_X0.N_3407\,
datae => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__N_7_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_RNI7V4R_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(37),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(37),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_RNI8V4R_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(38),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(38),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_RNI735R_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(44),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(44),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_RNO_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(33),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(33),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_RNI9V4R_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(39),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(39),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_RNI935R_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(46),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(46),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_RNIF75R_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(59),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(59),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_O2_0_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff0fffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18310\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(41),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0f0f000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(0),
dataf => \GRFPU0.GRFPU_X0.L4_1\(0),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfccc0ccc0cccfcc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(1),
dataf => \GRFPU0.GRFPU_X0.L4_1\(0),
datae => \GRFPU0.GRFPU_X0.L4_1_I\(1),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccfcccfccc0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(4),
dataf => N_32333,
datae => \GRFPU0.GRFPU_X0.L4_1\(4),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(4));
GRFPU0_GRFPU_X0_VITER_R_I_0_SQMUXA_1_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18664\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
GRFPU0_GRFPU_X0_COMB_UN1_FLOP4_0_0_A3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30ff303000000030")
port map (
combout => \GRFPU0.GRFPU_X0.N_18513\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(2));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNI8S3J1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fff3f3f0000003f")
port map (
combout => \GRFPU0.GRFPU_X0.N_18454\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(2));
\GRFPU0_GRFPU_X0_BCO_MSB_3_5_I_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfcffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_5_I_0\(1),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(57),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(29),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(28));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_20__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_0_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPC0_DIV_RESULT_0_0_53__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffefffcfffafff0")
port map (
combout => \FPO.RES\(53),
dataf => N_99904_1,
datae => \GRFPU0.GRFPU_X0.N_404_0\,
datad => \GRFPC0.DIV.RESULT_0_0_53__G3_0\,
datac => \GRFPC0.DIV.RESULT_0_0_53__G3_1\,
datab => \GRFPU0.GRFPU_X0.ST4.REG\(53),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(50));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03ff00ff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2\(16),
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55));
\GRFPC0_DIV_RESULT_0_0_50__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffefcfaf0")
port map (
combout => \FPO.RES\(50),
dataf => \GRFPC0.DIV.RESULT_0_0_50__G3_1\,
datae => N_99904_1,
datad => \GRFPU0.GRFPU_X0.N_404_0\,
datac => \GRFPC0.DIV.RESULT_0_0_50__G3_0\,
datab => \GRFPU0.GRFPU_X0.ST4.REG\(50),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(47));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_125_0_A2_0_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33c0000000000000")
port map (
combout => \GRFPC0.N_261_2\,
dataf => \GRFPC0.DIVI_0_SQMUXA_8\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_9_5\(0),
datad => \FPI.FLOP\(1),
datac => \GRFPC0.N_223\,
datab => \FPI.FLOP\(0));
GRFPC0_FIFO_INC_5_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000003")
port map (
combout => \GRFPC0.FIFO_INC_5_SQMUXA\,
dataf => \GRFPC0.N_23696\,
datae => \GRFPC0.N_23697\,
datad => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.MEM.CTRL.PEND\,
datab => \GRFPC0.WR.CTRL.PEND\);
GRFPC0_FP_PIPELINE_QNE2_I_A4_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000003")
port map (
combout => \GRFPC0.FP_PIPELINE.QNE2_I_A4_1\,
dataf => \GRFPC0.N_23687\,
datae => \GRFPC0.N_23697\,
datad => \GRFPC0.EX.CTRL.PEND\,
datac => \GRFPC0.MEM.CTRL.PEND\,
datab => \GRFPC0.WR.CTRL.PEND\);
GRFPC0_V_STDATA_0_SQMUXA_3_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff30ffff")
port map (
combout => \GRFPC0.N_23669\,
dataf => \GRFPC0.N_23697\,
datae => \GRFPC0.MEM.CTRL.PEND\,
datad => \GRFPC0.WR.CTRL.PEND\,
datac => N_248,
datab => N_249);
GRFPC0_FP_PIPELINE_VRFA_RDWR_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.RDWR_1\,
dataf => \GRFPC0.FP_PIPELINE.UN205_HOLDN\,
datae => N_108,
datad => N_109,
datac => \GRFPC0.N_220\,
datab => N_45119_I);
\GRFPC0_FP_PIPELINE_4_REGDEPX_84_0_A4_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fccc0000ffff")
port map (
combout => \GRFPC0.N_21277_1\,
dataf => \GRFPC0.N_22237\,
datae => \GRFPC0.FIFO.INST_1\(19),
datad => \GRFPC0.FIFO.INST_1\(12),
datac => \GRFPC0.FIFO.INST_1\(8),
datab => \GRFPC0.FIFO.INST_1\(25));
\GRFPU0_GRFPU_X0_RES_1_6_I_0_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000a000c000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19153_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_404\,
datae => N_99904,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0_0\(39),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0_1\(39),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(39),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(36));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_19__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_L2_0_6_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff0000003030")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_6\(2),
dataf => \GRFPU0.GRFPU_X0.L1_0_6\(3),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_3\(31),
datad => \GRFPU0.GRFPU_X0.UN248_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.N_13441\,
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3\(30));
GRFPC0_V_FSR_AEXC_0_SQMUXA_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0c0c000c00000")
port map (
combout => \GRFPC0.V.FSR.AEXC_0_SQMUXA_1\,
dataf => N_46992,
datae => \GRFPC0.V.FSR.FTT_1_SQMUXA_2_1_0\,
datad => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datac => N_35,
datab => \GRFPC0.R.FSR.FCC_0_0_1__N_5\);
GRFPC0_V_FSR_CEXC_1_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.V.FSR.CEXC_1_SQMUXA\,
dataf => N_44718_1,
datae => \GRFPC0.WR2.CTRL.SEQERR\,
datad => \GRFPC0.DIV.EXCT\(5),
datac => N_35,
datab => \GRFPC0.R.FSR.FCC_0_0_1__N_5\);
GRFPC0_V_FSR_CEXC_5_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c00000")
port map (
combout => \GRFPC0.V.FSR.CEXC_5_SQMUXA\,
dataf => N_46992,
datae => \GRFPC0.FP_PIPELINE.UN25_HOLDN_1\,
datad => \GRFPC0.WR2.CTRL.LD\,
datac => N_35,
datab => \GRFPC0.R.FSR.FCC_0_0_1__N_5\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_375_0_A3_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25409\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN253_REGDEPX2_1\,
datad => \GRFPC0.EX.CTRL.INST\(3),
datac => \GRFPC0.EX.CTRL.INST\(4),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M76_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccfc0c3cc0f00030")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_0_03\,
datad => N_32260,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_24772\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3975_REGDEPX2_1\,
datac => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.DIV.INST\(3));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_1_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f3330000ffff")
port map (
combout => \GRFPC0.N_23345_1\,
dataf => \GRFPC0.N_22237\,
datae => \GRFPC0.FIFO.INST_1\(19),
datad => \GRFPC0.FIFO.INST_1\(12),
datac => \GRFPC0.FIFO.INST_1\(8),
datab => \GRFPC0.FIFO.INST_1\(25));
\GRFPC0_DIV_RESULT_0_0_59__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffeca0")
port map (
combout => \FPO.RES\(59),
dataf => \GRFPC0.DIV.RESULT_0_0_59__G3_0\,
datae => \GRFPC0.DIV.RESULT_0_0_59__G3_1\,
datad => N_99904_1,
datac => \GRFPU0.GRFPU_X0.N_404_0\,
datab => \GRFPU0.GRFPU_X0.ST4.REG\(59),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(56));
GRFPC0_OP1_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030000030300ff")
port map (
combout => \GRFPC0.OP1_4\,
dataf => \GRFPC0.N_235\,
datae => \GRFPC0.RFA.ST\,
datad => \GRFPC0.RFA.RS1D\,
datac => N_167,
datab => N_172);
\GRFPU0_GRFPU_X0_L1_2_4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fc0000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_4\(1),
dataf => \GRFPU0.GRFPU_X0.UN48_BCO_LSB_0\,
datae => \GRFPU0.GRFPU_X0.N_13805_I_0\,
datad => \GRFPU0.GRFPU_X0.BCO_MSB_3_4_I_0_0\(1),
datac => \GRFPU0.GRFPU_X0.N_18387\,
datab => \GRFPU0.GRFPU_X0.TZI2\(23));
\GRFPU0_GRFPU_X0_RES_1_6_I_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000a000c000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20286_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_404\,
datae => N_99904,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(54),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(54),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(51));
\GRFPC0_DIV_RESULT_0_0_62__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffefffafffcfff0")
port map (
combout => \FPO.RES\(62),
dataf => N_99904_1,
datae => \GRFPU0.GRFPU_X0.N_404_0\,
datad => \GRFPC0.DIV.RESULT_0_0_62__G3_1\,
datac => \GRFPC0.DIV.RESULT_0_0_62__G3_0\,
datab => \GRFPU0.GRFPU_X0.ST4.REG\(59),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(62));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_1_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_24849_1\,
dataf => N_113,
datae => \GRFPC0.N_24820\,
datad => N_99,
datac => \GRFPC0.N_9172\,
datab => \GRFPC0.CCWR_0_SQMUXA_1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_1_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c000")
port map (
combout => \GRFPC0.N_25793_1\,
dataf => N_113,
datae => N_97,
datad => N_99,
datac => \GRFPC0.N_9172\,
datab => \GRFPC0.CCWR_0_SQMUXA_1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_1_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_25355_2\,
dataf => N_113,
datae => \GRFPC0.N_23978\,
datad => N_99,
datac => \GRFPC0.N_9172\,
datab => \GRFPC0.CCWR_0_SQMUXA_1\);
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_22_3328_I_A3_0_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f00ff0f0fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_22_3328_I_A3_0_0_0\,
dataf => \GRFPU0.GRFPU_X0.N_400\,
datae => \GRFPU0.GRFPU_X0.N_401\,
datad => \GRFPU0.GRFPU_X0.ST4.MSGNF\(18),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(18));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_4_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3500")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(44),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(44),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(44),
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datac => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datab => \GRFPU0.MULO.MRES\(104),
dataa => \GRFPU0.MULO.DRES_1\(104));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_45_0_A3_SUB_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.N_24624\,
dataf => \GRFPC0.N_225\,
datae => \GRFPC0.N_24039\,
datad => \GRFPC0.N_226\,
datac => \GRFPC0.N_227\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_10_I_A2_1_1_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000003")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_A2_1_1\(1),
dataf => \GRFPC0.V.STDATA_14_I_M_10\(0),
datae => \GRFPC0.N_225\,
datad => \GRFPC0.N_24039\,
datac => \GRFPC0.N_226\,
datab => \GRFPC0.N_227\);
\GRFPC0_V_STDATA_14_I_M2_RNI05VC1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.N_264\,
dataf => \GRFPC0.N_225\,
datae => \GRFPC0.N_24039\,
datad => \GRFPC0.N_226\,
datac => \GRFPC0.N_227\);
GRFPC0_FP_PIPELINE_9_CHECK_DEP_UN4193_REGDEPX2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4193_REGDEPX2\,
dataf => \GRFPC0.N_225\,
datae => \GRFPC0.N_24039\,
datad => \GRFPC0.N_226\,
datac => \GRFPC0.N_227\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_100_0_A2_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003000000")
port map (
combout => \GRFPC0.N_25178\,
dataf => \GRFPC0.V.STDATA_14_I_M_10\(0),
datae => \GRFPC0.N_225\,
datad => \GRFPC0.N_24039\,
datac => \GRFPC0.N_226\,
datab => \GRFPC0.N_227\);
GRFPU0_GRFPU_X0_COMB_UN1_ITER_DP_I_A2_RNIEL8I2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00000c0c0000")
port map (
combout => N_93159,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.GRFPU_X0.N_19742\,
datad => \GRFPU0.MULO.DRES_1\(97),
datac => \GRFPU0.MULO.DRES_1S\(96),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
GRFPU0_GRFPU_X0_UN1_QP1_SP_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f33")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\,
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(1),
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(2),
datad => \GRFPU0.MULO.MRES\(120),
datac => \GRFPU0.MULO.DRES_1\(97),
datab => \GRFPU0.MULO.DRES_1S\(96));
\GRFPC0_FP_PIPELINE_13_0_CHECK_DEP_DEP_2_IV_0_O2_1_RNI3B2K1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffcfffffffff")
port map (
combout => \GRFPC0.N_21257\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22777\,
datad => \GRFPC0.N_22517\,
datac => \GRFPC0.FIFO.INST_0\(29),
datab => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_13_0_REGDEPX_236_IV_I_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f0000000c0")
port map (
combout => \GRFPC0.N_22571\,
dataf => \GRFPC0.N_22777\,
datae => \GRFPC0.N_22517\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0\(29),
datab => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000030")
port map (
combout => \GRFPC0.N_23299\,
dataf => \GRFPC0.N_22777\,
datae => \GRFPC0.N_22517\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0\(29),
datab => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_D_STLCK_RNO_5_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff080808")
port map (
combout => \GRFPC0.D.STLCK_0_0_20__G1_1\,
dataf => \GRFPC0.N_23538\,
datae => \GRFPC0.N_21454\,
datad => \GRFPC0.N_23515_I\,
datac => \GRFPC0.N_61_I\,
datab => \GRFPC0.N_9483\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP\);
\GRFPU0_GRFPU_X0_COMB_VITER_ALLOW_1_2_RNO_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0f00cfcc")
port map (
combout => \GRFPU0.GRFPU_X0.N_18200\,
dataf => \GRFPU0.GRFPU_X0.N_5539\,
datae => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_5\,
datad => \GRFPU0.GRFPU_X0.N_3407\,
datac => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__N_7_1\,
datab => \GRFPU0.GRFPU_X0.N_5790\);
GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_SN_M3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffc0ccffffffff")
port map (
combout => N_99908_I,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.N_6\,
datad => \GRFPU0.GRFPU_X0.N_3407\,
datac => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__N_7_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
GRFPU0_GRFPU_X0_COMB_VITER_EXP27_RNIBIQL5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0f003f33")
port map (
combout => \GRFPU0.GRFPU_X0.N_148\,
dataf => \GRFPU0.GRFPU_X0.N_6736\,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => \GRFPU0.GRFPU_X0.N_3407\,
datac => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__N_7_1\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_DIVROM0_DATA_1_MUX_3_RNIRBV82_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3330330f000000")
port map (
combout => D_N_4_1_I,
dataf => \GRFPU0.GRFPU_X0.N_18326\,
datae => \GRFPU0.DIVAPPR\(2),
datad => \GRFPU0.GRFPU_X0.N_3407\,
datac => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__N_7_1\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNI3JU82_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f00ffff3f003f00")
port map (
combout => \GRFPU0.GRFPU_X0.N_8\,
dataf => \GRFPU0.GRFPU_X0.N_3407\,
datae => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__N_7_1\,
datad => \GRFPU0.GRFPU_X0.N_145\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(13));
GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_43_M7_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c0ccc0ccc0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_43_M7_0_0\,
dataf => \GRFPU0.GRFPU_X0.N_18329\,
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_3407\,
datac => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__N_7_1\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
GRFPU0_GRFPU_X0_ITER_V_RNO_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0cff0c0c0fff0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_163\,
dataf => \GRFPU0.GRFPU_X0.N_128\,
datae => \GRFPU0.GRFPU_X0.N_3407\,
datad => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__N_7_1\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(24));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_200_0_A2_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_24175\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(0),
datad => \GRFPC0.N_24180\,
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3386_REGDEPX2_2\,
datab => \GRFPC0.MEM.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_12_REGDEPX_228_0_A3_2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0fc000000000000")
port map (
combout => \GRFPC0.N_22273_2\,
dataf => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datae => \GRFPC0.N_22250\,
datad => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.FIFO.RD_1\(0),
datab => \GRFPC0.FIFO.FULL\);
\GRFPC0_FP_PIPELINE_8_REGDEPX_156_0_A2_1_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0fc000000000000")
port map (
combout => \GRFPC0.N_22480_2\,
dataf => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datae => \GRFPC0.N_22243\,
datad => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.FIFO.RD_1\(0),
datab => \GRFPC0.FIFO.FULL\);
\GRFPC0_FP_PIPELINE_9_REGDEPX_174_0_A2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0fc000000000000")
port map (
combout => \GRFPC0.N_25004\,
dataf => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datae => \GRFPC0.N_21626\,
datad => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.FIFO.RD_1\(0),
datab => \GRFPC0.FIFO.FULL\);
\GRFPC0_FP_PIPELINE_STDEP_1_0_IV_I_O2_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f03ffffffffffff")
port map (
combout => \GRFPC0.N_22837\,
dataf => N_99871,
datae => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datad => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.FIFO.RD_2\(0),
datab => \GRFPC0.FIFO.FULL\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_1_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0fc000000000000")
port map (
combout => \GRFPC0.N_23348_1\,
dataf => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datae => \GRFPC0.N_22252\,
datad => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.FIFO.RD_2\(0),
datab => \GRFPC0.FIFO.FULL\);
GRFPC0_FP_PIPELINE_14_1_CHECK_DEP_UN4552_REGDEPX_RNI3AO81: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f03ffffffffffff")
port map (
combout => \GRFPC0.N_23177\,
dataf => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datae => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4552_REGDEPX\,
datad => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.FIFO.RD_3\(0),
datab => \GRFPC0.FIFO.FULL\);
GRFPC0_FP_PIPELINE_UN77_PENDEXC_0_A4_RNI52D81: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3f03ffffffff")
port map (
combout => \GRFPC0.STDEP_0_SQMUXA_81_2_I\,
dataf => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datae => \GRFPC0.FIFO.INST_1\(19),
datad => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.FIFO.RD_3\(0),
datab => \GRFPC0.FIFO.FULL\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_24163\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.MEM.CTRL.INST\(1),
datad => \GRFPC0.MEM.CTRL.INST\(4),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0),
datab => \GRFPC0.N_24183\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_24167\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.N_25383\,
datad => \GRFPC0.MEM.CTRL.INST\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1),
datab => \GRFPC0.N_24183\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_24168\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(1),
datad => \GRFPC0.N_24137\,
datac => \GRFPC0.N_24181\,
datab => \GRFPC0.MEM.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_3_1_REGDEPX_64_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPC0.N_24767\,
dataf => \GRFPC0.N_21626\,
datae => \GRFPC0.N_24910\,
datad => \GRFPC0.N_22250\,
datac => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_1\(18));
GRFPC0_FP_PIPELINE_3_STDEP_128_SEL1_I_0_A2_0_A3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => \GRFPC0.N_18933\,
dataf => \GRFPC0.N_465\,
datae => \GRFPC0.WR.CTRL.RDD\,
datad => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(2));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_380_0_O2_0_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.N_258\,
dataf => \GRFPC0.N_225\,
datae => \GRFPC0.N_24039\,
datad => \GRFPC0.N_226\,
datac => \GRFPC0.N_227\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_394_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.N_25199\,
dataf => \GRFPC0.N_225\,
datae => \GRFPC0.N_24039\,
datad => \GRFPC0.N_226\,
datac => \GRFPC0.N_227\);
\GRFPC0_FP_PIPELINE_15_REGDEPX2_454_0_A2_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_454_0_A2_0\(1),
dataf => \GRFPC0.N_225\,
datae => \GRFPC0.N_24039\,
datad => \GRFPC0.N_226\,
datac => \GRFPC0.N_227\);
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_10_3640_I_A3_0_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f00ff0f0fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_10_3640_I_A3_0_0_0\,
dataf => \GRFPU0.GRFPU_X0.N_400_1\,
datae => \GRFPU0.GRFPU_X0.N_401\,
datad => \GRFPU0.GRFPU_X0.ST4.MSGNF\(30),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(30));
\GRFPC0_FP_PIPELINE_3_1_REGDEPX_65_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff2f02f0f2200")
port map (
combout => \GRFPC0.FP_PIPELINE.3.1.REGDEPX_65\(1),
dataf => \GRFPC0.FP_PIPELINE.3.1.REGDEPX_63\(1),
datae => \GRFPC0.FP_PIPELINE.3.1.REGDEPX_62\(1),
datad => \GRFPC0.N_22253\,
datac => \GRFPC0.N_21626\,
datab => \GRFPC0.N_24911\,
dataa => \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN839_REGDEPX_2\);
\GRFPC0_FP_PIPELINE_15_REGDEPX2_465_0_A2_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f000000000000")
port map (
combout => \GRFPC0.N_177\,
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.15.REGDEPX2_465_0_A2_4_0\(0),
datad => \FPI.FLOP\(1),
datac => \GRFPC0.V.STDATA_14\(25));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff3000000")
port map (
combout => \GRFPC0.N_277\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_12\(0),
datae => \GRFPC0.DIVI_0_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_9_0\(0),
datac => \FPI.FLOP\(1),
datab => \GRFPC0.V.STDATA_14\(25));
\GRFPC0_DIV_RESULT_0_0_58__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffefcfaf0")
port map (
combout => \FPO.RES\(58),
dataf => \GRFPC0.DIV.RESULT_0_0_58__G3_1\,
datae => N_99904_1,
datad => \GRFPU0.GRFPU_X0.N_404_0\,
datac => \GRFPC0.DIV.RESULT_0_0_58__G3_0\,
datab => \GRFPU0.GRFPU_X0.ST4.REG\(58),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(55));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_4_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffca00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(39),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(39),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(39),
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datac => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datab => \GRFPU0.MULO.MRES\(99),
dataa => \GRFPU0.MULO.DRES_1\(99));
\GRFPU0_GRFPU_X0_INF_ABS0_3_RNIFCUV7_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_6\(4),
dataf => \GRFPU0.GRFPU_X0.L1_0_6\(3),
datae => \GRFPU0.GRFPU_X0.UN248_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3\(19),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3\(18),
datab => \GRFPU0.GRFPU_X0.L2_0_9_0\(4));
\GRFPC0_D_STDLCK_RNO_4_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_6_7_1\,
dataf => \GRFPC0.N_470\,
datae => \GRFPC0.N_482\,
datad => \GRFPC0.N_25886\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_2\,
datab => \GRFPC0.MEM.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_215_I_O3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcfffffffffff")
port map (
combout => \GRFPC0.N_24579\,
dataf => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datab => \GRFPC0.V.STDATA_14\(25));
GRFPU0_GRFPU_X0_ITER_EMIN_RNI266I4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0ffccff")
port map (
combout => \GRFPU0.GRFPU_X0.N_134\,
dataf => \GRFPU0.GRFPU_X0.N_6509\,
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.GRFPU_X0.N_4623_2\,
datac => \GRFPU0.GRFPU_X0.ITER.NORM\,
datab => \GRFPU0.GRFPU_X0.ITER.EMIN\);
\GRFPU0_GRFPU_X0_RES_1_6_I_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000a000c000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20289_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_404\,
datae => N_99904,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(40),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(40),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(40),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(37));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3705")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(31),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_M\(31),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(31),
datad => N_99921,
datac => \GRFPU0.GRFPU_X0.N_18663\,
datab => \GRFPU0.MULO.MRES\(92),
dataa => \GRFPU0.MULO.MRES\(91));
GRFPC0_FP_PIPELINE_1_STDEP_56_SEL0_0_0_O4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3ffffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL0\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_2\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(2),
datab => \GRFPC0.EX.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_100_0_A2_4_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0000000c000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_100_0_A2_4_1\(1),
dataf => \FPI.FLOP\(1),
datae => \GRFPC0.N_24489\,
datad => \GRFPC0.N_24487\,
datac => \GRFPC0.N_24488\,
datab => \GRFPC0.N_235\);
\GRFPU0_GRFPU_X0_RES_1_6_I_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20274_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_404_0\,
datae => N_99904,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(34),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(34),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(31),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(34));
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_A2_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A2_0\,
dataf => \GRFPC0.FP_PIPELINE.8.STDEP_332_SEL0_1\,
datae => \GRFPC0.N_23810\,
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2698_DEP_1\,
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3026_DEP_2\,
datab => \GRFPC0.EX.CTRL.RDWR\);
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L1_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffc0000")
port map (
combout => N_82195,
dataf => \GRFPU0.GRFPU_X0.N_13552_1\,
datae => \GRFPU0.GRFPU_X0.UN258_BCO_LSB_0_0\,
datad => \GRFPU0.GRFPU_X0.UN242_BCO_MSB_1\(15),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3\(3),
datab => \GRFPU0.GRFPU_X0.N_19788\);
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L1_3_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fcff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L1_3\(2),
dataf => \GRFPU0.GRFPU_X0.N_13552_1\,
datae => \GRFPU0.GRFPU_X0.UN258_BCO_LSB_0_0\,
datad => \GRFPU0.GRFPU_X0.UN242_BCO_MSB_1\(15),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3\(3),
datab => \GRFPU0.GRFPU_X0.N_19788\);
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L1_3_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L1_3\(3),
dataf => \GRFPU0.GRFPU_X0.N_13552_1\,
datae => \GRFPU0.GRFPU_X0.UN258_BCO_LSB_0_0\,
datad => \GRFPU0.GRFPU_X0.UN242_BCO_MSB_1\(15),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3\(3),
datab => \GRFPU0.GRFPU_X0.N_19788\);
\GRFPC0_D_LDLCK_RNO_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff08f80")
port map (
combout => \GRFPC0.D.LDLCK_0_0_19__G1\,
dataf => \GRFPC0.D.LDLCK_0_0_19__G3\,
datae => \GRFPC0.FP_PIPELINE.9.REGDEPX_178\(1),
datad => \GRFPC0.FP_PIPELINE.9.REGDEPX_174\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3127_REGDEPX\,
dataa => \GRFPC0.N_23978\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff000c0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_3\(1),
dataf => \GRFPC0.N_25503\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datad => \GRFPC0.N_707\,
datac => \GRFPC0.N_25496\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_1\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00c00000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_2\(1),
dataf => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_0\(1),
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datad => \GRFPC0.N_707\,
datac => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1653_REGDEPX2_0\,
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1653_REGDEPX2_2\);
\GRFPU0_GRFPU_X0_RES_1_6_I_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20275_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_404_0\,
datae => N_99904,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(37),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(37),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(34),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(37));
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN5885_REGDEPX2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f00000fcf0cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5885_REGDEPX2\,
dataf => \GRFPC0.N_24643\,
datae => \GRFPC0.N_24551\,
datad => \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN512_REGDEPX_0\,
datac => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.UN408_REGDEPX_1\,
datab => \GRFPC0.FIFO.INST_1\(17));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O3_7_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffffffffff")
port map (
combout => \GRFPC0.N_22808\,
dataf => \GRFPC0.N_24921\,
datae => \GRFPC0.N_22427\,
datad => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.UN408_REGDEPX_1\,
datac => \GRFPC0.FIFO.INST_0\(18),
datab => \GRFPC0.FIFO.INST_0\(17));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_I_O3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3fffffffffff")
port map (
combout => \GRFPC0.N_24575\,
dataf => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN695_REGDEPX2_2\,
datae => \GRFPC0.EX.CTRL.INST\(16),
datad => \GRFPC0.EX.CTRL.INST\(15),
datac => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(0));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_100_I_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_24307\,
dataf => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN695_REGDEPX2_2\,
datae => \GRFPC0.EX.CTRL.INST\(15),
datad => \GRFPC0.EX.CTRL.INST\(16),
datac => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20287_I_0\,
dataf => N_99904,
datae => \GRFPU0.GRFPU_X0.N_403\,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(57),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(57),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(57),
dataa => \GRFPU0.GRFPU_X0.ST4.MEXP\(2));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_15_I_A2_5_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000000f")
port map (
combout => \GRFPC0.N_25662_2\,
dataf => \FPI.FLOP\(1),
datae => \GRFPC0.N_225\,
datad => \GRFPC0.N_24039\,
datac => \GRFPC0.N_223\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_2_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33cc33cc33cc3c3c")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_2_5\,
dataf => \GRFPU0.GRFPU_X0.N_5633\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.ID\(5),
datac => \GRFPU0.GRFPU_X0.ST3.ID\(5),
datab => \GRFPC0.WR.CTRL.ID\(5));
GRFPC0_FP_PIPELINE_0_UN1_FPO_5_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33cc33cc33cc3c3c")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_0\,
dataf => \GRFPU0.GRFPU_X0.N_5633\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.ID\(5),
datac => \GRFPU0.GRFPU_X0.ST3.ID\(5),
datab => \GRFPC0.DIV.ID\(5));
\GRFPU0_GRFPU_X0_RES_1_6_I_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000a000c000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20291_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_404\,
datae => N_99904,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(46),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(46),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(46),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(43));
\GRFPC0_DIV_RESULT_0_0_55__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffefffcfffafff0")
port map (
combout => \FPO.RES\(55),
dataf => N_99904_1,
datae => \GRFPU0.GRFPU_X0.N_404_0\,
datad => \GRFPC0.DIV.RESULT_0_0_55__G3_1\,
datac => \GRFPC0.DIV.RESULT_0_0_55__G3_0\,
datab => \GRFPU0.GRFPU_X0.ST4.REG\(55),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(52));
\GRFPC0_FP_PIPELINE_1_0_CHECK_DEP_DEP_2_IV_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fffffffcffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.DEP_2_I\(0),
dataf => \GRFPC0.N_22777\,
datae => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_2\,
datad => \GRFPC0.FIFO.INST_0\(26),
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(25));
GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_UN61_REGDEPX_2_I_O3_I_A2_0_A2_0_A2_RNI56D02: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_22157\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_2\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0\(26),
datab => \GRFPC0.FIFO.INST_0\(27));
GRFPU0_GRFPU_X0_COMB_VST2_ADD3_RNIO4L91: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00c0c0c000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19547\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_4202\,
datad => \GRFPU0.GRFPU_X0.N_4201\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_0_O3_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000fffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19582\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_5250\,
datad => \GRFPU0.GRFPU_X0.N_4202\,
datac => \GRFPU0.GRFPU_X0.N_4201\);
GRFPU0_GRFPU_X0_COMB_VST2_ADD3_RNIJC8U_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19549\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_5250\,
datad => \GRFPU0.GRFPU_X0.N_3407\,
datac => \GRFPU0.GRFPU_X0.N_4202\,
datab => \GRFPU0.GRFPU_X0.N_4201\);
GRFPU0_GRFPU_X0_COMB_VST2_ADD3_RNI0FOR: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19662\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_3407\,
datad => \GRFPU0.GRFPU_X0.N_4202\,
datac => \GRFPU0.GRFPU_X0.N_4201\);
GRFPU0_GRFPU_X0_COMB_VST2_ADD3_RNIS6MS: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0fffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18969\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_4202\,
datad => \GRFPU0.GRFPU_X0.N_4201\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
GRFPU0_GRFPU_X0_COMB_VST2_REG36: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
dataf => \GRFPU0.GRFPU_X0.N_4202\,
datae => \GRFPU0.GRFPU_X0.N_4201\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_1\,
datac => \GRFPU0.GRFPU_X0.N_3444\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_0_O4_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19553\,
dataf => \GRFPU0.GRFPU_X0.N_5250\,
datae => \GRFPU0.GRFPU_X0.N_4202\,
datad => \GRFPU0.GRFPU_X0.N_4201\);
GRFPU0_GRFPU_X0_COMB_VST2_ADD3_RNIJC8U: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000030000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19554\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_5250\,
datad => \GRFPU0.GRFPU_X0.N_3407\,
datac => \GRFPU0.GRFPU_X0.N_4202\,
datab => \GRFPU0.GRFPU_X0.N_4201\);
\GRFPU0_GRFPU_X0_ST2_EXC_RNO_0_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000030303ff")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.EXC_0_0_4__G0_0\,
dataf => \GRFPU0.GRFPU_X0.UN1_VST2.EXC_0_SQMUXA_2_1\,
datae => \GRFPU0.GRFPU_X0.N_4202\,
datad => \GRFPU0.GRFPU_X0.N_4201\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3));
GRFPU0_GRFPU_X0_VST2_REG_1_SQMUXA_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_2\,
dataf => \GRFPU0.GRFPU_X0.N_4202\,
datae => \GRFPU0.GRFPU_X0.N_4201\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNIVAC21_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.N_4202\,
datae => \GRFPU0.GRFPU_X0.N_4201\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7));
GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_53_M4_E_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_57_M4_E_2\,
dataf => \GRFPU0.GRFPU_X0.N_18527\,
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_19742\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
GRFPU0_GRFPU_X0_COMB_UN1_ITER_DP_I_A2_RNIRC1B2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000030300000")
port map (
combout => N_93160,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.GRFPU_X0.N_19742\,
datad => \GRFPU0.MULO.MRES\(97),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.MULO.MRES\(96));
GRFPU0_GRFPU_X0_COMB_UN1_ITER_DP_I_A2_RNIISLS2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc000000c0c00000")
port map (
combout => N_93163,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.GRFPU_X0.N_19742\,
datad => \GRFPU0.MULO.DRES_1\(119),
datac => \GRFPU0.MULO.DRES_1S\(118),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_26_3224_I_A3_0_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f00ff0f0fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_26_3224_I_A3_0_0_0\,
dataf => \GRFPU0.GRFPU_X0.N_400\,
datae => \GRFPU0.GRFPU_X0.N_401\,
datad => \GRFPU0.GRFPU_X0.ST4.MSGNF\(14),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(14));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03ff00ff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2\(19),
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A2_7_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_23012\,
dataf => \GRFPC0.N_24921\,
datae => \GRFPC0.N_24924\,
datad => \GRFPC0.N_24892\,
datac => \GRFPC0.FIFO.INST_0\(18),
datab => \GRFPC0.FIFO.INST_0\(17));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_420_0_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_1\(0),
dataf => \GRFPC0.N_24076\,
datae => \GRFPC0.N_24074\,
datad => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datac => \GRFPC0.N_24118\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_A2_3_0\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000c000c0000000")
port map (
combout => \GRFPC0.N_21589\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datad => N_106,
datac => N_107,
datab => \GRFPC0.N_9475_1\);
\GRFPC0_D_STLCK_RNO_1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcfffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_O3_2_0\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_2\,
datae => \GRFPC0.N_106_I\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(2),
datab => \GRFPC0.EX.CTRL.RD\(1));
\GRFPU0_DIVROM0_DATA_1_MUX_3_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feba7632dc985410")
port map (
combout => \GRFPU0.DIVAPPR\(2),
dataf => \GRFPU0.DIVROM0.DATA_1_2\(2),
datae => \GRFPU0.DIVROM0.DATA_1_3\(2),
datad => \GRFPU0.DIVROM0.DATA_1_1\(2),
datac => \GRFPU0.DIVROM0.DATA_1_0\(2),
datab => \GRFPU0.DIVROM0.RADDR\(6),
dataa => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_21__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_0_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000cfc0cfc0")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(28),
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => N_28226,
datad => \GRFPU0.GRFPU_X0.N_14516\,
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(31));
\GRFPU0_GRFPU_X0_RES_1_6_I_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c0a0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20288_I_0\,
dataf => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(60),
datae => \GRFPU0.GRFPU_X0.N_404\,
datad => N_99904,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(60),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(57),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(60));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_175_I_A4_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000cf00ff")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_I_A4_1\(0),
dataf => \GRFPC0.N_25620\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(0),
datad => \GRFPC0.N_25621\,
datac => \GRFPC0.N_25859\,
datab => \GRFPC0.N_25550\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff800080008000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_3\(0),
dataf => \GRFPC0.N_25124\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datad => \GRFPC0.N_25560_2\,
datac => \GRFPC0.N_24703_I\,
datab => \GRFPC0.DIV.RD\(3),
dataa => \GRFPC0.DIV.RD\(4));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_140_0_A2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.N_24143\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.MEM.CTRL.INST\(1),
datad => \GRFPC0.MEM.CTRL.INST\(4),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0),
datab => \GRFPC0.N_24183\);
\GRFPC0_FP_PIPELINE_5_0_REGDEPX_95_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0400")
port map (
combout => \GRFPC0.FP_PIPELINE.5.0.REGDEPX_95\(1),
dataf => \GRFPC0.N_24845\,
datae => \GRFPC0.N_24846\,
datad => \GRFPC0.N_24921\,
datac => \GRFPC0.N_22535\,
datab => \GRFPC0.N_24924\,
dataa => \GRFPC0.FIFO.INST_0\(18));
\GRFPC0_D_STDLCK_RNO_2_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_6\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_2\,
datad => \GRFPC0.N_23330\,
datac => \GRFPC0.N_106_I\,
datab => \GRFPC0.EX.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_A0_RNIBTP01_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff8fffffff80")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_2\(0),
dataf => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0\(0),
datad => N_1_2,
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(0),
dataa => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1286_REGDEPX2\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03ff00ff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55));
\GRFPU0_GRFPU_X0_RES_1_6_I_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20272_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_404\,
datae => N_99904,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(45),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(45),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(42),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(45));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe001010fe00fefe")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1_IV_I\(63),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_I\(63),
datae => \GRFPU0.GRFPU_X0.N_3476\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(6));
\GRFPC0_D_STLCK_RNO_6_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_1__G1_TZ\,
dataf => \GRFPC0.N_594\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => N_242,
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN919_DEP_2\,
datab => N_243);
GRFPC0_STDDEP_0_SQMUXA_116_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ffffffffffff")
port map (
combout => \GRFPC0.N_22341\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_24900\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3705")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(28),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(28),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(28),
datad => N_99921,
datac => \GRFPU0.GRFPU_X0.N_18663\,
datab => \GRFPU0.MULO.MRES\(89),
dataa => \GRFPU0.MULO.MRES\(88));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_45_0_A3_6_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_25421_1\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.EX.CTRL.INST\(16),
datad => \GRFPC0.EX.CTRL.INST\(15),
datac => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_250_0_A2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25257\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.N_25190\,
datad => \GRFPC0.N_25316\,
datac => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_0_A4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_25566\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(1),
datad => \GRFPC0.N_25227\,
datac => \GRFPC0.WR2.CTRL.INST\(29),
datab => \GRFPC0.WR2.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_5_STDEP_212_3_0_O3_1_I_A3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000003000")
port map (
combout => \GRFPC0.N_663\,
dataf => \GRFPC0.N_494\,
datae => \GRFPC0.N_465\,
datad => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(2));
\GRFPC0_FP_PIPELINE_5_STDEP_212_3_0_O3_2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcfffffffffff")
port map (
combout => \GRFPC0.N_21616\,
dataf => \GRFPC0.N_494\,
datae => \GRFPC0.N_465\,
datad => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(2));
GRFPC0_STDDEP_0_SQMUXA_114: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_114\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_2\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0\(26),
datab => \GRFPC0.FIFO.INST_0\(27));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_340_0_A2_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_24527\,
dataf => \GRFPC0.N_23946_2\,
datae => \GRFPC0.N_24531\,
datad => \GRFPC0.FIFO.INST_0\(17),
datac => \GRFPC0.FIFO.INST_0\(16),
datab => \GRFPC0.FIFO.INST_0\(15));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_34_3016_I_A3_0_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f00ff0f0fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_34_3016_I_A3_0_0_0\,
dataf => \GRFPU0.GRFPU_X0.N_400\,
datae => \GRFPU0.GRFPU_X0.N_401\,
datad => \GRFPU0.GRFPU_X0.ST4.MSGNF\(6),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(6));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000030")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_1_0\(0),
dataf => \GRFPC0.N_24489\,
datae => \GRFPC0.N_24487\,
datad => \GRFPC0.N_24488\,
datac => \GRFPC0.N_24643\,
datab => \GRFPC0.N_24531\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_125_0_A2_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_125_0_A2_0\(1),
dataf => \GRFPC0.N_25658\,
datae => \FPI.FLOP\(6),
datad => \GRFPC0.N_24489\,
datac => \GRFPC0.N_24643\,
datab => \GRFPC0.N_24531\);
\GRFPU0_DIVROM0_DATA_1_MUX_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feba7632dc985410")
port map (
combout => \GRFPU0.DIVAPPR\(0),
dataf => \GRFPU0.DIVROM0.DATA_1_2\(0),
datae => \GRFPU0.DIVROM0.DATA_1_3\(0),
datad => \GRFPU0.DIVROM0.DATA_1_1\(0),
datac => \GRFPU0.DIVROM0.DATA_1_0\(0),
datab => \GRFPU0.DIVROM0.RADDR\(6),
dataa => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPC0_OP2_4_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19678\,
dataf => \GRFPC0.N_223\,
datae => \GRFPC0.RFA.RS2D\,
datad => N_742,
datac => N_678);
\GRFPC0_OP2_4_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19679\,
dataf => \GRFPC0.N_223\,
datae => \GRFPC0.RFA.RS2D\,
datad => N_743,
datac => N_679);
\GRFPC0_OP2_4_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19680\,
dataf => \GRFPC0.N_223\,
datae => \GRFPC0.RFA.RS2D\,
datad => N_744,
datac => N_680);
\GRFPC0_OP2_4_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19681\,
dataf => \GRFPC0.N_223\,
datae => \GRFPC0.RFA.RS2D\,
datad => N_745,
datac => N_681);
\GRFPC0_OP2_4_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19682\,
dataf => \GRFPC0.N_223\,
datae => \GRFPC0.RFA.RS2D\,
datad => N_746,
datac => N_682);
\GRFPC0_OP2_4_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19683\,
dataf => \GRFPC0.N_223\,
datae => \GRFPC0.RFA.RS2D\,
datad => N_747,
datac => N_683);
\GRFPC0_OP2_4_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19684\,
dataf => \GRFPC0.N_223\,
datae => \GRFPC0.RFA.RS2D\,
datad => N_748,
datac => N_684);
\GRFPC0_OP2_4_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19685\,
dataf => \GRFPC0.N_223\,
datae => \GRFPC0.RFA.RS2D\,
datad => N_749,
datac => N_685);
\GRFPC0_OP2_4_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19687\,
dataf => \GRFPC0.N_223\,
datae => \GRFPC0.RFA.RS2D\,
datad => N_751,
datac => N_687);
\GRFPC0_OP2_4_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19688\,
dataf => \GRFPC0.N_223\,
datae => \GRFPC0.RFA.RS2D\,
datad => N_752,
datac => N_688);
\GRFPC0_OP2_4_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19689\,
dataf => \GRFPC0.N_223\,
datae => \GRFPC0.RFA.RS2D\,
datad => N_753,
datac => N_689);
\GRFPC0_OP2_4_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f0f0f0")
port map (
combout => \GRFPC0.N_19690\,
dataf => \GRFPC0.N_223\,
datae => \GRFPC0.RFA.RS2D\,
datad => N_754,
datac => N_690);
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c000c000c000000")
port map (
combout => \GRFPC0.N_749\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datad => N_106,
datac => N_107,
datab => \GRFPC0.N_9475_1\);
\GRFPU0_GRFPU_X0_RES_1_6_I_0_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19240_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_404\,
datae => N_99904,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_0_0\(47),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0_1\(47),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(44),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(47));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_28_3172_I_A3_0_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f00ff0f0fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_28_3172_I_A3_0_0_0\,
dataf => \GRFPU0.GRFPU_X0.N_400\,
datae => \GRFPU0.GRFPU_X0.N_401\,
datad => \GRFPU0.GRFPU_X0.ST4.MSGNF\(12),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(12));
GRFPU0_GRFPU_X0_COMB_VST1_V2_1_RNI0FJU4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
dataf => \GRFPU0.GRFPU_X0.N_10059_I\,
datae => \FPI.FLOP\(1),
datad => \FPI.FLOP\(6),
datac => \FPI.FLOP\(5));
GRFPU0_GRFPU_X0_ST1_DEFERNX_RET_1_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff33f03000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.DEFERNX_0_0_G0_I_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.DEFERNX_0_0_G4\,
datae => \FPI.FLOP\(6),
datad => \FPI.FLOP\(7),
datac => \FPI.FLOP\(5),
datab => \FPI.FLOP\(4));
GRFPC0_WR2_EXC_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5555555550505450")
port map (
combout => \GRFPC0.WR2.EXC_0_0_G1\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.VWR2.EXC_1_IV_I_A4_0_0\,
datad => \GRFPC0.N_23694\,
datac => \GRFPC0.WR2.CTRL.SEQERR\,
datab => \GRFPC0.WR2.EXC\,
dataa => \GRFPC0.DIV.EXC_MB_2_I_0\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_45_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_25441\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(1),
datae => \GRFPC0.N_24181\,
datad => \GRFPC0.MEM.CTRL.RS1V\,
datac => \GRFPC0.MEM.CTRL.INST\(17),
datab => \GRFPC0.MEM.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_23_3302_I_A3_0_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f00ff0f0fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_23_3302_I_A3_0_0_0\,
dataf => \GRFPU0.GRFPU_X0.N_400\,
datae => \GRFPU0.GRFPU_X0.N_401\,
datad => \GRFPU0.GRFPU_X0.ST4.MSGNF\(17),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(17));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_375_0_A3_4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_25407\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2004_REGDEPX2_1\,
datad => \GRFPC0.EX.CTRL.INST\(27),
datac => \GRFPC0.EX.CTRL.INST\(29),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_25715\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.EX.CTRL.INST\(27),
datad => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1),
datab => \GRFPC0.N_24322\);
GRFPC0_FP_PIPELINE_13_1_CHECK_DEP_UN4240_REGDEPX_1_RNIGKBM1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffffffffffff")
port map (
combout => \GRFPC0.N_21246\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX_1\,
datad => \GRFPC0.FIFO.INST_1\(19),
datac => \GRFPC0.FIFO.INST_1\(29),
datab => \GRFPC0.FIFO.INST_1\(27));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_9_3666_I_A3_0_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f00ff0f0fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_9_3666_I_A3_0_0_0\,
dataf => \GRFPU0.GRFPU_X0.N_400_1\,
datae => \GRFPU0.GRFPU_X0.N_401\,
datad => \GRFPU0.GRFPU_X0.ST4.MSGNF\(31),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(31));
\GRFPC0_FP_PIPELINE_14_CHECK_DEP_DEP_16_I_I2_0_S_0_O3_RNIVCPP1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_24449_I\,
dataf => \GRFPC0.N_494\,
datae => \GRFPC0.N_469\,
datad => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(2));
\GRFPU0_GRFPU_X0_RES_1_6_I_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000a000c000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20298_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_404\,
datae => N_99904,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(44),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(44),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(44),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(41));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_25624\,
dataf => \GRFPC0.N_24201\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(1),
datad => \GRFPC0.DIV.INST\(17),
datac => \GRFPC0.DIV.INST\(18),
datab => \GRFPC0.DIV.RS1V\);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_A2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_24159\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.N_24189\,
datad => \GRFPC0.EX.CTRL.INST\(3),
datac => \GRFPC0.EX.CTRL.INST\(4),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_45_0_A3_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_25420\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.N_25460\,
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_25610\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.N_24189\,
datad => \GRFPC0.EX.CTRL.INST\(3),
datac => \GRFPC0.EX.CTRL.INST\(4),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A5_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00fc00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18242\,
dataf => \GRFPU0.GRFPU_X0.N_4260\,
datae => \GRFPU0.GRFPU_X0.N_18213\,
datad => \GRFPU0.GRFPU_X0.C\(11),
datac => \GRFPU0.GRFPU_X0.C\(10),
datab => \GRFPU0.GRFPU_X0.C\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_O3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c0c00003c0c3")
port map (
combout => \GRFPU0.GRFPU_X0.N_72\,
dataf => \GRFPU0.GRFPU_X0.N_4260\,
datae => \GRFPU0.GRFPU_X0.N_18221\,
datad => \GRFPU0.GRFPU_X0.N_18213\,
datac => \GRFPU0.GRFPU_X0.C\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
\GRFPC0_D_STLCK_RNO_2_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff8f8f8fff8f8")
port map (
combout => \GRFPC0.D.STLCK_0_0_8__G1_2\,
dataf => \GRFPC0.N_22639\,
datae => \GRFPC0.N_22689\,
datad => N_99871,
datac => \GRFPC0.D.STLCK_0_0_8__G1_0\,
datab => \GRFPC0.N_21454\,
dataa => \GRFPC0.N_22707\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_94_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc0000000c000000")
port map (
combout => \GRFPC0.N_24656\,
dataf => \FPI.FLOP\(1),
datae => \GRFPC0.N_225\,
datad => \GRFPC0.N_24039\,
datac => \GRFPC0.N_223\,
datab => \GRFPC0.N_25450_1\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_25340\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22253\,
datad => \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN839_REGDEPX_2\,
datac => \GRFPC0.FIFO.INST_1\(2),
datab => \GRFPC0.FIFO.INST_1\(1));
\GRFPU0_GRFPU_X0_EXPOP_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f0f00ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_5678\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datad => N_28163,
datac => N_28164);
\GRFPC0_FP_PIPELINE_15_REGDEPX2_465_0_A3_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_25511\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datad => \GRFPC0.N_25382\,
datac => \GRFPC0.MEM.CTRL.INST\(26),
datab => \GRFPC0.MEM.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_9_1_REGDEPX_170_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000000c")
port map (
combout => \GRFPC0.FP_PIPELINE.9.1.REGDEPX_170\(1),
dataf => \GRFPC0.FP_PIPELINE.9.0.REGDEPX_168\(1),
datae => N_40557,
datad => \GRFPC0.N_531\,
datac => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FIFO.INST_1\(26));
\GRFPC0_FP_PIPELINE_9_REGDEPX_174_0_A4_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000c0000")
port map (
combout => \GRFPC0.N_24959\,
dataf => N_99871,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_531\,
datac => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FIFO.INST_1\(26));
\GRFPC0_FP_PIPELINE_12_REGDEPX_228_0_A3_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_23348\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22252\,
datad => \GRFPC0.FP_PIPELINE.15.1.CHECK_DEP.UN4895_REGDEPX_2\,
datac => \GRFPC0.FIFO.INST_1\(2),
datab => \GRFPC0.FIFO.INST_1\(1));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_0_3_TZ_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffdcec50a0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_3_TZ\(52),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_A2_3_1\(52),
datae => \GRFPU0.GRFPU_X0.N_73\,
datad => \GRFPU0.GRFPU_X0.COMB.EXP57\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(52),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(0));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_36_2964_I_A3_0_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f00ff0f0fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_36_2964_I_A3_0_0_0\,
dataf => \GRFPU0.GRFPU_X0.N_400\,
datae => \GRFPU0.GRFPU_X0.N_401\,
datad => \GRFPU0.GRFPU_X0.ST4.MSGNF\(4),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(4));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN4994_DEP_I_O3_RNIPN801: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcfffffffffff")
port map (
combout => \GRFPC0.N_22331\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datae => \GRFPC0.N_23330\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_7_STDEP_296_SEL1_I_0_A2_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffcfff")
port map (
combout => \GRFPC0.N_21713\,
dataf => \GRFPC0.N_23330\,
datae => \GRFPC0.N_106_I\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(4));
\GRFPU0_GRFPU_X0_ITER_EXPOP_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"afabafabafaba0a8")
port map (
combout => N_53560,
dataf => \GRFPU0.GRFPU_X0.EXPOP_0_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.EXPOP_1_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.N_19742\,
datac => \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
dataa => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0));
\GRFPC0_FP_PIPELINE_4_0_REGDEPX_77_0_A3_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_23180\,
dataf => \GRFPC0.N_24921\,
datae => \GRFPC0.N_24924\,
datad => \GRFPC0.N_24892\,
datac => \GRFPC0.FIFO.INST_0\(18),
datab => \GRFPC0.FIFO.INST_0\(17));
\GRFPC0_FP_PIPELINE_6_0_REGDEPX_113_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc00f0f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_113_0_0\(1),
dataf => \GRFPC0.N_24921\,
datae => \GRFPC0.FP_PIPELINE.6.0.CHECK_DEP.UN1983_REGDEPX\,
datad => \GRFPC0.N_24924\,
datac => \GRFPC0.N_24926\,
datab => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_113_0_A4_0\(1));
\GRFPC0_D_STLCK_RNO_4_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => \GRFPC0.N_21205\,
dataf => N_40557,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_531\,
datac => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FIFO.INST_1\(26));
\GRFPC0_FP_PIPELINE_8_REGDEPX_156_0_A4_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => \GRFPC0.N_22274\,
dataf => N_99871,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_531\,
datac => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FIFO.INST_1\(26));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_52__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_COMB_VST3_EXC18LTO10_RNI7V2M3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0f0fcf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_6321\,
dataf => \GRFPU0.GRFPU_X0.N_6206\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__I3_I_3\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.EXC18\,
datac => \GRFPU0.GRFPU_X0.N_5773\,
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8));
GRFPU0_GRFPU_X0_UN1_RNDOP_0_SQMUXA_10_RNIQGO43: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_6509_I_M\,
dataf => \GRFPU0.GRFPU_X0.N_4482\,
datae => \GRFPU0.GRFPU_X0.N_4664\,
datad => \GRFPU0.GRFPU_X0.N_4481\,
datac => \GRFPU0.GRFPU_X0.N_4623_2\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_140_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_24141\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.N_702\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN351_REGDEPX2_1\,
datac => \GRFPC0.WR.CTRL.INST\(4),
datab => \GRFPC0.WR.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_145_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f300000000000000")
port map (
combout => \GRFPC0.N_24087\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.N_24761_2\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN383_REGDEPX2_1\,
datac => \GRFPC0.WR2.CTRL.RDD\,
datab => \GRFPC0.WR2.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff004000400040")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_0\(1),
dataf => \GRFPC0.N_25652\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datad => \GRFPC0.N_703\,
datac => \GRFPC0.N_25854\,
datab => \GRFPC0.N_25824_1\,
dataa => \GRFPC0.WR.CTRL.INST\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_S_0_TZ_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffceccca00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_S_0_TZ\(20),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_S_0_TZ_1\(20),
datae => \GRFPU0.GRFPU_X0.N_3560_I\,
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datac => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datab => \GRFPU0.MULO.MRES\(80),
dataa => \GRFPU0.MULO.DRES_1\(80));
GRFPC0_FIFO_INC_5_SQMUXA_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000003")
port map (
combout => \GRFPC0.FIFO_INC_5_SQMUXA_1\,
dataf => \GRFPC0.N_23687\,
datae => \GRFPC0.N_23699\,
datad => \GRFPC0.N_23694\,
datac => \GRFPC0.WR2.CTRL.SEQERR\,
datab => \GRFPC0.MEM.CTRL.PEND\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f030000000000000")
port map (
combout => \GRFPC0.N_24787\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.N_275\,
datad => \GRFPC0.DIV.RDD\,
datac => \GRFPC0.DIV.RD\(3),
datab => \GRFPC0.DIV.RD\(0));
GRFPU0_GRFPU_X0_COMB_UN1_FLOP4_0_0_A3_0_RNIRVK52: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3fff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18522\,
dataf => \GRFPU0.GRFPU_X0.N_18516\,
datae => \GRFPU0.GRFPU_X0.N_18449\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(2));
\GRFPU0_GRFPU_X0_VST3_REG_37_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcc0a0a33000a0a")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(49),
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_2_03\,
datac => \GRFPU0.GRFPU_X0.N_5774\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(49));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_49__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
\GRFPU0_GRFPU_X0_RES_1_6_I_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000a000c000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20297_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_404\,
datae => N_99904,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(41),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(41),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(41),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(38));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_275_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000300000000000")
port map (
combout => \GRFPC0.N_23994\,
dataf => \GRFPC0.N_23946_2\,
datae => \GRFPC0.N_24489\,
datad => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.N_24487\,
datab => \GRFPC0.N_24488\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_33_0_A2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_33_0_A2_1\(1),
dataf => \FPI.FLOP\(6),
datae => \GRFPC0.N_24489\,
datad => \GRFPC0.N_24487\,
datac => \GRFPC0.N_24488\);
GRFPC0_VWR2_CTRL_PEND_0_SQMUXA_RNIOT5S: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000030000000f0")
port map (
combout => \GRFPC0.FIFO.RD_I_M_1\(0),
dataf => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datae => \GRFPC0.FIFO.RD_0\(0),
datad => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA\,
datac => N_35,
datab => N_39);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_215_I_A3_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.N_24622\,
dataf => \GRFPC0.N_225\,
datae => \GRFPC0.N_24039\,
datad => \GRFPC0.N_226\,
datac => \GRFPC0.N_227\);
\GRFPC0_DIV_RESULT_0_0_36__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffefffcfffafff0")
port map (
combout => \FPO.RES\(36),
dataf => N_99904_1,
datae => \GRFPU0.GRFPU_X0.N_404_0\,
datad => \GRFPC0.DIV.RESULT_0_0_36__G3_0\,
datac => \GRFPC0.DIV.RESULT_0_0_36__G3_1\,
datab => \GRFPU0.GRFPU_X0.ST4.REG\(36),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(33));
\GRFPC0_FP_PIPELINE_0_STDEP_82_0_IV_I_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_22855\,
dataf => \GRFPC0.N_21454\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => N_242,
datac => N_243,
datab => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN919_DEP_2\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_0_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00c0ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_0\(26),
dataf => \GRFPC0.N_24921\,
datae => \GRFPC0.N_22587\,
datad => \GRFPC0.N_22535\,
datac => \GRFPC0.N_22427\,
datab => \GRFPC0.FIFO.INST_0\(18));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003fff0000")
port map (
combout => \GRFPC0.N_23184_2\,
dataf => N_113,
datae => \GRFPC0.FP_PIPELINE.UN24_OP\,
datad => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_0\,
datac => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_1\,
datab => N_103);
\GRFPC0_FP_PIPELINE_0_STDEP_482_0_IV_0_A2_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_482_0_IV_0_A2_0\(0),
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datad => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_0\,
datac => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_1\,
datab => N_103);
\GRFPC0_FP_PIPELINE_11_REGDEPX_212_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000fffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_0_0\(2),
dataf => N_97,
datae => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_0\,
datad => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_1\,
datac => N_103);
\GRFPC0_FP_PIPELINE_12_CHECK_DEP_DEP_25_IV_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_25_I\(0),
dataf => \GRFPC0.N_9465\,
datae => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_0\,
datad => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_1\,
datac => N_103);
\GRFPC0_FP_PIPELINE_4_CHECK_DEP_DEP_25_IV_0_O4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_25_I\(0),
dataf => \GRFPC0.N_9477\,
datae => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_0\,
datad => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_1\,
datac => N_103);
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_25_IV_I_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_25_I_I_0\(0),
dataf => \GRFPC0.N_9480\,
datae => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_0\,
datad => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_1\,
datac => N_103);
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c000c000c00000")
port map (
combout => \GRFPC0.N_755\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datad => N_106,
datac => N_107,
datab => \GRFPC0.N_9475_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(15),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(17),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(17));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(21),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(21));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(24),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(25),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(25));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(26),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(27),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(27));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(29),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(30),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(30));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(37),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(37));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(38),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfff0000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(39),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.V\,
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(40),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(40));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(42),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(42));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfff0000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(44),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.V\,
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(45),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(45));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfff0000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(46),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.V\,
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(47),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(47));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(48),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(49),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(49));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(50),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(50));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(51),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(51));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(59),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.V\,
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(7),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(9),
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(9));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f33333333333333")
port map (
combout => \GRFPU0.GRFPU_X0.N_18191\,
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(18));
GRFPU0_GRFPU_X0_COMB_VST2_EXC15_RNI2ALN2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G2\,
dataf => \GRFPU0.GRFPU_X0.N_5673_0\,
datae => \GRFPU0.GRFPU_X0.N_4175\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.V\,
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcff00003000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16518\,
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(4),
datae => \GRFPU0.GRFPU_X0.N_5508\,
datad => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datac => \GRFPU0.GRFPU_X0.UN23_EXP\(3),
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\);
\GRFPU0_GRFPU_X0_EXP_11_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3fcffff030c0000")
port map (
combout => \GRFPU0.GRFPU_X0.EXP_11\(4),
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(5),
datae => \GRFPU0.GRFPU_X0.COMB.EXP37\,
datad => N_32649,
datac => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(4));
\GRFPU0_GRFPU_X0_RES_1_6_I_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000a000c000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20295_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_404_0\,
datae => N_99904,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(35),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(35),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(35),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(32));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_49__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
\GRFPU0_GRFPU_X0_RES_1_6_I_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80c0a0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20292_I_0\,
dataf => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(49),
datae => \GRFPU0.GRFPU_X0.N_404\,
datad => N_99904,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(49),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(46),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(49));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf0fffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(28),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(28),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(28),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_18664\,
datab => \GRFPU0.MULO.MRES\(88));
\GRFPC0_DIV_RESULT_0_0_33__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffefafcf0")
port map (
combout => \FPO.RES\(33),
dataf => \GRFPC0.DIV.RESULT_0_0_33__G3_1\,
datae => N_99904_1,
datad => \GRFPU0.GRFPU_X0.N_404_0\,
datac => \GRFPC0.DIV.RESULT_0_0_33__G3_0\,
datab => \GRFPU0.GRFPU_X0.ST4.REG\(30),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(33));
\GRFPU0_GRFPU_X0_VST3_REG_37_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcc0a0a33000a0a")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(51),
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_2_03\,
datac => \GRFPU0.GRFPU_X0.N_5774\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(51));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_340_I_A4_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5f005f0013005f00")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_I_A4_1\(1),
dataf => \GRFPC0.N_25122\,
datae => \GRFPC0.N_24160_1\,
datad => \GRFPC0.N_24278\,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5105_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1),
dataa => \GRFPC0.N_24327\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_52__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
\GRFPU0_DIVROM0_DATA_1_MUX_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feba7632dc985410")
port map (
combout => \GRFPU0.DIVAPPR\(1),
dataf => \GRFPU0.DIVROM0.DATA_1_2\(1),
datae => \GRFPU0.DIVROM0.DATA_1_3\(1),
datad => \GRFPU0.DIVROM0.DATA_1_1\(1),
datac => \GRFPU0.DIVROM0.DATA_1_0\(1),
datab => \GRFPU0.DIVROM0.RADDR\(6),
dataa => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_275_0_A2_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3300000030000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_275_0_A2_0_0\(1),
dataf => \FPI.FLOP\(1),
datae => \GRFPC0.V.STDATA_14\(18),
datad => \GRFPC0.N_24487\,
datac => \GRFPC0.N_235\,
datab => \GRFPC0.N_24580\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_334_0_A2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f00000f0000000")
port map (
combout => \GRFPC0.N_24502\,
dataf => \FPI.FLOP\(1),
datae => \FPI.FLOP\(6),
datad => \GRFPC0.N_235\,
datac => \GRFPC0.FP_PIPELINE.11.REGDEPX2_340_0_A2_3_0\(0));
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_23_IV_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffff3fffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_23_IV\(1),
dataf => \FPI.FLOP\(1),
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datac => \GRFPC0.N_24611_1\,
datab => \GRFPC0.V.STDATA_14\(25));
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_24_IV_I_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f0000000c0")
port map (
combout => \GRFPC0.N_24597\,
dataf => \FPI.FLOP\(1),
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datac => \GRFPC0.N_24611_1\,
datab => \GRFPC0.V.STDATA_14\(25));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_50__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
\GRFPC0_FP_PIPELINE_9_0_CHECK_DEP_DEP_2_IV_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffffcfffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.DEP_2_I\(0),
dataf => \GRFPC0.N_22777\,
datae => \GRFPC0.N_23961\,
datad => \GRFPC0.FIFO.INST_0\(29),
datac => \GRFPC0.FIFO.INST_0\(26),
datab => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_375_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPC0.N_25442\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(1),
datae => \GRFPC0.N_24137\,
datad => \GRFPC0.MEM.CTRL.RS1V\,
datac => \GRFPC0.MEM.CTRL.INST\(15),
datab => \GRFPC0.MEM.CTRL.INST\(16));
\GRFPC0_FP_PIPELINE_15_REGDEPX_282_0_A2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_23125\,
dataf => \GRFPC0.N_21626\,
datae => \GRFPC0.N_24910\,
datad => \GRFPC0.N_22243\,
datac => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_1\(18));
GRFPC0_STDDEP_0_SQMUXA_174: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3fff00000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_174\,
dataf => \GRFPC0.UN1_STDDEP_0_SQMUXA_108\,
datae => \GRFPC0.N_25886\,
datad => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.MEM.CTRL.RD\(4),
datab => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff003fc0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16069\,
dataf => \GRFPU0.GRFPU_X0.N_18195\,
datae => N_32507,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(55));
GRFPU0_GRFPU_X0_UN1_ST3_REG_ANC5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => N_32527,
dataf => N_32507,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(54),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(57),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(55));
GRFPC0_FP_PIPELINE_4_1_CHECK_DEP_UN1432_REGDEPX_2_0_A2_RNIMVS81: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_11__G3\,
dataf => N_40557,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX_1\,
datac => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX_2\,
datab => \GRFPC0.FIFO.INST_1\(19));
\GRFPU0_GRFPU_X0_TZI_RNIK2373_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000530000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_9559\,
dataf => \GRFPU0.GRFPU_X0.N_9608\,
datae => \GRFPU0.GRFPU_X0.TZI\(5),
datad => \GRFPU0.GRFPU_X0.L1_0_10_1\(3),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(44),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(15));
\GRFPC0_FP_PIPELINE_10_REGDEPX_197_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff888f000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX_197\(1),
dataf => \GRFPC0.FP_PIPELINE.10.REGDEPX_194\(1),
datae => \GRFPC0.N_21627\,
datad => \GRFPC0.N_23978\,
datac => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3439_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3424_REGDEPX\,
dataa => \GRFPC0.N_23976\);
GRFPU0_GRFPU_X0_COMB_UN1_FLOP4_10_0_A3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_10_0_A3_0\,
dataf => \GRFPU0.GRFPU_X0.N_18449\,
datae => \GRFPU0.GRFPU_X0.N_6038_3\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(5));
GRFPU0_GRFPU_X0_COMB_TMP316_1_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6038\,
dataf => \GRFPU0.GRFPU_X0.N_6038_3\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_42_0\,
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(2));
\GRFPC0_D_STDLCK_RNO_8_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_13_1_A2_1\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_13_4\,
datae => \GRFPC0.N_579\,
datad => \GRFPC0.RFA.LD\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN243_DEP_1\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN5169_DEP_2\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff30cf00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(14),
dataf => \GRFPC0.N_23712\,
datae => \GRFPC0.WR2.CTRL.INST\(14),
datad => \GRFPC0.WR2.CTRL.PC\(14),
datac => N_248,
datab => N_249);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff30cf00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(19),
dataf => \GRFPC0.N_23712\,
datae => \GRFPC0.WR2.CTRL.INST\(19),
datad => \GRFPC0.WR2.CTRL.PC\(19),
datac => N_248,
datab => N_249);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff30cf00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(21),
dataf => \GRFPC0.N_23712\,
datae => \GRFPC0.WR2.CTRL.INST\(21),
datad => \GRFPC0.WR2.CTRL.PC\(21),
datac => N_248,
datab => N_249);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff30cf00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(23),
dataf => \GRFPC0.N_23712\,
datae => \GRFPC0.WR2.CTRL.INST\(23),
datad => \GRFPC0.WR2.CTRL.PC\(23),
datac => N_248,
datab => N_249);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M2_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff30cf00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M2\(8),
dataf => \GRFPC0.N_23712\,
datae => \GRFPC0.WR2.CTRL.INST\(8),
datad => \GRFPC0.WR2.CTRL.PC\(8),
datac => N_248,
datab => N_249);
\GRFPC0_FP_PIPELINE_STDEP_1_0_IV_I_A2_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0fffff00000000")
port map (
combout => \GRFPC0.N_23119\,
dataf => \GRFPC0.N_23136\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_22777\,
datac => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_D_STLCK_RNO_6_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f00000000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_23__G1_3\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22777\,
datad => \GRFPC0.N_23895\,
datac => \GRFPC0.FIFO.INST_0\(25));
GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_UN61_REGDEPX_0_A2_0_A2_RNIR23P1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000c0000000000")
port map (
combout => \GRFPC0.N_730\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22777\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX\,
datac => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A2_6_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000f00000")
port map (
combout => \GRFPC0.N_23010\,
dataf => \GRFPC0.N_22777\,
datae => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_5_0_REGDEPX_95_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f0000000c")
port map (
combout => \GRFPC0.N_24845\,
dataf => \GRFPC0.N_22777\,
datae => \GRFPC0.N_22517\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0\(29),
datab => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_D_STLCK_RNO_3_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => N_40549,
dataf => \GRFPC0.N_22777\,
datae => \GRFPC0.N_22517\,
datad => \GRFPC0.FIFO.INST_0\(29),
datac => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_8_REGDEPX_156_0_A2_4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000c00")
port map (
combout => \GRFPC0.N_22311\,
dataf => \GRFPC0.N_22777\,
datae => \GRFPC0.N_24935\,
datad => \GRFPC0.N_23961\,
datac => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_1_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0000000c000")
port map (
combout => \GRFPC0.N_23201_2\,
dataf => \GRFPC0.N_22777\,
datae => \GRFPC0.N_24935\,
datad => \GRFPC0.FIFO.INST_0\(27),
datac => \GRFPC0.FIFO.INST_0\(28),
datab => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A2_6_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000ff00")
port map (
combout => \GRFPC0.N_23178_1\,
dataf => \GRFPC0.N_22777\,
datae => \GRFPC0.FIFO.INST_0\(19),
datad => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25082\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22252\,
datad => \GRFPC0.N_25010\,
datac => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_1\(2));
GRFPU0_GRFPU_X0_UN23_EXP_ANC7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => N_32669,
dataf => N_32649,
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(4),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(6),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(7));
GRFPU0_GRFPU_X0_UN23_EXP_ANC6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => N_32664,
dataf => N_32649,
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(4),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(6));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_334_0_A2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_24501\,
dataf => \GRFPC0.N_25221\,
datae => \FPI.FLOP\(6),
datad => \GRFPC0.N_24643\,
datac => \GRFPC0.N_23530_2\,
datab => \GRFPC0.FIFO.INST_1\(15));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN4994_DEP_I_O3_RNIPN801_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3ffffffffff")
port map (
combout => \GRFPC0.N_23380\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datae => \GRFPC0.N_23330\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN4994_DEP_I_O3_RNIPN801_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff3ff")
port map (
combout => \GRFPC0.N_23382\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datae => \GRFPC0.N_23330\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(3),
datab => \GRFPC0.EX.CTRL.RD\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_4_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3500")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(38),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(38),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(38),
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datac => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datab => \GRFPU0.MULO.MRES\(98),
dataa => \GRFPU0.MULO.DRES_1\(98));
GRFPC0_FP_PIPELINE_11_STDEP_456_SEL0_0_0_O2_0_O2_RNI93N51: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c000c000c000000")
port map (
combout => \GRFPC0.N_23491\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datae => \GRFPC0.N_21721\,
datad => \GRFPC0.N_470\,
datac => \GRFPC0.N_467\,
datab => \GRFPC0.MEM.CTRL.RD\(2));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_475_0_A2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_25817\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.N_25785\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(1),
datac => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_24_3276_I_A3_0_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f00ff0f0fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_24_3276_I_A3_0_0_0\,
dataf => \GRFPU0.GRFPU_X0.N_400\,
datae => \GRFPU0.GRFPU_X0.N_401\,
datad => \GRFPU0.GRFPU_X0.ST4.MSGNF\(16),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(16));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_185_I_I2_0_O2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00300000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_185_I_I2_0_O2_0\(0),
dataf => \GRFPC0.N_25204\,
datae => \GRFPC0.N_225\,
datad => \GRFPC0.N_24039\,
datac => \GRFPC0.N_226\,
datab => \GRFPC0.N_227\);
\GRFPU0_GRFPU_X0_RES_1_6_I_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000a000c000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20293_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_404\,
datae => N_99904,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(52),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(52),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(52),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(49));
\GRFPU0_DIVROM0_DATA_1_MUX_3_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feba7632dc985410")
port map (
combout => \GRFPU0.DIVAPPR\(3),
dataf => \GRFPU0.DIVROM0.DATA_1_2\(3),
datae => \GRFPU0.DIVROM0.DATA_1_3\(3),
datad => \GRFPU0.DIVROM0.DATA_1_1\(3),
datac => \GRFPU0.DIVROM0.DATA_1_0\(3),
datab => \GRFPU0.DIVROM0.RADDR\(6),
dataa => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_51__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
\GRFPU0_GRFPU_X0_VST3_REG_37_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcc0a0a33000a0a")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_37\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_2_03\,
datac => \GRFPU0.GRFPU_X0.N_5774\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(48));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_175_0_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff40")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_0_5\(1),
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_0_2\(1),
datae => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_0_0\(1),
datad => \GRFPC0.N_25576\,
datac => \GRFPC0.N_25635\,
datab => \GRFPC0.N_24761_2\,
dataa => \GRFPC0.WR2.CTRL.INST\(16));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cfff0000")
port map (
combout => \GRFPC0.N_21639_2\,
dataf => N_113,
datae => \GRFPC0.FP_PIPELINE.UN24_OP\,
datad => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_0\,
datac => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_1\,
datab => N_103);
\GRFPC0_D_STLCK_RNO_3_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_2\(0),
dataf => \GRFPC0.N_9482\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datad => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_0\,
datac => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_1\,
datab => N_103);
\GRFPC0_FP_PIPELINE_10_REGDEPX_194_0_A2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffffff00000000")
port map (
combout => \GRFPC0.N_96_1\,
dataf => \GRFPC0.N_9483\,
datae => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_0\,
datad => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_1\,
datac => N_103);
\GRFPC0_FP_PIPELINE_15_REGDEPX_284_0_A2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0ffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_0_0\(3),
dataf => N_97,
datae => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_0\,
datad => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_1\,
datac => N_103);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_6_RNIOIMP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffffff00000000")
port map (
combout => \GRFPC0.N_22468_1\,
dataf => \GRFPC0.N_9479\,
datae => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_0\,
datad => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_1\,
datac => N_103);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_7_0_A2_RNIK6RU: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_25_I_I_0\(1),
dataf => \GRFPC0.N_9480\,
datae => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_0\,
datad => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_1\,
datac => N_103);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A2_5_0_A3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffffff00000000")
port map (
combout => \GRFPC0.N_23036\,
dataf => \GRFPC0.N_9453\,
datae => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_0\,
datad => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_1\,
datac => N_103);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN64_DEP_2_RNITP121: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffffffffff")
port map (
combout => \GRFPC0.N_507\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_2\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(2),
datab => \GRFPC0.EX.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN64_DEP_2_RNIPCDT: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcffffffffff")
port map (
combout => \GRFPC0.N_569\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_2\,
datae => \GRFPC0.N_106_I\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(2),
datab => \GRFPC0.EX.CTRL.RD\(1));
GRFPU0_GRFPU_X0_COMB_UN13_ITER_OF: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0c00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN13_ITER_OF\,
dataf => \GRFPU0.GRFPU_X0.N_5633\,
datae => \GRFPU0.GRFPU_X0.N_10191\,
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datab => \GRFPU0.GRFPU_X0.ITER.FLUSH0\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_19_3_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffe0f01f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_19\(63),
dataf => \GRFPU0.GRFPU_X0.N_17322\,
datae => \GRFPU0.GRFPU_X0.N_17323\,
datad => \GRFPU0.GRFPU_X0.C\(11),
datac => \GRFPU0.GRFPU_X0.N_3516\,
datab => \GRFPU0.GRFPU_X0.N_4201\,
dataa => \GRFPU0.GRFPU_X0.N_3440\);
GRFPU0_GRFPU_X0_UN1_VST2_QSNAN12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00c0ffffc000")
port map (
combout => \GRFPU0.GRFPU_X0.N_3499\,
dataf => \GRFPU0.GRFPU_X0.N_3440\,
datae => \GRFPU0.GRFPU_X0.REST_1_1\(2),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6));
\GRFPC0_FP_PIPELINE_10_REGDEPX_192_0_A2_1_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cf0c000000000000")
port map (
combout => \GRFPC0.N_25356_1\,
dataf => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datae => \GRFPC0.N_24926\,
datad => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.FIFO.RD_1\(0),
datab => \GRFPC0.FIFO.FULL\);
\GRFPC0_FP_PIPELINE_4_STDEP_194_0_IV_0_O2_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff30f3ffffffff")
port map (
combout => \GRFPC0.N_543_1\,
dataf => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datae => \GRFPC0.FIFO.INST_0\(19),
datad => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.FIFO.RD_1\(0),
datab => \GRFPC0.FIFO.FULL\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_7_1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cf0c000000000000")
port map (
combout => \GRFPC0.N_22593_1\,
dataf => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datae => \GRFPC0.N_24921\,
datad => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.FIFO.RD_2\(0),
datab => \GRFPC0.FIFO.FULL\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_4_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cf0c000000000000")
port map (
combout => \GRFPC0.N_22444_1\,
dataf => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datae => \GRFPC0.N_22429\,
datad => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.FIFO.RD_2\(0),
datab => \GRFPC0.FIFO.FULL\);
\GRFPC0_D_STDLCK_RNO_2_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cf0c000000000000")
port map (
combout => \GRFPC0.N_21557\,
dataf => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datae => \GRFPC0.STDDEP_0_SQMUXA_111_I_I_A2_0_A3_0\,
datad => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.FIFO.RD_3\(0),
datab => \GRFPC0.FIFO.FULL\);
\GRFPC0_DIV_RESULT_0_0_61__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffefffafffcfff0")
port map (
combout => \FPO.RES\(61),
dataf => N_99904_1,
datae => \GRFPU0.GRFPU_X0.N_404_0\,
datad => \GRFPC0.DIV.RESULT_0_0_61__G3_1\,
datac => \GRFPC0.DIV.RESULT_0_0_61__G3_0\,
datab => \GRFPU0.GRFPU_X0.ST4.REG\(58),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(61));
\GRFPC0_FP_PIPELINE_13_STDEP_536_3_I_O3_0_A4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000330003")
port map (
combout => \GRFPC0.N_23288\,
dataf => \GRFPC0.N_114\,
datae => \GRFPC0.N_53\,
datad => \GRFPC0.N_21241\,
datac => \GRFPC0.N_470\,
datab => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_465_0_A3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_25510\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.N_25383\,
datad => \GRFPC0.MEM.CTRL.INST\(1),
datac => \GRFPC0.MEM.CTRL.INST\(2),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_7_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff2000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_7\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_2\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_1\(1),
datad => \GRFPC0.N_25592_1\,
datac => \GRFPC0.N_25859\,
datab => \GRFPC0.WR2.CTRL.INST\(26),
dataa => \GRFPC0.WR2.CTRL.INST\(27));
GRFPU0_GRFPU_X0_VITER_EXP_0_SQMUXA_1_I_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0fff3fff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18408\,
dataf => \GRFPU0.GRFPU_X0.N_5673_0\,
datae => \GRFPU0.GRFPU_X0.N_4438\,
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPC0_FP_PIPELINE_0_STDEP_42_0_IV_I_A4_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00030000000000")
port map (
combout => \GRFPC0.N_22983\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22777\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX\,
datac => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_D_STLCK_RNO_1_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0300000")
port map (
combout => \GRFPC0.D.STLCK_0_0_28__G1_2\,
dataf => \GRFPC0.D.STLCK_0_0_28__G1_1\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_22777\,
datac => \GRFPC0.STDDEP_0_SQMUXA_111_I_I_A2_0_A3_0\,
datab => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_11_0_REGDEPX_203_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000ff0000")
port map (
combout => \GRFPC0.N_23985\,
dataf => \GRFPC0.N_22777\,
datae => \GRFPC0.N_23895\,
datad => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_6_REGDEPX_120_0_A2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000f0000000000")
port map (
combout => \GRFPC0.N_22446\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22777\,
datad => \GRFPC0.FP_PIPELINE.6.REGDEPX_120_0_A2_1_0\(0),
datac => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_8_0_REGDEPX_149_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000300")
port map (
combout => \GRFPC0.N_23953\,
dataf => \GRFPC0.N_22777\,
datae => \GRFPC0.N_24935\,
datad => \GRFPC0.N_23961\,
datac => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_4_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00000000")
port map (
combout => \GRFPC0.N_25078\,
dataf => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_2\(14),
datae => \GRFPC0.N_22777\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0\(25));
GRFPC0_STDEP_0_SQMUXA_80_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000000f")
port map (
combout => \GRFPC0.STDEP_0_SQMUXA_80_2\,
dataf => \GRFPC0.N_22777\,
datae => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1015_REGDEPX_I_1\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0\(25));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03ff00ff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2\(17),
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55));
\GRFPU0_GRFPU_X0_RES_1_6_I_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20271_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_404\,
datae => N_99904,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(42),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(42),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(39),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(42));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_25343\,
dataf => N_113,
datae => \GRFPC0.FP_PIPELINE.UN24_OP\,
datad => \GRFPC0.N_22370_2\,
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN928_REGDEPX_2\,
datab => \GRFPC0.N_21627\);
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_12_3588_I_A3_0_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f00ff0f0fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_12_3588_I_A3_0_0_0\,
dataf => \GRFPU0.GRFPU_X0.N_400_1\,
datae => \GRFPU0.GRFPU_X0.N_401\,
datad => \GRFPU0.GRFPU_X0.ST4.MSGNF\(28),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(28));
GRFPU0_GRFPU_X0_COMB_DPRES4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6404\,
dataf => \GRFPU0.GRFPU_X0.N_6051_5\,
datae => \GRFPU0.GRFPU_X0.N_6038_3\,
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(7));
GRFPU0_GRFPU_X0_VST4_EXC_1_SQMUXA_9_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.N_6051_5\,
datae => \GRFPU0.GRFPU_X0.N_6038_3\,
datad => \GRFPU0.GRFPU_X0.ST3.RDY\,
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(7));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN1889_DEP_RNIITNV1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffccc00000")
port map (
combout => \GRFPC0.N_22546\,
dataf => \GRFPC0.N_22606\,
datae => \GRFPC0.RFA.LD\,
datad => \GRFPC0.RFA.RDD\,
datac => N_172,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1889_DEP\);
\GRFPC0_FP_PIPELINE_7_STDEP_292_3_0_A4_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f3fff3fff3ff")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_A4_1_0\(0),
dataf => \GRFPC0.N_690\,
datae => \GRFPC0.N_470\,
datad => \GRFPC0.N_494\,
datac => \GRFPC0.N_21817\,
datab => \GRFPC0.WR.CTRL.RDWR\);
GRFPC0_FP_PIPELINE_0_STDDEP_180_IV_0_A2_10_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f30000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_10_1\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datae => \GRFPC0.N_22325\,
datad => \GRFPC0.N_458\,
datac => \GRFPC0.N_21817\,
datab => \GRFPC0.WR.CTRL.RDWR\);
\GRFPU0_GRFPU_X0_RES_1_6_I_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000c000a000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20294_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_404_0\,
datae => N_99904,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(32),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(32),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(29),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(32));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_11_3614_I_A3_0_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f00ff0f0fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_11_3614_I_A3_0_0_0\,
dataf => \GRFPU0.GRFPU_X0.N_400_1\,
datae => \GRFPU0.GRFPU_X0.N_401\,
datad => \GRFPU0.GRFPU_X0.ST4.MSGNF\(29),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(29));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_334_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000c00")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_334_0_0\(1),
dataf => \GRFPC0.N_24500\,
datae => \GRFPC0.V.STDATA_14_I_M_10\(0),
datad => \GRFPC0.N_225\,
datac => \GRFPC0.N_226\,
datab => \GRFPC0.FP_PIPELINE.11.REGDEPX2_334_0_A2_0_0_0\(1));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_65_0_A2_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_65_0_A2_0\(0),
dataf => \GRFPC0.N_225\,
datae => \GRFPC0.N_24039\,
datad => \GRFPC0.N_226\,
datac => \GRFPC0.N_227\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_51__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_32_3068_I_A3_0_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f00ff0f0fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_32_3068_I_A3_0_0_0\,
dataf => \GRFPU0.GRFPU_X0.N_400\,
datae => \GRFPU0.GRFPU_X0.N_401\,
datad => \GRFPU0.GRFPU_X0.ST4.MSGNF\(8),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(8));
GRFPU0_GRFPU_X0_UN253_BCO_LSB_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000003f300000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN253_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.UN253_BCO_LSB_1\(15),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_3\(14),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(15),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(47));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_4_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffca00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(46),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(46),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(46),
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datac => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datab => \GRFPU0.MULO.MRES\(106),
dataa => \GRFPU0.MULO.DRES_1\(106));
\GRFPC0_D_STLCK_RNO_4_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff30ff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_21__G1_2\,
dataf => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.D.STLCK_0_0_21__G1_1\,
datac => \GRFPC0.N_23522_I_1\,
datab => \GRFPC0.N_24819\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_RNO_0_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000f300f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18481_1\,
dataf => \GRFPU0.GRFPU_X0.N_5508\,
datae => \GRFPU0.GRFPU_X0.N_5633\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffc0cf000fc0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(53),
dataf => \GRFPU0.GRFPU_X0.N_16516\,
datae => \GRFPU0.GRFPU_X0.N_5633\,
datad => \GRFPU0.GRFPU_X0.COMB.EXP_14\(1),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(53));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0f0f3f0c0f0c0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(54),
dataf => \GRFPU0.GRFPU_X0.EXP_11\(2),
datae => \GRFPU0.GRFPU_X0.N_5508\,
datad => \GRFPU0.GRFPU_X0.N_5633\,
datac => \GRFPU0.GRFPU_X0.N_16452\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffc0cf000fc0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(55),
dataf => \GRFPU0.GRFPU_X0.N_16518\,
datae => \GRFPU0.GRFPU_X0.N_5633\,
datad => \GRFPU0.GRFPU_X0.COMB.EXP_14\(3),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(55));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfff0030cfcf0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(56),
dataf => \GRFPU0.GRFPU_X0.EXP_11\(4),
datae => \GRFPU0.GRFPU_X0.N_16454\,
datad => \GRFPU0.GRFPU_X0.N_5508\,
datac => \GRFPU0.GRFPU_X0.N_5633\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0f0cf0fc000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(57),
dataf => \GRFPU0.GRFPU_X0.N_16520\,
datae => \GRFPU0.GRFPU_X0.COMB.EXP_14\(5),
datad => \GRFPU0.GRFPU_X0.N_5633\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(57));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfff0030cfcf0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(58),
dataf => \GRFPU0.GRFPU_X0.EXP_11\(6),
datae => \GRFPU0.GRFPU_X0.N_16456\,
datad => \GRFPU0.GRFPU_X0.N_5508\,
datac => \GRFPU0.GRFPU_X0.N_5633\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0f0cf0fc000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(59),
dataf => \GRFPU0.GRFPU_X0.N_16522\,
datae => \GRFPU0.GRFPU_X0.COMB.EXP_14\(7),
datad => \GRFPU0.GRFPU_X0.N_5633\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(59));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0f0cf0fc000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(60),
dataf => \GRFPU0.GRFPU_X0.N_16523\,
datae => \GRFPU0.GRFPU_X0.COMB.EXP_14\(8),
datad => \GRFPU0.GRFPU_X0.N_5633\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(60));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfff0030cfcf0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(61),
dataf => \GRFPU0.GRFPU_X0.EXP_11\(9),
datae => \GRFPU0.GRFPU_X0.N_16459\,
datad => \GRFPU0.GRFPU_X0.N_5508\,
datac => \GRFPU0.GRFPU_X0.N_5633\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0f0cf0fc000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(62),
dataf => \GRFPU0.GRFPU_X0.N_16525\,
datae => \GRFPU0.GRFPU_X0.COMB.EXP_14\(10),
datad => \GRFPU0.GRFPU_X0.N_5633\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(62));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_2_A2_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00cc00cc0ccc00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18487\,
dataf => \GRFPU0.GRFPU_X0.N_5508\,
datae => \GRFPU0.GRFPU_X0.N_5633\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datac => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(41));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_2_A2_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00cc00cc0ccc00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18489\,
dataf => \GRFPU0.GRFPU_X0.N_5508\,
datae => \GRFPU0.GRFPU_X0.N_5633\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datac => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(42));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_2_A3_0_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000c0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18705\,
dataf => \GRFPU0.GRFPU_X0.N_5508\,
datae => \GRFPU0.GRFPU_X0.N_5633\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datac => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(24));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_2_A3_1_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18706\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(24));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_2_O2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000f303f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_33\,
dataf => \GRFPU0.GRFPU_X0.N_5508\,
datae => \GRFPU0.GRFPU_X0.N_5633\,
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_50__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
\GRFPU0_GRFPU_X0_RES_1_6_I_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000a000c000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20273_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_404\,
datae => N_99904,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(48),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(48),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(48),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(45));
GRFPC0_FP_PIPELINE_11_1_CHECK_DEP_UN3616_REGDEPX_1_I_O4_RNI9QPV1_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.N_21866\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_24936\,
datad => \GRFPC0.FIFO.INST_1\(19),
datac => \GRFPC0.FIFO.INST_1\(29),
datab => \GRFPC0.FIFO.INST_1\(28));
\GRFPU0_GRFPU_X0_RES_1_6_I_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a0c0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20285_I_0\,
dataf => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(51),
datae => \GRFPU0.GRFPU_X0.N_404\,
datad => N_99904,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(51),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(51),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(48));
GRFPC0_DIV_EXC_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffcfffffcfcf")
port map (
combout => \GRFPC0.DIV.EXC_0_0_N_7\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.DIV.EXC_0_0_G0_I_O4_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datac => N_35,
datab => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA\);
GRFPC0_EX_CTRL_PEND_RNO_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000303030")
port map (
combout => \GRFPC0.EX.CTRL.PEND_0_0_G2_1\,
dataf => \GRFPC0.EX.CTRL.VCNT\(1),
datae => \GRFPC0.EX.CTRL.VCNT\(0),
datad => N_39,
datac => N_35,
datab => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA\);
GRFPC0_VWR2_CTRL_PEND_0_SQMUXA_RNIU9PD: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPC0.FIFO.RD_M_0\(0),
dataf => \GRFPC0.FIFO.RD_0\(0),
datae => N_35,
datad => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA\);
GRFPC0_WR_CTRL_PEND_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000300030000000")
port map (
combout => \GRFPC0.WR.CTRL.PEND_0_0_N_5\,
dataf => \GRFPC0.N_23696\,
datae => \GRFPC0.N_23697\,
datad => \GRFPC0.WR.CTRL.PEND\,
datac => N_35,
datab => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf0fffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(13),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(13),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(13),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_18664\,
datab => \GRFPU0.MULO.MRES\(73));
\GRFPU0_GRFPU_X0_RES_1_6_I_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80a0c0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20296_I_0\,
dataf => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(38),
datae => \GRFPU0.GRFPU_X0.N_404\,
datad => N_99904,
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(38),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(38),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(35));
\GRFPU0_GRFPU_X0_RES_1_6_I_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000a000c000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20290_I_0\,
dataf => \GRFPU0.GRFPU_X0.N_404\,
datae => N_99904,
datad => \GRFPU0.GRFPU_X0.RES_1_6_I_1\(43),
datac => \GRFPU0.GRFPU_X0.RES_1_6_I_0\(43),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(43),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(40));
GRFPC0_FP_PIPELINE_VMEM_RREG_RES_1_3_2735_I_A3_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"efffcfffafff0fff")
port map (
combout => N_46771_3,
dataf => N_99904_1,
datae => \GRFPU0.GRFPU_X0.N_404_0\,
datad => \GRFPC0.FP_PIPELINE.VMEM.RREG.RES_1_3_2735_I_A3_3_1\,
datac => \GRFPC0.FP_PIPELINE.VMEM.RREG.RES_1_3_2735_I_A3_3_0\,
datab => \GRFPU0.GRFPU_X0.ST4.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST4.REG\(53));
\GRFPC0_FP_PIPELINE_12_REGDEPX_228_0_A3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.N_23345\,
dataf => N_99871,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_23324\,
datac => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_FP_PIPELINE_6_REGDEPX_120_0_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f00000f3f03300")
port map (
combout => \GRFPC0.N_22426\,
dataf => N_99871,
datae => \GRFPC0.N_22902_1\,
datad => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2056_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2072_REGDEPX\,
datab => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_0_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPC0.N_22767\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_87_1\,
datae => N_99871,
datad => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A3_4_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => \GRFPC0.N_22903\,
dataf => N_99871,
datae => \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN496_REGDEPX_0\,
datad => \GRFPC0.FIFO.INST_1\(19),
datac => \GRFPC0.FIFO.INST_1\(28),
datab => \GRFPC0.FIFO.INST_1\(29));
GRFPC0_FP_PIPELINE_0_UN1_FPO_7_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00fcc3300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_3\,
dataf => \GRFPU0.GRFPU_X0.N_18528_I\,
datae => \GRFPU0.GRFPU_X0.N_73\,
datad => \GRFPC0.WR.CTRL.ID\(2),
datac => \GRFPU0.GRFPU_X0.ST3.ID\(2),
datab => \GRFPU0.GRFPU_X0.ITER.ID\(2));
GRFPC0_FP_PIPELINE_0_UN1_FPO_8_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00fcc3300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_3\,
dataf => \GRFPU0.GRFPU_X0.N_18528_I\,
datae => \GRFPU0.GRFPU_X0.N_73\,
datad => \GRFPC0.MEM.CTRL.ID\(2),
datac => \GRFPU0.GRFPU_X0.ST3.ID\(2),
datab => \GRFPU0.GRFPU_X0.ITER.ID\(2));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0c3f0c3")
port map (
combout => \GRFPU0.GRFPU_X0.N_18235\,
dataf => \GRFPU0.GRFPU_X0.N_18408\,
datae => \GRFPU0.GRFPU_X0.C\(5),
datad => N_32458,
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(4));
GRFPU0_GRFPU_X0_UN1_ITER_EXP_C6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => N_32473,
dataf => N_32458,
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(4),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(6));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_I_A4_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f0dffdd")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_I_A4_1\(0),
dataf => \GRFPC0.N_25618\,
datae => \GRFPC0.N_25633\,
datad => \GRFPC0.N_25545\,
datac => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_I_A2_0\(0),
datab => \GRFPC0.WR2.CTRL.INST\(26),
dataa => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_OP1_1_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ffccf0f0ff00")
port map (
combout => \GRFPC0.N_19950\,
dataf => \GRFPU0.GRFPU_X0.N_401\,
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \FPO.RES_1\(25),
datac => \GRFPC0.WR2.RREG.RES\(25),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(25));
\GRFPC0_OP2_1_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0ccf0fff000")
port map (
combout => \GRFPC0.N_19455\,
dataf => \GRFPU0.GRFPU_X0.N_401\,
datae => \FPO.RES_1\(25),
datad => \GRFPC0.RFA2.RS2SEL\(4),
datac => \GRFPC0.WR2.RREG.RES\(25),
datab => \GRFPU0.GRFPU_X0.ST4.SGNF\(25));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_185_I_A3_1_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_24623\,
dataf => \FPI.FLOP\(6),
datae => \GRFPC0.N_24489\,
datad => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.N_24487\,
datab => \GRFPC0.N_24488\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_215_I_A3_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_24621\,
dataf => \FPI.FLOP\(6),
datae => \GRFPC0.N_24489\,
datad => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.N_24487\,
datab => \GRFPC0.N_24488\);
\GRFPC0_FP_PIPELINE_3_STDEP_150_0_IV_TZ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfffffffcfffff")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_150_I_TZ\(0),
dataf => N_40557,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.3.0.STDEP_145_0_IV_M_1_0\(0),
datac => \GRFPC0.FP_PIPELINE.3.1.CHECK_DEP.UN1120_REGDEPX\,
datab => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_FP_PIPELINE_3_1_REGDEPX_62_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.3.1.REGDEPX_62\(1),
dataf => \GRFPC0.FP_PIPELINE.3.0.REGDEPX_60\(1),
datae => N_40557,
datad => \GRFPC0.FP_PIPELINE.3.1.CHECK_DEP.UN1120_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_D_STDLCK_RNO_0_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff03ff00")
port map (
combout => \GRFPC0.D.STDLCK_0_0_8__G1_2\,
dataf => \GRFPC0.N_21199\,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.D.STDLCK_0_0_8__G1_0\,
datac => \GRFPC0.N_22244\,
datab => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_D_STLCK_RNO_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3000")
port map (
combout => \GRFPC0.D.STLCK_0_0_16__G1\,
dataf => \GRFPC0.N_22259\,
datae => \GRFPC0.D.STLCK_0_0_16__G1_3\,
datad => \GRFPC0.N_23345_1\,
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datab => \GRFPC0.N_22244\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_O2_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0eac0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_O2_3\(0),
dataf => \GRFPC0.N_24173\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datad => \GRFPC0.N_702\,
datac => \GRFPC0.N_24796\,
datab => \GRFPC0.N_24777_1_0\,
dataa => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A4_1_0\(1));
\GRFPC0_EX_RREG_EXCT_0_0_2__G4\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000030003")
port map (
combout => \FPO.EXC\(2),
dataf => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datae => \GRFPU0.GRFPU_X0.ST4.EXC\(2),
datad => \GRFPU0.GRFPU_X0.ST4.MOF\,
datac => \GRFPU0.GRFPU_X0.ST4.IOF\,
datab => \GRFPU0.GRFPU_X0.ST4.ADDOF\);
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_4_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffccffccf0cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(2),
dataf => \GRFPC0.DIV.EXCT_0_0_2__G0_0_A3_0\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPU0.GRFPU_X0.ST4.EXC\(2),
datab => \GRFPC0.WR2.RREG.EXCT\(2));
\GRFPC0_WR2_RREG_EXCT_RNO_0_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccffffccccf000")
port map (
combout => \GRFPC0.WR2.RREG.EXCT_0_0_2__G3\,
dataf => \GRFPC0.DIV.EXCT_0_0_2__G0_0_A3_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datac => \GRFPU0.GRFPU_X0.ST4.EXC\(2),
datab => \GRFPC0.WR.RREG.EXCT\(2));
\GRFPC0_DIV_EXCT_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f0cc00f0f0")
port map (
combout => N_27123,
dataf => \GRFPC0.DIV.EXCT_0_0_2__G0_0_A3_0\,
datae => \GRFPC0.FP_PIPELINE.VDIV.VALID2_0\,
datad => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datac => \GRFPC0.DIV.EXCT\(2),
datab => \GRFPU0.GRFPU_X0.ST4.EXC\(2));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3330330000300000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M84_2_03_1\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_COMB_VEXC_5_IV_0_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fffcfffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
dataf => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datae => \GRFPU0.GRFPU_X0.ST4.EXC\(3),
datad => \GRFPU0.GRFPU_X0.ST4.ADDOF\,
datac => \GRFPU0.GRFPU_X0.ST4.IOF\,
datab => \GRFPU0.GRFPU_X0.ST4.MOF\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A2_4_0_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcfffcfffcff")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A2_4_0\(2),
dataf => \GRFPC0.N_22892_1\,
datae => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN616_REGDEPX\,
datad => \GRFPC0.N_9474\,
datac => \GRFPC0.N_61_I\,
datab => N_97);
\GRFPC0_D_STLCK_RNO_4_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000300000003000")
port map (
combout => \GRFPC0.N_22878\,
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_128\,
datab => \GRFPC0.FIFO.INST_0\(19));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O3_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffffff00ffcfff")
port map (
combout => \GRFPC0.N_22822\,
dataf => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datae => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_O3_5_0\(3),
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_128\,
datab => \GRFPC0.FIFO.INST_0\(19));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_O2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_O2_1\(1),
dataf => \GRFPC0.N_24072\,
datae => \GRFPC0.N_25244_1\,
datad => \GRFPC0.N_25624_1\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2168_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2196_REGDEPX2\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_9_RNI4HIL5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cfcc0300")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9\,
datae => \GRFPC0.N_155_1\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RESV\,
datab => N_37);
GRFPC0_MEM_RREG_RESV_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3033fcff30333033")
port map (
combout => \GRFPC0.MEM.RREG.RESV_0_0_G0_0\,
dataf => N_40640,
datae => \GRFPC0.N_155_1\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RESV\,
datab => N_37);
\GRFPC0_FP_PIPELINE_9_0_STDEP_385_0_IV_0_TZ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffffffcfffcfff")
port map (
combout => \GRFPC0.FP_PIPELINE.9.0.STDEP_385_I_TZ\(0),
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2887_REGDEPX\,
datab => \GRFPC0.FIFO.INST_0\(19));
GRFPC0_FP_PIPELINE_9_0_CHECK_DEP_UN2887_REGDEPX_0_A2_RNICLM72: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000300000003000")
port map (
combout => \GRFPC0.N_735\,
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2887_REGDEPX\,
datab => \GRFPC0.FIFO.INST_0\(19));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O4_5_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff008f00")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O4_5\(31),
dataf => \GRFPC0.N_25630\,
datae => \GRFPC0.N_24311\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datac => \GRFPC0.N_24279\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6869_REGDEPX2\,
dataa => \GRFPC0.N_24327\);
\GRFPC0_D_STLCK_RNO_14_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000c00000000000")
port map (
combout => \GRFPC0.N_21322\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datae => \GRFPC0.N_61_I\,
datad => \GRFPC0.N_23298\,
datac => N_107,
datab => \GRFPC0.N_59\);
\GRFPC0_D_STLCK_RNO_2_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff4f4f4ff")
port map (
combout => \GRFPC0.D.STLCK_0_0_3__G1_3\,
dataf => \GRFPC0.N_22878\,
datae => \GRFPC0.N_22836\,
datad => N_40557,
datac => \GRFPC0.D.STLCK_0_0_3__G1_0\,
datab => \GRFPC0.N_594\,
dataa => \GRFPC0.N_22819\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_0_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f333fffff000f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(37),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => N_99921,
datac => \GRFPU0.MULO.MRES\(98),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(37));
GRFPC0_FP_PIPELINE_0_UN1_FPO_6_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3003300330300303")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_0\,
dataf => \GRFPU0.GRFPU_X0.N_73\,
datae => \GRFPU0.GRFPU_X0.ITER.ID\(5),
datad => \GRFPU0.GRFPU_X0.ST3.ID\(5),
datac => \GRFPC0.WR2.CTRL.ID\(5),
datab => \GRFPC0.WR2.CTRL.ID\(7));
GRFPC0_FP_PIPELINE_0_UN1_FPO_9_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3003300330300303")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_0\,
dataf => \GRFPU0.GRFPU_X0.N_73\,
datae => \GRFPU0.GRFPU_X0.ITER.ID\(5),
datad => \GRFPU0.GRFPU_X0.ST3.ID\(5),
datac => \GRFPC0.EX.CTRL.ID\(5),
datab => \GRFPC0.EX.CTRL.ID\(7));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.N_23336\,
dataf => N_40557,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_23324\,
datac => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O2_0_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f00000f3f03300")
port map (
combout => \GRFPC0.N_22428\,
dataf => N_40557,
datae => \GRFPC0.N_22253\,
datad => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2056_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2087_REGDEPX\,
datab => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A3_4_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => \GRFPC0.N_22900\,
dataf => N_40557,
datae => \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN496_REGDEPX_0\,
datad => \GRFPC0.FIFO.INST_1\(19),
datac => \GRFPC0.FIFO.INST_1\(28),
datab => \GRFPC0.FIFO.INST_1\(29));
GRFPU0_GRFPU_X0_VITER_STATE_15_SQMUXA_I_I_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000033030000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18204_I\,
dataf => \GRFPU0.GRFPU_X0.N_5673_0\,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_5\,
datac => \GRFPU0.GRFPU_X0.N_5790\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
GRFPU0_GRFPU_X0_ITER_V_RNIQ8R4B: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0f0fff0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_4364\,
dataf => \GRFPU0.GRFPU_X0.N_194\,
datae => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_5\,
datad => \GRFPU0.GRFPU_X0.N_5790\,
datac => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_ALLOW_I_O3_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000cc0c")
port map (
combout => \GRFPU0.GRFPU_X0.VALLOW_5_SQMUXA_7_1\,
dataf => \GRFPU0.GRFPU_X0.N_5539\,
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_5\,
datac => \GRFPU0.GRFPU_X0.N_5790\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_ITER_EXPT_RNI5KTN3_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_10086_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.N_5790\,
datad => N_35);
GRFPU0_GRFPU_X0_ITER_V_RNITHP44: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ffffff00ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_4364_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.N_5790\,
datad => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffe2c00000e2c0")
port map (
combout => N_82230,
dataf => \GRFPU0.GRFPU_X0.N_15374\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.N_4105\,
datac => \GRFPU0.GRFPU_X0.COMB.CCV_8_0_1\(1),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_8_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff888")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_8\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_3\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_4\(0),
datad => \GRFPC0.N_24651\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datab => \GRFPC0.N_24976_2\,
dataa => \GRFPC0.N_24087_1\);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_250_0_A2_7_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c000000")
port map (
combout => \GRFPC0.N_25299\,
dataf => \GRFPC0.N_25658\,
datae => \GRFPC0.N_25221\,
datad => \FPI.FLOP\(6),
datac => \GRFPC0.N_24489\,
datab => \GRFPC0.V.STDATA_14\(18));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff880000fff80000")
port map (
combout => \GRFPC0.N_23417\,
dataf => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_23857\,
datac => \GRFPC0.N_23895\,
datab => \GRFPC0.N_25016\,
dataa => \GRFPC0.FP_PIPELINE.11.0.REGDEPX_203_0_A4_0\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A2_4_3_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A2_4_3\(3),
dataf => \GRFPC0.N_22822\,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_22813\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A2_4_1\(3));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffecffec0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_16__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.N_18705\,
datac => \GRFPU0.GRFPU_X0.N_73\,
datab => \GRFPU0.GRFPU_X0.N_18706\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(16));
\GRFPC0_D_STLCK_RNO_1_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffff3000")
port map (
combout => \GRFPC0.D.STLCK_0_0_24__G1_2\,
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.D.STLCK_0_0_24__G1_1\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_24875\,
datab => \GRFPC0.FIFO.INST_0\(19));
\GRFPC0_FP_PIPELINE_12_0_STDEP_505_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffcfffffffcfff")
port map (
combout => \GRFPC0.N_18232\,
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_24875\,
datab => \GRFPC0.FIFO.INST_0\(19));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_375_0_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0c0ffc0")
port map (
combout => \GRFPC0.N_25370\,
dataf => \GRFPC0.N_25410\,
datae => \GRFPC0.N_25120\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_1\,
datac => \GRFPC0.N_25715_1\,
datab => \GRFPC0.FP_PIPELINE.12.REGDEPX2_380_0_A2_2_1\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_10_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_10\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_8\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_4\(1),
datad => \GRFPC0.N_25410\,
datac => \GRFPC0.N_25715_1\,
datab => \GRFPC0.FP_PIPELINE.12.REGDEPX2_380_0_A2_2_1\(0));
\GRFPC0_FP_PIPELINE_0_STDEP_282_0_IV_I_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.N_22452\,
dataf => N_99871,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2056_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_FP_PIPELINE_0_STDEP_42_0_IV_I_A4_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.N_22982\,
dataf => N_99871,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_D_LDLCK_RNO_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0c0c000000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_4__G1_3\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22902_1\,
datad => \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN824_REGDEPX\,
datac => \GRFPC0.N_22252\,
datab => \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN839_REGDEPX\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_4_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_24857\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22902_1\,
datad => \GRFPC0.N_24910\,
datac => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_1\(18));
\GRFPC0_D_STDLCK_RNO_4_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fcff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_13_4_0\,
dataf => \GRFPC0.N_23366\,
datae => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_13_2\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_23324\,
datab => \GRFPC0.FIFO.INST_1\(19));
GRFPC0_FP_PIPELINE_0_STDDEP_290_IV_3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_3_0\,
dataf => \GRFPC0.N_23366\,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_23324\,
datac => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_D_STLCK_RNO_3_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff000000f3")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O3_4_0\(1),
dataf => \GRFPC0.N_22869\,
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datad => \GRFPC0.N_26\,
datac => \GRFPC0.N_570\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ec00a000ec0020")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(0),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(0),
datad => \GRFPU0.GRFPU_X0.N_5673_0\,
datac => \GRFPU0.GRFPU_X0.N_128\,
datab => \GRFPU0.GRFPU_X0.ITER.V\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(0));
\GRFPC0_D_STLCK_RNO_7_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000300000003000")
port map (
combout => \GRFPC0.N_22377\,
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_25056\,
datab => \GRFPC0.FIFO.INST_0\(19));
\GRFPC0_D_STLCK_RNO_8_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff3ffffff")
port map (
combout => \GRFPC0.N_21182\,
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_24935\,
datab => \GRFPC0.N_23961\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_15_I_O2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0ff00c0c00000")
port map (
combout => \GRFPC0.N_25377\,
dataf => \GRFPC0.N_23966\,
datae => \GRFPC0.N_23980\,
datad => \GRFPC0.N_25649\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN205_REGDEPX2_1\,
datab => \GRFPC0.N_25450_1\);
GRFPC0_FP_PIPELINE_V_STATE2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000003")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STATE2_1\,
dataf => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2\,
datae => \GRFPC0.N_23687\,
datad => \GRFPC0.N_23699\,
datac => \GRFPC0.EX.CTRL.PEND\,
datab => \GRFPC0.MEM.CTRL.PEND\);
GRFPC0_V_STDATA_0_SQMUXA_4_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff30ffff")
port map (
combout => \GRFPC0.N_23670\,
dataf => \GRFPC0.N_23699\,
datae => \GRFPC0.EX.CTRL.PEND\,
datad => \GRFPC0.MEM.CTRL.PEND\,
datac => N_248,
datab => N_249);
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_I_A4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1000f0e0f0e0f0e0")
port map (
combout => \GRFPC0.N_22291\,
dataf => \GRFPC0.N_742_1\,
datae => \GRFPC0.N_23818_2\,
datad => \GRFPC0.N_114\,
datac => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_I_A4_0\(1),
datab => \GRFPC0.N_494\,
dataa => \GRFPC0.N_23810\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_0_A2_1_1_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ccccccc0c000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19802_1\,
dataf => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_2\,
datae => \GRFPU0.GRFPU_X0.REST_2\(5),
datad => \GRFPU0.GRFPU_X0.N_3516\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \FPI.OP1_RETO\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(27),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(27),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(27));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f03ff000c00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(21),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_21__G5\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_21__G1\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f03ff000c00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(23),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_23__G5\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_23__G1\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0cffff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(40),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_11__G1\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_11__G5\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fcffff000c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(48),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_19__G1\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_V_0_19__G5\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fcffff000c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(50),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_21__G1\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_V_0_21__G5\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f030c00ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(29),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_1_0__G5\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_1_0__G1\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0cffff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(39),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_1_10__G1\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_1_10__G5\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0cffff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(32),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_1_3__G1\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_1_3__G5\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0cffff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(33),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__G1\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__G5\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0cffff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(34),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_1_5__G1\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_1_5__G5\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0cffff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(35),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__G1\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__G5\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0cffff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(36),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_1_7__G1\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_1_7__G5\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0cffff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(38),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_1_9__G1\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_1_9__G5\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPC0_D_STLCK_RNO_5_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003fff00000000")
port map (
combout => \GRFPC0.N_22380\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.N_21713\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2370_DEP\,
datab => \GRFPC0.EX.CTRL.RDWR\);
GRFPC0_FP_PIPELINE_0_STDDEP_180_IV_0_A2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0c00000c0c000")
port map (
combout => \GRFPC0.N_21884\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datad => \GRFPC0.N_505\,
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN2370_DEP\,
datab => \GRFPC0.EX.CTRL.RDWR\);
\GRFPC0_D_STLCK_RNO_6_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300030000000300")
port map (
combout => \GRFPC0.N_21325\,
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_22536\,
datab => \GRFPC0.FIFO.INST_0\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccfccccccc0ccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16923\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(53),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_4623_2\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(52));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccfccccccc0ccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16925\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(55),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_4623_2\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(54));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccfccccccc0ccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16926\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(56),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_4623_2\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(55));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccfccccccc0ccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16927\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(57),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_4623_2\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(56));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccfccccccc0ccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16928\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(58),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_4623_2\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(57));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccfccccccc0ccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16929\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(59),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_4623_2\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(58));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_I_M2_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccfccccccc0ccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_18340\,
dataf => \GRFPU0.GRFPU_X0.N_89\,
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_4623_2\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(53));
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_A3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c000000")
port map (
combout => \GRFPC0.N_21200\,
dataf => \GRFPC0.N_114\,
datae => \GRFPC0.FP_PIPELINE.8.STDEP_332_SEL0_1\,
datad => \GRFPC0.N_55\,
datac => \GRFPC0.N_23810\,
datab => \GRFPC0.WR.CTRL.RDD\);
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_A3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.N_21199\,
dataf => \GRFPC0.FP_PIPELINE.8.STDEP_332_SEL0_1\,
datae => \GRFPC0.N_55\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A3_1\,
datac => \GRFPC0.WR.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_7_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_25727\,
dataf => \GRFPC0.N_25221\,
datae => \FPI.FLOP\(6),
datad => \GRFPC0.N_24539\,
datac => \GRFPC0.FIFO.INST_0\(18),
datab => \GRFPC0.FIFO.RD_1\(0));
\GRFPC0_EXSEL_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000ff00ff00")
port map (
combout => \GRFPC0.EXSEL_1\(2),
dataf => \GRFPC0.N_82\,
datae => \GRFPC0.EX.RREG.RESV\,
datad => N_37);
\GRFPC0_FP_PIPELINE_15_REGDEPX2_454_0_A2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fc000000000000")
port map (
combout => \GRFPC0.N_25129\,
dataf => \GRFPC0.N_25221\,
datae => \FPI.FLOP\(6),
datad => \GRFPC0.N_24271\,
datac => \GRFPC0.N_24551\,
datab => \GRFPC0.N_24550\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_M4_0_A2_1\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.COMB.CCV_8_0_1\(0),
datad => \GRFPU0.GRFPU_X0.N_5250\,
datac => \GRFPU0.GRFPU_X0.N_3407\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_4_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0c00000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19959\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_5250\,
datad => \GRFPU0.GRFPU_X0.N_3407\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(55));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f00ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_2_0\(52),
dataf => \GRFPU0.GRFPU_X0.N_19547\,
datae => \GRFPU0.GRFPU_X0.REST_2\(5),
datad => \GRFPU0.GRFPU_X0.N_5250\,
datac => \GRFPU0.GRFPU_X0.N_3407\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_A2_4_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000003ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_394\,
dataf => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datae => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_2\,
datad => \GRFPU0.GRFPU_X0.REST_2\(5),
datac => \GRFPU0.GRFPU_X0.N_5250\,
datab => \GRFPU0.GRFPU_X0.N_3516\);
\GRFPU0_GRFPU_X0_REST_1_1_0_IV_RNI5H2I_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18983_I\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_5250\,
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffccfff000cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(63),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_53\(63),
datae => \GRFPU0.GRFPU_X0.REST_2\(5),
datad => \GRFPU0.GRFPU_X0.N_5250\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(63),
datab => \GRFPU0.GRFPU_X0.N_3440\);
\GRFPU0_GRFPU_X0_REST_1_1_0_IV_RNI5H2I_0_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18998\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_5250\,
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(5));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19963\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(55),
datae => \GRFPU0.GRFPU_X0.N_307\,
datad => \GRFPU0.GRFPU_X0.N_19546\,
datac => \GRFPU0.GRFPU_X0.N_5250\);
GRFPU0_GRFPU_X0_COMB_VITER_EXP_1_SN_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00cc00c000c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
dataf => \GRFPU0.GRFPU_X0.N_5673_0\,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => \GRFPU0.GRFPU_X0.N_19750\,
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000c00cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1__G0_I_M2_M5_E_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datae => \GRFPU0.GRFPU_X0.REST_2\(5),
datad => \GRFPU0.GRFPU_X0.COMB.CCV_8_0_1\(1),
datac => \GRFPU0.GRFPU_X0.N_3407\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(4));
GRFPC0_FP_PIPELINE_VWR2_EXC_1_IV_I_A4_0_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.EXC_1_IV_I_A4_0_0\,
dataf => N_44718_1,
datae => \GRFPC0.FP_PIPELINE.VWR2.CTRL.PEND_1_IV_0_A4_0_4_4\,
datad => \GRFPC0.FP_PIPELINE.VWR2.CTRL.PEND_1_IV_0_A4_0_4_3\,
datac => \GRFPC0.WR2.CTRL.CCWR\,
datab => \GRFPC0.WR2.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_0_O2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c3f00330c0c0000")
port map (
combout => \GRFPC0.N_102\,
dataf => \GRFPC0.N_24361\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.WR.RREG.RESV\,
datac => \GRFPC0.MEM.RREG.RESV\,
datab => N_37);
\GRFPC0_FP_PIPELINE_4_STDEP_194_0_IV_0_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => \GRFPC0.N_22631\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1327_REGDEPX_0\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0\(29),
datab => \GRFPC0.FIFO.INST_0\(26));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A2_1_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => \GRFPC0.N_22588\,
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_22517\,
datac => \GRFPC0.FIFO.INST_0\(19),
datab => \GRFPC0.FIFO.INST_0\(29));
GRFPC0_UN1_FIFO_INST_0_1_I_A2_0_A2_0_RNIV4U91: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.N_23136\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_24900\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0\(29));
GRFPU0_GRFPU_X0_UN6_SGNFX_CARRY_22_BUF_RNI87C41: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0fffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18448\,
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_22\,
datae => \GRFPU0.GRFPU_X0.N_6833\,
datad => \GRFPU0.GRFPU_X0.ST3.RDY\,
datac => \GRFPU0.GRFPU_X0.ST3.EMAX\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ec00a000ec0020")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(2),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(2),
datad => \GRFPU0.GRFPU_X0.N_5673_0\,
datac => \GRFPU0.GRFPU_X0.N_128\,
datab => \GRFPU0.GRFPU_X0.ITER.V\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(2));
\GRFPU0_GRFPU_X0_ITER_EXPT_RNIAPSG6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000f00")
port map (
combout => \GRFPU0.GRFPU_X0.N_5937\,
dataf => \GRFPU0.GRFPU_X0.N_5937_1\,
datae => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_5\,
datad => \GRFPU0.GRFPU_X0.ITER.EXPT\(1),
datac => \GRFPU0.GRFPU_X0.ITER.EXPT\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_26_IV_0_O2_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00ff20")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_O2_3\,
dataf => \GRFPC0.N_21407\,
datae => \GRFPC0.N_114\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_O2_1\,
datac => \GRFPC0.N_477\,
datab => \GRFPC0.N_21353\,
dataa => \GRFPC0.N_494\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_45_0_A3_6_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_25421\,
dataf => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN695_REGDEPX2_2\,
datae => \GRFPC0.N_25319\,
datad => \GRFPC0.EX.CTRL.INST\(16),
datac => \GRFPC0.EX.CTRL.INST\(15),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_375_0_A3_6_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25410\,
dataf => \GRFPC0.N_25319\,
datae => \GRFPC0.N_25190\,
datad => \GRFPC0.EX.CTRL.INST\(17),
datac => \GRFPC0.EX.CTRL.INST\(18),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_105_0_A2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25692\,
dataf => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN695_REGDEPX2_2\,
datae => \GRFPC0.N_25319\,
datad => \GRFPC0.EX.CTRL.INST\(15),
datac => \GRFPC0.EX.CTRL.INST\(16),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1));
\GRFPC0_D_STLCK_RNO_2_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff300030003000")
port map (
combout => \GRFPC0.D.STLCK_0_0_14__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(0),
datae => \GRFPC0.N_21902\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datac => \GRFPC0.N_9480\,
datab => \GRFPC0.N_61_I\);
\GRFPU0_GRFPU_X0_L4_3_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000c000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_3\(4),
dataf => \GRFPU0.GRFPU_X0.L3_0\(5),
datae => \GRFPU0.GRFPU_X0.N_6535\,
datad => \GRFPU0.GRFPU_X0.L1_4\(3),
datac => \GRFPU0.GRFPU_X0.L1_1_2\(3),
datab => \GRFPU0.GRFPU_X0.UN163_BCO_LSB\(15));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A2_5_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_22593\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_24921\,
datad => \GRFPC0.N_22535\,
datac => \GRFPC0.N_22427\,
datab => \GRFPC0.FIFO.INST_0\(18));
\GRFPC0_FP_PIPELINE_3_0_REGDEPX_60_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffeac000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.0.REGDEPX_60\(0),
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.STDEP_0_SQMUXA_80_2\,
datad => \GRFPC0.N_22429\,
datac => \GRFPC0.N_23986_1\,
datab => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1032_REGDEPX\,
dataa => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1047_REGDEPX\);
\GRFPC0_D_LDLCK_RNO_0_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff40f040f040f0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_13__G1_0\,
dataf => \GRFPC0.N_22480_2\,
datae => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A2_2_0\(13),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A2_1_0_0\(13),
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datab => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2176_REGDEPX\,
dataa => \GRFPC0.N_22433_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ec00a000ec0020")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(1),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(1),
datad => \GRFPU0.GRFPU_X0.N_5673_0\,
datac => \GRFPU0.GRFPU_X0.N_128\,
datab => \GRFPU0.GRFPU_X0.ITER.V\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(1));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_8_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_8\(0),
dataf => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_6\(0),
datae => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_5\(0),
datad => \GRFPC0.N_25634\,
datac => \GRFPC0.N_267\,
datab => \GRFPC0.WR2.CTRL.RS1V\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ec00a000ec0020")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(5),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(5),
datad => \GRFPU0.GRFPU_X0.N_5673_0\,
datac => \GRFPU0.GRFPU_X0.N_128\,
datab => \GRFPU0.GRFPU_X0.ITER.V\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(5));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_2_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_24945\,
dataf => \GRFPC0.N_59\,
datae => \GRFPC0.N_9467\,
datad => N_97,
datac => \GRFPC0.FP_PIPELINE.UN24_OP\,
datab => N_113);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_0_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A5_1_0\(4),
dataf => \GRFPC0.N_21627\,
datae => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN928_REGDEPX_2\,
datad => \GRFPC0.N_24818\,
datac => \GRFPC0.FP_PIPELINE.UN24_OP\,
datab => N_113);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_3_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000300000")
port map (
combout => \GRFPC0.N_24855\,
dataf => N_97,
datae => \GRFPC0.N_9468\,
datad => \GRFPC0.N_61_I\,
datac => \GRFPC0.FP_PIPELINE.UN24_OP\,
datab => N_113);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_5_0_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_5_0\(25),
dataf => N_97,
datae => \GRFPC0.N_59\,
datad => \GRFPC0.FP_PIPELINE.UN24_OP\,
datac => N_113);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A5_0_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_22742\,
dataf => \GRFPC0.N_24820\,
datae => \GRFPC0.N_22742_2\,
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN943_REGDEPX_2\,
datac => \GRFPC0.FP_PIPELINE.UN24_OP\,
datab => N_113);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000300000")
port map (
combout => \GRFPC0.N_22035\,
dataf => \GRFPC0.N_61_I\,
datae => \GRFPC0.N_9479\,
datad => N_97,
datac => \GRFPC0.FP_PIPELINE.UN24_OP\,
datab => N_113);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000300000")
port map (
combout => \GRFPC0.N_21184\,
dataf => \GRFPC0.N_61_I\,
datae => \GRFPC0.N_9481\,
datad => N_97,
datac => \GRFPC0.FP_PIPELINE.UN24_OP\,
datab => N_113);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_0_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000300000")
port map (
combout => \GRFPC0.N_23184\,
dataf => \GRFPC0.N_61_I\,
datae => \GRFPC0.N_9467\,
datad => N_97,
datac => \GRFPC0.FP_PIPELINE.UN24_OP\,
datab => N_113);
\GRFPC0_D_LDLCK_RNO_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff30cf00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_18__G1\,
dataf => \GRFPC0.D.LDLCK_0_0_18__G3\,
datae => \GRFPC0.FP_PIPELINE.9.REGDEPX_179\(0),
datad => \GRFPC0.FP_PIPELINE.9.REGDEPX_174\(0),
datac => \GRFPC0.FP_PIPELINE.UN24_OP\,
datab => N_113);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_0_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f000f000f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(50),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => N_99921,
datac => \GRFPU0.MULO.MRES\(111),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(50));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(32),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(32),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3003300330033")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(32),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => \GRFPU0.GRFPU_X0.N_18663\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datab => \GRFPU0.MULO.MRES\(92));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(14),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(14),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f000f000f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(14),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => N_99921,
datac => \GRFPU0.MULO.MRES\(75),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(14));
\GRFPC0_D_STLCK_RNO_3_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0f0f00000000")
port map (
combout => \GRFPC0.N_23543\,
dataf => \GRFPC0.N_23560\,
datae => N_40557,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_5_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.N_23270\,
dataf => N_99871,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4240_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1\(19));
GRFPC0_FP_PIPELINE_1_1_CHECK_DEP_UN496_REGDEPX_0_RNIKTEL1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => \GRFPC0.N_22836\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN496_REGDEPX_0\,
datad => \GRFPC0.FIFO.INST_1\(19),
datac => \GRFPC0.FIFO.INST_1\(28),
datab => \GRFPC0.FIFO.INST_1\(29));
\GRFPC0_FP_PIPELINE_9_1_CHECK_DEP_DEP_2_IV_0_A4_RNIG3851_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffffffffff")
port map (
combout => \GRFPC0.N_23512\,
dataf => N_40557,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O2_4_0_A3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.N_694\,
dataf => N_40557,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX\,
datac => \GRFPC0.FIFO.INST_1\(19));
GRFPC0_STDDEP_0_SQMUXA_118_0_A3_0_A3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_118\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2056_REGDEPX\,
datad => \GRFPC0.FIFO.INST_1\(19));
GRFPC0_FP_PIPELINE_11_1_CHECK_DEP_UN3616_REGDEPX_1_I_O4_RNI9QPV1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.N_23122\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_24936\,
datad => \GRFPC0.FIFO.INST_1\(19),
datac => \GRFPC0.FIFO.INST_1\(28),
datab => \GRFPC0.FIFO.INST_1\(29));
\GRFPC0_D_STDLCK_RNO_3_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3ffffffff")
port map (
combout => \GRFPC0.N_23396\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_24936\,
datad => \GRFPC0.FIFO.INST_1\(19),
datac => \GRFPC0.FIFO.INST_1\(28),
datab => \GRFPC0.FIFO.INST_1\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(12),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(12),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(12),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(12),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(12),
datac => \GRFPU0.GRFPU_X0.N_128\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(12));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_8_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff8")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_8\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_0_0\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_3\(1),
datad => \GRFPC0.N_25409\,
datac => \GRFPC0.N_25406\,
datab => \GRFPC0.N_24215_1\,
dataa => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5724_REGDEPX2\);
\GRFPC0_D_LDLCK_RNO_0_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff08f8f8f80")
port map (
combout => \GRFPC0.D.LDLCK_0_0_9__G3\,
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX_88\(1),
datae => \GRFPC0.N_22657\,
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX_84_0_1\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1567_REGDEPX\,
dataa => \GRFPC0.N_23978\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_8_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_8\(0),
dataf => \GRFPC0.N_24081\,
datae => \GRFPC0.N_24142\,
datad => \GRFPC0.N_24222_1\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2196_REGDEPX2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_RNI10HR1_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff88ffffffa0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(46),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(46),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(46),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(9),
datab => \GRFPU0.GRFPU_X0.N_15752\,
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_S_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff3fff")
port map (
combout => \GRFPU0.GRFPU_X0.N_307\,
dataf => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datae => \GRFPU0.GRFPU_X0.REST_2\(5),
datad => \GRFPU0.GRFPU_X0.N_3516\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7));
\GRFPC0_FP_PIPELINE_10_REGDEPX_194_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX_194\(1),
dataf => \GRFPC0.FP_PIPELINE.10.REGDEPX_192\(1),
datae => N_97,
datad => \GRFPC0.N_9483\,
datac => \GRFPC0.N_59\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_5_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffeca0ffffcc00")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_5\(6),
dataf => \GRFPC0.N_263\,
datae => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_1\(6),
datad => \GRFPC0.N_24796\,
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN873_REGDEPX2_2\,
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1770_REGDEPX2\,
dataa => \GRFPC0.DIV.INST\(15));
GRFPC0_UN1_STDDEP_0_SQMUXA_102: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f000f000f000f")
port map (
combout => \GRFPC0.UN1_STDDEP_0_SQMUXA_102\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datae => \GRFPC0.UN1_STDEP514\,
datad => \GRFPC0.FP_PIPELINE.3.STDEP_128_SEL0_1\,
datac => \GRFPC0.WR.CTRL.RDD\);
GRFPC0_FP_PIPELINE_FCC_VALID_1_U_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003f003f003f00")
port map (
combout => CPO_CCVZ,
dataf => \GRFPC0.FIFO.INST_0\(19),
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_24385\,
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datab => \GRFPC0.FIFO.INST_1\(19));
GRFPU0_GRFPU_X0_COMB_VST3_EXC36: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000030ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_5768\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__I3_I_3\,
datae => \GRFPU0.GRFPU_X0.N_19691\,
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(1));
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_RNICDBG1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_3\,
dataf => \GRFPU0.GRFPU_X0.N_19691\,
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(29),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(29),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(29));
\GRFPU0_GRFPU_X0_L1_2_5_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000003000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_5\(3),
dataf => \GRFPU0.GRFPU_X0.UN253_BCO_LSB_1\(15),
datae => \GRFPU0.GRFPU_X0.N_13562_1\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3\(11),
datac => \GRFPU0.GRFPU_X0.N_13515\,
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3\(10));
GRFPU0_GRFPU_X0_VALLOW_5_SQMUXA_0_O2_RNI1TG24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c00000c0cf0f0fcf")
port map (
combout => \GRFPU0.GRFPU_X0.N_19692_1\,
dataf => \GRFPU0.GRFPU_X0.N_128\,
datae => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH\,
datad => \GRFPU0.GRFPU_X0.N_6736_I_I_X2_0\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \FPI.FLUSH\);
\GRFPC0_EX_RREG_EXCT_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030303033000000")
port map (
combout => N_27201,
dataf => \GRFPC0.N_82\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPC0.DIV.EXCT_0_0_1__I1_I_3\,
datac => \GRFPC0.EX.RREG.EXCT\(1),
datab => N_37);
\GRFPC0_R_FSR_CEXC_RNO_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0cc0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4_M\(1),
dataf => \GRFPC0.V.FSR.CEXC_5_SQMUXA\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.EXCT_0_0_1__I1_I_3\,
datab => \GRFPC0.WR2.RREG.EXCT\(1));
\GRFPC0_WR2_RREG_EXCT_RNO_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ff000000")
port map (
combout => \GRFPC0.WR2.RREG.EXCT_0_0_1__G3\,
dataf => \GRFPC0.N_24361\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPC0.DIV.EXCT_0_0_1__I1_I_3\,
datac => \GRFPC0.WR.RREG.EXCT\(1));
GRFPU0_GRFPU_X0_VITER_ND_I_0_SQMUXA_7_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3f3fffff333")
port map (
combout => \GRFPU0.GRFPU_X0.N_68\,
dataf => \GRFPU0.GRFPU_X0.N_6509\,
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_18664\,
datac => \GRFPU0.GRFPU_X0.N_145\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
GRFPU0_GRFPU_X0_ITER_V_RNITA2T8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff3ff33")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
dataf => \GRFPU0.GRFPU_X0.N_188\,
datae => \GRFPU0.GRFPU_X0.N_236\,
datad => \GRFPU0.GRFPU_X0.N_5673_0\,
datac => \GRFPU0.GRFPU_X0.N_191_5\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
GRFPU0_GRFPU_X0_VITER_ND_I_4_SQMUXA_0_0_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff3fff0fff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18548\,
dataf => \GRFPU0.GRFPU_X0.N_5673_0\,
datae => \GRFPU0.GRFPU_X0.N_19733\,
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(17));
\GRFPC0_D_STLCK_RNO_3_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcc0c0000")
port map (
combout => \GRFPC0.D.STLCK_0_0_6__G1_1\,
dataf => \GRFPC0.D.STLCK_0_0_6__G1_0\,
datae => \GRFPC0.RFA.LD\,
datad => \GRFPC0.RFA.RDD\,
datac => N_172,
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1233_DEP\);
\GRFPC0_WR_RREG_EXCT_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3fffff3c0ff00")
port map (
combout => N_45251,
dataf => \GRFPC0.DIV.EXCT_0_0_2__G0_0_A3_0\,
datae => \GRFPC0.N_24428\,
datad => N_45232_1,
datac => \GRFPC0.MEM.RREG.EXCT\(2),
datab => N_37);
\GRFPC0_WR_RREG_EXCT_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0f3f3f300ffffff")
port map (
combout => N_47194,
dataf => \GRFPC0.N_24428\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPC0.FP_PIPELINE.VWR.RREG.EXCT_1_0_1733_I_A3_0_0_0\,
datac => \GRFPC0.MEM.RREG.EXCT\(0),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffffff0000000")
port map (
combout => N_47277,
dataf => \FPO.RES\(61),
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(61),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47264,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_13_3562_I_A3_0\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(27),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47263,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_14_3536_I_A3_0\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(26),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47261,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_16_3484_I_A3_0\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(24),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47260,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_17_3458_I_A3_0\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(23),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47259,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_18_3432_I_A3_0\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(22),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47258,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_19_3406_I_A3_0\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(21),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffffff0000000")
port map (
combout => N_47276,
dataf => \FPO.RES\(59),
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(59),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47257,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_20_3380_I_A3_0\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(20),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47256,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_21_3354_I_A3_0\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(19),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47252,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_25_3250_I_A3_0\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(15),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47250,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_27_3198_I_A3_0\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(13),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47248,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_29_3146_I_A3_0\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(11),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffffff0000000")
port map (
combout => N_47275,
dataf => \FPO.RES\(58),
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(58),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47247,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_30_3120_I_A3_0\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(10),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47246,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_31_3094_I_A3_0\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(9),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47244,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_33_3042_I_A3_0\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(7),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47242,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_35_2990_I_A3_0\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(5),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47240,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_37_2938_I_A3_0\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(3),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47239,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_38_2912_I_A3_0\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(2),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffffff0000000")
port map (
combout => N_47278,
dataf => \FPO.RES\(62),
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(62),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47238,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_39_2886_I_A3_0\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(1),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffffff0000000")
port map (
combout => N_47274,
dataf => N_46771_3,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(56),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47237,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_40_2860_I_A3_0\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(0),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffffff0000000")
port map (
combout => N_47273,
dataf => \FPO.RES\(55),
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(55),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffffff0000000")
port map (
combout => N_47272,
dataf => \FPO.RES\(53),
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(53),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffffff0000000")
port map (
combout => N_47271,
dataf => \FPO.RES\(50),
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(50),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffffff0000000")
port map (
combout => N_47270,
dataf => \FPO.RES\(36),
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(36),
datac => N_37);
\GRFPC0_WR_RREG_RES_RNO_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffffff0000000")
port map (
combout => N_47269,
dataf => \FPO.RES\(33),
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.MEM.RREG.RES\(33),
datac => N_37);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(21),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(21),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(21));
GRFPC0_FP_PIPELINE_UN68_HOLDN: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f0003000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datae => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datad => \GRFPC0.FP_PIPELINE.UN68_HOLDN_3\,
datac => \GRFPC0.WR2.RREG.RESV\,
datab => \GRFPC0.FPR.RDY\);
GRFPC0_V_FSR_FCC_2_SQMUXA_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccccccccc0ccccc")
port map (
combout => \GRFPC0.V.FSR.FCC_2_SQMUXA_0\,
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datae => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.WR2.CTRL.CCWR\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(11),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(11),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(11));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(11),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(11),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(11),
datac => \GRFPU0.GRFPU_X0.N_128\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(11));
GRFPU0_GRFPU_X0_COMB_UN1_VITER_FLUSH0_2_SQMUXA_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcfff3fff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA_0\,
dataf => \GRFPU0.GRFPU_X0.N_73\,
datae => \GRFPU0.GRFPU_X0.N_5661\,
datad => \GRFPU0.GRFPU_X0.N_10191\,
datac => \GRFPU0.GRFPU_X0.N_6071\,
datab => \GRFPU0.GRFPU_X0.ST3.RDY\);
GRFPU0_GRFPU_X0_COMB_DPRES_1_IV: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff33ff3330")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
dataf => \GRFPU0.GRFPU_X0.N_16197_M\,
datae => \GRFPU0.GRFPU_X0.N_6404\,
datad => \GRFPU0.GRFPU_X0.N_10191\,
datac => \GRFPU0.GRFPU_X0.N_6071\,
datab => \GRFPU0.GRFPU_X0.ITER.DP\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(23),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(23),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(23));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccf000f000f000f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(23),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => \GRFPU0.GRFPU_X0.N_18663\,
datac => \GRFPU0.MULO.MRES\(83),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(23));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_RNIPFGR1_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff22ffffff0a")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV\(44),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(44),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(44),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(7),
datab => \GRFPU0.GRFPU_X0.N_15750\,
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\);
GRFPU0_GRFPU_X0_ITER_SIGN_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000ccccf000")
port map (
combout => N_53558,
dataf => \GRFPU0.GRFPU_X0.N_5673_0\,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => \GRFPU0.GRFPU_X0.N_3440\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ITER.SIGN\);
GRFPU0_GRFPU_X0_ITER_V_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffc0f300000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.V_0_0_G0_3\,
dataf => \GRFPU0.GRFPU_X0.ITER.V_0_0_G0_3_1\,
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.N_73\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPC0_D_STLCK_RNO_0_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f4f4fff4ffffffff")
port map (
combout => \GRFPC0.D.STLCK_0_0_26__G1_3\,
dataf => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_TZ\(0),
datae => \GRFPC0.N_21246\,
datad => N_40557,
datac => \GRFPC0.D.STLCK_0_0_26__G1_0\,
datab => \GRFPC0.N_21454\,
dataa => \GRFPC0.N_23261\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ec00a000ec0020")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(3),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(3),
datad => \GRFPU0.GRFPU_X0.N_5673_0\,
datac => \GRFPU0.GRFPU_X0.N_128\,
datab => \GRFPU0.GRFPU_X0.ITER.V\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(15),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(15),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(15));
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19199\,
dataf => \FPO.RES\(0),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(0),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19209\,
dataf => \FPO.RES\(10),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(10),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19210\,
dataf => \FPO.RES\(11),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(11),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19211\,
dataf => \FPO.RES\(12),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(12),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19212\,
dataf => \FPO.RES\(13),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(13),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19213\,
dataf => \FPO.RES\(14),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(14),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19214\,
dataf => \FPO.RES\(15),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(15),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19215\,
dataf => \FPO.RES\(16),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(16),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19216\,
dataf => \FPO.RES\(17),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(17),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19217\,
dataf => \FPO.RES\(18),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(18),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19218\,
dataf => \FPO.RES\(19),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(19),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19200\,
dataf => \FPO.RES\(1),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(1),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19219\,
dataf => \FPO.RES\(20),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(20),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19220\,
dataf => \FPO.RES\(21),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(21),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19221\,
dataf => \FPO.RES\(22),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(22),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19222\,
dataf => \FPO.RES\(23),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(23),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19223\,
dataf => \FPO.RES\(24),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(24),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff300c0ffff0000")
port map (
combout => \GRFPC0.N_19224\,
dataf => \GRFPC0.N_24361\,
datae => \FPO.RES\(25),
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(25),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19225\,
dataf => \FPO.RES\(26),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(26),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19226\,
dataf => \FPO.RES\(27),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(27),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19227\,
dataf => \FPO.RES\(28),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(28),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19228\,
dataf => \FPO.RES\(29),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(29),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19201\,
dataf => \FPO.RES\(2),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(2),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19229\,
dataf => \FPO.RES\(30),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(30),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19230\,
dataf => \FPO.RES\(31),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(31),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19231\,
dataf => \GRFPU0.GRFPU_X0.N_20294_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(32),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19232\,
dataf => \FPO.RES\(33),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(33),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19233\,
dataf => \GRFPU0.GRFPU_X0.N_20274_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(34),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19234\,
dataf => \GRFPU0.GRFPU_X0.N_20295_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(35),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19235\,
dataf => \FPO.RES\(36),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(36),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19236\,
dataf => \GRFPU0.GRFPU_X0.N_20275_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(37),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19237\,
dataf => \GRFPU0.GRFPU_X0.N_20296_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(38),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19238\,
dataf => \GRFPU0.GRFPU_X0.N_19153_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(39),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19202\,
dataf => \FPO.RES\(3),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(3),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19239\,
dataf => \GRFPU0.GRFPU_X0.N_20289_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(40),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19240\,
dataf => \GRFPU0.GRFPU_X0.N_20297_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(41),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19241\,
dataf => \GRFPU0.GRFPU_X0.N_20271_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(42),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19242\,
dataf => \GRFPU0.GRFPU_X0.N_20290_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(43),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19243\,
dataf => \GRFPU0.GRFPU_X0.N_20298_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(44),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19244\,
dataf => \GRFPU0.GRFPU_X0.N_20272_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(45),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19245\,
dataf => \GRFPU0.GRFPU_X0.N_20291_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(46),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19246\,
dataf => \GRFPU0.GRFPU_X0.N_19240_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(47),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19247\,
dataf => \GRFPU0.GRFPU_X0.N_20273_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(48),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19248\,
dataf => \GRFPU0.GRFPU_X0.N_20292_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(49),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19203\,
dataf => \FPO.RES\(4),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(4),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19249\,
dataf => \FPO.RES\(50),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(50),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19250\,
dataf => \GRFPU0.GRFPU_X0.N_20285_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(51),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19251\,
dataf => \GRFPU0.GRFPU_X0.N_20293_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(52),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19252\,
dataf => \FPO.RES\(53),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(53),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19253\,
dataf => \GRFPU0.GRFPU_X0.N_20286_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(54),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19254\,
dataf => \FPO.RES\(55),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(55),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19255\,
dataf => N_46771_3,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(56),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19256\,
dataf => \GRFPU0.GRFPU_X0.N_20287_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(57),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19257\,
dataf => \FPO.RES\(58),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(58),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19258\,
dataf => \FPO.RES\(59),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(59),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19204\,
dataf => \FPO.RES\(5),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(5),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19259\,
dataf => \GRFPU0.GRFPU_X0.N_20288_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(60),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19260\,
dataf => \FPO.RES\(61),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(61),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19261\,
dataf => \FPO.RES\(62),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(62),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f3c0ff00ff00")
port map (
combout => \GRFPC0.N_19262\,
dataf => \GRFPC0.N_24361\,
datae => \GRFPC0.WR.CTRL.LD\,
datad => \FPO.RES\(63),
datac => \GRFPC0.WR.RREG.RES\(63),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19205\,
dataf => \FPO.RES\(6),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(6),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19206\,
dataf => \FPO.RES\(7),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(7),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19207\,
dataf => \FPO.RES\(8),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(8),
datab => N_37);
\GRFPC0_FP_PIPELINE_VWR2_RREG_RES_1_1_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00c00000")
port map (
combout => \GRFPC0.N_19208\,
dataf => \FPO.RES\(9),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.RREG.RES\(9),
datab => N_37);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O3_0_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5f00ffff1300ffff")
port map (
combout => \GRFPC0.N_22821\,
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_22808\,
datac => \GRFPC0.N_22429\,
datab => \GRFPC0.N_23897\,
dataa => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.UN423_REGDEPX\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_21639\,
dataf => \GRFPC0.N_59\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datad => N_97,
datac => \GRFPC0.N_23298\,
datab => N_107);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_13_0_A2_0_RNIE8TU: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030300000000000")
port map (
combout => \GRFPC0.N_22579\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => N_103,
datad => \GRFPC0.N_22615\,
datac => \GRFPC0.N_23298\,
datab => N_107);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff800")
port map (
combout => \GRFPC0.N_25034\,
dataf => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_2\(14),
datae => \GRFPC0.N_25082\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_3_0\(14),
datab => \GRFPC0.N_23986_1\,
dataa => \GRFPC0.N_24978_1\);
\GRFPC0_D_STLCK_RNO_4_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffc000c000c000")
port map (
combout => \GRFPC0.D.STLCK_0_0_29__G1_0\,
dataf => \GRFPC0.N_661\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datac => \GRFPC0.N_9467\,
datab => \GRFPC0.N_59\);
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fcfcff00ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(0),
dataf => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datae => \GRFPC0.WR2.RREG.RESV\,
datad => \GRFPC0.WR2.RREG.EXCT\(0),
datac => \GRFPU0.GRFPU_X0.ST4.DEFERNX\,
datab => \GRFPU0.GRFPU_X0.ST4.EXC\(0));
\GRFPC0_WR2_RREG_EXCT_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccfff0ffff")
port map (
combout => \GRFPC0.WR2.RREG.EXCT_0_0_0__G3\,
dataf => \GRFPC0.N_24361\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPU0.GRFPU_X0.ST4.DEFERNX\,
datac => \GRFPU0.GRFPU_X0.ST4.EXC\(0),
datab => \GRFPC0.WR.RREG.EXCT\(0));
\GRFPC0_D_STLCK_RNO_2_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff000000000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_18__G1_TZ\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datae => \GRFPC0.N_9482\,
datad => \GRFPC0.N_61_I\,
datac => \GRFPC0.N_59\);
\GRFPC0_D_STLCK_RNO_7_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fff3fff00003fff")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_A2_0_0\(1),
dataf => \GRFPC0.N_449\,
datae => \GRFPC0.N_505\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datac => \GRFPC0.N_9482\,
datab => \GRFPC0.N_59\);
\GRFPC0_FP_PIPELINE_9_REGDEPX_176_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX_176\(1),
dataf => \GRFPC0.FP_PIPELINE.9.REGDEPX_174\(1),
datae => N_97,
datad => \GRFPC0.N_9482\,
datac => \GRFPC0.N_59\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffeca00000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_0_0\(1),
dataf => \GRFPC0.N_25500\,
datae => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datab => \GRFPC0.N_24213_2\,
dataa => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5739_REGDEPX2\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(18),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(18));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffd50000ffc00000")
port map (
combout => \GRFPC0.N_24942\,
dataf => \GRFPC0.N_23201_2\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_24979\,
datac => \GRFPC0.N_25016\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_0\(29),
dataa => \GRFPC0.FIFO.INST_0\(19));
\GRFPU0_GRFPU_X0_L1_4_3_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_3\(3),
dataf => \GRFPU0.GRFPU_X0.UN123_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(10),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(8),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(7),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(9));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_O6_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000f03")
port map (
combout => \GRFPU0.GRFPU_X0.N_19016\,
dataf => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_3\,
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__I3_I_3\,
datac => \GRFPU0.GRFPU_X0.N_5774\,
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A2_0_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19079\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__I3_I_3\,
datad => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff003fc0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16071\,
dataf => \GRFPU0.GRFPU_X0.N_18195\,
datae => N_32517,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(57));
GRFPU0_GRFPU_X0_UN1_ST3_REG_ANC7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => N_32537,
dataf => N_32517,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(59),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(57));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ec00a000ec0020")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(6),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(6),
datad => \GRFPU0.GRFPU_X0.N_5673_0\,
datac => \GRFPU0.GRFPU_X0.N_128\,
datab => \GRFPU0.GRFPU_X0.ITER.V\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(6));
GRFPU0_GRFPU_X0_COMB_DPRES4_7_RNIHTFP4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000030f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16197_M\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN13_ITER_OF\,
datae => \GRFPU0.GRFPU_X0.N_7502\,
datad => \GRFPU0.GRFPU_X0.N_6833\,
datac => \GRFPU0.GRFPU_X0.N_16197_M_0\,
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
GRFPU0_GRFPU_X0_UN1_ITER_OF_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER_OF_1\,
dataf => \GRFPU0.GRFPU_X0.N_6833\,
datae => \GRFPU0.GRFPU_X0.N_10191\,
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
\GRFPC0_EX_RREG_EXCT_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030303033000000")
port map (
combout => N_27205,
dataf => \GRFPC0.N_82\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPC0.DIV.EXCT_0_0_5__I1_I_1\,
datac => \GRFPC0.EX.RREG.EXCT\(5),
datab => N_37);
\GRFPC0_WR2_RREG_EXCT_RNO_0_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ff000000")
port map (
combout => \GRFPC0.WR2.RREG.EXCT_0_0_5__G3\,
dataf => \GRFPC0.N_24361\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPC0.DIV.EXCT_0_0_5__I1_I_1\,
datac => \GRFPC0.WR.RREG.EXCT\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(25),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(25),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(25));
\GRFPC0_FP_PIPELINE_4_0_REGDEPX_77_0_A3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => \GRFPC0.N_23178\,
dataf => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datae => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1327_REGDEPX_0\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0\(29),
datab => \GRFPC0.FIFO.INST_0\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(10),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(10),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(10),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(10),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(10),
datac => \GRFPU0.GRFPU_X0.N_128\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(10));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_O2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffeaaac000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_O2_1\(1),
dataf => \GRFPC0.N_25282\,
datae => \GRFPC0.N_25592_1\,
datad => \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A2_0_2_0\(0),
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_A0_1\(1),
datab => \GRFPC0.N_24181\,
dataa => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4344_REGDEPX2\);
\GRFPC0_D_LDLCK_RNO_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff44f040fffff0f0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_1__G1_TZ\,
dataf => \GRFPC0.N_22967\,
datae => \GRFPC0.N_23043\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_15\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN300_REGDEPX\,
dataa => \GRFPC0.N_22433_1\);
\GRFPC0_D_STDLCK_RNO_1_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0f2f0f0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_14__G1_1\,
dataf => \GRFPC0.N_21563\,
datae => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2698_DEP_1\,
datad => \GRFPC0.N_473_1\,
datac => \GRFPC0.N_661\,
datab => \GRFPC0.N_106_I\,
dataa => \GRFPC0.EX.CTRL.RD\(3));
\GRFPU0_GRFPU_X0_L2_0_4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000eef0eef0")
port map (
combout => N_82214,
dataf => \GRFPU0.GRFPU_X0.N_9559\,
datae => N_82198,
datad => \GRFPU0.GRFPU_X0.N_9608\,
datac => \GRFPU0.GRFPU_X0.N_13845_1\,
datab => \GRFPU0.GRFPU_X0.BCO_MSB_1_5_I_0\(1),
dataa => \GRFPU0.GRFPU_X0.N_13648\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003330000")
port map (
combout => \GRFPC0.N_23032\,
dataf => \GRFPC0.N_22959\,
datae => \GRFPC0.N_22957\,
datad => \GRFPC0.N_22253\,
datac => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN207_REGDEPX\,
datab => \GRFPC0.N_23036\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0ff0000")
port map (
combout => \GRFPC0.N_23043\,
dataf => \GRFPC0.N_22959\,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_22957\,
datac => \GRFPC0.N_22253\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN207_REGDEPX\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_7_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f03300f0f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_7\(0),
dataf => \GRFPC0.N_263\,
datae => \GRFPC0.N_24765_1\,
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3960_REGDEPX2_1\,
datac => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4664_REGDEPX2\,
datab => \GRFPC0.DIV.INST\(17));
\GRFPC0_R_FSR_AEXC_RNO_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff88888")
port map (
combout => \GRFPC0.R.FSR.AEXC_0_0_1__G1_1\,
dataf => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_2_M\(1),
datae => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
datad => \GRFPC0.R.FSR.AEXC\(1),
datac => \GRFPC0.DIV.EXCT\(1),
datab => \GRFPC0.V.FSR.AEXC_0_SQMUXA\,
dataa => N_437);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_4_RNIGFN12_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff22ffffff0a")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV\(38),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(38),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(38),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(1),
datab => \GRFPU0.GRFPU_X0.N_100\,
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(26),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(26),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(26));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_475_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00000cae0000")
port map (
combout => \GRFPC0.N_25807\,
dataf => \GRFPC0.N_25846\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datad => \GRFPC0.N_706\,
datac => \GRFPC0.N_704\,
datab => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_0_A2_5_0\(0),
dataa => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6945_REGDEPX2\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff40")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235\(0),
dataf => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220\(0),
datae => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235_0_1\(0),
datad => \GRFPC0.N_25507\,
datac => \GRFPC0.N_24761_2\,
datab => \GRFPC0.N_24087_1\,
dataa => \GRFPC0.N_25557\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_RNIS7GR1_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff88ffffffa0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(39),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(39),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(39),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(2),
datab => \GRFPU0.GRFPU_X0.N_15745\,
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\);
\GRFPC0_D_LDLCK_RNO_0_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffaaaaaaffaaeaaa")
port map (
combout => \GRFPC0.D.LDLCK_0_0_30__G1_3\,
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.N_24813\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_24900\,
datab => \GRFPC0.N_23522_I_1\,
dataa => \GRFPC0.D.LDLCK_0_0_30__G1_1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M10_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_2_03\,
datae => \GRFPU0.GRFPU_X0.N_9683\,
datad => \GRFPU0.GRFPU_X0.L2_0_0_0\(4),
datac => \GRFPU0.GRFPU_X0.UN213_BCO_LSB_0\,
datab => \GRFPU0.GRFPU_X0.N_14025_1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M11_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_2_03\,
datae => \GRFPU0.GRFPU_X0.N_9683\,
datad => \GRFPU0.GRFPU_X0.L2_0_0_0\(4),
datac => \GRFPU0.GRFPU_X0.UN213_BCO_LSB_0\,
datab => \GRFPU0.GRFPU_X0.N_14025_1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M12_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_2_03\,
datae => \GRFPU0.GRFPU_X0.N_9683\,
datad => \GRFPU0.GRFPU_X0.L2_0_0_0\(4),
datac => \GRFPU0.GRFPU_X0.UN213_BCO_LSB_0\,
datab => \GRFPU0.GRFPU_X0.N_14025_1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M13_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_2_03\,
datae => \GRFPU0.GRFPU_X0.N_9683\,
datad => \GRFPU0.GRFPU_X0.L2_0_0_0\(4),
datac => \GRFPU0.GRFPU_X0.UN213_BCO_LSB_0\,
datab => \GRFPU0.GRFPU_X0.N_14025_1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M14_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_2_03\,
datae => \GRFPU0.GRFPU_X0.N_9683\,
datad => \GRFPU0.GRFPU_X0.L2_0_0_0\(4),
datac => \GRFPU0.GRFPU_X0.UN213_BCO_LSB_0\,
datab => \GRFPU0.GRFPU_X0.N_14025_1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M15_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_2_03\,
datae => \GRFPU0.GRFPU_X0.N_9683\,
datad => \GRFPU0.GRFPU_X0.L2_0_0_0\(4),
datac => \GRFPU0.GRFPU_X0.UN213_BCO_LSB_0\,
datab => \GRFPU0.GRFPU_X0.N_14025_1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M8_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_2_03\,
datae => \GRFPU0.GRFPU_X0.N_9683\,
datad => \GRFPU0.GRFPU_X0.L2_0_0_0\(4),
datac => \GRFPU0.GRFPU_X0.UN213_BCO_LSB_0\,
datab => \GRFPU0.GRFPU_X0.N_14025_1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M9_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_2_03\,
datae => \GRFPU0.GRFPU_X0.N_9683\,
datad => \GRFPU0.GRFPU_X0.L2_0_0_0\(4),
datac => \GRFPU0.GRFPU_X0.UN213_BCO_LSB_0\,
datab => \GRFPU0.GRFPU_X0.N_14025_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(17),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(17),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(17));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_D_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f8fff80008ff0800")
port map (
combout => N_67751,
dataf => \GRFPU0.GRFPU_X0.N_15373\,
datae => N_67744,
datad => \GRFPU0.GRFPU_X0.N_307\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datab => \GRFPU0.GRFPU_X0.N_4105\,
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(0));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fffc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(2),
dataf => \GRFPU0.GRFPU_X0.UN233_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.UN228_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_8\,
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(17));
\GRFPC0_D_STLCK_RNO_2_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff2fffffff0")
port map (
combout => \GRFPC0.D.STLCK_0_0_23__G1_7\,
dataf => \GRFPC0.N_23495\,
datae => \GRFPC0.N_23389\,
datad => \GRFPC0.N_23454\,
datac => \GRFPC0.D.STLCK_0_0_23__G1_4\,
datab => \GRFPC0.N_21729\,
dataa => \GRFPC0.WR.CTRL.RDD\);
GRFPU0_GRFPU_X0_UN1_VST3_REG22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3fffffff0ffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST3.REG22\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6\,
datae => \GRFPU0.GRFPU_X0.N_5806\,
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\,
datac => \GRFPU0.GRFPU_X0.ST2.RDY\,
datab => \GRFPU0.GRFPU_X0.ST2.DIFFN\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff0ff80")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_3\(1),
dataf => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_0\(1),
datae => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_O2_0_845_1\,
datad => \GRFPC0.N_25715\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datab => \GRFPC0.N_25746\,
dataa => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1181_REGDEPX2\);
\GRFPC0_MEM_RREG_EXCT_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3fffff3c0ff00")
port map (
combout => N_45216,
dataf => \GRFPC0.DIV.EXCT_0_0_2__G0_0_A3_0\,
datae => \GRFPC0.N_82\,
datad => N_45232_1,
datac => \GRFPC0.EX.RREG.EXCT\(2),
datab => N_37);
\GRFPC0_MEM_RREG_EXCT_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0f3f3f300ffffff")
port map (
combout => N_47193,
dataf => \GRFPC0.N_82\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPC0.FP_PIPELINE.VWR.RREG.EXCT_1_0_1733_I_A3_0_0_0\,
datac => \GRFPC0.EX.RREG.EXCT\(0),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffffff0000000")
port map (
combout => N_47235,
dataf => \FPO.RES\(61),
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(61),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47222,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_13_3562_I_A3_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(27),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47221,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_14_3536_I_A3_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(26),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47219,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_16_3484_I_A3_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(24),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47218,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_17_3458_I_A3_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(23),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47217,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_18_3432_I_A3_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(22),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47216,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_19_3406_I_A3_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(21),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffffff0000000")
port map (
combout => N_47234,
dataf => \FPO.RES\(59),
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(59),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47215,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_20_3380_I_A3_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(20),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47214,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_21_3354_I_A3_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(19),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47210,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_25_3250_I_A3_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(15),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47208,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_27_3198_I_A3_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(13),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffffff0000000")
port map (
combout => N_47236,
dataf => \FPO.RES\(62),
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(62),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47206,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_29_3146_I_A3_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(11),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffffff0000000")
port map (
combout => N_47233,
dataf => \FPO.RES\(58),
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(58),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47205,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_30_3120_I_A3_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(10),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47204,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_31_3094_I_A3_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(9),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47202,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_33_3042_I_A3_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(7),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47200,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_35_2990_I_A3_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(5),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47198,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_37_2938_I_A3_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(3),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47197,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_38_2912_I_A3_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(2),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47196,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_39_2886_I_A3_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(1),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffffff0000000")
port map (
combout => N_47232,
dataf => N_46771_3,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(56),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000ff0fffff")
port map (
combout => N_47195,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_40_2860_I_A3_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(0),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffffff0000000")
port map (
combout => N_47231,
dataf => \FPO.RES\(55),
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(55),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffffff0000000")
port map (
combout => N_47230,
dataf => \FPO.RES\(53),
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(53),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffffff0000000")
port map (
combout => N_47229,
dataf => \FPO.RES\(50),
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(50),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffffff0000000")
port map (
combout => N_47228,
dataf => \FPO.RES\(36),
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(36),
datac => N_37);
\GRFPC0_MEM_RREG_RES_RNO_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ffffff0000000")
port map (
combout => N_47227,
dataf => \FPO.RES\(33),
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.RES\(33),
datac => N_37);
\GRFPU0_GRFPU_X0_L4_D_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0fffff0f0fff0")
port map (
combout => N_93124,
dataf => \GRFPU0.GRFPU_X0.L1_6_1_3\(0),
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(1),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(2),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(0));
\GRFPC0_D_STDLCK_RNO_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_6_5_1\,
dataf => \GRFPC0.N_22173_I\,
datae => \GRFPC0.FP_PIPELINE.3.STDEP_128_SEL0_1\,
datad => \GRFPC0.FP_PIPELINE.3.STDEP_136_SEL0_1\,
datac => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1040_DEP\,
datab => \GRFPC0.MEM.CTRL.RDWR\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(9),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(9),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(9));
\GRFPC0_D_STDLCK_RNO_2_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdfcfcfcffffffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_7__G1_2\,
dataf => \GRFPC0.N_22341\,
datae => \GRFPC0.N_690\,
datad => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_1\,
datac => \GRFPC0.N_21902\,
datab => \GRFPC0.N_21899\,
dataa => \GRFPC0.N_579\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(30),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(30),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(30));
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_O2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"003f0000ffffffff")
port map (
combout => \GRFPC0.N_21524\,
dataf => \GRFPC0.N_25895\,
datae => \GRFPC0.N_533\,
datad => \GRFPC0.N_655\,
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN730_DEP\,
datab => \GRFPC0.EX.CTRL.RDWR\);
\GRFPC0_EX_RREG_EXCT_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030303033000000")
port map (
combout => N_27204,
dataf => \GRFPC0.N_82\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPC0.DIV.EXCT_0_0_4__I1_I_2\,
datac => \GRFPC0.EX.RREG.EXCT\(4),
datab => N_37);
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_4_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00f0f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(4),
dataf => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datae => \GRFPC0.WR2.RREG.RESV\,
datad => \GRFPC0.DIV.EXCT_0_0_4__I1_I_2\,
datac => \GRFPC0.WR2.RREG.EXCT\(4));
\GRFPC0_WR2_RREG_EXCT_RNO_0_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ff000000")
port map (
combout => \GRFPC0.WR2.RREG.EXCT_0_0_4__G3\,
dataf => \GRFPC0.N_24361\,
datae => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datad => \GRFPC0.DIV.EXCT_0_0_4__I1_I_2\,
datac => \GRFPC0.WR.RREG.EXCT\(4));
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_EQ_EXPT63_0_A5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000300")
port map (
combout => \GRFPU0.GRFPU_X0.N_4275\,
dataf => \GRFPU0.GRFPU_X0.N_18216\,
datae => \GRFPU0.GRFPU_X0.C\(11),
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT63_0_A2_0_2\,
datac => \GRFPU0.GRFPU_X0.N_18220\,
datab => \GRFPU0.GRFPU_X0.C\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ec00a000ec0020")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(4),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(4),
datad => \GRFPU0.GRFPU_X0.N_5673_0\,
datac => \GRFPU0.GRFPU_X0.N_128\,
datab => \GRFPU0.GRFPU_X0.ITER.V\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(24),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(24),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(24));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0c0cfcfcfc0c")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_0\,
dataf => \GRFPU0.GRFPU_X0.NXX_1\,
datae => \GRFPU0.GRFPU_X0.N_7502\,
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18633\,
dataf => \GRFPU0.GRFPU_X0.N_7502\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
datad => \GRFPU0.GRFPU_X0.N_18611\,
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f0fffff000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_5\,
dataf => \GRFPU0.GRFPU_X0.N_7502\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNIIMV42_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_8976\,
dataf => \GRFPU0.GRFPU_X0.N_6408_2\,
datae => \GRFPU0.GRFPU_X0.N_18500\,
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(6));
\GRFPU0_GRFPU_X0_COMB_EXP_14_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3cf0f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXP_14\(7),
dataf => N_32654,
datae => \GRFPU0.GRFPU_X0.COMB.EXP57\,
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(6));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A2_2_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_22589\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22429\,
datad => \GRFPC0.N_25011\,
datac => \GRFPC0.FIFO.INST_0\(1),
datab => \GRFPC0.FIFO.INST_0\(2));
\GRFPC0_D_STDLCK_RNO_0_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0fffffff00")
port map (
combout => \GRFPC0.D.STDLCK_0_0_10__G1_2\,
dataf => \GRFPC0.N_23560\,
datae => \GRFPC0.N_23522_I\,
datad => \GRFPC0.D.STDLCK_0_0_10__G1_0\,
datac => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_FPUSEL_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00cc03030000")
port map (
combout => \GRFPC0.FPUSEL_1\(2),
dataf => \GRFPC0.FP_PIPELINE.1.EXEN7\,
datae => \GRFPC0.FP_PIPELINE.1.MEMEN10\,
datad => \GRFPC0.N_155_1\,
datac => \GRFPC0.N_24389\,
datab => N_37);
\GRFPC0_D_LDLCK_RNO_1_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0ff00ff00ff00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_15__G1_1\,
dataf => \GRFPC0.N_22370_2\,
datae => \GRFPC0.N_22370_3\,
datad => \GRFPC0.D.LDLCK_0_0_15__G1_0\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datab => \GRFPC0.N_21627\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_394_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8f0f8800ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_394\(1),
dataf => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_23_IV\(1),
datae => \GRFPC0.N_25199\,
datad => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5885_REGDEPX2\,
datac => \GRFPC0.V.STDATA_14_I_M_10\(0),
datab => \GRFPC0.N_25221\,
dataa => \FPI.FLOP\(6));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_3_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_23266\,
dataf => N_107,
datae => \GRFPC0.N_23298\,
datad => \GRFPC0.N_61_I\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datab => N_97);
\GRFPC0_MEM_RREG_EXCT_RNO_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccc0000ccccf0ff")
port map (
combout => \GRFPC0.EX.RREG.EXCT_0_0_3__N_6\,
dataf => \GRFPC0.DIV.EXCT_0_0_2__G0_0_A3_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datac => \GRFPU0.GRFPU_X0.ST4.EXC\(3),
datab => \GRFPC0.EX.RREG.EXCT\(3));
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_13_M_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c0f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13_M\(3),
dataf => \GRFPC0.V.FSR.CEXC_3_SQMUXA\,
datae => \GRFPC0.DIV.EXCT_0_0_2__G0_0_A3_0\,
datad => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datac => \GRFPC0.R.FSR.TEM\(3),
datab => \GRFPU0.GRFPU_X0.ST4.EXC\(3));
\GRFPC0_MEM_RREG_EXCT_RNO_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccc0000ccccf0ff")
port map (
combout => \GRFPC0.MEM.RREG.EXCT_0_0_3__N_6\,
dataf => \GRFPC0.DIV.EXCT_0_0_2__G0_0_A3_0\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datac => \GRFPU0.GRFPU_X0.ST4.EXC\(3),
datab => \GRFPC0.EX.RREG.EXCT\(3));
\GRFPC0_WR2_RREG_EXCT_RNO_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccc0000ccccf0ff")
port map (
combout => \GRFPC0.WR2.RREG.EXCT_0_0_3__G3\,
dataf => \GRFPC0.DIV.EXCT_0_0_2__G0_0_A3_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datac => \GRFPU0.GRFPU_X0.ST4.EXC\(3),
datab => \GRFPC0.WR.RREG.EXCT\(3));
\GRFPC0_EX_RREG_EXCT_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030333330303300")
port map (
combout => N_53551,
dataf => \GRFPC0.DIV.EXCT_0_0_2__G0_0_A3_0\,
datae => \GRFPC0.N_82\,
datad => N_45232_1,
datac => \GRFPC0.EX.RREG.EXCT\(2),
datab => N_37);
\GRFPC0_FP_PIPELINE_11_REGDEPX_210_0_O2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff3")
port map (
combout => \GRFPC0.N_23403\,
dataf => \GRFPC0.STDEP_0_SQMUXA_81_2_I\,
datae => N_99871,
datad => \GRFPC0.N_24936\,
datac => \GRFPC0.FIFO.INST_1\(28),
datab => \GRFPC0.FIFO.INST_1\(29));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPC0.N_23415\,
dataf => \GRFPC0.STDEP_0_SQMUXA_81_2_I\,
datae => N_40557,
datad => \GRFPC0.N_24936\,
datac => \GRFPC0.FIFO.INST_1\(28),
datab => \GRFPC0.FIFO.INST_1\(29));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3300000033000300")
port map (
combout => \GRFPU0.GRFPU_X0.N_19991\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datae => \GRFPU0.GRFPU_X0.N_19662\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(47));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3300000033000300")
port map (
combout => \GRFPU0.GRFPU_X0.N_271\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datae => \GRFPU0.GRFPU_X0.N_19662\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(49));
\GRFPU0_GRFPU_X0_ST3_EXC_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffab0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1\(4),
dataf => \GRFPU0.GRFPU_X0.N_5775\,
datae => \GRFPU0.GRFPU_X0.VST3.EXC_1_0_F0_0_4__G0_1\,
datad => \GRFPU0.GRFPU_X0.N_7113\,
datac => \GRFPU0.GRFPU_X0.N_5757\,
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(3),
dataa => \GRFPU0.GRFPU_X0.ST2.EXC\(4));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0300fcf0000")
port map (
combout => D_N_7_0_I,
dataf => N_82235,
datae => N_67748,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datac => \GRFPU0.GRFPU_X0.N_19546\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_A2_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccc0c0000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19949\,
dataf => \GRFPU0.GRFPU_X0.N_19777\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(13));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_A2_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccc0c0000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19944\,
dataf => \GRFPU0.GRFPU_X0.N_19777\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(19));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_A2_5_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000033030303")
port map (
combout => \GRFPU0.GRFPU_X0.N_391\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datae => \GRFPU0.GRFPU_X0.N_19547\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_1_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000fffcfcfc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_1\(59),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datae => N_40510,
datad => \GRFPU0.GRFPU_X0.UN8_C\(7),
datac => \GRFPU0.GRFPU_X0.N_19902\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_A2_0_0_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0033000f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_0\(8),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datac => \FPI.OP1_RETO\(8),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(8));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f000cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(33),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f000cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(39),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f000cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(40),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f000cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(41),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0f0c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_0\(27),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f000cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_0\(50),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datac => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000300030f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19984\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f003300")
port map (
combout => \GRFPU0.GRFPU_X0.N_283\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f003300")
port map (
combout => \GRFPU0.GRFPU_X0.N_280\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_3_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f03030")
port map (
combout => \GRFPU0.GRFPU_X0.N_277\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.DIVROM0.RADDR\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_3_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f03030")
port map (
combout => \GRFPU0.GRFPU_X0.N_273\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49));
\GRFPC0_D_STLCK_RNO_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffcfffff3000")
port map (
combout => \GRFPC0.D.STLCK_0_0_14__G1\,
dataf => \GRFPC0.N_21855\,
datae => \GRFPC0.D.STLCK_0_0_14__G1_5\,
datad => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datab => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_0_O2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccffccc0c0ffc0")
port map (
combout => \GRFPC0.N_528\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => \GRFPC0.N_543_1\,
datad => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2887_REGDEPX\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datab => \GRFPC0.N_9482\);
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_I_A2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00c000ff00f000")
port map (
combout => \GRFPC0.N_173\,
dataf => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1\,
datae => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_0\,
datad => \GRFPC0.N_100\,
datac => \GRFPC0.WR2.RREG.RESV\,
datab => \GRFPC0.WR.RREG.RESV\);
\GRFPU0_GRFPU_X0_ST3_EXC_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffccfc")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1_IV_0_0__G0_1\,
dataf => \GRFPU0.GRFPU_X0.N_6206\,
datae => \GRFPU0.GRFPU_X0.N_5940\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__I3_I_3\,
datac => \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_0\,
datab => \GRFPU0.GRFPU_X0.N_5773\);
\GRFPC0_D_LDLCK_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff8008800")
port map (
combout => \GRFPC0.D.LDLCK_0_0_0__G1_4\,
dataf => \GRFPC0.D.LDLCK_0_0_0__G1_3\,
datae => \GRFPC0.N_23345_1\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN207_REGDEPX\,
dataa => \GRFPC0.N_22252\);
\GRFPC0_D_STLCK_RNO_1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0fffff0f3ffff")
port map (
combout => \GRFPC0.D.STLCK_0_0_6__G1_3\,
dataf => \GRFPC0.FP_PIPELINE.3.STDEP_140_I_M_2\(0),
datae => \GRFPC0.FP_PIPELINE.3.STDEP_150_I_TZ\(0),
datad => \GRFPC0.N_543_1\,
datac => \GRFPC0.D.STLCK_0_0_6__G1_1\,
datab => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1015_REGDEPX_I_1\);
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_A3_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000ccccccc")
port map (
combout => \GRFPC0.N_113\,
dataf => \GRFPC0.N_65\,
datae => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2644_DEP\,
datad => \GRFPC0.N_123\,
datac => \GRFPC0.N_23810\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A3_3_0\);
\GRFPC0_FIFO_VCNT_0_RNO_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff0f")
port map (
combout => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_A6_1_0\,
dataf => N_47098,
datae => \GRFPC0.FIFO.VCNT_0\(0),
datad => \GRFPC0.FIFO.VCNT_0\(1),
datac => \GRFPC0.FIFO.VCNT_0\(2));
\GRFPC0_FIFO_VCNT_0_RNO_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000f000f0f0")
port map (
combout => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_0\,
dataf => N_47098,
datae => \GRFPC0.FIFO.VCNT_0\(0),
datad => \GRFPC0.FIFO.VCNT_0\(1),
datac => N_35);
\GRFPC0_D_LDLCK_RNO_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffea")
port map (
combout => \GRFPC0.D.LDLCK_0_0_25__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390\(1),
datae => \GRFPC0.D.LDLCK_0_0_25__G1_3\,
datad => \GRFPC0.N_23336\,
datac => \GRFPC0.N_22480_2\,
datab => \GRFPC0.N_23349_1\,
dataa => \GRFPC0.D.LDLCK_0_0_25__G1_1\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0021000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\,
dataf => \GRFPU0.GRFPU_X0.N_18528_I\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_4\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_0\,
datac => \FPO.IDOUT\(3),
datab => \GRFPC0.DIV.ID\(7),
dataa => \GRFPC0.DIV.ID\(3));
GRFPU0_GRFPU_X0_UN1_ITER_EXP_C8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => N_32483,
dataf => N_32463,
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(6));
\GRFPC0_D_STDLCK_RNO_5_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff003f00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_10_3\,
dataf => \GRFPC0.N_23122\,
datae => \GRFPC0.N_543_1\,
datad => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_10_1\,
datac => \GRFPC0.N_24900\,
datab => \GRFPC0.FIFO.INST_0\(29));
GRFPC0_FP_PIPELINE_STDDEP_1_IV_4_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff000f000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.STDDEP_1_4\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => \GRFPC0.STDDEP_0_SQMUXA_I_I_A2_1\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datac => \GRFPC0.N_9468\);
\GRFPU0_GRFPU_X0_L3_1_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0f0cccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.L3_1_1\(2),
dataf => \GRFPU0.GRFPU_X0.L1_4_5\(3),
datae => \GRFPU0.GRFPU_X0.L1_5_2_0\(3),
datad => \GRFPU0.GRFPU_X0.UN68_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.UN63_BCO_LSB\(15),
datab => \GRFPU0.GRFPU_X0.UN58_BCO_LSB\(15));
\GRFPC0_D_STDLCK_RNO_5_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0fcf0fffffcf0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_3__G1_3\,
dataf => \GRFPC0.STDEP_0_SQMUXA_81_2_I\,
datae => \GRFPC0.FP_PIPELINE.3.1.CHECK_DEP.UN1120_REGDEPX\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A2_0\,
datac => \GRFPC0.D.STDLCK_0_0_3__G1_1\,
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1058_DEP\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff73500000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_4\(0),
dataf => \GRFPC0.N_24772\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_3_1\(0),
datac => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_8_1\(0),
datab => \GRFPC0.MEM.CTRL.INST\(26),
dataa => \GRFPC0.MEM.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_8_RNII40J7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffc000c000c000")
port map (
combout => \GRFPC0.N_63\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.N_21225\,
datad => \GRFPC0.N_59\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datab => \GRFPC0.N_9481\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"9000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9\,
dataf => \GRFPU0.GRFPU_X0.N_18528_I\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_0\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_1\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_2\,
datab => \FPO.IDOUT\(2),
dataa => \GRFPC0.EX.CTRL.ID\(2));
\GRFPC0_FP_PIPELINE_9_0_REGDEPX_168_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc00f000fe00fa00")
port map (
combout => \GRFPC0.FP_PIPELINE.9.0.REGDEPX_168\(1),
dataf => \GRFPC0.N_23916\,
datae => \GRFPC0.N_23178_1\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_23950\,
datab => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.UN2887_REGDEPX\,
dataa => \GRFPC0.FP_PIPELINE.9.0.REGDEPX_167_0_A2_0\(1));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0baa08aa03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(19),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37_1\(9),
datae => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_19__G5\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(19));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O4_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffdcffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1\(1),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O4_7\(31),
datad => \GRFPC0.N_25130\,
datac => \GRFPC0.FP_PIPELINE.15.REGDEPX2_454_0_A2_0\(1),
datab => \GRFPC0.N_25129\,
dataa => \GRFPC0.V.STDATA_14_I_M_10\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_O3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00330000f0f3f0f0")
port map (
combout => \GRFPC0.N_21269\,
dataf => \GRFPC0.STDEP_0_SQMUXA_81_2_I\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_22536\,
datac => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4240_REGDEPX\,
datab => \GRFPC0.FIFO.INST_0\(19));
\GRFPC0_D_LDLCK_RNO_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffeca0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_20__G1\,
dataf => \GRFPC0.N_277\,
datae => \GRFPC0.D.LDLCK_0_0_20__G1_3\,
datad => \GRFPC0.N_23560\,
datac => \GRFPC0.N_23348_1\,
datab => \GRFPC0.N_23345_1\,
dataa => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2_0\(20));
\GRFPC0_R_FSR_AEXC_RNO_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffcf000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_2_M\(0),
dataf => \GRFPC0.V.FSR.CEXC_5_SQMUXA\,
datae => \FPO.EXC\(0),
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.R.FSR.AEXC\(0),
datab => \GRFPC0.WR2.RREG.EXCT\(0));
\GRFPC0_D_STDLCK_RNO_7_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0ffffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_12__G1_1\,
dataf => \GRFPC0.N_18319\,
datae => \GRFPC0.STDDEP_0_SQMUXA_25_I_1\,
datad => \GRFPC0.STDDEP_0_SQMUXA_12_I_1\,
datac => \GRFPC0.N_9465\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7f5f30000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_2_0\(0),
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3975_REGDEPX2\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A2_6_2_1\(0),
datac => \GRFPC0.DIV.RDD\,
datab => \GRFPC0.DIV.RD\(0),
dataa => \GRFPC0.DIV.INST\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffeaffffffc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(53),
dataf => \GRFPU0.GRFPU_X0.N_19563\,
datae => \GRFPU0.GRFPU_X0.N_19585\,
datad => \GRFPU0.GRFPU_X0.N_18983_I\,
datac => N_40510,
datab => \GRFPU0.GRFPU_X0.UN8_C\(1),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(53));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_215_I_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"08000a000c000f00")
port map (
combout => \GRFPC0.N_24581\,
dataf => \GRFPC0.N_24621\,
datae => \GRFPC0.N_24622\,
datad => \GRFPC0.N_24579\,
datac => \FPI.FLOP\(1),
datab => \GRFPC0.N_223\,
dataa => \GRFPC0.N_235\);
GRFPU0_GRFPU_X0_UN1_VST3_EXC37: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3333ff3f3333")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST3.EXC37\,
dataf => \GRFPU0.GRFPU_X0.N_19700\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__I3_I_3\,
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5));
GRFPU0_GRFPU_X0_UN1_VST3_EXC_4_SQMUXA_TZ: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff0cffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST3.EXC_4_SQMUXA_TZ\,
dataf => \GRFPU0.GRFPU_X0.N_19700\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__I3_I_3\,
datad => \GRFPU0.GRFPU_X0.N_5820\,
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(7));
GRFPU0_GRFPU_X0_VST3_EXC_3_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cccc00c0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_7113\,
dataf => \GRFPU0.GRFPU_X0.N_19700\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__I3_I_3\,
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffeca0ffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(13),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(13),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(13),
datac => \GRFPU0.GRFPU_X0.N_128\,
datab => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(13));
\GRFPC0_D_STDLCK_RNO_0_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0fdf5")
port map (
combout => \GRFPC0.D.STDLCK_0_0_14__G1_4\,
dataf => \GRFPC0.D.STDLCK_0_0_14__G1_1\,
datae => \GRFPC0.N_23177\,
datad => \GRFPC0.N_21581_2\,
datac => \GRFPC0.N_21557\,
datab => \GRFPC0.N_19008\,
dataa => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_D_LDLCK_RNO_0_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc00000c0c00000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_17__G1_0\,
dataf => \GRFPC0.N_23978\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2815_REGDEPX\,
datac => \GRFPC0.N_21186_1\,
datab => \GRFPC0.N_23976\);
\GRFPC0_D_LDLCK_RNO_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffeca0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_28__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450\(0),
datae => \GRFPC0.D.LDLCK_0_0_28__G1_4\,
datad => \GRFPC0.N_25051_1\,
datac => \GRFPC0.N_23348_1\,
datab => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4568_REGDEPX\,
dataa => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4583_REGDEPX\);
\GRFPC0_D_LDLCK_RNO_1_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0ff00ff00ff00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_10__G1_1\,
dataf => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1879_REGDEPX_1\,
datae => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1879_REGDEPX_2\,
datad => \GRFPC0.D.LDLCK_0_0_10__G1_0\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datab => \GRFPC0.N_24820\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffeaffffffc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(54),
dataf => \GRFPU0.GRFPU_X0.N_19563\,
datae => \GRFPU0.GRFPU_X0.N_19590\,
datad => \GRFPU0.GRFPU_X0.N_18983_I\,
datac => N_40510,
datab => \GRFPU0.GRFPU_X0.UN8_C\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(54));
\GRFPC0_D_LDLCK_RNO_0_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffefaeeaaeeaa")
port map (
combout => \GRFPC0.D.LDLCK_0_0_16__G1_3\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_23953\,
datad => \GRFPC0.N_22273_2\,
datac => \GRFPC0.FP_PIPELINE.8.0.REGDEPX_149_0_0\(0),
datab => \GRFPC0.N_22273_1\,
dataa => \GRFPC0.D.LDLCK_0_0_16__G1_1\);
GRFPU0_GRFPU_X0_UN23_EXP_ANC9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => N_32677,
dataf => N_32664,
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(9));
\GRFPC0_D_STLCK_RNO_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc0ff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_10__G1\,
dataf => \GRFPC0.N_23289\,
datae => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datad => \GRFPC0.D.STLCK_0_0_10__G1_4\,
datac => \GRFPC0.N_23514\,
datab => \GRFPC0.N_9478\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.N_23418\,
dataf => N_82,
datae => N_81,
datad => \GRFPC0.N_25037\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datab => \GRFPC0.N_23978\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_2_0_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f3f000003300")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_2\(14),
dataf => \GRFPC0.N_25028\,
datae => \GRFPC0.FIFO.INST_0_M_11\(25),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_2\(14),
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datab => \GRFPC0.FIFO.INST_0\(19));
GRFPU0_GRFPU_X0_EXPDEC_SP_0_SQMUXA_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => N_99661,
dataf => \GRFPU0.GRFPU_X0.UN4_S3ADDO3\(23),
datae => \GRFPU0.GRFPU_X0.N_6408_2\,
datad => \GRFPU0.GRFPU_X0.N_6050_6\,
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(6));
\GRFPC0_D_LDLCK_RNO_0_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffeeefaaa")
port map (
combout => \GRFPC0.D.LDLCK_0_0_12__G1_4\,
dataf => \GRFPC0.N_22446\,
datae => \GRFPC0.N_23348_1\,
datad => \GRFPC0.N_22444_1\,
datac => \GRFPC0.FP_PIPELINE.6.0.CHECK_DEP.UN1983_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2087_REGDEPX\,
dataa => \GRFPC0.D.LDLCK_0_0_12__G1_1\);
\GRFPC0_D_LDLCK_RNO_0_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffeaafc00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_26__G1_4\,
dataf => \GRFPC0.D.LDLCK_0_0_26__G1_2\,
datae => \GRFPC0.N_23348_1\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_23299\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_0\(26),
dataa => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4271_REGDEPX\);
\GRFPU0_GRFPU_X0_L2_0_5_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fcff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_5\(2),
dataf => \GRFPU0.GRFPU_X0.N_9487\,
datae => \GRFPU0.GRFPU_X0.N_9500\,
datad => \GRFPU0.GRFPU_X0.N_13718\,
datac => \GRFPU0.GRFPU_X0.TZI2\(5),
datab => \GRFPU0.GRFPU_X0.N_40\);
GRFPU0_GRFPU_X0_VALLOW_5_SQMUXA_0_O2_RNIG6OD9_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff3ff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_3__G0\,
dataf => \GRFPU0.GRFPU_X0.N_19690\,
datae => \GRFPU0.GRFPU_X0.N_6736\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => N_35);
GRFPU0_GRFPU_X0_VALLOW_5_SQMUXA_0_O2_RNIG6OD9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ccc0")
port map (
combout => \GRFPU0.GRFPU_X0.N_10088_1\,
dataf => \GRFPU0.GRFPU_X0.N_19690\,
datae => \GRFPU0.GRFPU_X0.N_6736\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => N_35);
\GRFPC0_FP_PIPELINE_3_0_REGDEPX_60_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff8f0000ff880000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.0.REGDEPX_60\(1),
dataf => \GRFPC0.N_23178_1\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_23334\,
datac => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1015_REGDEPX_I_1\,
datab => \GRFPC0.N_24926\,
dataa => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1047_REGDEPX\);
GRFPC0_FP_PIPELINE_VDIV_VALID2_0_RNIC8NH1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cccc0000cfcc")
port map (
combout => \GRFPC0.DIV.EXEC_0_0_G0_2_0\,
dataf => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datae => \GRFPC0.FP_PIPELINE.VDIV.VALID2_0\,
datad => \GRFPC0.FP_PIPELINE.UN68_HOLDN_3\,
datac => \GRFPC0.WR2.RREG.RESV\,
datab => \GRFPC0.DIV.EXEC\);
\GRFPC0_FP_PIPELINE_VDIV_RD_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0ccf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
dataf => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datae => \GRFPC0.FP_PIPELINE.UN68_HOLDN_3\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RD\(1),
datab => \GRFPC0.WR2.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_VDIV_RD_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0ccf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
dataf => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datae => \GRFPC0.FP_PIPELINE.UN68_HOLDN_3\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.WR2.CTRL.RD\(2));
\GRFPC0_FP_PIPELINE_VDIV_RD_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0ccf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
dataf => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datae => \GRFPC0.FP_PIPELINE.UN68_HOLDN_3\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RD\(3),
datab => \GRFPC0.WR2.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_VDIV_RD_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0ccf0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
dataf => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datae => \GRFPC0.FP_PIPELINE.UN68_HOLDN_3\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.WR2.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_VDIV_RDD_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccccf0cccc")
port map (
combout => \GRFPC0.N_74_I_I\,
dataf => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datae => \GRFPC0.FP_PIPELINE.UN68_HOLDN_3\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.CTRL.RDD\,
datab => \GRFPC0.DIV.RDD\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffeca0")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_5\(0),
dataf => \GRFPC0.N_25171\,
datae => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_2\(0),
datad => \GRFPC0.N_24765_1\,
datac => \GRFPC0.N_25676_1\,
datab => \GRFPC0.FP_PIPELINE.13.REGDEPX2_400_0_A2_2_0\(1),
dataa => \GRFPC0.N_24168_1\);
\GRFPC0_D_STLCK_RNO_1_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff05cdffff00cc")
port map (
combout => \GRFPC0.D.STLCK_0_0_29__G1_5\,
dataf => \GRFPC0.N_23512\,
datae => \GRFPC0.D.STLCK_0_0_29__G1_3\,
datad => \GRFPC0.N_543_1\,
datac => \GRFPC0.N_23177\,
datab => \GRFPC0.N_23201_2\,
dataa => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_FP_PIPELINE_12_0_REGDEPX_221_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff88fff0fff8")
port map (
combout => \GRFPC0.FP_PIPELINE.12.0.REGDEPX_221\(1),
dataf => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datae => \GRFPC0.N_23916\,
datad => \GRFPC0.N_24839\,
datac => \GRFPC0.FP_PIPELINE.12.0.REGDEPX_221_0_A2_0\(1),
datab => \GRFPC0.N_24892\,
dataa => \GRFPC0.FIFO.INST_0\(17));
\GRFPC0_D_LDLCK_RNO_1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff8000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_5__G1_2\,
dataf => \GRFPC0.N_25336\,
datae => \GRFPC0.D.LDLCK_0_0_5__G1_0\,
datad => \GRFPC0.N_23976\,
datac => \GRFPC0.N_25357_1\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
dataa => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN928_REGDEPX_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3a0a2a2a30000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(20),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_37_1\(9),
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_20__G5\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(20));
\GRFPC0_D_STLCK_RNO_2_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff40ff4040")
port map (
combout => \GRFPC0.D.STLCK_0_0_2__G1_1\,
dataf => \GRFPC0.N_22855\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(0),
datad => \GRFPC0.N_22820\,
datac => \GRFPC0.N_9474\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
dataa => \GRFPC0.N_61_I\);
GRFPU0_GRFPU_X0_COMB_ORV_TMP_5_I_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18662\,
dataf => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_12\(0),
datae => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_13\(0),
datad => \GRFPU0.MULO.MRES\(96),
datac => \GRFPU0.MULO.MRES\(95),
datab => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_16\(0));
\GRFPU0_GRFPU_X0_UN1_INC_SP_I_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18635\,
dataf => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_12\(0),
datae => \GRFPU0.MULO.MRES\(97),
datad => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_13\(0),
datac => \GRFPU0.MULO.MRES\(95),
datab => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_16\(0));
GRFPC0_FP_PIPELINE_11_1_CHECK_DEP_UN3616_REGDEPX_1_I_O4_RNIOV3R2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000c0")
port map (
combout => \GRFPC0.N_23108\,
dataf => \GRFPC0.STDEP_0_SQMUXA_81_2_I\,
datae => N_40557,
datad => \GRFPC0.N_24936\,
datac => \GRFPC0.FIFO.INST_1\(28),
datab => \GRFPC0.FIFO.INST_1\(29));
\GRFPC0_D_STLCK_RNO_1_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff8fff8f8")
port map (
combout => \GRFPC0.D.STLCK_0_0_14__G1_3\,
dataf => \GRFPC0.N_25078\,
datae => \GRFPC0.N_21866\,
datad => N_99871,
datac => \GRFPC0.D.STLCK_0_0_14__G1_0\,
datab => \GRFPC0.N_21454\,
dataa => \GRFPC0.N_21899\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff003fc0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16073\,
dataf => \GRFPU0.GRFPU_X0.N_18195\,
datae => N_32527,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(59));
GRFPU0_GRFPU_X0_UN1_ST3_REG_ANC9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => N_32545,
dataf => N_32527,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(61),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(59));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_0_A2_0_0_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000003f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_0_A2_0\(15),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datae => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_2\,
datac => \GRFPU0.GRFPU_X0.N_19553\,
datab => \GRFPU0.GRFPU_X0.REST_2\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_ALLOW_1_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f030fffff030")
port map (
combout => \GRFPU0.GRFPU_X0.N_15365\,
dataf => \GRFPU0.GRFPU_X0.N_13485\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ALLOW_1_SN_N_3\,
datad => \GRFPU0.GRFPU_X0.N_5987\,
datac => \GRFPU0.GRFPU_X0.N_128\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_L4_4_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3fff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4\(4),
dataf => \GRFPU0.GRFPU_X0.N_9672\,
datae => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(4),
datad => \GRFPU0.GRFPU_X0.N_9671\,
datac => \GRFPU0.GRFPU_X0.N_9673\,
datab => \GRFPU0.GRFPU_X0.L3_2\(5));
\GRFPC0_D_STLCK_RNO_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffff3000")
port map (
combout => \GRFPC0.D.STLCK_0_0_20__G1\,
dataf => N_40688,
datae => \GRFPC0.D.STLCK_0_0_20__G1_7\,
datad => \GRFPC0.N_24455_I\,
datac => \GRFPC0.N_24463_2\,
datab => \GRFPC0.N_24449_I\);
GRFPU0_GRFPU_X0_VITER_EXP_0_SQMUXA_1_I_0_1_RNILE5E8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcfff0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17818\,
dataf => \GRFPU0.GRFPU_X0.N_188\,
datae => \GRFPU0.GRFPU_X0.N_236\,
datad => \GRFPU0.GRFPU_X0.N_18408_1\,
datac => \GRFPU0.GRFPU_X0.N_3560_I\,
datab => \GRFPU0.GRFPU_X0.N_191_5\);
\GRFPC0_D_STLCK_RNO_5_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5fff173300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_A2_1_1\(1),
dataf => \GRFPC0.N_92_I\,
datae => \GRFPC0.N_21616\,
datad => \GRFPC0.N_860\,
datac => \GRFPC0.N_470\,
datab => \GRFPC0.WR.CTRL.RDD\,
dataa => \GRFPC0.N_579\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f4ffff00040000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(51),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_22__G1\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.OUT_1\(84),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_RNO_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0fffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_17807\,
dataf => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(2),
datae => \GRFPU0.GRFPU_X0.N_16197_M\,
datad => \GRFPU0.GRFPU_X0.COMB.UN13_ITER_OF\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER_OF_1\,
datab => \GRFPU0.GRFPU_X0.ITER.DP\);
GRFPU0_GRFPU_X0_ST3_QSNAN_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_20518\,
dataf => \GRFPU0.GRFPU_X0.N_5768\,
datae => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(4),
datad => \GRFPU0.GRFPU_X0.ST2.QSNAN\);
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fffc00000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14998\,
dataf => \GRFPU0.GRFPU_X0.N_10059_I\,
datae => \FPI.OP2\(58),
datad => \FPI.OP2\(55),
datac => \FPI.OP2\(56),
datab => \FPI.OP2\(57));
GRFPU0_GRFPU_X0_UN38_EXP_1_CO4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN38_EXP_1_CO4\,
dataf => \FPI.OP2\(58),
datae => \FPI.OP2\(55),
datad => \FPI.OP2\(56),
datac => \FPI.OP2\(59),
datab => \FPI.OP2\(57));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_A2_3_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000300000")
port map (
combout => \GRFPU0.GRFPU_X0.N_291\,
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_19547\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_S_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => N_67750,
dataf => \GRFPU0.GRFPU_X0.N_19547\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff0e0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270\(0),
dataf => \GRFPC0.FP_PIPELINE.8.REGDEPX2_250\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_4\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_2_0\(0),
datac => \GRFPC0.N_24386\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_2_1\(0),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\);
\GRFPC0_D_LDLCK_RNO_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff0f3")
port map (
combout => \GRFPC0.D.LDLCK_0_0_26__G1\,
dataf => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415\(0),
datae => \GRFPC0.D.LDLCK_0_0_26__G1_4\,
datad => \GRFPC0.N_21246\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_1\(0),
datab => N_99871);
GRFPU0_GRFPU_X0_COMB_UN1_VITER_FLUSH0_2_SQMUXA_RNIPND19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffcff30")
port map (
combout => \GRFPU0.GRFPU_X0.N_10060\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_18516\,
datad => \GRFPU0.GRFPU_X0.ST4.SEL_0_0_0_0__G0_0_TZ_0\,
datac => \GRFPU0.GRFPU_X0.N_18523\,
datab => \GRFPU0.GRFPU_X0.N_18454\);
GRFPU0_GRFPU_X0_COMB_UN9_G_DP_RNI05L45: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff00fcf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_I_O3_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.S_SP_1_1\,
datae => \GRFPU0.GRFPU_X0.N_6039\,
datad => \GRFPU0.GRFPU_X0.N_8976\,
datac => \GRFPU0.GRFPU_X0.N_8975\,
datab => \GRFPU0.GRFPU_X0.S3ADDI\(28));
\GRFPC0_D_STLCK_RNO_2_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff33ff00ffb3ffa0")
port map (
combout => \GRFPC0.D.STLCK_0_0_20__G1_4\,
dataf => \GRFPC0.N_21948_1\,
datae => \GRFPC0.N_176\,
datad => \GRFPC0.D.STLCK_0_0_20__G1_2\,
datac => \GRFPC0.N_24463_2\,
datab => N_99871,
dataa => \GRFPC0.N_24449_I\);
\GRFPC0_D_STLCK_RNO_5_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffefee")
port map (
combout => \GRFPC0.D.STLCK_0_0_23__G1_4\,
dataf => \GRFPC0.N_23415\,
datae => \GRFPC0.D.STLCK_0_0_23__G1_3\,
datad => \GRFPC0.N_23491\,
datac => \GRFPC0.N_664\,
datab => \GRFPC0.D.STLCK_0_0_23__G1_0\,
dataa => \GRFPC0.N_23431\);
GRFPU0_GRFPU_X0_COMB_INCX_1_M2S2_I_A2_0_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000c00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18629_2\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2S2_I_A2_1_1\,
datae => \GRFPU0.GRFPU_X0.N_9402\,
datad => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_15\(0),
datac => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_16\(0));
GRFPU0_GRFPU_X0_UN28_EXP_ANC4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => N_32406,
dataf => \FPI.OP2\(55),
datae => \FPI.OP2\(56),
datad => \FPI.OP2\(52),
datac => \FPI.OP2\(53),
datab => \FPI.OP2\(54));
GRFPU0_GRFPU_X0_UN28_EXP_ANC3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => N_32401,
dataf => \FPI.OP2\(55),
datae => \FPI.OP2\(52),
datad => \FPI.OP2\(53),
datac => \FPI.OP2\(54));
GRFPU0_GRFPU_X0_UN28_EXP_ANC2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => N_32396,
dataf => \FPI.OP2\(52),
datae => \FPI.OP2\(53),
datad => \FPI.OP2\(54));
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_A3_2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff003300f0f03030")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A3_2_0\,
dataf => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datae => \GRFPC0.N_467\,
datad => \GRFPC0.WR2.CTRL.RDD\,
datac => \GRFPC0.DIV.RDD\,
datab => \GRFPC0.MEM.CTRL.RD\(2));
\GRFPC0_FP_PIPELINE_0_STDEP_16_3_I_O2_2_1_O3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccccfff0fff0")
port map (
combout => \GRFPC0.N_458\,
dataf => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.DIV.RDD\,
datac => \GRFPC0.DIV.RD\(0),
datab => \GRFPC0.WR2.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_10_STDEP_416_3_0_A2_2_1_I_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3333ff0fff0f")
port map (
combout => \GRFPC0.N_481\,
dataf => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.DIV.RDD\,
datac => \GRFPC0.DIV.RD\(0),
datab => \GRFPC0.WR2.CTRL.RD\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_3_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffaaccc0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_3\(59),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_1\(59),
datae => \GRFPU0.GRFPU_X0.N_19547\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(59));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1332_DEP_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0c0c00ff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1332_DEP_0\,
dataf => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datae => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.DIV.RD\(1),
datac => \GRFPC0.WR2.CTRL.RD\(1),
datab => \GRFPC0.WR2.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_VFIFO_FULL_6_F0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f0ff00cc0c00c")
port map (
combout => \GRFPC0.FP_PIPELINE.VFIFO.FULL_6\,
dataf => \GRFPC0.VFIFO.WR_0_SQMUXA_3\,
datae => \FPI.START\,
datad => \GRFPC0.FIFO.WR\(0),
datac => \GRFPC0.FIFO.RD_3\(0),
datab => \GRFPC0.FIFO.FULL\);
GRFPC0_UN1_VFIFO_RD_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff0f00ff00f0ff0")
port map (
combout => \GRFPC0.FP_PIPELINE.VFIFO.FULL10\,
dataf => \GRFPC0.FIFO.WR\(0),
datae => \GRFPC0.VFIFO.WR_0_SQMUXA_3\,
datad => \GRFPC0.FIFO.RD_3\(0),
datac => \FPI.START\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M16_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_2_03\,
datad => \GRFPU0.GRFPU_X0.N_9666\,
datac => \GRFPU0.GRFPU_X0.N_9672\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M17_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_2_03\,
datad => \GRFPU0.GRFPU_X0.N_9666\,
datac => \GRFPU0.GRFPU_X0.N_9672\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M18_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_2_03\,
datad => \GRFPU0.GRFPU_X0.N_9666\,
datac => \GRFPU0.GRFPU_X0.N_9672\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M22_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_2_03\,
datad => \GRFPU0.GRFPU_X0.N_9666\,
datac => \GRFPU0.GRFPU_X0.N_9672\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M24_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_2_03\,
datad => \GRFPU0.GRFPU_X0.N_9666\,
datac => \GRFPU0.GRFPU_X0.N_9672\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M25_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_2_03\,
datad => \GRFPU0.GRFPU_X0.N_9666\,
datac => \GRFPU0.GRFPU_X0.N_9672\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M26_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_2_03\,
datad => \GRFPU0.GRFPU_X0.N_9666\,
datac => \GRFPU0.GRFPU_X0.N_9672\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M27_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_2_03\,
datad => \GRFPU0.GRFPU_X0.N_9666\,
datac => \GRFPU0.GRFPU_X0.N_9672\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M28_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_2_03\,
datad => \GRFPU0.GRFPU_X0.N_9666\,
datac => \GRFPU0.GRFPU_X0.N_9672\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M29_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_2_03\,
datad => \GRFPU0.GRFPU_X0.N_9666\,
datac => \GRFPU0.GRFPU_X0.N_9672\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M30_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_2_03\,
datad => \GRFPU0.GRFPU_X0.N_9666\,
datac => \GRFPU0.GRFPU_X0.N_9672\);
\GRFPU0_GRFPU_X0_ST3_EXC_RNO_0_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000333f")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1_0_F0_0_4__G0_1\,
dataf => \GRFPU0.GRFPU_X0.N_5937\,
datae => \GRFPU0.GRFPU_X0.N_6321\,
datad => \GRFPU0.GRFPU_X0.N_5768\,
datac => \GRFPU0.GRFPU_X0.N_5820\,
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(3));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccccccc3ccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16075\,
dataf => \GRFPU0.GRFPU_X0.N_18195\,
datae => N_32537,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(61),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(62));
\GRFPC0_D_LDLCK_RNO_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffeee")
port map (
combout => \GRFPC0.D.LDLCK_0_0_30__G1\,
dataf => \GRFPC0.FP_PIPELINE.REGDEPX2_1\(0),
datae => \GRFPC0.D.LDLCK_0_0_30__G1_3\,
datad => \GRFPC0.N_22837\,
datac => \GRFPC0.N_23122\,
datab => \GRFPC0.N_24857\,
dataa => \GRFPC0.N_24854\);
GRFPU0_GRFPU_X0_UN3_EXP_ANC3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => N_32594,
dataf => \FPI.OP1\(52),
datae => \FPI.OP1\(53),
datad => \FPI.OP1\(55),
datac => \FPI.OP1\(54));
GRFPU0_GRFPU_X0_UN3_EXP_ANC2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => N_32589,
dataf => \FPI.OP1\(52),
datae => \FPI.OP1\(53),
datad => \FPI.OP1\(54));
GRFPC0_FP_PIPELINE_UN3_FIFO_CLR: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"330033003f0f3300")
port map (
combout => \GRFPC0.FP_PIPELINE.UN3_FIFO_CLR\,
dataf => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2\,
datae => \GRFPC0.FP_PIPELINE.QNE2_I_A4_1\,
datad => \GRFPC0.FIFO_INC_5_SQMUXA_1\,
datac => \GRFPC0.N_23695\,
datab => \GRFPC0.EX.CTRL.PEND\);
\GRFPC0_D_LDLCK_RNO_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffcf0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_15__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240\(1),
datae => \GRFPC0.D.LDLCK_0_0_15__G1_3\,
datad => \GRFPC0.N_21638_1\,
datac => \GRFPC0.N_24962\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_8_0\(14));
\GRFPC0_D_LDLCK_RNO_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_0__G1_3\,
dataf => \GRFPC0.N_22983\,
datae => \GRFPC0.N_25063\,
datad => \GRFPC0.N_25062\,
datac => \GRFPC0.D.LDLCK_0_0_0__G1_0\,
datab => \GRFPC0.N_25042\);
\GRFPC0_D_LDLCK_RNO_1_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff8f8f8")
port map (
combout => \GRFPC0.D.LDLCK_0_0_26__G1_2\,
dataf => \GRFPC0.N_23265\,
datae => \GRFPC0.N_25795_1\,
datad => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4360_REGDEPX\,
datac => \GRFPC0.N_23266\,
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4375_REGDEPX\,
dataa => \GRFPC0.N_24849_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_1_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccf0f0f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16621\,
dataf => \GRFPU0.GRFPU_X0.N_6509_I_M\,
datae => \GRFPU0.GRFPU_X0.N_18408_1\,
datad => \GRFPU0.GRFPU_X0.N_145\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(18));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_1_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccf0f0f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16624\,
dataf => \GRFPU0.GRFPU_X0.N_6509_I_M\,
datae => \GRFPU0.GRFPU_X0.N_18408_1\,
datad => \GRFPU0.GRFPU_X0.N_145\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(21));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_1_I_M2_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccf0f0f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.N_18681\,
dataf => \GRFPU0.GRFPU_X0.N_6509_I_M\,
datae => \GRFPU0.GRFPU_X0.N_18408_1\,
datad => \GRFPU0.GRFPU_X0.N_145\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(22));
\GRFPC0_D_LDLCK_RNO_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0f00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_31__G1\,
dataf => \GRFPC0.FP_PIPELINE.REGDEPX2_1\(1),
datae => \GRFPC0.D.LDLCK_0_0_31__G1_2\,
datad => \GRFPC0.N_23122\,
datac => N_40557);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0003000f000f0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(37),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV\(37),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => N_93115,
datac => \GRFPU0.GRFPU_X0.N_5673_0\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPC0_D_LDLCK_RNO_1_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff8ff88ff88ff88")
port map (
combout => \GRFPC0.D.LDLCK_0_0_16__G1_1\,
dataf => \GRFPC0.N_21186_1\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datad => \GRFPC0.N_21184\,
datac => \GRFPC0.N_24818\,
datab => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2815_REGDEPX\,
dataa => \GRFPC0.N_24849_1\);
GRFPC0_FP_PIPELINE_UN6_FIFOV_RNIVVLH: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00fffc03ff00")
port map (
combout => \FPI.OPID\(0),
dataf => \FPI.START\,
datae => \GRFPC0.FP_PIPELINE.UN6_FIFOV\,
datad => \GRFPC0.EX.CTRL.ID\(0),
datac => N_179,
datab => N_180);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ffc0fff0ff00")
port map (
combout => CPO_LDLOCKZ,
dataf => \GRFPC0.N_21933\,
datae => \GRFPC0.N_21984\,
datad => \GRFPC0.N_21108\,
datac => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_0\,
datab => N_99);
\GRFPC0_D_LDLCK_RNO_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_11__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180\(1),
datae => \GRFPC0.D.LDLCK_0_0_11__G1_3\,
datad => \GRFPC0.D.STLCK_0_0_11__G3\,
datac => \GRFPC0.N_21638_1\,
datab => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1760_REGDEPX\);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1332_DEP_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1660_DEP_2\,
dataf => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datae => \GRFPC0.DIV.RD\(4),
datad => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.WR2.CTRL.RD\(4),
datab => \GRFPC0.WR2.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3628_DEP_1_I_O3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3f3f3f00ffffff")
port map (
combout => \GRFPC0.N_525\,
dataf => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datae => \GRFPC0.DIV.RD\(2),
datad => \GRFPC0.DIV.RD\(1),
datac => \GRFPC0.WR2.CTRL.RD\(1),
datab => \GRFPC0.WR2.CTRL.RD\(2));
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_O2_2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3f3f3ff00ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_2_0\(1),
dataf => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datae => \GRFPC0.DIV.RD\(2),
datad => \GRFPC0.DIV.RD\(1),
datac => \GRFPC0.WR2.CTRL.RD\(1),
datab => \GRFPC0.WR2.CTRL.RD\(2));
\GRFPC0_EX_RREG_EXCT_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f0f0f000000")
port map (
combout => N_27203,
dataf => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
datae => \GRFPC0.N_82\,
datad => \GRFPC0.EX.RREG.EXCT\(3),
datac => N_37);
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_I_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffccccccc0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18751_1\,
dataf => \GRFPU0.GRFPU_X0.N_18768\,
datae => \FPI.OP1\(52),
datad => \FPI.OP1\(53),
datac => \FPI.OP1\(54),
datab => \FPI.FLOP\(1));
\GRFPC0_D_STLCK_RNO_0_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff08")
port map (
combout => \GRFPC0.D.STLCK_0_0_12__G1_2\,
dataf => \GRFPC0.N_22446\,
datae => \GRFPC0.N_22454\,
datad => \GRFPC0.N_22453\,
datac => \GRFPC0.N_61_I\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
dataa => \GRFPC0.N_9479\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"9000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6\,
dataf => \GRFPU0.GRFPU_X0.N_18528_I\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_0\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_1\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_2\,
datab => \FPO.IDOUT\(2),
dataa => \GRFPC0.WR2.CTRL.ID\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(27),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16747\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(27),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(27));
\GRFPU0_GRFPU_X0_COMB_EXP_14_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXP_14\(10),
dataf => N_32669,
datae => \GRFPU0.GRFPU_X0.COMB.EXP57\,
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(9),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(10));
GRFPC0_DIV_EXEC_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000cc00c0")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.EXEC_1\,
dataf => \GRFPC0.VDIV.EXEC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datad => \GRFPC0.FP_PIPELINE.VDIV.VALID2_0\,
datac => \GRFPC0.DIV.EXEC\,
datab => N_35);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_1_6_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_1_6\(24),
dataf => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_1_0\(24),
datae => \GRFPC0.N_25672\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_1_1\(24),
datac => \GRFPC0.N_25676_1\,
datab => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5591_REGDEPX2\);
\GRFPC0_D_STLCK_RNO_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff7f0f0")
port map (
combout => \GRFPC0.D.STLCK_0_0_2__G1_3\,
dataf => \GRFPC0.N_22854\,
datae => \GRFPC0.N_22157\,
datad => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datac => \GRFPC0.D.STLCK_0_0_2__G1_1\,
datab => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.DEP_2_I\(0),
dataa => \GRFPC0.N_128\);
GRFPU0_GRFPU_X0_UN28_EXP_ANC5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => N_32411,
dataf => \GRFPU0.GRFPU_X0.N_18882_1\,
datae => \FPI.OP2\(55),
datad => \FPI.OP2\(56),
datac => \FPI.OP2\(54),
datab => \FPI.OP2\(57));
GRFPC0_FP_PIPELINE_UN24_FPUSTART_RNIEN5F: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff0f0f0f0f0f0f0")
port map (
combout => \FPI.OPID\(2),
dataf => \GRFPC0.FP_PIPELINE.UN24_FPUSTART\,
datae => \GRFPC0.EX.CTRL.ID\(0),
datad => \GRFPC0.EX.CTRL.ID\(1),
datac => \GRFPC0.EX.CTRL.ID\(2));
GRFPC0_FP_PIPELINE_UN24_FPUSTART_RNICGQJ: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccccccccccccccc")
port map (
combout => \FPI.OPID\(3),
dataf => \GRFPC0.FP_PIPELINE.UN24_FPUSTART\,
datae => \GRFPC0.EX.CTRL.ID\(0),
datad => \GRFPC0.EX.CTRL.ID\(1),
datac => \GRFPC0.EX.CTRL.ID\(2),
datab => \GRFPC0.EX.CTRL.ID\(3));
\GRFPC0_D_STLCK_RNO_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0fffffeff")
port map (
combout => \GRFPC0.D.STLCK_0_0_19__G1\,
dataf => \GRFPC0.N_757\,
datae => \GRFPC0.N_747\,
datad => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_O2_1_0_TZ\(1),
datac => \GRFPC0.D.STLCK_0_0_19__G1_1\,
datab => \GRFPC0.N_735\,
dataa => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_2\(0));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"faaafeeef000fccc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_9__G1\,
dataf => \GRFPU0.GRFPU_X0.N_19016\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2\(17),
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(35),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(38));
\GRFPU0_GRFPU_X0_COMB_UN6_FLUSH_ALTB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcc000f000f0c0fc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.ALTB\(1),
dataf => \GRFPC0.FP_PIPELINE.UN24_FPUSTART\,
datae => \GRFPC0.EX.CTRL.ID\(0),
datad => \GRFPC0.EX.CTRL.ID\(1),
datac => \FPI.FLUSHID\(1),
datab => \FPI.FLUSHID\(0));
\GRFPC0_D_LDLCK_RNO_1_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff8f8f8")
port map (
combout => \GRFPC0.D.LDLCK_0_0_23__G1_2\,
dataf => \GRFPC0.N_23421\,
datae => \GRFPC0.N_21639_2\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\(23),
datac => \GRFPC0.N_23418\,
datab => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3736_REGDEPX\,
dataa => \GRFPC0.N_23988_1\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M0_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_2_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(3),
datae => \GRFPU0.GRFPU_X0.L4_4\(2),
datad => \GRFPU0.GRFPU_X0.L4_4\(0),
datac => \GRFPU0.GRFPU_X0.L4_4\(1),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(0));
\GRFPC0_D_LDLCK_RNO_1_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff8ff88ff88ff88")
port map (
combout => \GRFPC0.D.LDLCK_0_0_11__G1_1\,
dataf => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1879_REGDEPX_1\,
datae => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1879_REGDEPX_2\,
datad => \GRFPC0.N_21639\,
datac => \GRFPC0.N_25355_2\,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1864_REGDEPX\,
dataa => \GRFPC0.N_23988_1\);
\GRFPC0_D_LDLCK_RNO_1_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff888f888f888")
port map (
combout => \GRFPC0.D.LDLCK_0_0_25__G1_1\,
dataf => \GRFPC0.N_25355_2\,
datae => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4063_REGDEPX\,
datad => \GRFPC0.N_9465\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A3_5_0\(25),
datab => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4048_REGDEPX\,
dataa => \GRFPC0.N_23988_1\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"faaafeeef000fccc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_10__G1\,
dataf => \GRFPU0.GRFPU_X0.N_19016\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2\(18),
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(36),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(39));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"faaafeeef000fccc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_11__G1\,
dataf => \GRFPU0.GRFPU_X0.N_19016\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2\(19),
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(37),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(40));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0051")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_2\(1),
datad => \GRFPU0.GRFPU_X0.N_4260\,
datac => \GRFPU0.GRFPU_X0.N_91\,
datab => \GRFPU0.GRFPU_X0.C\(7),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_I_M4_RNIIIK12_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"a088a0aaf0ccf0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1__G1_1\,
dataf => \GRFPU0.GRFPU_X0.N_391\,
datae => \GRFPU0.GRFPU_X0.N_19905\,
datad => \GRFPU0.GRFPU_X0.N_18983_I\,
datac => \GRFPU0.GRFPU_X0.N_19931\,
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(1),
dataa => \FPI.OP1_RETO\(1));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3628_DEP_0_A3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3628_DEP\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN4940_DEP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4940_DEP\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2));
GRFPC0_FP_PIPELINE_7_STDEP1186_0_A2_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fffffffffffff")
port map (
combout => \GRFPC0.N_22325\,
dataf => \GRFPC0.N_481\,
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2));
\GRFPC0_D_STLCK_RNO_4_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A2_7_0\(1),
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.N_21822\);
\GRFPU0_GRFPU_X0_L4_6_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3fff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_6\(4),
dataf => \GRFPU0.GRFPU_X0.N_9548\,
datae => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(4),
datad => \GRFPU0.GRFPU_X0.N_9547\,
datac => \GRFPU0.GRFPU_X0.N_9549\,
datab => \GRFPU0.GRFPU_X0.L3_0_4_2\(5));
GRFPU0_GRFPU_X0_UN3_EXP_ANC5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => N_32604,
dataf => \GRFPU0.GRFPU_X0.N_18772\,
datae => \FPI.OP1\(55),
datad => \FPI.OP1\(56),
datac => \FPI.OP1\(54),
datab => \FPI.OP1\(57));
\GRFPC0_FP_PIPELINE_5_STDEP_212_3_0_A3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_21701\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2));
\GRFPC0_FP_PIPELINE_4_CHECK_DEP_DEP_26_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_26\(1),
dataf => \GRFPC0.N_458\,
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2));
GRFPC0_FP_PIPELINE_14_STDEP2363_I_O2_I_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf000000000")
port map (
combout => \GRFPC0.N_23842\,
dataf => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4612_DEP\,
datae => \GRFPC0.N_74_I_I\,
datad => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datac => \GRFPC0.DIV.RD\(0),
datab => \GRFPC0.WR2.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_7_STDEP_292_3_I_A2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf000000000")
port map (
combout => \GRFPC0.N_21878_1\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datae => \GRFPC0.N_74_I_I\,
datad => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datac => \GRFPC0.DIV.RD\(0),
datab => \GRFPC0.WR2.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_21496\,
dataf => \GRFPC0.N_805\,
datae => \GRFPC0.N_21524\,
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datab => \GRFPC0.N_74_I_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_11_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfc0cfc0c0cfc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(2),
dataf => \GRFPU0.GRFPU_X0.L3_0_3\(0),
datae => \GRFPU0.GRFPU_X0.L3_0_3\(1),
datad => \GRFPU0.GRFPU_X0.L3_0_3\(2),
datac => \GRFPU0.GRFPU_X0.N_19742\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(2));
GRFPU0_GRFPU_X0_VITER_DBUF_7_1_CO2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff00ffffff")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.DBUF_7_1_CO2\,
dataf => \GRFPU0.GRFPU_X0.L3_0_3\(0),
datae => \GRFPU0.GRFPU_X0.L3_0_3\(1),
datad => \GRFPU0.GRFPU_X0.L3_0_3\(2));
\GRFPC0_D_LDLCK_RNO_0_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000ffc0c0c0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_6__G1_0\,
dataf => \GRFPC0.N_25036\,
datae => \GRFPC0.N_23184_2\,
datad => \GRFPC0.N_25341_1\,
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN928_REGDEPX_2\,
datab => \GRFPC0.N_25795_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffd5ffffffc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(48),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(48),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(48),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(48),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
dataa => \GRFPU0.GRFPU_X0.N_18664\);
\GRFPC0_D_LDLCK_RNO_0_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff8")
port map (
combout => \GRFPC0.D.LDLCK_0_0_29__G1_3\,
dataf => \GRFPC0.N_24942\,
datae => \GRFPC0.N_24948\,
datad => \GRFPC0.N_24944\,
datac => \GRFPC0.N_24945\,
datab => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4672_REGDEPX\,
dataa => \GRFPC0.N_23988_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ffddf0f0ffcc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(16),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(16),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(16),
datac => \GRFPU0.GRFPU_X0.N_16099\,
datab => \GRFPU0.GRFPU_X0.MULO_M\(76),
dataa => \GRFPU0.GRFPU_X0.N_18664\);
GRFPC0_VFIFO_FULL_3_SQMUXA_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000303")
port map (
combout => \GRFPC0.VFIFO.FULL_3_SQMUXA_0\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE2_1\,
datae => \GRFPC0.FIFO_INC_5_SQMUXA\,
datad => \GRFPC0.N_23695\,
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD10\,
datab => \GRFPC0.DIV.EXC_MB_2_I_0\);
\GRFPC0_FIFO_WR_RNO_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0303030003030303")
port map (
combout => \GRFPC0.FIFO.WR_0_0_0__G3_0_0\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE2_1\,
datae => \GRFPC0.FIFO_INC_5_SQMUXA\,
datad => \GRFPC0.N_23695\,
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD10\,
datab => \GRFPC0.DIV.EXC_MB_2_I_0\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"faaafeeef000fccc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_8__G1\,
dataf => \GRFPU0.GRFPU_X0.N_19016\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2\(16),
datac => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(34),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(37));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffd5ffffffc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(49),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(49),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(49),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(49),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(49),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
dataa => \GRFPU0.GRFPU_X0.N_18664\);
GRFPC0_FP_PIPELINE_4_STDEP682: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000300000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP682\,
dataf => \GRFPC0.N_481\,
datae => \GRFPC0.N_458\,
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1660_DEP_2\,
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1));
\GRFPU0_GRFPU_X0_L4_7_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3fff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_7\(4),
dataf => \GRFPU0.GRFPU_X0.L2_0_5\(4),
datae => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(4),
datad => \GRFPU0.GRFPU_X0.L1_2_3\(3),
datac => \GRFPU0.GRFPU_X0.L3_0_3_1\(5),
datab => \GRFPU0.GRFPU_X0.UN53_BCO_LSB\(15));
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_26_I_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcfffffffffff")
port map (
combout => \GRFPC0.N_21943\,
dataf => \GRFPC0.N_458\,
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2));
\GRFPC0_D_LDLCK_RNO_1_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff8f8f8f8f8f8f8")
port map (
combout => \GRFPC0.D.LDLCK_0_0_12__G1_1\,
dataf => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2191_REGDEPX_0\,
datae => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2191_REGDEPX_1\,
datad => \GRFPC0.N_24849_1\,
datac => \GRFPC0.N_22035\,
datab => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2176_REGDEPX\,
dataa => \GRFPC0.N_25795_1\);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fcf0f03cfcf0303")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_0__N_6\,
dataf => \GRFPU0.GRFPU_X0.N_7278\,
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(0),
datad => \GRFPU0.GRFPU_X0.N_3274\,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datab => \GRFPU0.GRFPU_X0.ST3.DIFFV\);
\GRFPU0_GRFPU_X0_COMB_UN1_L4_ALTB_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0fcccff00ccc0fc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_L4.ALTB\(3),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_L4.ALTB\(1),
datae => \GRFPU0.GRFPU_X0.L4_3\(2),
datad => \GRFPU0.GRFPU_X0.L4_3\(3),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(3));
\GRFPC0_D_STLCK_RNO_1_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eaffffffffffffff")
port map (
combout => \GRFPC0.D.STLCK_0_0_18__G1_3\,
dataf => \GRFPC0.FP_PIPELINE.9.0.STDEP_385_I_TZ\(0),
datae => \GRFPC0.FP_PIPELINE.9.STDEP_390_I_TZ\(0),
datad => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_TZ\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(0),
datab => \GRFPC0.N_854\,
dataa => \GRFPC0.D.STLCK_0_0_18__G1_TZ\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fdfdff00fcfc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(31),
dataf => \GRFPU0.GRFPU_X0.N_18685\,
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_16114\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(31),
datab => \GRFPU0.GRFPU_X0.MULO_M\(91),
dataa => \GRFPU0.GRFPU_X0.N_18664\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffba30")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(33),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(33),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(33),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => N_99921,
datab => \GRFPU0.MULO.MRES\(94),
dataa => \GRFPU0.MULO.MRES\(93));
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_O3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff2fff0")
port map (
combout => \GRFPC0.N_65\,
dataf => \GRFPC0.N_21227_2\,
datae => \GRFPC0.N_23818_2\,
datad => \GRFPC0.N_21212\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O3_0_1\,
datab => \GRFPC0.N_74_I_I\,
dataa => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A2_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_6_0_4_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000003000000020")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6_0_4\(43),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(43),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_18366\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6_0_0\(43),
datab => \GRFPU0.GRFPU_X0.N_18365\,
dataa => \GRFPU0.GRFPU_X0.N_18664\);
\GRFPC0_D_LDLCK_RNO_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff80")
port map (
combout => \GRFPC0.D.LDLCK_0_0_17__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270\(1),
datae => \GRFPC0.FP_PIPELINE.8.REGDEPX_156\(1),
datad => \GRFPC0.D.LDLCK_0_0_17__G1_0\,
datac => \GRFPC0.N_9481\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_0_0\(3),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_OP\);
\GRFPC0_D_STLCK_RNO_2_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffeaff")
port map (
combout => \GRFPC0.D.STLCK_0_0_5__G1_3\,
dataf => \GRFPC0.N_25336\,
datae => \GRFPC0.N_22779\,
datad => \GRFPC0.N_18150\,
datac => \GRFPC0.N_594\,
datab => \GRFPC0.N_21521\,
dataa => \GRFPC0.N_22753\);
GRFPU0_GRFPU_X0_COMB_VST4_REG30_RNIG0JI1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffffffcff33")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
dataf => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
datae => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(2),
datad => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(1),
datac => \GRFPU0.GRFPU_X0.N_5661\,
datab => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffcf0000000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(53),
dataf => \GRFPU0.GRFPU_X0.N_15666\,
datae => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
datad => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(2),
datac => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(1),
datab => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(0));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M0_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_0_03\,
datae => \GRFPU0.GRFPU_X0.L4_4\(3),
datad => \GRFPU0.GRFPU_X0.L4_4\(2),
datac => \GRFPU0.GRFPU_X0.N_9672\);
GRFPC0_WR2_CTRL_SEQERR_RNITTKJD: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffcfcfc")
port map (
combout => N_46992,
dataf => \GRFPC0.FPEXC_0_SQMUXA_D\,
datae => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datac => N_44718_1,
datab => \GRFPC0.WR2.CTRL.SEQERR\);
GRFPC0_VEX_CTRL_RDWR_0_SQMUXA_I_A2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3030ffff3000")
port map (
combout => CPO_EXCZ,
dataf => \GRFPC0.FPEXC_0_SQMUXA_D\,
datae => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datad => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => N_44718_1);
GRFPC0_FP_PIPELINE_UN24_OP_RNID5M4C: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000f000f0f0f0")
port map (
combout => N_47157_2,
dataf => \GRFPC0.FPEXC_0_SQMUXA_D\,
datae => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datac => \GRFPC0.FP_PIPELINE.UN24_OP\);
\GRFPC0_FIFO_VCNT_0_RNO_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f000000")
port map (
combout => N_47101,
dataf => \GRFPC0.FPEXC_0_SQMUXA_D\,
datae => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datac => \GRFPC0.FIFO.VCNT_0\(1));
\GRFPC0_R_FSR_TEM_RNI1RI1C_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff00ffffff")
port map (
combout => N_47093,
dataf => \GRFPC0.FPEXC_0_SQMUXA_D\,
datae => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\);
\GRFPC0_R_FSR_TEM_RNI139ED_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f000000")
port map (
combout => \GRFPC0.PENDEXC_0_SQMUXA\,
dataf => \GRFPC0.FPEXC_0_SQMUXA_D\,
datae => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datac => N_44718_1);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M1_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\,
datae => \GRFPU0.GRFPU_X0.L4_4\(3),
datad => \GRFPU0.GRFPU_X0.L4_4\(2),
datac => \GRFPU0.GRFPU_X0.N_9672\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M4_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0033000300300000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_0_03\,
datad => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.L4_4\(2),
datab => \GRFPU0.GRFPU_X0.N_9672\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fafa3a0afafa0a0a")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(59),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(59),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_2_3\(59),
datad => \GRFPU0.GRFPU_X0.N_394\,
datac => \GRFPU0.GRFPU_X0.N_19546\,
datab => \GRFPU0.GRFPU_X0.N_5250\,
dataa => \GRFPU0.GRFPU_X0.N_19902\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M2_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03\,
datae => \GRFPU0.GRFPU_X0.L4_4\(3),
datad => \GRFPU0.GRFPU_X0.L4_4\(2),
datac => \GRFPU0.GRFPU_X0.N_9672\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M3_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\,
datae => \GRFPU0.GRFPU_X0.L4_4\(3),
datad => \GRFPU0.GRFPU_X0.L4_4\(2),
datac => \GRFPU0.GRFPU_X0.N_9672\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_2_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_15607\,
dataf => \GRFPU0.GRFPU_X0.N_6806\,
datae => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
datad => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(2));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00fffffff0ff")
port map (
combout => \GRFPC0.N_22967\,
dataf => \GRFPC0.N_23043\,
datae => \GRFPC0.N_23032\,
datad => \GRFPC0.N_23041\,
datac => N_97);
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0cf00ff300000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(0),
dataf => \GRFPU0.GRFPU_X0.N_10059_I\,
datae => \FPI.OP2\(55),
datad => \FPI.OP2\(52),
datac => \FPI.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M6_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0033003000030000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03\,
datad => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.L4_4\(2),
datab => \GRFPU0.GRFPU_X0.N_9672\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M5_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0033003000030000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03\,
datad => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.L4_4\(2),
datab => \GRFPU0.GRFPU_X0.N_9672\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffb3ffffffa0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(9),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(9),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(9),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(9),
datac => \GRFPU0.GRFPU_X0.N_3560_I\,
datab => \GRFPU0.GRFPU_X0.N_18664\,
dataa => \GRFPU0.MULO.MRES\(69));
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2_7_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3ff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_7_0\,
dataf => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4612_DEP\,
datae => \GRFPC0.N_458\,
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2698_DEP_1\,
datac => \GRFPC0.N_473_1\,
datab => \GRFPC0.EX.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_A3_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c00000")
port map (
combout => \GRFPC0.N_119\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datae => \GRFPC0.N_102\,
datad => \GRFPC0.N_53\,
datac => N_99872,
datab => \GRFPC0.N_470\);
\GRFPC0_D_STLCK_RNO_4_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_23454\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datae => \GRFPC0.N_102\,
datad => \GRFPC0.N_23382\,
datac => \GRFPC0.N_23390\,
datab => \GRFPC0.N_664\);
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_O2_4_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00ffffff")
port map (
combout => \GRFPC0.N_514\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datae => \GRFPC0.N_102\,
datad => \GRFPC0.N_579\);
\GRFPC0_FP_PIPELINE_13_STDEP_536_3_I_O3_0_M4_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff0000")
port map (
combout => \GRFPC0.N_765\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datae => \GRFPC0.N_102\,
datad => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_D_STLCK_RNO_0_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfffcf00003000")
port map (
combout => \GRFPC0.N_23174\,
dataf => \GRFPC0.FP_PIPELINE.14.STDEP_568\(1),
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datad => \GRFPC0.N_102\,
datac => \GRFPC0.N_858\,
datab => \GRFPC0.N_470\);
\GRFPC0_FP_PIPELINE_3_STDEP_132_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3fff303030f03")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_132\(0),
dataf => \GRFPC0.FP_PIPELINE.3.STDEP_128\(0),
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datad => \GRFPC0.N_102\,
datac => \GRFPC0.FP_PIPELINE.3.STDEP_132_SEL0\,
datab => \GRFPC0.N_18634\);
\GRFPC0_FP_PIPELINE_3_STDEP_132_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3fff3f0303c303")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_132\(1),
dataf => \GRFPC0.FP_PIPELINE.3.STDEP_128\(1),
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datad => \GRFPC0.N_102\,
datac => \GRFPC0.FP_PIPELINE.3.STDEP_132_SEL0\,
datab => \GRFPC0.N_18634\);
\GRFPC0_FP_PIPELINE_9_STDEP_376_3_I_A2_1_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff000000ff")
port map (
combout => \GRFPC0.N_21951_1\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datae => \GRFPC0.N_102\,
datad => \GRFPC0.N_579\);
\GRFPC0_D_STLCK_RNO_4_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f070c040")
port map (
combout => \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_A2_1_4\(1),
dataf => \GRFPC0.N_169\,
datae => \GRFPC0.N_104\,
datad => \GRFPC0.N_114\,
datac => \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_A2_1_1\(1),
datab => \GRFPC0.N_21615\,
dataa => \GRFPC0.N_663\);
GRFPU0_GRFPU_X0_COMB_VITER_ALLOW_1_SN_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ALLOW_1_SN_N_3\,
dataf => \GRFPU0.GRFPU_X0.N_140\,
datae => \GRFPU0.GRFPU_X0.N_5987\,
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(15));
GRFPU0_GRFPU_X0_UN28_EXP_ANC6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => N_32416,
dataf => N_32396,
datae => \FPI.OP2\(58),
datad => \FPI.OP2\(55),
datac => \FPI.OP2\(56),
datab => \FPI.OP2\(57));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M7_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0033003000030000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03\,
datad => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.L4_4\(2),
datab => \GRFPU0.GRFPU_X0.N_9672\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffb3ffffffa0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(8),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(8),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(8),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(8),
datac => \GRFPU0.GRFPU_X0.N_3560_I\,
datab => \GRFPU0.GRFPU_X0.N_18664\,
dataa => \GRFPU0.MULO.MRES\(68));
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_A2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000c0000")
port map (
combout => \GRFPC0.N_21676\,
dataf => \GRFPC0.N_114\,
datae => \GRFPC0.N_21612\,
datad => \GRFPC0.N_860\,
datac => \GRFPC0.N_21610\,
datab => \GRFPC0.WR.CTRL.RDD\);
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000c0000")
port map (
combout => \GRFPC0.N_21579\,
dataf => \GRFPC0.N_114\,
datae => \GRFPC0.N_21581_2\,
datad => \GRFPC0.N_23806\,
datac => \GRFPC0.N_23802\,
datab => \GRFPC0.WR.CTRL.RDD\);
GRFPU0_GRFPU_X0_COMB_UNPACK_FLTYPE45: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7241\,
dataf => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE45_2\,
datae => \FPI.OP2\(58),
datad => \FPI.OP2\(60),
datac => \FPI.OP2\(59),
datab => \FPI.OP2\(57));
GRFPU0_GRFPU_X0_UN13_EXP_1_CO3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN13_EXP_1_CO3\,
dataf => \FPI.OP1\(55),
datae => \FPI.OP1\(56),
datad => \FPI.OP1\(58),
datac => \FPI.OP1\(57));
\GRFPC0_D_LDLCK_RNO_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPC0.D.LDLCK_0_0_24__G1\,
dataf => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_1\(24),
datae => \GRFPC0.N_23347\,
datad => \GRFPC0.N_23345\,
datac => \GRFPC0.N_23348\,
datab => \GRFPC0.N_23349\,
dataa => \GRFPC0.D.LDLCK_0_0_24__G1_1\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_0_1_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f0000003333")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1\(52),
dataf => \GRFPU0.GRFPU_X0.N_15611\,
datae => \GRFPU0.GRFPU_X0.N_14\,
datad => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
datac => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(2),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_2_I_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18444\,
dataf => \GRFPU0.GRFPU_X0.N_6806\,
datae => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
datad => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(2));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_2_I_A2_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18491\,
dataf => \GRFPU0.GRFPU_X0.N_6806\,
datae => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
datad => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(2));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_I_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff30ff00ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18443\,
dataf => \GRFPU0.GRFPU_X0.N_18467\,
datae => \GRFPU0.GRFPU_X0.N_15611\,
datad => \GRFPU0.GRFPU_X0.N_53\,
datac => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
datab => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(2));
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_M3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000f0f")
port map (
combout => \GRFPC0.N_21636\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.N_21612\,
datad => \GRFPC0.N_21610\,
datac => \GRFPC0.N_106_I\);
\GRFPC0_FP_PIPELINE_0_STDEP_482_0_IV_0_A2_6_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_482_0_IV_0_A2_6_1\(0),
dataf => \GRFPC0.N_481\,
datae => \GRFPC0.N_525\,
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datab => \GRFPC0.N_21729\);
\GRFPC0_D_STLCK_RNO_4_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c00000c0000000")
port map (
combout => N_40689,
dataf => \GRFPC0.N_22173_I\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datad => \GRFPC0.N_481\,
datac => \GRFPC0.N_458\,
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN2972_DEP\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfc0c0cfcfc0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(2),
dataf => \GRFPU0.GRFPU_X0.L4_1\(0),
datae => \GRFPU0.GRFPU_X0.L4_1_I\(1),
datad => \GRFPU0.GRFPU_X0.L4_1\(2),
datac => \GRFPU0.GRFPU_X0.N_4623_2\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(2));
GRFPU0_GRFPU_X0_VITER_DBUF_13_ANC3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000f0f0f000f")
port map (
combout => N_32333,
dataf => \GRFPU0.GRFPU_X0.L4_1\(0),
datae => \GRFPU0.GRFPU_X0.L4_1_I\(1),
datad => \GRFPU0.GRFPU_X0.L4_1\(2),
datac => \GRFPU0.GRFPU_X0.L4_1\(3));
\GRFPC0_D_STLCK_RNO_0_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffff0c0f")
port map (
combout => \GRFPC0.D.STLCK_0_0_22__G1_5\,
dataf => \GRFPC0.N_23383\,
datae => \GRFPC0.D.STLCK_0_0_22__G1_4\,
datad => \GRFPC0.N_114\,
datac => \GRFPC0.N_21729\,
datab => \GRFPC0.WR.CTRL.RDD\);
GRFPU0_GRFPU_X0_ST3_RDY_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.N_10041\,
dataf => \GRFPU0.GRFPU_X0.N_5775\,
datae => \GRFPU0.GRFPU_X0.ST3.RDY_0_0_G0_2\,
datad => \GRFPU0.GRFPU_X0.N_5987\,
datac => \GRFPU0.GRFPU_X0.N_5774\,
datab => \GRFPU0.GRFPU_X0.N_5773\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_O4_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33003300f3f03300")
port map (
combout => \GRFPU0.GRFPU_X0.N_19896\,
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datae => \GRFPU0.GRFPU_X0.N_394\,
datad => \GRFPU0.GRFPU_X0.N_18983_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
GRFPC0_FP_PIPELINE_UN1_PENDEXC_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333030033330000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_PENDEXC_1\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datac => N_44718_1,
datab => \GRFPC0.MEM.CTRL.LD\);
GRFPC0_FP_PIPELINE_UN26_PENDEXC: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3f33ffff3333")
port map (
combout => \GRFPC0.N_23673\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datac => N_44718_1,
datab => \GRFPC0.N_23695\);
GRFPC0_FP_PIPELINE_UN3_SHARE: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c0cc0000cccc")
port map (
combout => \GRFPC0.N_9163\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datac => N_44718_1,
datab => N_39);
GRFPC0_DIV_PEND_RNO_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c000c0c0c0c0c0c")
port map (
combout => \GRFPC0.N_23746\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datad => N_44718_1,
datac => \GRFPC0.N_23696\,
datab => \GRFPC0.DIV.PEND\);
\GRFPC0_RFA2_FID_RNO_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0cc00cc00cc00")
port map (
combout => \GRFPC0.FID_1_IV_0_0__G0_0\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datad => N_44718_1,
datac => \GRFPC0.WR2.CTRL.ID\(0),
datab => \GRFPC0.DIV.ID\(0));
\GRFPC0_RFA2_FID_RNO_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0cc00cc00cc00")
port map (
combout => \GRFPC0.FID_1_IV_0_1__G0_0\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datad => N_44718_1,
datac => \GRFPC0.WR2.CTRL.ID\(1),
datab => \GRFPC0.DIV.ID\(1));
\GRFPC0_RFA2_FID_RNO_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0cc00cc00cc00")
port map (
combout => \GRFPC0.FID_1_IV_0_2__G0_0\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datad => N_44718_1,
datac => \GRFPC0.WR2.CTRL.ID\(2),
datab => \GRFPC0.DIV.ID\(2));
\GRFPC0_RFA2_FID_RNO_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0cc00cc00cc00")
port map (
combout => \GRFPC0.FID_1_IV_0_3__G0_0\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datad => N_44718_1,
datac => \GRFPC0.WR2.CTRL.ID\(3),
datab => \GRFPC0.DIV.ID\(3));
\GRFPC0_RFA2_FID_RNO_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0cc00cc00cc00")
port map (
combout => \GRFPC0.FID_1_IV_0_4__G0_0\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datad => N_44718_1,
datac => \GRFPC0.WR2.CTRL.ID\(4),
datab => \GRFPC0.DIV.ID\(4));
\GRFPC0_RFA2_FID_RNO_1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0cc00cc00cc00")
port map (
combout => \GRFPC0.FID_1_IV_0_5__G0_0\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datad => N_44718_1,
datac => \GRFPC0.WR2.CTRL.ID\(5),
datab => \GRFPC0.DIV.ID\(5));
GRFPC0_EX_CTRL_LD_RNIQ2RQD: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0cfc0c0c0c0c0c0")
port map (
combout => N_44987,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datad => N_44718_1,
datac => \GRFPC0.EX.CTRL.LD\,
datab => N_39);
GRFPC0_V_FSR_FTT_2_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ccc0c000c000c00")
port map (
combout => \GRFPC0.V.FSR.FTT_2_SQMUXA\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datad => N_44718_1,
datac => \GRFPC0.DIV.EXCT\(5),
datab => N_35);
\GRFPC0_FP_PIPELINE_0_STDEP_482_0_IV_0_O2_7_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000003ff00ff")
port map (
combout => \GRFPC0.N_23383\,
dataf => \GRFPC0.N_571\,
datae => \GRFPC0.N_104\,
datad => \GRFPC0.N_23380\,
datac => \GRFPC0.N_23390\,
datab => \GRFPC0.N_579\);
\GRFPC0_FP_PIPELINE_9_STDEP_376_3_I_A2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3303000000000000")
port map (
combout => \GRFPC0.N_21951\,
dataf => \GRFPC0.N_104\,
datae => \GRFPC0.N_670\,
datad => \GRFPC0.N_449\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datab => \GRFPC0.N_579\);
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_A2_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c0000000c0c0")
port map (
combout => \GRFPC0.N_21678\,
dataf => \GRFPC0.N_841\,
datae => \GRFPC0.N_104\,
datad => \GRFPC0.N_21612\,
datac => \GRFPC0.N_860\,
datab => \GRFPC0.N_470\);
\GRFPC0_D_LDLCK_RNO_0_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffefffa")
port map (
combout => \GRFPC0.D.LDLCK_0_0_4__G1_6\,
dataf => \GRFPC0.N_22767\,
datae => \GRFPC0.N_22445_1\,
datad => \GRFPC0.N_22773\,
datac => \GRFPC0.D.LDLCK_0_0_4__G1_3\,
datab => \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.UN720_REGDEPX\,
dataa => \GRFPC0.D.LDLCK_0_0_4__G1_1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0f03000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(13),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_1\(13),
datae => \GRFPU0.GRFPU_X0.N_291\,
datad => \GRFPU0.GRFPU_X0.N_18983_I\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0f03000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(19),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_1\(19),
datae => \GRFPU0.GRFPU_X0.N_291\,
datad => \GRFPU0.GRFPU_X0.N_18983_I\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M39_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3726332215041100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(40),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_2_01\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_2_03\,
datac => \GRFPU0.GRFPU_X0.L4_4\(3),
datab => \GRFPU0.GRFPU_X0.N_9666\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4));
GRFPC0_STDDEP_0_SQMUXA_145: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccc0c0000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_145\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.4.STDEP682\,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_26\(1),
datac => \GRFPC0.N_74_I_I\,
datab => \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL0_1\);
GRFPC0_VFIFO_INST_0_1_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff0ffff")
port map (
combout => \GRFPC0.VFIFO.INST_0_1_0\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.VFIFO.WR_0_SQMUXA_3\,
datad => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datac => \GRFPC0.FIFO.WR\(0));
\GRFPC0_FP_PIPELINE_RS1_6_I_M2_2_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00ff00")
port map (
combout => \GRFPC0.N_23705\,
dataf => \GRFPC0.VFIFO.WR_0_SQMUXA_3\,
datae => \GRFPC0.FIFO.WR\(0),
datad => \GRFPC0.FIFO.INST_0\(16),
datac => N_94);
\GRFPC0_INST_I_M3_1_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00ff00")
port map (
combout => \GRFPC0.N_22827\,
dataf => \GRFPC0.VFIFO.WR_0_SQMUXA_3\,
datae => \GRFPC0.FIFO.WR\(0),
datad => \GRFPC0.FIFO.INST_0\(14),
datac => N_92);
\GRFPC0_VFIFO_INST_0_4_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00ff00")
port map (
combout => \GRFPC0.VFIFO.INST_0_4\(15),
dataf => \GRFPC0.VFIFO.WR_0_SQMUXA_3\,
datae => \GRFPC0.FIFO.WR\(0),
datad => \GRFPC0.FIFO.INST_0\(15),
datac => N_93);
GRFPU0_GRFPU_X0_UN13_EXP_1_CO5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN13_EXP_1_CO5\,
dataf => \GRFPU0.GRFPU_X0.UN13_EXP_1_CO1\,
datae => \FPI.OP1\(59),
datad => \FPI.OP1\(60),
datac => \FPI.OP1\(58),
datab => \FPI.OP1\(57));
GRFPC0_VFIFO_INST_1_1_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff0fffff")
port map (
combout => \GRFPC0.VFIFO.INST_1_1_0\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.VFIFO.WR_0_SQMUXA_3\,
datad => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datac => \GRFPC0.FIFO.WR\(0));
\GRFPC0_FP_PIPELINE_RS1_6_I_M2_3_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ff00ff00")
port map (
combout => \GRFPC0.N_23706\,
dataf => \GRFPC0.VFIFO.WR_0_SQMUXA_3\,
datae => \GRFPC0.FIFO.WR\(0),
datad => \GRFPC0.FIFO.INST_1\(16),
datac => N_94);
\GRFPC0_INST_I_M3_0_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ff00ff00")
port map (
combout => \GRFPC0.N_22826\,
dataf => \GRFPC0.VFIFO.WR_0_SQMUXA_3\,
datae => \GRFPC0.FIFO.WR\(0),
datad => \GRFPC0.FIFO.INST_1\(14),
datac => N_92);
\GRFPC0_VFIFO_INST_1_4_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ff00ff00")
port map (
combout => \GRFPC0.VFIFO.INST_1_4\(15),
dataf => \GRFPC0.VFIFO.WR_0_SQMUXA_3\,
datae => \GRFPC0.FIFO.WR\(0),
datad => \GRFPC0.FIFO.INST_1\(15),
datac => N_93);
GRFPU0_GRFPU_X0_UN28_EXP_ANC7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => N_32421,
dataf => N_32401,
datae => \FPI.OP2\(58),
datad => \FPI.OP2\(56),
datac => \FPI.OP2\(59),
datab => \FPI.OP2\(57));
\GRFPC0_D_LDLCK_RNO_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc8")
port map (
combout => \GRFPC0.D.LDLCK_0_0_27__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420\(1),
datae => \GRFPC0.D.LDLCK_0_0_27__G1_2\,
datad => \GRFPC0.N_24006\,
datac => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_238\(1),
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
dataa => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.DEP_1\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_ALLOW_1_2_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ccc00000cccc")
port map (
combout => \GRFPU0.GRFPU_X0.VALLOW_1_SQMUXA_3\,
dataf => \GRFPU0.GRFPU_X0.N_194\,
datae => \GRFPU0.GRFPU_X0.N_18200\,
datad => \GRFPU0.GRFPU_X0.N_19707\,
datac => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_60_2\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPC0_D_LDLCK_RNO_0_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccccffffccfc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_15__G1_3\,
dataf => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datae => \GRFPC0.N_24984\,
datad => \GRFPC0.N_543_1\,
datac => \GRFPC0.N_25056\,
datab => \GRFPC0.D.LDLCK_0_0_15__G1_1\);
\GRFPC0_D_STDLCK_RNO_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffafffbf")
port map (
combout => \GRFPC0.D.STDLCK_0_0_1__G1_4\,
dataf => \GRFPC0.N_22910\,
datae => \GRFPC0.N_841\,
datad => \GRFPC0.N_22157\,
datac => \GRFPC0.N_22836\,
datab => \GRFPC0.N_570\,
dataa => \GRFPC0.D.STDLCK_0_0_1__G1_1\);
GRFPC0_WR_CTRL_RDD_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c000c000c000f0")
port map (
combout => \GRFPC0.WR.CTRL.RDD_0_0_G1\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datad => \GRFPC0.FP_PIPELINE.UN1_CPI_6\,
datac => \GRFPC0.N_579\,
datab => \GRFPC0.MEM.CTRL.LD\);
GRFPC0_WR_CTRL_STDFQ_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c000c000c000cc")
port map (
combout => \GRFPC0.WR.CTRL.STDFQ_0_0_G1\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datad => \GRFPC0.FP_PIPELINE.UN1_CPI_6\,
datac => \GRFPC0.MEM.CTRL.LD\,
datab => \GRFPC0.MEM.CTRL.STDFQ\);
GRFPC0_FP_PIPELINE_VDIV_VALID_7_F1_A0_C_RNI3CHCG: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00c000cc00cc")
port map (
combout => \GRFPC0.N_10567_2\,
dataf => \GRFPC0.FP_PIPELINE.UN29_WREN_1\,
datae => \GRFPC0.PENDEXC_0_SQMUXA\,
datad => \GRFPC0.VDIV.EXEC_0_SQMUXA\,
datac => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datab => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F1_A0_C\);
GRFPC0_WREN_0_SQMUXA_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcf0fffffff0")
port map (
combout => \GRFPC0.WREN_0_SQMUXA_5\,
dataf => \GRFPC0.FP_PIPELINE.UN29_WREN_1\,
datae => \GRFPC0.UN28_WREN_2\,
datad => \GRFPC0.WR2.CTRL.SEQERR\,
datac => \GRFPC0.PENDEXC_0_SQMUXA\,
datab => \GRFPC0.FP_PIPELINE.FLUSH_1_2\);
GRFPC0_WREN_1_SQMUXA_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.WREN_1_SQMUXA_4\,
dataf => \GRFPC0.FP_PIPELINE.UN29_WREN_1\,
datae => \GRFPC0.DIV.RDD\,
datad => \GRFPC0.PENDEXC_0_SQMUXA\,
datac => \GRFPC0.FP_PIPELINE.FLUSH_1_2\);
GRFPC0_FID_1_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000c0")
port map (
combout => \GRFPC0.N_9159\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datad => \GRFPC0.FP_PIPELINE.UN17_SHARE\,
datac => \GRFPC0.FP_PIPELINE.UN11_SHARE\,
datab => N_39);
GRFPC0_EX_CTRL_AFSR_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => N_45076,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datad => \GRFPC0.RFA.AFSR\,
datac => N_39,
datab => N_35);
GRFPC0_EX_CTRL_LD_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => N_45066,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datad => \GRFPC0.RFA.LD\,
datac => N_39,
datab => N_35);
GRFPC0_EX_CTRL_SEQERR_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => N_45021,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datad => \GRFPC0.RFA.SEQERR\,
datac => N_39,
datab => N_35);
GRFPC0_EX_CTRL_STDFQ_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => N_45085,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datad => \GRFPC0.RFA.STDFQ\,
datac => N_39);
GRFPC0_EX_CTRL_PEND_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf0fcf0fc00cc")
port map (
combout => \GRFPC0.EX.CTRL.PEND_0_0_G1\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datad => \GRFPC0.FIFO_INC_5_SQMUXA_1\,
datac => \GRFPC0.EX.CTRL.PEND_0_0_G2_3\,
datab => \GRFPC0.EX.CTRL.PEND_0_0_G1_0_A3_1\);
GRFPC0_FP_PIPELINE_VFIFO_RD10_RNIUJSGI: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffccccccc0")
port map (
combout => \GRFPC0.FIFO.RD_0_0_0__G1\,
dataf => \GRFPC0.FIFO.RD_0_0_0__G1_0\,
datae => \GRFPC0.PENDEXC_0_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datac => \GRFPC0.FP_PIPELINE.VFIFO.RD10\,
datab => \GRFPC0.FIFO.RD_M_0\(0));
\GRFPC0_FIFO_WR_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000003000c0")
port map (
combout => \GRFPC0.FIFO.WR_0_0_0__G3\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.VFIFO.WR_0_SQMUXA_3\,
datad => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datac => \GRFPC0.FIFO.WR_0_0_0__G3_0_0\,
datab => \GRFPC0.FIFO.WR\(0));
GRFPC0_MEM_RREG_RESV_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"303030303030333f")
port map (
combout => N_40640,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datad => \GRFPC0.FP_PIPELINE.ORV.TMP\,
datac => \GRFPC0.EX.CTRL.LD\,
datab => N_39);
GRFPC0_WR_CTRL_LD_RNIH6MPF: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0fff0fff000")
port map (
combout => N_44831,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => N_39);
GRFPC0_MEM_CTRL_LD_RNI1QSOF: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0fff0fff000")
port map (
combout => N_44904,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datad => \GRFPC0.MEM.CTRL.LD\,
datac => N_39);
GRFPU0_GRFPU_X0_UN28_EXP_ANC8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => N_32426,
dataf => N_32406,
datae => \FPI.OP2\(58),
datad => \FPI.OP2\(60),
datac => \FPI.OP2\(59),
datab => \FPI.OP2\(57));
\GRFPC0_D_STLCK_RNO_0_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f5fff5ff31370005")
port map (
combout => \GRFPC0.N_23511\,
dataf => \GRFPC0.N_708\,
datae => \GRFPC0.N_810\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datac => \GRFPC0.N_490\,
datab => \GRFPC0.N_501\,
dataa => \GRFPC0.N_106_I\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M47_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5f5c53500f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_2_03\,
datac => \GRFPU0.GRFPU_X0.N_9666\,
datab => \GRFPU0.GRFPU_X0.N_9672\,
dataa => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(4));
\GRFPU0_GRFPU_X0_ITER_ALLOW_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000ff00c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18198_I\,
dataf => \GRFPU0.GRFPU_X0.N_13485\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ALLOW_1_SN_N_3\,
datad => \GRFPU0.GRFPU_X0.N_138\,
datac => \GRFPU0.GRFPU_X0.N_4364_1\,
datab => \GRFPU0.GRFPU_X0.N_128\);
GRFPU0_GRFPU_X0_ST1_OP1NX_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10118\,
dataf => \GRFPU0.GRFPU_X0.N_18784\,
datae => \GRFPU0.GRFPU_X0.N_18768\,
datad => \GRFPU0.GRFPU_X0.N_10059_I\,
datac => \GRFPU0.GRFPU_X0.N_18754\,
datab => \FPI.NONSTD\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_380_0_A2_7_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_25704\,
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.N_25658\,
datad => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6767_REGDEPX2_2\,
datac => \FPI.FLOP\(6),
datab => \GRFPC0.N_23975\);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0cff00ff00ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18744_I\,
dataf => \GRFPU0.GRFPU_X0.N_18751_1\,
datae => \GRFPU0.GRFPU_X0.N_18781\,
datad => \GRFPU0.GRFPU_X0.N_10059_I\,
datac => N_32589,
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_0_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_A3_0_6__G0_2\,
dataf => \GRFPU0.GRFPU_X0.N_18781\,
datae => \GRFPU0.GRFPU_X0.N_18829_13\,
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_A3_0_6__G0_0\,
datac => \GRFPU0.GRFPU_X0.N_10059_I\);
GRFPC0_FP_PIPELINE_UN1_DIV_EXEC_RNIA5VHG: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"333f000033ff0000")
port map (
combout => \GRFPC0.N_10575_2\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.DIV.EXEC_0_0_G0_2_0\,
datad => N_44718_1,
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datab => N_37);
\GRFPC0_D_STLCK_RNO_1_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3fff7fff0fff4ff")
port map (
combout => \GRFPC0.D.STLCK_0_0_22__G1_4\,
dataf => \GRFPC0.N_571\,
datae => \GRFPC0.N_21951_1\,
datad => \GRFPC0.N_23403\,
datac => \GRFPC0.D.STLCK_0_0_22__G1_1\,
datab => \GRFPC0.N_23380\,
dataa => \GRFPC0.N_23390\);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000003000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18751_I\,
dataf => \GRFPU0.GRFPU_X0.N_18784\,
datae => \GRFPU0.GRFPU_X0.N_18768\,
datad => \GRFPU0.GRFPU_X0.N_10059_I\,
datac => \GRFPU0.GRFPU_X0.N_18754\,
datab => \FPI.NONSTD\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_125_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffeac0ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_125\(1),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.N_261\,
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_125_0_A2_1_0\(1),
datac => \GRFPC0.FP_PIPELINE.4.REGDEPX2_125_0_A2_0\(1),
datab => \GRFPC0.N_25221\,
dataa => \GRFPC0.N_24484\);
GRFPC0_V_FSR_CEXC_4_SQMUXA_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => N_44718_1,
datad => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datac => \GRFPC0.WR2.CTRL.SEQERR\,
datab => \GRFPC0.V.FSR.AEXC_1_SQMUXA\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_13\(1),
datae => \GRFPC0.DIVI_0_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_11\(1),
datac => \GRFPC0.N_25204\,
datab => \GRFPC0.V.STDATA_14\(25));
\GRFPC0_D_STDLCK_RNO_0_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc5ff05fff5fff5")
port map (
combout => \GRFPC0.D.STDLCK_0_0_11__G1_5\,
dataf => \GRFPC0.N_25899\,
datae => \GRFPC0.N_165\,
datad => \GRFPC0.D.STDLCK_0_0_11__G1_3\,
datac => \GRFPC0.N_21721\,
datab => \GRFPC0.WR.CTRL.RDD\,
dataa => \GRFPC0.N_106_I\);
GRFPU0_GRFPU_X0_COMB_UNPACK_FLUSH0_IV_I_A3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0c00000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18784\,
dataf => \GRFPU0.GRFPU_X0.N_18831\,
datae => \GRFPU0.GRFPU_X0.N_18829\,
datad => \GRFPU0.GRFPU_X0.N_18805\,
datac => \FPI.OP1\(51),
datab => \FPI.FLOP\(1));
\GRFPC0_R_FSR_CEXC_RNO_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc8ff88ffc0ff00")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_0__G1_2\,
dataf => \GRFPC0.V.FSR.CEXC_2_SQMUXA\,
datae => \GRFPC0.V.FSR.CEXC_3_SQMUXA\,
datad => \GRFPC0.R.FSR.CEXC_0_0_0__G1_0\,
datac => \FPO.EXC\(0),
datab => \GRFPC0.R.FSR.TEM\(0),
dataa => \GRFPC0.WR2.RREG.EXCT\(0));
GRFPC0_FP_PIPELINE_RSDEC_RS1V_I_I_A2_1_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_I_A2_1_1\,
dataf => \GRFPC0.RFA.WRITE_RD_0_0_I1_I_1\,
datae => \GRFPC0.N_23631\,
datad => \GRFPC0.INST\(5),
datac => \GRFPC0.N_23618\,
datab => \GRFPC0.INST\(7));
GRFPC0_FP_PIPELINE_RSDEC_RS2D_IV_I_O2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff333f3f3")
port map (
combout => \GRFPC0.N_23636\,
dataf => \GRFPC0.N_23625\,
datae => \GRFPC0.N_23631\,
datad => \GRFPC0.INST\(7),
datac => \GRFPC0.INST\(10),
datab => \GRFPC0.INST\(31));
\GRFPC0_RFA2_FOP_RNO_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.RFA2.FOP_0_0_0_1__G0_0_A4_0_4\,
dataf => \GRFPC0.RFA2.FOP_0_0_0_1__G1_2\,
datae => \GRFPC0.N_23631\,
datad => \GRFPC0.INST\(5),
datac => \GRFPC0.N_23618\,
datab => \GRFPC0.INST\(7));
\GRFPC0_RFA2_FOP_RNO_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.RFA2.FOP_0_0_0_1__G1\,
dataf => \GRFPC0.N_23789\,
datae => \GRFPC0.N_23781\,
datad => \GRFPC0.RFA2.FOP_0_0_0_1__G1_2\,
datac => \GRFPC0.N_23631\,
datab => \GRFPC0.INST\(7));
GRFPC0_FP_PIPELINE_RSDEC_RS2D_IV_I_O3_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff00ff")
port map (
combout => \GRFPC0.N_93\,
dataf => \GRFPC0.N_23631\,
datae => \GRFPC0.INST\(12),
datad => \GRFPC0.INST\(9));
GRFPC0_FP_PIPELINE_ORV_TMP_RNIAJF31: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000300033003f00")
port map (
combout => \GRFPC0.MEM.CTRL.RDD_0_0_G1\,
dataf => CPO_EXCZ,
datae => \GRFPC0.FP_PIPELINE.ORV.TMP\,
datad => \GRFPC0.N_106_I\,
datac => \GRFPC0.EX.CTRL.LD\,
datab => N_39);
GRFPC0_MEM_CTRL_STDFQ_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30003000303030f0")
port map (
combout => \GRFPC0.MEM.CTRL.STDFQ_0_0_G1\,
dataf => CPO_EXCZ,
datae => \GRFPC0.FP_PIPELINE.ORV.TMP\,
datad => \GRFPC0.EX.CTRL.LD\,
datac => \GRFPC0.EX.CTRL.STDFQ\,
datab => N_39);
GRFPC0_FP_PIPELINE_1_WR2EN10_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0003003000cf00")
port map (
combout => \GRFPC0.FP_PIPELINE.1.WR2EN10_0\,
dataf => \GRFPC0.INST\(2),
datae => \GRFPC0.WR2.CTRL.RD\(2),
datad => \GRFPC0.WR2.CTRL.RDWR\,
datac => \GRFPC0.RFA.RS2\(2),
datab => N_37);
\GRFPC0_EX_CTRL_INST_RNO_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ccf0")
port map (
combout => N_47279,
dataf => N_46865,
datae => CPO_EXCZ,
datad => \GRFPC0.N_23695\,
datac => \GRFPC0.EX.CTRL.INST\(20),
datab => N_167);
\GRFPC0_EX_CTRL_INST_RNO_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ccf0")
port map (
combout => N_47280,
dataf => N_46865,
datae => CPO_EXCZ,
datad => \GRFPC0.N_23695\,
datac => \GRFPC0.EX.CTRL.INST\(22),
datab => N_169);
\GRFPC0_EX_CTRL_INST_RNO_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ccf0")
port map (
combout => N_47281,
dataf => N_46865,
datae => CPO_EXCZ,
datad => \GRFPC0.N_23695\,
datac => \GRFPC0.EX.CTRL.INST\(30),
datab => N_177);
\GRFPC0_FP_PIPELINE_0_STDEP_482_0_IV_0_A2_6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"50f0000040c00000")
port map (
combout => \GRFPC0.N_23460\,
dataf => \GRFPC0.N_22173_I\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datad => \GRFPC0.N_23383\,
datac => \GRFPC0.FP_PIPELINE.0.STDEP_482_0_IV_0_A2_6_1\(0),
datab => \GRFPC0.N_458\,
dataa => \GRFPC0.N_23403\);
GRFPC0_RFA2_RS2DEP_RNO_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fc03000030cf")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP34_I_M_0_0\,
dataf => \GRFPC0.INST\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEP34\,
datad => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.RFA.RS2\(0),
datab => N_37);
GRFPC0_FP_PIPELINE_1_UN1_DIV_RD: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffff0f0ff0f00")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD\,
dataf => \GRFPC0.INST\(0),
datae => \GRFPC0.DIV.RD\(0),
datad => \GRFPC0.RFA.RS2\(0),
datac => N_37);
GRFPC0_FP_PIPELINE_1_UN1_WR2_CTRL_RD: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffff0f0ff0f00")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_WR2.CTRL.RD\,
dataf => \GRFPC0.INST\(0),
datae => \GRFPC0.WR2.CTRL.RD\(0),
datad => \GRFPC0.RFA.RS2\(0),
datac => N_37);
\GRFPC0_R_FSR_CEXC_RNO_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc8ff88ffc0ff00")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_2__G1_2\,
dataf => \GRFPC0.V.FSR.CEXC_2_SQMUXA\,
datae => \GRFPC0.V.FSR.CEXC_3_SQMUXA\,
datad => \GRFPC0.R.FSR.CEXC_0_0_2__G1_0\,
datac => \FPO.EXC\(2),
datab => \GRFPC0.R.FSR.TEM\(2),
dataa => \GRFPC0.WR2.RREG.EXCT\(2));
GRFPC0_FP_PIPELINE_1_UN1_DIV_RD_1_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffff0f0ff0f00")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD_2_1\,
dataf => \GRFPC0.INST\(1),
datae => \GRFPC0.DIV.RD\(1),
datad => \GRFPC0.RFA.RS2\(1),
datac => N_37);
GRFPC0_FP_PIPELINE_1_UN1_WR_CTRL_RD_1_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffff0f0ff0f00")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_WR.CTRL.RD_2_1\,
dataf => \GRFPC0.INST\(1),
datae => \GRFPC0.WR.CTRL.RD\(1),
datad => \GRFPC0.RFA.RS2\(1),
datac => N_37);
\GRFPC0_D_STDLCK_RNO_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff1fffffffd")
port map (
combout => \GRFPC0.D.STDLCK_0_0_13__G1\,
dataf => \GRFPC0.N_21266\,
datae => \GRFPC0.N_21285\,
datad => \GRFPC0.D.STDLCK_0_0_13__G1_2\,
datac => \GRFPC0.N_119\,
datab => N_99872,
dataa => \GRFPC0.N_106_I\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccc0fffcccc00f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(51),
dataf => \GRFPU0.GRFPU_X0.N_15541\,
datae => N_99909_I_0,
datad => \GRFPU0.GRFPU_X0.N_18491\,
datac => \GRFPU0.GRFPU_X0.N_15611\,
datab => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0ffccccf000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(54),
dataf => \GRFPU0.GRFPU_X0.N_15544\,
datae => N_99909_I_0,
datad => \GRFPU0.GRFPU_X0.N_15611\,
datac => \GRFPU0.GRFPU_X0.N_15607\,
datab => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(0));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_6_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffc0f0f0f0c")
port map (
combout => \GRFPC0.N_17407\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_13\(1),
datad => \GRFPC0.N_25613\,
datac => \GRFPC0.INST\(26),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_11\(1));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaafcffaaaafc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(55),
dataf => \GRFPU0.GRFPU_X0.N_15545\,
datae => N_99909_I_0,
datad => \GRFPU0.GRFPU_X0.N_15611\,
datac => \GRFPU0.GRFPU_X0.N_6806\,
datab => \GRFPU0.GRFPU_X0.N_17807\,
dataa => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(0));
GRFPC0_DIV_VALID_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000c000c0")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID_1\,
dataf => \GRFPC0.FP_PIPELINE.UN29_WREN_1\,
datae => CPO_EXCZ,
datad => \GRFPC0.VDIV.EXEC_0_SQMUXA\,
datac => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F1_A0_C\,
datab => N_35);
\GRFPU0_GRFPU_X0_UN13_EXP_1_SUM_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccccccccccccccc")
port map (
combout => N_32562,
dataf => \GRFPU0.GRFPU_X0.UN13_EXP_1_CO3\,
datae => \FPI.OP1\(59),
datad => \FPI.OP1\(60),
datac => \FPI.OP1\(61),
datab => \FPI.OP1\(62));
\GRFPC0_RFA2_FID_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000c000")
port map (
combout => \GRFPC0.FID_1_IV_0_0__G0_1\,
dataf => \GRFPC0.FID_1_IV_0_0__G0_0\,
datae => CPO_EXCZ,
datad => \GRFPC0.FP_PIPELINE.UN17_SHARE\,
datac => \GRFPC0.WR.CTRL.ID\(0),
datab => N_39);
\GRFPC0_RFA2_FID_RNO_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000c000")
port map (
combout => \GRFPC0.FID_1_IV_0_1__G0_1\,
dataf => \GRFPC0.FID_1_IV_0_1__G0_0\,
datae => CPO_EXCZ,
datad => \GRFPC0.FP_PIPELINE.UN17_SHARE\,
datac => \GRFPC0.WR.CTRL.ID\(1),
datab => N_39);
\GRFPC0_RFA2_FID_RNO_0_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000c000")
port map (
combout => \GRFPC0.FID_1_IV_0_2__G0_1\,
dataf => \GRFPC0.FID_1_IV_0_2__G0_0\,
datae => CPO_EXCZ,
datad => \GRFPC0.FP_PIPELINE.UN17_SHARE\,
datac => \GRFPC0.WR.CTRL.ID\(2),
datab => N_39);
\GRFPC0_RFA2_FID_RNO_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000c000")
port map (
combout => \GRFPC0.FID_1_IV_0_3__G0_1\,
dataf => \GRFPC0.FID_1_IV_0_3__G0_0\,
datae => CPO_EXCZ,
datad => \GRFPC0.FP_PIPELINE.UN17_SHARE\,
datac => \GRFPC0.WR.CTRL.ID\(3),
datab => N_39);
\GRFPC0_RFA2_FID_RNO_0_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000c000")
port map (
combout => \GRFPC0.FID_1_IV_0_4__G0_1\,
dataf => \GRFPC0.FID_1_IV_0_4__G0_0\,
datae => CPO_EXCZ,
datad => \GRFPC0.FP_PIPELINE.UN17_SHARE\,
datac => \GRFPC0.WR.CTRL.ID\(4),
datab => N_39);
\GRFPC0_RFA2_FID_RNO_0_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000c000")
port map (
combout => \GRFPC0.FID_1_IV_0_5__G0_1\,
dataf => \GRFPC0.FID_1_IV_0_5__G0_0\,
datae => CPO_EXCZ,
datad => \GRFPC0.FP_PIPELINE.UN17_SHARE\,
datac => \GRFPC0.WR.CTRL.ID\(5),
datab => N_39);
GRFPU0_GRFPU_X0_ITER_LOB_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcec5c4c0cec0c4c")
port map (
combout => N_53556,
dataf => \GRFPU0.GRFPU_X0.N_6149\,
datae => \GRFPU0.GRFPU_X0.N_6151\,
datad => \GRFPU0.GRFPU_X0.N_5511\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.LOB\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(2));
GRFPC0_RFA_RDWR_RNIEOR71: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f003f333f00")
port map (
combout => \GRFPC0.N_21133\,
dataf => CPO_EXCZ,
datae => \FPI.START\,
datad => \GRFPC0.RFA.RDWR\,
datac => N_37,
datab => N_39);
GRFPC0_FP_PIPELINE_1_IS_RDD_UN1_V_STDATA_15_RNIP0GU1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030000000")
port map (
combout => \GRFPC0.TMP_0_SQMUXA_2\,
dataf => CPO_EXCZ,
datae => \GRFPC0.FP_PIPELINE.1.IS_RDD.UN1_V.STDATA_15\,
datad => \FPI.START\,
datac => \GRFPC0.V.STDATA_14\(31),
datab => N_39);
\GRFPC0_FP_PIPELINE_VEX_CTRL_RD_1_I_M2_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f3c0f0f0")
port map (
combout => \GRFPC0.N_24644\,
dataf => CPO_EXCZ,
datae => \FPI.START\,
datad => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datac => \GRFPC0.RFA.RD\(2),
datab => N_39);
GRFPC0_FP_PIPELINE_1_UN1_DIV_RD_1_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffff0f0ff0f00")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD_2_3\,
dataf => \GRFPC0.N_23921\,
datae => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.RFA.RS2\(3),
datac => N_37);
GRFPC0_FP_PIPELINE_1_REGDEP160_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc03000030cf0000")
port map (
combout => \GRFPC0.FPUSEL_1_0_1__G0_3_0\,
dataf => \GRFPC0.N_25334\,
datae => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.EX.CTRL.RD\(4),
datac => \GRFPC0.RFA.RS2\(4),
datab => N_37);
GRFPC0_FP_PIPELINE_1_UN1_DIV_RD_1_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffff0f0ff0f00")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD_2_4\,
dataf => \GRFPC0.N_25334\,
datae => \GRFPC0.DIV.RD\(4),
datad => \GRFPC0.RFA.RS2\(4),
datac => N_37);
GRFPC0_FP_PIPELINE_1_UN1_MEM_CTRL_RD_1_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffff0f0ff0f00")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN1_MEM.CTRL.RD_2_4\,
dataf => \GRFPC0.N_25334\,
datae => \GRFPC0.MEM.CTRL.RD\(4),
datad => \GRFPC0.RFA.RS2\(4),
datac => N_37);
\GRFPC0_R_FSR_CEXC_RNO_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_1__G1_3\,
dataf => \GRFPC0.R.FSR.CEXC_0_0_1__G1_1\,
datae => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
datad => \GRFPC0.V.FSR.CEXC_3_SQMUXA\,
datac => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13\(1),
datab => \GRFPC0.DIV.EXCT\(1));
\GRFPC0_R_FSR_CEXC_RNO_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4_M\(4),
dataf => N_46992,
datae => \GRFPC0.FP_PIPELINE.UN25_HOLDN_1\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(4),
datac => \GRFPC0.WR2.CTRL.LD\,
datab => \GRFPC0.V.FSR.AEXC_1_SQMUXA\);
\GRFPC0_FP_PIPELINE_RS2_1_RNI0DK31_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FPUSEL_1_0_3__G0_E_1\,
dataf => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datae => RFI2_RD2ADDRZ(3),
datad => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.MEM.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_A2_1_I_O3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffcfffffffff")
port map (
combout => \GRFPC0.N_22133\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2));
\GRFPC0_FP_PIPELINE_0_STDEP_12_3_0_A2_4_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPC0.N_21419\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2));
GRFPC0_FP_PIPELINE_1_REGDEP172_I_X2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f333333f0cccccc")
port map (
combout => \GRFPC0.N_196_I\,
dataf => RFI2_RD2ADDRZ(3),
datae => N_47178_2,
datad => \FPI.START\,
datac => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datab => \GRFPC0.RFA.RD\(4));
GRFPC0_FP_PIPELINE_1_REGDEP172_I_X2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f333333f0cccccc")
port map (
combout => \GRFPC0.N_197_I\,
dataf => RFI2_RD2ADDRZ(2),
datae => N_47178_2,
datad => \FPI.START\,
datac => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datab => \GRFPC0.RFA.RD\(3));
GRFPC0_FP_PIPELINE_1_REGDEP172_I_X2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f333333f0cccccc")
port map (
combout => \GRFPC0.N_198_I\,
dataf => RFI2_RD2ADDRZ(0),
datae => N_47178_2,
datad => \FPI.START\,
datac => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datab => \GRFPC0.RFA.RD\(1));
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0ff00ff00ff00f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1\(0),
dataf => \GRFPU0.MULO.MRES_1\(121),
datae => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(52));
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3c3ccc3ccc3ccc3c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1\(1),
dataf => \GRFPU0.MULO.MRES_1\(121),
datae => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(53));
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3c3ccc3ccc3ccc3c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_4__N_21\,
dataf => \GRFPU0.MULO.MRES_1\(121),
datae => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
datac => N_32517,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(56));
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33ccc3ccc3ccc3cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_6__N_31\,
dataf => \GRFPU0.MULO.MRES_1\(121),
datae => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datad => N_32527,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(58));
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33ccc3ccc3ccc3cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_8__N_41\,
dataf => \GRFPU0.MULO.MRES_1\(121),
datae => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datad => N_32537,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(60));
GRFPU0_GRFPU_X0_ST4_MOF_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f000f000f000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MOF_1\,
dataf => \GRFPU0.MULO.MRES_1\(121),
datae => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
datac => \GRFPU0.GRFPU_X0.ST3.EMAX\);
GRFPC0_D_FSTLCK_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffce")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1\,
dataf => \GRFPC0.N_10567_2\,
datae => \GRFPC0.D.FSTLCK_0_0_G1_15\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datac => \GRFPC0.FP_PIPELINE.UN205_HOLDN\,
datab => \GRFPC0.N_21133\,
dataa => N_45055_1);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_1_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0ffc0c0c0c0c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_0_7__G0_0_0_TZ\,
dataf => \GRFPU0.GRFPU_X0.N_18954\,
datae => \GRFPU0.GRFPU_X0.N_18947\,
datad => \FPI.OP2\(51),
datac => \FPI.FLOP\(1),
datab => \FPI.NONSTD\);
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_A2_2_RNIP8RB5_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18957\,
dataf => \GRFPU0.GRFPU_X0.N_18954\,
datae => \GRFPU0.GRFPU_X0.N_18947\,
datad => \FPI.OP2\(51));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ffffff80ff8f")
port map (
combout => \GRFPC0.N_24712\,
dataf => \GRFPC0.FP_PIPELINE.3.REGDEPX2_103\(0),
datae => \GRFPC0.N_27\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_7\(6),
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1637_REGDEPX2\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_2_RNI63RT2_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eeeeeeeeeeeeee2e")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(54),
dataf => \GRFPU0.GRFPU_X0.N_18318\,
datae => \GRFPU0.GRFPU_X0.N_177\,
datad => \GRFPU0.GRFPU_X0.N_18371\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_3\(54),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_54_N_3\,
dataa => D_N_4_1_I);
\GRFPC0_FP_PIPELINE_9_STDEP_376_3_I_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"2a0a2aaaaa0aaaaa")
port map (
combout => \GRFPC0.N_21947\,
dataf => \GRFPC0.N_16_I\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datad => \GRFPC0.N_21943\,
datac => \GRFPC0.N_481\,
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN2972_DEP\,
dataa => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_I_A2_1\(0));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_9_0_A2_RNIU9JD1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0c000000000")
port map (
combout => \GRFPC0.N_747\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => \GRFPC0.FP_PIPELINE.UN205_HOLDN\,
datad => N_103,
datac => \GRFPC0.N_9482\,
datab => \GRFPC0.N_22615\);
\GRFPC0_D_STLCK_RNO_3_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0c000000000")
port map (
combout => \GRFPC0.N_21208\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => \GRFPC0.FP_PIPELINE.UN205_HOLDN\,
datad => N_103,
datac => \GRFPC0.N_9481\,
datab => \GRFPC0.N_22615\);
GRFPC0_STDEP_0_SQMUXA_136_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
combout => \GRFPC0.STDEP_0_SQMUXA_136_2\,
dataf => \GRFPC0.FP_PIPELINE.UN205_HOLDN\,
datae => N_103,
datad => \GRFPC0.N_22615\);
\GRFPC0_D_STLCK_RNO_1_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0c000000000")
port map (
combout => \GRFPC0.N_23091\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => \GRFPC0.FP_PIPELINE.UN205_HOLDN\,
datad => N_103,
datac => \GRFPC0.N_9468\,
datab => \GRFPC0.N_22615\);
\GRFPC0_FP_PIPELINE_0_STDEP_42_0_IV_I_A2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0c0f000000000")
port map (
combout => \GRFPC0.N_23028\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => \GRFPC0.FP_PIPELINE.UN205_HOLDN\,
datad => N_103,
datac => \GRFPC0.N_9453\,
datab => \GRFPC0.N_22615\);
\GRFPC0_FP_PIPELINE_STDEP_1_0_IV_I_A2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0c0f000000000")
port map (
combout => \GRFPC0.N_23102\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => \GRFPC0.FP_PIPELINE.UN205_HOLDN\,
datad => N_103,
datac => \GRFPC0.N_9468\,
datab => \GRFPC0.N_22615\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_1_1_I_O2_0_0_O5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffff00")
port map (
combout => \GRFPC0.N_62\,
dataf => \GRFPC0.FP_PIPELINE.UN205_HOLDN\,
datae => N_103,
datad => \GRFPC0.N_22615\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_1_1_I_O2_I_O3_0_I_I4_0_O2_0_0_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffff00ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1\(0),
dataf => \GRFPC0.FP_PIPELINE.UN205_HOLDN\,
datae => N_103,
datad => \GRFPC0.N_22615\);
\GRFPC0_R_FSR_AEXC_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffeca0")
port map (
combout => \GRFPC0.R.FSR.AEXC_0_0_0__G1\,
dataf => \GRFPC0.R.FSR.AEXC_0_0_0__G1_0\,
datae => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_2_M\(0),
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\,
datac => \GRFPC0.V.FSR.AEXC_0_SQMUXA_1\,
datab => \GRFPC0.WR2.RREG.RES\(5),
dataa => \GRFPC0.R.FSR.AEXC\(0));
\GRFPC0_R_FSR_CEXC_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_0__G1_4\,
dataf => \GRFPC0.R.FSR.CEXC_0_0_0__G1_2\,
datae => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
datad => \GRFPC0.V.FSR.CEXC_5_SQMUXA\,
datac => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(0),
datab => \GRFPC0.DIV.EXCT\(0));
\GRFPC0_R_FSR_AEXC_RNO_0_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffefefeffeeaaaa")
port map (
combout => \GRFPC0.R.FSR.AEXC_0_0_4__G1_1\,
dataf => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
datae => \GRFPC0.V.FSR.CEXC_5_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(4),
datac => \GRFPC0.DIV.EXCT\(4),
datab => \GRFPC0.R.FSR.AEXC\(4),
dataa => \GRFPC0.CPI_M\(401));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00fc30f3c0f0f0f")
port map (
combout => N_82241,
dataf => N_32619,
datae => \GRFPU0.GRFPU_X0.UN13_EXP_1_CO5\,
datad => \FPI.OP1\(61),
datac => \FPI.OP1\(62),
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30cf03cffc03cf03")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(9),
dataf => N_32619,
datae => \GRFPU0.GRFPU_X0.UN13_EXP_1_CO5\,
datad => \FPI.OP1\(61),
datac => \FPI.OP1\(62),
datab => \FPI.FLOP\(1));
GRFPC0_FP_PIPELINE_1_DIVEN10_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00000f00f00000f")
port map (
combout => \GRFPC0.FP_PIPELINE.1.DIVEN10_3\,
dataf => RFI2_RD2ADDRZ(1),
datae => RFI2_RD2ADDRZ(2),
datad => \GRFPC0.DIV.RD\(3),
datac => \GRFPC0.DIV.RD\(2));
\GRFPC0_D_STLCK_RNO_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffbbbbffffbbb2")
port map (
combout => \GRFPC0.D.STLCK_0_0_15__G1\,
dataf => \GRFPC0.N_22390\,
datae => \GRFPC0.D.STLCK_0_0_15__G1_5\,
datad => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_O2_6_0\(1),
datac => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_O2_6_1\(1),
datab => \GRFPC0.N_22331\,
dataa => \GRFPC0.N_21713\);
GRFPC0_FP_PIPELINE_1_EXEN7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c030000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.EXEN7\,
dataf => \GRFPC0.FPUSEL_1_2\(1),
datae => \GRFPC0.FPUSEL_1_0_1__G0_3_1\,
datad => RFI2_RD2ADDRZ(3),
datac => \GRFPC0.EX.CTRL.RDWR\,
datab => \GRFPC0.EX.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_4_STDEP_164_0_IV_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_164\(1),
dataf => \GRFPC0.N_22173_I\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_26\(1),
datac => \GRFPC0.N_481\);
\GRFPC0_FP_PIPELINE_15_STDEP_604_0_IV_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c00000c0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_604\(1),
dataf => \GRFPC0.N_22173_I\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datad => \GRFPC0.N_481\,
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4940_DEP\,
datab => \GRFPC0.N_458\);
\GRFPC0_FP_PIPELINE_14_STDEP_568_3_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f00000000000000")
port map (
combout => \GRFPC0.N_23830\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datae => \GRFPC0.N_23842\,
datad => \GRFPC0.N_481\,
datac => \GRFPC0.N_23807\,
datab => \GRFPC0.N_19008\);
\GRFPC0_R_FSR_AEXC_RNO_0_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffefefeffeeaaaa")
port map (
combout => \GRFPC0.R.FSR.AEXC_0_0_2__G1_1\,
dataf => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
datae => \GRFPC0.V.FSR.CEXC_5_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(2),
datac => \GRFPC0.DIV.EXCT\(2),
datab => \GRFPC0.R.FSR.AEXC\(2),
dataa => \GRFPC0.CPI_M\(399));
GRFPC0_FP_PIPELINE_1_WRENX10_1_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.1.WRENX10_1_0\,
dataf => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datae => RFI2_RD2ADDRZ(0),
datad => \GRFPC0.WR.CTRL.RD\(0),
datac => \GRFPC0.WR.CTRL.RD\(1));
\GRFPC0_R_FSR_AEXC_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffeca0")
port map (
combout => \GRFPC0.R.FSR.AEXC_0_0_3__G1\,
dataf => \GRFPC0.R.FSR.AEXC_0_0_3__G1_0\,
datae => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_2_M\(3),
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\,
datac => \GRFPC0.V.FSR.AEXC_0_SQMUXA_1\,
datab => \GRFPC0.WR2.RREG.RES\(8),
dataa => \GRFPC0.R.FSR.AEXC\(3));
GRFPC0_FP_PIPELINE_0_UN1_FPO_5_RNI696VU: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33ff33ff33ff030f")
port map (
combout => \GRFPC0.N_22173_I\,
dataf => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datae => \GRFPC0.VDIV.EXEC_0_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\,
datac => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F1_A0_C\,
datab => \GRFPC0.DIV.EXEC\);
\GRFPC0_R_FSR_CEXC_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffeac0")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_1__G1\,
dataf => \GRFPC0.R.FSR.CEXC_0_0_1__G1_3\,
datae => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4_M\(1),
datad => \GRFPC0.V.FSR.CEXC_0_SQMUXA_2\,
datac => \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\,
datab => \GRFPC0.WR2.RREG.RES\(1),
dataa => \GRFPC0.R.FSR.CEXC\(1));
GRFPC0_FP_PIPELINE_1_REGDEP118: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP118\,
dataf => \GRFPC0.FP_PIPELINE.1.WR2EN10_0_0\,
datae => RFI2_RD2ADDRZ(3),
datad => \GRFPC0.FP_PIPELINE.1.WR2EN10_0\,
datac => \GRFPC0.WR2.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_1_WR2EN10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0003000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.WR2EN10\,
dataf => \GRFPC0.FP_PIPELINE.1.WR2EN10_0_0\,
datae => RFI2_RD2ADDRZ(3),
datad => \GRFPC0.FP_PIPELINE.1.UN1_WR2.CTRL.RD\,
datac => \GRFPC0.FP_PIPELINE.1.WR2EN10_0\,
datab => \GRFPC0.WR2.CTRL.RD\(4));
GRFPC0_D_FSTLCK_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffccc5444")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1_15\,
dataf => \GRFPC0.D.FSTLCK_0_0_G1_13\,
datae => N_47178_2,
datad => \GRFPC0.RFA.LD\,
datac => \GRFPC0.RFA.AFSR\,
datab => \GRFPC0.RFA.STDFQ\,
dataa => N_37);
\GRFPC0_R_FSR_CEXC_RNO_0_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_2__G1_4\,
dataf => \GRFPC0.R.FSR.CEXC_0_0_2__G1_2\,
datae => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
datad => \GRFPC0.V.FSR.CEXC_5_SQMUXA\,
datac => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4\(2),
datab => \GRFPC0.DIV.EXCT\(2));
GRFPC0_FP_PIPELINE_1_DIVEN10_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000030")
port map (
combout => \GRFPC0.FP_PIPELINE.1.DIVEN10_4\,
dataf => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datae => \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD_2_4\,
datad => \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD_2_1\,
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datab => \GRFPC0.DIV.RD\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_26_IV_0_A2_3_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_A2_3_1\,
dataf => \GRFPC0.N_805\,
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2),
datac => \GRFPC0.N_477\,
datab => \GRFPC0.N_21353\);
\GRFPC0_R_FSR_CEXC_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_2__G1\,
dataf => \GRFPC0.R.FSR.CEXC_0_0_2__G1_4\,
datae => \GRFPC0.V.FSR.CEXC_0_SQMUXA_2\,
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\,
datac => \GRFPC0.WR2.RREG.RES\(2),
datab => \GRFPC0.R.FSR.CEXC\(2));
\GRFPC0_D_STLCK_RNO_0_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0fffffffc")
port map (
combout => \GRFPC0.D.STLCK_0_0_5__G1_5\,
dataf => \GRFPC0.N_22725\,
datae => \GRFPC0.FP_PIPELINE.VRFA.RDD_1\,
datad => \GRFPC0.D.STLCK_0_0_5__G1_3\,
datac => \GRFPC0.N_22762\,
datab => N_103);
\GRFPC0_R_FSR_AEXC_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPC0.R.FSR.AEXC_0_0_2__G1\,
dataf => \GRFPC0.R.FSR.AEXC_0_0_2__G1_1\,
datae => \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\,
datad => \GRFPC0.V.FSR.AEXC_0_SQMUXA_1\,
datac => \GRFPC0.WR2.RREG.RES\(7),
datab => \GRFPC0.R.FSR.AEXC\(2));
\GRFPC0_FP_PIPELINE_3_STDEP_128_3_0_A3_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_644\,
dataf => \GRFPC0.N_22173_I\,
datae => \GRFPC0.N_805\,
datad => \GRFPC0.N_481\,
datac => \GRFPC0.N_525\,
datab => \GRFPC0.N_494\);
\GRFPC0_EX_CTRL_PC_RNO_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_10__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_243\,
datac => \GRFPC0.EX.CTRL.PC\(10),
datab => N_125);
\GRFPC0_EX_CTRL_PC_RNO_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_11__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_25234\,
datac => \GRFPC0.EX.CTRL.PC\(11),
datab => N_126);
\GRFPC0_EX_CTRL_PC_RNO_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_12__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_244\,
datac => \GRFPC0.EX.CTRL.PC\(12),
datab => N_127);
\GRFPC0_EX_CTRL_PC_RNO_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_13__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_25235\,
datac => \GRFPC0.EX.CTRL.PC\(13),
datab => N_128);
\GRFPC0_EX_CTRL_PC_RNO_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_14__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_245\,
datac => \GRFPC0.EX.CTRL.PC\(14),
datab => N_129);
\GRFPC0_EX_CTRL_PC_RNO_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_15__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_246\,
datac => \GRFPC0.EX.CTRL.PC\(15),
datab => N_130);
\GRFPC0_EX_CTRL_PC_RNO_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_16__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_247\,
datac => \GRFPC0.EX.CTRL.PC\(16),
datab => N_131);
\GRFPC0_EX_CTRL_PC_RNO_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_17__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_248\,
datac => \GRFPC0.EX.CTRL.PC\(17),
datab => N_132);
\GRFPC0_EX_CTRL_PC_RNO_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_18__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_249\,
datac => \GRFPC0.EX.CTRL.PC\(18),
datab => N_133);
\GRFPC0_EX_CTRL_PC_RNO_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_19__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_250\,
datac => \GRFPC0.EX.CTRL.PC\(19),
datab => N_134);
\GRFPC0_EX_CTRL_PC_RNO_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_20__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_251\,
datac => \GRFPC0.EX.CTRL.PC\(20),
datab => N_135);
\GRFPC0_EX_CTRL_PC_RNO_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_21__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_252\,
datac => \GRFPC0.EX.CTRL.PC\(21),
datab => N_136);
\GRFPC0_EX_CTRL_PC_RNO_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_22__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_253\,
datac => \GRFPC0.EX.CTRL.PC\(22),
datab => N_137);
\GRFPC0_EX_CTRL_PC_RNO_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_23__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(23),
datac => \GRFPC0.EX.CTRL.PC\(23),
datab => N_138);
\GRFPC0_EX_CTRL_PC_RNO_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_24__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(24),
datac => \GRFPC0.EX.CTRL.PC\(24),
datab => N_139);
\GRFPC0_EX_CTRL_PC_RNO_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_25__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(25),
datac => \GRFPC0.EX.CTRL.PC\(25),
datab => N_140);
\GRFPC0_EX_CTRL_PC_RNO_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_26__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(26),
datac => \GRFPC0.EX.CTRL.PC\(26),
datab => N_141);
\GRFPC0_EX_CTRL_PC_RNO_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_27__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_25236\,
datac => \GRFPC0.EX.CTRL.PC\(27),
datab => N_142);
\GRFPC0_EX_CTRL_PC_RNO_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_28__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_254\,
datac => \GRFPC0.EX.CTRL.PC\(28),
datab => N_143);
\GRFPC0_EX_CTRL_PC_RNO_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_29__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_255\,
datac => \GRFPC0.EX.CTRL.PC\(29),
datab => N_144);
\GRFPC0_EX_CTRL_PC_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_2__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_237\,
datac => \GRFPC0.EX.CTRL.PC\(2),
datab => N_117);
\GRFPC0_EX_CTRL_PC_RNO_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_30__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_256\,
datac => \GRFPC0.EX.CTRL.PC\(30),
datab => N_145);
\GRFPC0_EX_CTRL_PC_RNO_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_31__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_257\,
datac => \GRFPC0.EX.CTRL.PC\(31),
datab => N_146);
\GRFPC0_EX_CTRL_PC_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_3__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_238\,
datac => \GRFPC0.EX.CTRL.PC\(3),
datab => N_118);
\GRFPC0_EX_CTRL_PC_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_4__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_239\,
datac => \GRFPC0.EX.CTRL.PC\(4),
datab => N_119);
\GRFPC0_EX_CTRL_PC_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_5__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_240\,
datac => \GRFPC0.EX.CTRL.PC\(5),
datab => N_120);
\GRFPC0_EX_CTRL_PC_RNO_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_6__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_241\,
datac => \GRFPC0.EX.CTRL.PC\(6),
datab => N_121);
\GRFPC0_EX_CTRL_PC_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_7__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_242\,
datac => \GRFPC0.EX.CTRL.PC\(7),
datab => N_122);
\GRFPC0_EX_CTRL_PC_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_8__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_23982\,
datac => \GRFPC0.EX.CTRL.PC\(8),
datab => N_123);
\GRFPC0_EX_CTRL_PC_RNO_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.PC_0_0_9__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_25233\,
datac => \GRFPC0.EX.CTRL.PC\(9),
datab => N_124);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN24_DP_I_O2_RNI3IU86_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffc0c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_8869\,
dataf => \GRFPU0.GRFPU_X0.N_18880\,
datae => \GRFPU0.GRFPU_X0.N_18954\,
datad => \GRFPU0.GRFPU_X0.N_18948\,
datac => \GRFPU0.GRFPU_X0.N_18871\,
datab => \FPI.NONSTD\);
\GRFPC0_D_STLCK_RNO_0_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc0ff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_9__G1_5\,
dataf => \GRFPC0.N_22633\,
datae => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datad => \GRFPC0.D.STLCK_0_0_9__G1_3\,
datac => N_103,
datab => \GRFPC0.N_9477\);
\GRFPC0_R_FSR_CEXC_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_0__G1\,
dataf => \GRFPC0.R.FSR.CEXC_0_0_0__G1_4\,
datae => \GRFPC0.V.FSR.CEXC_0_SQMUXA_2\,
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\,
datac => \GRFPC0.WR2.RREG.RES\(0),
datab => \GRFPC0.R.FSR.CEXC\(0));
\GRFPC0_FPR_ALLOW_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => \GRFPC0.FPRIN.ALLOW\(0),
dataf => \GRFPC0.N_10567_2\,
datae => \GRFPC0.N_10575_2\,
datad => \GRFPU0.GRFPU_X0.N_15365\,
datac => \GRFPU0.GRFPU_X0.N_138\,
datab => N_35);
GRFPC0_FP_PIPELINE_0_UN1_FPO_5_RNITOR5K: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000fff00000000")
port map (
combout => \GRFPC0.N_16_I\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datae => \GRFPC0.N_10567_2\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\,
datac => \GRFPC0.DIV.EXEC\);
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_O3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0f3fff0f0f")
port map (
combout => \GRFPC0.N_21634\,
dataf => \GRFPC0.N_10567_2\,
datae => \GRFPC0.N_481\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\,
datac => \GRFPC0.N_74_I_I\,
datab => \GRFPC0.DIV.EXEC\);
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_0_A2_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f00003fff0000")
port map (
combout => \GRFPC0.N_731\,
dataf => \GRFPC0.N_10567_2\,
datae => \GRFPC0.N_24455_I\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\,
datac => \GRFPC0.N_74_I_I\,
datab => \GRFPC0.DIV.EXEC\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_5_RNI9MKRH: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000ff003f00")
port map (
combout => \GRFPC0.N_742_1\,
dataf => \GRFPC0.N_10567_2\,
datae => \GRFPC0.N_481\,
datad => \GRFPC0.N_458\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\,
datab => \GRFPC0.DIV.EXEC\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_5_RNI9MKRH_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffffff00c0ffff")
port map (
combout => N_40688,
dataf => \GRFPC0.N_10567_2\,
datae => \GRFPC0.N_481\,
datad => \GRFPC0.N_458\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\,
datab => \GRFPC0.DIV.EXEC\);
GRFPC0_UN1_WRENX10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.UN1_WRENX10\,
dataf => \GRFPC0.FP_PIPELINE.1.MEMEN10\,
datae => \GRFPC0.FP_PIPELINE.1.WRENX10\,
datad => \GRFPC0.FPUSEL_1_2\(1),
datac => \GRFPC0.FPUSEL_1_0_1__G0_3_1\,
datab => \GRFPC0.FPUSEL_1_0_1__G0_3_0\);
GRFPC0_UN1_WRENX10_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0000000")
port map (
combout => \GRFPC0.UN1_WRENX10_1\,
dataf => \GRFPC0.FP_PIPELINE.1.MEMEN10\,
datae => \GRFPC0.FPUSEL_1_2\(1),
datad => \GRFPC0.FPUSEL_1_0_1__G0_3_1\,
datac => \GRFPC0.FPUSEL_1_0_1__G0_3_0\);
\GRFPC0_D_STLCK_RNO_0_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0fffffff3")
port map (
combout => \GRFPC0.D.STLCK_0_0_4__G1_5\,
dataf => \GRFPC0.N_22725\,
datae => \GRFPC0.FP_PIPELINE.VRFA.RDD_1\,
datad => \GRFPC0.D.STLCK_0_0_4__G1_3\,
datac => \GRFPC0.N_22764\,
datab => N_103);
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_A3_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.N_21690\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => \GRFPC0.N_21636\,
datad => \GRFPC0.N_21617\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\);
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_A2_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f0000000c0")
port map (
combout => \GRFPC0.N_139\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => N_106,
datad => N_107,
datac => \GRFPC0.N_9475_1\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP\);
\GRFPC0_R_FSR_AEXC_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPC0.R.FSR.AEXC_0_0_1__G1\,
dataf => \GRFPC0.R.FSR.AEXC_0_0_1__G1_1\,
datae => \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\,
datad => \GRFPC0.V.FSR.AEXC_0_SQMUXA_1\,
datac => \GRFPC0.R.FSR.AEXC\(1),
datab => \GRFPC0.WR2.RREG.RES\(6));
\GRFPC0_R_FSR_AEXC_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPC0.R.FSR.AEXC_0_0_4__G1\,
dataf => \GRFPC0.R.FSR.AEXC_0_0_4__G1_1\,
datae => \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\,
datad => \GRFPC0.V.FSR.AEXC_0_SQMUXA_1\,
datac => \GRFPC0.WR2.RREG.RES\(9),
datab => \GRFPC0.R.FSR.AEXC\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(11),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(11),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(23),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(23),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(15));
GRFPC0_FP_PIPELINE_0_UN1_WR2_CTRL_RD_1_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffff0f0ff0f00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_1\,
dataf => \GRFPC0.N_17951\,
datae => \GRFPC0.WR2.CTRL.RD\(1),
datad => \GRFPC0.RFA.RS1\(1),
datac => N_37);
GRFPC0_FP_PIPELINE_0_UN1_MEM_CTRL_RD_1_2_RNINV7G: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fc0330cf")
port map (
combout => \GRFPC0.FPUSEL_6_0_3__G0_E_1\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.RD_2_3\,
datae => \GRFPC0.N_17951\,
datad => \GRFPC0.MEM.CTRL.RD\(1),
datac => \GRFPC0.RFA.RS1\(1),
datab => N_37);
\GRFPC0_RS1_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => RFI2_RD1ADDRZ(0),
dataf => N_423,
datae => N_427,
datad => N_37,
datac => \GRFPC0.N_17951\,
datab => \GRFPC0.RFA.RS1\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(13),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(13),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(32),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(32),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(12),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(12),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(4));
GRFPC0_FP_PIPELINE_0_UN1_WR2_CTRL_RD_1_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffff0f0ff0f00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_2\,
dataf => \GRFPC0.N_116\,
datae => \GRFPC0.WR2.CTRL.RD\(2),
datad => \GRFPC0.RFA.RS1\(2),
datac => N_37);
\GRFPC0_RS1_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => RFI2_RD1ADDRZ(1),
dataf => N_423,
datae => N_428,
datad => N_37,
datac => \GRFPC0.N_116\,
datab => \GRFPC0.RFA.RS1\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(22),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(22),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(28),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(28),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(20));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(10),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(30),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.N_18684\,
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(22));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(9),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(9),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(24),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(24),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(20),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(20),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(12));
GRFPU0_GRFPU_X0_COMB_UN1_VST4_ADDOF_0_RNIM2A3C: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000040400000444")
port map (
combout => \GRFPU0.GRFPU_X0.N_18441_I\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.ADDOF_1\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ADDI3\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_VST4.ADDOF_0\,
datac => \GRFPU0.GRFPU_X0.COMB.ADDI2\,
datab => \GRFPU0.GRFPU_X0.N_18441_I_0_G0_1\,
dataa => \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(17),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(17),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(9));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(25),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(25),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(17));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(33),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(33),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(25));
\GRFPC0_D_STLCK_RNO_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffefefefff2f2f2")
port map (
combout => \GRFPC0.D.STLCK_0_0_28__G1\,
dataf => \GRFPC0.N_23173\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1\(0),
datad => \GRFPC0.FP_PIPELINE.14.STDEP_598_I_M_I_A3_0\(1),
datac => \GRFPC0.D.STLCK_0_0_28__G1_4\,
datab => \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0\,
dataa => \GRFPC0.N_106_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(21),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(21),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(13));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(29),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(29),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(21));
GRFPC0_FP_PIPELINE_1_REGDEP172_I_S: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff6f")
port map (
combout => \GRFPC0.N_24011\,
dataf => \GRFPC0.N_196_I\,
datae => \GRFPC0.N_198_I\,
datad => \GRFPC0.N_197_I\,
datac => \GRFPC0.EX.CTRL.RDWR_0_0_G2\,
datab => \GRFPC0.N_24644\,
dataa => RFI2_RD2ADDRZ(1));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(31),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.N_18683\,
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(23));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(35),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(35),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(27));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(15),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(15),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(7));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_238_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffbaaf300")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_238\(0),
dataf => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235\(0),
datae => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_7\(0),
datad => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3505_REGDEPX2\,
datac => \GRFPC0.DIV.RDD\,
datab => \GRFPC0.DIV.RD\(0),
dataa => \GRFPC0.DIV.RS1V\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(34),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(34),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(18),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(18),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(14),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(14),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(6));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(19),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(19),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(11));
\GRFPC0_D_STDLCK_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffefffc")
port map (
combout => \GRFPC0.D.STDLCK_0_0_5__G1\,
dataf => \GRFPC0.N_21672\,
datae => \GRFPC0.N_461\,
datad => \GRFPC0.N_21678\,
datac => \GRFPC0.D.STDLCK_0_0_5__G1_3\,
datab => \GRFPC0.N_21674\,
dataa => \GRFPC0.N_9478\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(16),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(16),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(8));
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f3003300000000")
port map (
combout => \GRFPC0.N_21672\,
dataf => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_1\,
datae => \GRFPC0.N_22173_I\,
datad => \GRFPC0.N_21690\,
datac => \GRFPC0.N_481\,
datab => \GRFPC0.N_74_I_I\);
\GRFPC0_D_STLCK_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffcfcfcf")
port map (
combout => \GRFPC0.D.STLCK_0_0_7__G1\,
dataf => \GRFPC0.FP_PIPELINE.3.STDEP_136\(1),
datae => \GRFPC0.N_62\,
datad => \GRFPC0.STDDEP_0_SQMUXA_139\,
datac => \GRFPC0.N_18198\,
datab => \GRFPC0.D.STLCK_0_0_7__G1_2\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(8),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(8),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(26),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(26),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(18));
\GRFPC0_R_FSR_CEXC_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffefafcf0")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_4__G1\,
dataf => \GRFPC0.R.FSR.CEXC_0_0_4__G1_3\,
datae => \GRFPC0.V.FSR.CEXC_0_SQMUXA_2\,
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\,
datac => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_4_M\(4),
datab => \GRFPC0.WR2.RREG.RES\(4),
dataa => \GRFPC0.R.FSR.CEXC\(4));
\GRFPC0_D_STLCK_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff2f2f2")
port map (
combout => \GRFPC0.D.STLCK_0_0_2__G1\,
dataf => \GRFPC0.N_22875\,
datae => \GRFPC0.N_22910\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1\(0),
datac => \GRFPC0.D.STLCK_0_0_2__G1_5\,
datab => \GRFPC0.N_21951_1\,
dataa => \GRFPC0.FP_PIPELINE.0.STDEP_82_0_IV_I_A3_3_0\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(36),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(36),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(28));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(27),
dataf => \GRFPU0.GRFPU_X0.N_18750\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(27),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP1\(19));
GRFPC0_FP_PIPELINE_0_REGDEP30: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00c00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP30\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEP30_1\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_3\,
datad => \GRFPC0.FP_PIPELINE.RS1_6\(1),
datac => \GRFPC0.WR2.CTRL.RD\(1),
datab => \GRFPC0.WR2.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0f0f080")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180\(1),
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175\(1),
datae => \GRFPC0.N_24071\,
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_1\(1),
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_21\(1),
dataa => \GRFPC0.DIV.RS1V\);
\GRFPC0_D_STLCK_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3f2fffffffe")
port map (
combout => \GRFPC0.D.STLCK_0_0_0__G1\,
dataf => \GRFPC0.N_367\,
datae => \GRFPC0.N_23028\,
datad => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datac => \GRFPC0.D.STLCK_0_0_0__G1_3\,
datab => \GRFPC0.N_507\,
dataa => \GRFPC0.N_106_I\);
\GRFPC0_D_LDLCK_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcfff3fff0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_5__G1\,
dataf => \GRFPC0.FP_PIPELINE.2.REGDEPX2_89\(1),
datae => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85\(1),
datad => \GRFPC0.D.LDLCK_0_0_5__G1_6\,
datac => \GRFPC0.N_22762\,
datab => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\);
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff8cff08ff08ff08")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_252\(1),
dataf => \GRFPC0.N_742_1\,
datae => \GRFPC0.N_842\,
datad => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_0_1\(1),
datac => \GRFPC0.N_76\,
datab => \GRFPC0.N_74\,
dataa => \GRFPC0.N_22000\);
GRFPC0_REGDEP_0_SQMUXA_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ff00")
port map (
combout => \GRFPC0.REGDEP_0_SQMUXA_2\,
dataf => \GRFPC0.N_23598_I_0\,
datae => \GRFPC0.N_24011\,
datad => \GRFPC0.EX.CTRL.RDD_0_0_G1\);
\GRFPC0_D_LDLCK_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcfffffff0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_4__G1\,
dataf => \GRFPC0.FP_PIPELINE.2.REGDEPX2_83\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_2\(0),
datad => \GRFPC0.D.LDLCK_0_0_4__G1_6\,
datac => \GRFPC0.N_22764\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcf3f0ff0c03000")
port map (
combout => \GRFPC0.N_17401\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90\(1),
datae => \GRFPC0.FP_PIPELINE.3.REGDEPX2_119\(1),
datad => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115\(1),
datac => \GRFPC0.INST\(26),
datab => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\);
GRFPC0_FP_PIPELINE_0_WR2EN2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0008000200000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.WR2EN2\,
dataf => \GRFPC0.FP_PIPELINE.0.WR2EN2_1\,
datae => \GRFPC0.N_22829\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_2\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_1\,
datab => \GRFPC0.WR2.CTRL.RD\(0),
dataa => \GRFPC0.WR2.CTRL.RDWR\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(23),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(23),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(34),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(34),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(17),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(17),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(9));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(18),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(18),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(9),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(9),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(25),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(25),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(17));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(20),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(20),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(15),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(15),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(19),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(19),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(11));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(16),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(16),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(11),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(11),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(14),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(14),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(6));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(28),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(28),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(20));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(29),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(29),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(21));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(22),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(22),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(24),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(24),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(36),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(36),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(28));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(26),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(26),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(18));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(35),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(35),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(27));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(31),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(31),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(23));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(30),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(30),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(22));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(13),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(13),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(21),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(21),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(13));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_49_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffae0c")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_49\(0),
dataf => \GRFPC0.FP_PIPELINE.1.REGDEPX2_45\(0),
datae => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_7\(0),
datad => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_6\(0),
datac => \GRFPC0.N_702\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN800_REGDEPX2\,
dataa => \GRFPC0.WR.CTRL.RS1V\);
GRFPC0_RFA2_RS1SEL_RET_22_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"030f0f0f33ffffff")
port map (
combout => \GRFPC0.FPUSEL_6_1\(7),
dataf => \GRFPC0.FPUSEL_6_3\(1),
datae => \GRFPC0.FPUSEL_6_0_3__G0_E_2\,
datad => \GRFPC0.FPUSEL_6_0_3__G0_E_1\,
datac => \GRFPC0.FPUSEL_6_2\(1),
datab => \GRFPC0.FPUSEL_6_0_3__G0_E_0\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_29_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_29\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_26\(1),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_16\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN447_REGDEPX2\,
datab => \GRFPC0.DIV.RS1V\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(12),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(12),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(4));
\GRFPC0_D_LDLCK_RNO_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_10__G1\,
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_170\(0),
datae => \GRFPC0.D.LDLCK_0_0_10__G1_4\,
datad => \GRFPC0.N_22588\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180_0_2\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(27),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(27),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(10),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(10),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff00000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(32),
dataf => \GRFPU0.GRFPU_X0.N_8862\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(32),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(24));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_9_I_M2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0cfc03f300f00")
port map (
combout => \GRFPC0.N_24729\,
dataf => \GRFPC0.FP_PIPELINE.9.REGDEPX2_299\(1),
datae => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270\(1),
datac => \GRFPC0.INST\(26),
datab => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\);
\GRFPC0_D_STLCK_RNO_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff20ff20ff20ffff")
port map (
combout => \GRFPC0.D.STLCK_0_0_11__G1\,
dataf => \GRFPC0.N_22582\,
datae => \GRFPC0.N_22583\,
datad => \GRFPC0.D.STLCK_0_0_11__G3\,
datac => \GRFPC0.N_168\,
datab => \GRFPC0.N_543_1\,
dataa => N_40549);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_420_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffccfff3ffc0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420\(0),
dataf => \GRFPC0.FP_PIPELINE.13.REGDEPX2_413\(0),
datae => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410\(0),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_1\(0),
datac => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_3\(0),
datab => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_17496\,
dataf => \GRFPC0.D.LDLCK\(0),
datae => \GRFPC0.D.LDLCK\(8),
datad => \GRFPC0.D.LDLCK\(24),
datac => \GRFPC0.D.LDLCK\(16),
datab => N_106,
dataa => N_107);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_13_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_17516\,
dataf => \GRFPC0.D.LDLCK\(6),
datae => \GRFPC0.D.LDLCK\(14),
datad => \GRFPC0.D.LDLCK\(30),
datac => \GRFPC0.D.LDLCK\(22),
datab => N_106,
dataa => N_107);
GRFPC0_LDLOCK_6_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPC0.N_196\,
dataf => \GRFPC0.D.STDLCK\(1),
datae => \GRFPC0.D.STDLCK\(5),
datad => \GRFPC0.D.STDLCK\(9),
datac => \GRFPC0.D.STDLCK\(13),
datab => N_106,
dataa => N_107);
\GRFPU0_GRFPU_X0_BCO_MSB_3_1_0_TZ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_1_TZ\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(23),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(22),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(21));
GRFPU0_GRFPU_X0_NXX_1_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_3\,
dataf => \GRFPU0.GRFPU_X0.NXX_1_5\,
datae => \GRFPU0.MULO.MRES\(61),
datad => \GRFPU0.MULO.MRES\(63),
datac => \GRFPU0.MULO.MRES\(62),
datab => \GRFPU0.MULO.MRES\(16));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_10_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_17510\,
dataf => \GRFPC0.D.LDLCK\(4),
datae => \GRFPC0.D.LDLCK\(12),
datad => \GRFPC0.D.LDLCK\(28),
datac => \GRFPC0.D.LDLCK\(20),
datab => N_106,
dataa => N_107);
GRFPC0_LDLOCK_13_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_23590\,
dataf => \GRFPC0.D.STDLCK\(3),
datae => \GRFPC0.D.STDLCK\(7),
datad => \GRFPC0.D.STDLCK\(15),
datac => \GRFPC0.D.STDLCK\(11),
datab => N_106,
dataa => N_107);
GRFPU0_GRFPU_X0_COMB_ANDV_TMP_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ANDV.TMP_4\,
dataf => \GRFPU0.GRFPU_X0.C\(8),
datae => \GRFPU0.GRFPU_X0.C\(1),
datad => \GRFPU0.GRFPU_X0.C\(6),
datac => \GRFPU0.GRFPU_X0.C\(3));
GRFPC0_LDLOCK_3_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_193\,
dataf => \GRFPC0.D.STDLCK\(0),
datae => \GRFPC0.D.STDLCK\(4),
datad => \GRFPC0.D.STDLCK\(12),
datac => \GRFPC0.D.STDLCK\(8),
datab => N_106,
dataa => N_107);
\GRFPU0_GRFPU_X0_ALLOW_I_O3_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_14\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(16),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(19));
GRFPC0_LDLOCK_10_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_200\,
dataf => \GRFPC0.D.STDLCK\(2),
datae => \GRFPC0.D.STDLCK\(6),
datad => \GRFPC0.D.STDLCK\(14),
datac => \GRFPC0.D.STDLCK\(10),
datab => N_106,
dataa => N_107);
\GRFPU0_GRFPU_X0_COMB_UN43_FLUSH_ALTB_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"7f37130177331100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH.ALTB\(2),
dataf => \FPI.FLUSHID\(0),
datae => \FPI.FLUSHID\(2),
datad => \FPI.FLUSHID\(1),
datac => \GRFPU0.GRFPU_X0.ST2.ID\(0),
datab => \GRFPU0.GRFPU_X0.ST2.ID\(2),
dataa => \GRFPU0.GRFPU_X0.ST2.ID\(1));
\GRFPC0_FP_PIPELINE_DBGDATA_4_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3c0f3f3c0c0c0")
port map (
combout => CPO_DBG_DATAZ(8),
dataf => N_635,
datae => N_699,
datad => N_426,
datac => \GRFPC0.R.FSR.AEXC\(3),
datab => N_425);
\GRFPC0_STDATA_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"caffca00ca00ca00")
port map (
combout => CPO_DATAZ(28),
dataf => \GRFPC0.EX.CTRL.STDFQ\,
datae => \GRFPC0.R.STDATA\(28),
datad => N_99884,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI_2\,
datab => \GRFPC0.EX.RREG.RES\(28),
dataa => \GRFPC0.EX.RREG.RES\(60));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNIH8C02_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fa00ea0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G1\,
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4));
\GRFPC0_STDATA_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"caffca00ca00ca00")
port map (
combout => CPO_DATAZ(29),
dataf => \GRFPC0.EX.CTRL.STDFQ\,
datae => \GRFPC0.R.STDATA\(29),
datad => N_99884,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI_2\,
datab => \GRFPC0.EX.RREG.RES\(29),
dataa => \GRFPC0.EX.RREG.RES\(61));
\GRFPC0_FP_PIPELINE_DBGDATA_4_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3c0f3f3c0c0c0")
port map (
combout => CPO_DBG_DATAZ(9),
dataf => N_636,
datae => N_700,
datad => N_426,
datac => \GRFPC0.R.FSR.AEXC\(4),
datab => N_425);
GRFPC0_FP_PIPELINE_0_STDDEP_180_IV_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_21899\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_244,
datad => N_245,
datac => N_243,
datab => N_242);
\GRFPC0_STDATA_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"caffca00caffcaff")
port map (
combout => CPO_DATAZ(18),
dataf => \GRFPC0.EX.CTRL.STDFQ\,
datae => \GRFPC0.R.STDATA\(18),
datad => N_99884,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI_2\,
datab => \GRFPC0.EX.RREG.RES\(18),
dataa => \GRFPC0.EX.RREG.RES\(50));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_6_I_M2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_22349\,
dataf => \GRFPC0.D.LDLCK\(3),
datae => \GRFPC0.D.LDLCK\(11),
datad => \GRFPC0.D.LDLCK\(27),
datac => \GRFPC0.D.LDLCK\(19),
datab => N_106,
dataa => N_107);
\GRFPU0_GRFPU_X0_L1_6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff230000ff22")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6\(0),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(0),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(1),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(2));
GRFPC0_D_FLDLCK_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPC0.D.FLDLCK_0_0_G1_3\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.MEM.CTRL.RDWR\,
datac => \GRFPC0.WR.CTRL.CCWR\,
datab => \GRFPC0.EX.CTRL.CCWR\,
dataa => \GRFPC0.MEM.CTRL.CCWR\);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1386_DEP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1386_DEP\,
dataf => \GRFPC0.EX.CTRL.RD\(3),
datae => \GRFPC0.EX.CTRL.RD\(2),
datad => \GRFPC0.EX.CTRL.RD\(1),
datac => \GRFPC0.EX.CTRL.RD\(4));
\GRFPC0_STDATA_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"caffca00ca00ca00")
port map (
combout => CPO_DATAZ(20),
dataf => \GRFPC0.EX.CTRL.STDFQ\,
datae => \GRFPC0.R.STDATA\(20),
datad => N_99884,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI_2\,
datab => \GRFPC0.EX.RREG.RES\(20),
dataa => \GRFPC0.EX.RREG.RES\(52));
GRFPU0_GRFPU_X0_COMB_SHV2LTO10_0_O3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"007fffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_20729\,
dataf => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(5),
datae => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(4),
datad => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(3),
datac => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(2),
datab => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(1),
dataa => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(0));
\GRFPC0_FIFO_INST_1_RNI7G2I1_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"013301003f3f3f3f")
port map (
combout => \GRFPC0.N_22237\,
dataf => \GRFPC0.FIFO.INST_1\(6),
datae => \GRFPC0.FIFO.INST_1\(12),
datad => \GRFPC0.FIFO.INST_1\(8),
datac => \GRFPC0.FIFO.INST_1\(11),
datab => \GRFPC0.FIFO.INST_1\(10),
dataa => \GRFPC0.FIFO.INST_1\(7));
\GRFPC0_FP_PIPELINE_DBGDATA_4_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3c0f3f3c0c0c0")
port map (
combout => CPO_DBG_DATAZ(14),
dataf => N_641,
datae => N_705,
datad => N_426,
datac => \GRFPC0.R.FSR.FTT\(0),
datab => N_425);
\GRFPU0_GRFPU_X0_L1_4_4_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0001ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_4\(3),
dataf => \GRFPU0.GRFPU_X0.UN23_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(44),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(47),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(46),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(45));
GRFPU0_GRFPU_X0_COMB_UINT17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000ccc00cc0c")
port map (
combout => \GRFPU0.GRFPU_X0.N_3476\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(7));
\GRFPC0_STDATA_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"caffca00ca00ca00")
port map (
combout => CPO_DATAZ(12),
dataf => \GRFPC0.EX.CTRL.STDFQ\,
datae => \GRFPC0.R.STDATA\(12),
datad => N_99884,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI_2\,
datab => \GRFPC0.EX.RREG.RES\(12),
dataa => \GRFPC0.EX.RREG.RES\(44));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_17502\,
dataf => \GRFPC0.D.LDLCK\(2),
datae => \GRFPC0.D.LDLCK\(10),
datad => \GRFPC0.D.LDLCK\(26),
datac => \GRFPC0.D.LDLCK\(18),
datab => N_106,
dataa => N_107);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_3_I_M2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fd75b931ec64a820")
port map (
combout => \GRFPC0.N_22346\,
dataf => \GRFPC0.D.LDLCK\(1),
datae => \GRFPC0.D.LDLCK\(9),
datad => \GRFPC0.D.LDLCK\(25),
datac => \GRFPC0.D.LDLCK\(17),
datab => N_106,
dataa => N_107);
GRFPC0_FP_PIPELINE_STDBL_1_1_U: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"88f0880088008800")
port map (
combout => \GRFPC0.FP_PIPELINE.STDBL_1_1\,
dataf => N_167,
datae => \GRFPC0.RFA.ST\,
datad => N_37,
datac => N_166,
datab => N_98,
dataa => N_97);
\GRFPC0_FP_PIPELINE_DBGDATA_4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3c0f3f3c0c0c0")
port map (
combout => CPO_DBG_DATAZ(1),
dataf => N_628,
datae => N_692,
datad => N_426,
datac => \GRFPC0.R.FSR.CEXC\(1),
datab => N_425);
\GRFPC0_FP_PIPELINE_DBGDATA_4_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3c0f3f3c0c0c0")
port map (
combout => CPO_DBG_DATAZ(23),
dataf => N_650,
datae => N_714,
datad => N_426,
datac => \GRFPC0.R.FSR.TEM\(0),
datab => N_425);
\GRFPC0_FP_PIPELINE_DBGDATA_4_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000f0f000000")
port map (
combout => CPO_DBG_DATAZ(21),
dataf => N_648,
datae => N_712,
datad => N_426,
datac => N_425);
\GRFPC0_STDATA_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"caffca00ca00ca00")
port map (
combout => CPO_DATAZ(21),
dataf => \GRFPC0.EX.CTRL.STDFQ\,
datae => \GRFPC0.R.STDATA\(21),
datad => N_99884,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI_2\,
datab => \GRFPC0.EX.RREG.RES\(21),
dataa => \GRFPC0.EX.RREG.RES\(53));
GRFPC0_DEP_1_SQMUXA_88_0_A3_0_I2_1_I2_0_0_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffceffcccf000")
port map (
combout => \GRFPC0.N_22777\,
dataf => \GRFPC0.FIFO.INST_0\(6),
datae => \GRFPC0.FIFO.INST_0\(11),
datad => \GRFPC0.FIFO.INST_0\(12),
datac => \GRFPC0.FIFO.INST_0\(8),
datab => \GRFPC0.FIFO.INST_0\(10),
dataa => \GRFPC0.FIFO.INST_0\(7));
GRFPU0_GRFPU_X0_UN28_BCO_LSB_RNIQ4212: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0001ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_4\(3),
dataf => \GRFPU0.GRFPU_X0.UN28_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(53),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(55),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(52));
\GRFPC0_FP_PIPELINE_DBGDATA_4_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3c0f3f3c0c0c0")
port map (
combout => CPO_DBG_DATAZ(31),
dataf => N_658,
datae => N_722,
datad => N_426,
datac => \FPI.RNDMODE\(1),
datab => N_425);
GRFPU0_GRFPU_X0_COMB_VST2_REG107: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000004000400040")
port map (
combout => \GRFPU0.GRFPU_X0.N_5250\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.FLOP\(7));
GRFPU0_GRFPU_X0_COMB_VST3_EXC19LTO6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000001")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LT9\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(58));
GRFPC0_FP_PIPELINE_6_1_CHECK_DEP_UN2087_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2087_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(3),
datae => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.INST_1\(1));
\GRFPU0_GRFPU_X0_COMB_UN21_FLUSH_ALTB_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"7f37130177331100")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.ALTB\(2),
dataf => \FPI.FLUSHID\(0),
datae => \FPI.FLUSHID\(2),
datad => \FPI.FLUSHID\(1),
datac => \GRFPU0.GRFPU_X0.ST1.ID\(0),
datab => \GRFPU0.GRFPU_X0.ST1.ID\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.ID\(1));
GRFPU0_GRFPU_X0_UN98_BCO_LSB_0_RNIJM632: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000100000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_9792\,
dataf => \GRFPU0.GRFPU_X0.UN98_BCO_LSB_0\,
datae => \GRFPU0.GRFPU_X0.N_14275_1\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(20),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(23),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(22),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(21));
GRFPU0_GRFPU_X0_COMB_VITER_EXP27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_3407\,
dataf => \GRFPU0.GRFPU_X0.ST1.V\,
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(3));
\GRFPU0_GRFPU_X0_L1_1_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffff0000")
port map (
combout => N_82187,
dataf => \GRFPU0.GRFPU_X0.UN93_BCO_LSB_0\,
datae => \GRFPU0.GRFPU_X0.N_14295_1\,
datad => \GRFPU0.GRFPU_X0.N_9793_2\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(12),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(13));
\GRFPU0_GRFPU_X0_COMB_VITER_ALLOW_1_2_RNO_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcfffcfffc")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_60_2\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(5),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(23),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(20));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_175_I_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00030000000000")
port map (
combout => \GRFPC0.N_25620\,
dataf => \GRFPC0.N_24761_2\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.CTRL.INST\(15),
datac => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_DBGDATA_4_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3c0f3f3c0c0c0")
port map (
combout => CPO_DBG_DATAZ(22),
dataf => N_649,
datae => N_713,
datad => N_426,
datac => \FPI.NONSTD\,
datab => N_425);
\GRFPC0_STDATA_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"caffca00ca00ca00")
port map (
combout => CPO_DATAZ(17),
dataf => \GRFPC0.EX.CTRL.STDFQ\,
datae => \GRFPC0.R.STDATA\(17),
datad => N_99884,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI_2\,
datab => \GRFPC0.EX.RREG.RES\(17),
dataa => \GRFPC0.EX.RREG.RES\(49));
\GRFPC0_STDATA_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"caffca00ca00ca00")
port map (
combout => CPO_DATAZ(19),
dataf => \GRFPC0.EX.CTRL.STDFQ\,
datae => \GRFPC0.R.STDATA\(19),
datad => N_99884,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI_2\,
datab => \GRFPC0.EX.RREG.RES\(19),
dataa => \GRFPC0.EX.RREG.RES\(51));
\GRFPU0_GRFPU_X0_L1_3_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffafb0000")
port map (
combout => N_82186,
dataf => \GRFPU0.GRFPU_X0.N_14255_1\,
datae => \GRFPU0.GRFPU_X0.N_9794_2\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(28));
\GRFPC0_FP_PIPELINE_DBGDATA_4_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3c0f3f3c0c0c0")
port map (
combout => CPO_DBG_DATAZ(15),
dataf => N_642,
datae => N_706,
datad => N_426,
datac => \GRFPC0.R.FSR.FTT\(1),
datab => N_425);
\GRFPU0_GRFPU_X0_COMB_EXPADDSUB_EXPT_1_O2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16\,
dataf => \GRFPU0.GRFPU_X0.UN8_C\(6),
datae => \GRFPU0.GRFPU_X0.UN8_C\(3),
datad => \GRFPU0.GRFPU_X0.UN8_C\(5),
datac => \GRFPU0.GRFPU_X0.UN8_C\(2),
datab => \GRFPU0.GRFPU_X0.UN8_C\(4));
\GRFPU0_GRFPU_X0_L1_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffeeef0000")
port map (
combout => N_82183,
dataf => \GRFPU0.GRFPU_X0.N_14275_1\,
datae => \GRFPU0.GRFPU_X0.UN98_BCO_LSB_0\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(22),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(23),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(21),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(20));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0cccaaccaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(29),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_5508\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datac => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(29));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5aaaccccaaaacccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16452\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXP57\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(1),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(2));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003300fa0afa0a")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(45),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_5508\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(45));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003300fa0afa0a")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(31),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_5508\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(31));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003300fa0afa0a")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(49),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_5508\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(49));
GRFPC0_FP_PIPELINE_VRFA_ST_1_U_1_RNIEFQ61: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => N_45055_1,
dataf => N_97,
datae => \GRFPC0.FP_PIPELINE.VRFA.ST_1_1\,
datad => N_102,
datac => N_99,
datab => N_98);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_429_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eccca000cccc0000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_429_0\(0),
dataf => \GRFPC0.N_24189\,
datae => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6414_REGDEPX2\,
datad => \GRFPC0.EX.CTRL.INST\(3),
datac => \GRFPC0.EX.CTRL.INST\(4),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(0),
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003300fa0afa0a")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(50),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_5508\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(50));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0303000000aa00aa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_28__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_2_01\,
datad => \GRFPU0.GRFPU_X0.N_5774\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(28));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_23560\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.FIFO.INST_1\(28),
datad => \GRFPC0.FIFO.INST_1\(29),
datac => \GRFPC0.FIFO.INST_1\(26),
datab => \GRFPC0.FIFO.INST_1\(27));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_70_0_A3_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_25426\,
dataf => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN695_REGDEPX2_2\,
datae => \GRFPC0.N_25319\,
datad => \GRFPC0.EX.CTRL.INST\(15),
datac => \GRFPC0.EX.CTRL.INST\(16),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(0));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M5_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_ST2_V_RNIL8RI2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000008000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VCS_DP_1_I_0_I_0_N_5\,
dataf => \GRFPU0.GRFPU_X0.N_335\,
datae => \GRFPU0.GRFPU_X0.N_5777_I_I_O2_I_O2_2_0_0\,
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
dataa => \GRFPU0.GRFPU_X0.ST2.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0fff00000f0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(13),
dataf => N_99921,
datae => \GRFPU0.GRFPU_X0.N_18663\,
datad => \GRFPU0.MULO.MRES\(74),
datac => \GRFPU0.MULO.MRES\(73));
GRFPU0_GRFPU_X0_COMB_DPRES4_3_RNIB1RA2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0020000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.SEL_0_I_A2_0_3\(1),
dataf => \GRFPU0.GRFPU_X0.N_18449\,
datae => \GRFPU0.GRFPU_X0.N_6038_3\,
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(2));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0cccaaccaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(30),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_5508\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datac => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(30));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M6_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPC0_D_FSTLCK_RNO_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffefc")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1_8\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.MEM.CTRL.LD\,
datac => \GRFPC0.WR.CTRL.CCWR\,
datab => \GRFPC0.EX.CTRL.CCWR\,
dataa => \GRFPC0.MEM.CTRL.AFSR\);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_325_0_A4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf00000000000")
port map (
combout => \GRFPC0.N_24975\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(1),
datac => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4814_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4785_REGDEPX2\);
GRFPU0_GRFPU_X0_ITER_EMIN_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaaaaaaaae000c")
port map (
combout => N_26927,
dataf => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.N_5790\,
datad => \GRFPU0.GRFPU_X0.ITER.EXPT\(0),
datac => \GRFPU0.GRFPU_X0.ITER.EXPT\(1),
datab => \GRFPU0.GRFPU_X0.ITER.EXPT\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.EMIN\);
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M4_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000f0f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_115_0_A4_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1000000000000000")
port map (
combout => \GRFPC0.N_25570\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(0),
datad => \GRFPC0.WR2.CTRL.INST\(1),
datac => \GRFPC0.WR2.CTRL.INST\(2),
datab => \GRFPC0.WR2.CTRL.INST\(4),
dataa => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0cfc0ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(24),
dataf => N_25,
datae => \GRFPC0.N_24035\,
datad => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(24),
datac => \GRFPC0.EX.CTRL.PEND\,
datab => \GRFPC0.EX.CTRL.INST\(24));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_A0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000002000000000")
port map (
combout => N_1_4,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.N_705\,
datad => \GRFPC0.N_25498\,
datac => \GRFPC0.WR.CTRL.RS1V\,
datab => \GRFPC0.WR.CTRL.INST\(15),
dataa => \GRFPC0.WR.CTRL.INST\(16));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003300fa0afa0a")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(51),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_5508\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(51));
GRFPC0_DIV_EXC_RNO_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPC0.DIV.EXC_0_0_G4_0_1042_A2_1\,
dataf => \GRFPC0.WR2.CTRL.SEQERR\,
datae => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA\,
datad => N_35);
\GRFPU0_GRFPU_X0_RNDOP_29_IV_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ffff000000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
dataf => \GRFPU0.MULO.MRES\(67),
datae => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datac => \GRFPU0.GRFPU_X0.ITER.SIGN\);
GRFPC0_FP_PIPELINE_UN1_CPI_RNIC2TO1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0002000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_642_0_A2_1\,
dataf => N_109,
datae => N_108,
datad => N_112,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI\,
datab => N_113,
dataa => \GRFPC0.N_220\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0cccaaccaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(46),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_5508\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datac => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(46));
\GRFPU0_GRFPU_X0_L1_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_9804\,
dataf => \GRFPU0.GRFPU_X0.N_9856\,
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(6),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(7));
\GRFPC0_FP_PIPELINE_8_0_REGDEPX_149_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f8f08800f0f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.0.REGDEPX_149_0_0\(0),
dataf => \GRFPC0.N_24921\,
datae => \GRFPC0.N_22429\,
datad => \GRFPC0.N_22427\,
datac => \GRFPC0.FP_PIPELINE.8.0.CHECK_DEP.UN2607_REGDEPX\,
datab => \GRFPC0.N_23963\,
dataa => \GRFPC0.FP_PIPELINE.8.0.REGDEPX_149_0_A2_1_0_0\(0));
GRFPU0_GRFPU_X0_UN1_VST2_REG82_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST2.REG82_1\,
dataf => \GRFPU0.GRFPU_X0.N_3516\,
datae => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__N_7_1\,
datad => \GRFPU0.GRFPU_X0.REST_1_1\(2),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3));
GRFPC0_UN1_STDEP382: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000010001000000")
port map (
combout => \GRFPC0.UN1_STDEP382\,
dataf => \GRFPC0.N_470\,
datae => \GRFPC0.N_482\,
datad => \GRFPC0.MEM.CTRL.RD\(2),
datac => \GRFPC0.MEM.CTRL.RD\(4),
datab => \GRFPC0.MEM.CTRL.RD\(1),
dataa => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_175_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f888f00088880000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_0_0\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datae => \GRFPC0.N_24193\,
datad => \GRFPC0.N_24199\,
datac => \GRFPC0.N_24194\,
datab => \GRFPC0.N_24198\,
dataa => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003300fa0afa0a")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_5508\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(48));
\GRFPU0_GRFPU_X0_L1_4_5_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f1f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_5\(3),
dataf => \GRFPU0.GRFPU_X0.UN58_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(47));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003300fa0afa0a")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(47),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_5508\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(47));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_175_0_4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"b3a0a0a033000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_0_4\(1),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.N_25592_1\,
datad => \GRFPC0.N_25859\,
datac => \GRFPC0.N_25746\,
datab => \GRFPC0.N_25550\,
dataa => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2504_REGDEPX2\);
GRFPC0_DIV_PEND_RNO_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333333333333303")
port map (
combout => \GRFPC0.DIV.PEND_0_0_G5_0\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.N_23687\,
datad => \GRFPC0.N_23694\,
datac => \GRFPC0.DIV.PEND\,
datab => \GRFPC0.DIV.EXC_MB_2_I_0\);
GRFPU0_GRFPU_X0_UN1_RNDOP_2_I_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"802a000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18570\,
dataf => \GRFPU0.GRFPU_X0.VALLOW_0_SQMUXA_2\,
datae => \GRFPU0.GRFPU_X0.N_13387\,
datad => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datac => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ITER.SIGN\,
dataa => \GRFPU0.GRFPU_X0.ITER.LOB\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_O2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00004400f0f0f4f0")
port map (
combout => \GRFPC0.N_24386\,
dataf => \GRFPC0.N_702\,
datae => \GRFPC0.N_706\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_1\,
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3887_REGDEPX2\,
datab => \GRFPC0.WR.CTRL.INST\(29),
dataa => \GRFPC0.WR.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_14_0_REGDEPX_257_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eca0eca0ffffeca0")
port map (
combout => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_257\(0),
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.STDDEP_0_SQMUXA_111_I_I_A2_0_A3_0\,
datad => \GRFPC0.N_23986_1\,
datac => \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.UN735_REGDEPX_1\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_0\(29),
dataa => \GRFPC0.N_24902\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5accaaccaaccaacc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16456\,
dataf => N_32654,
datae => \GRFPU0.GRFPU_X0.COMB.EXP57\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(58),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(6));
GRFPU0_GRFPU_X0_UN1_VST2_EXC_1_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f1f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST2.EXC_1_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.N_3499\,
datae => \GRFPU0.GRFPU_X0.N_3516\,
datad => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__N_7_1\,
datac => \GRFPU0.GRFPU_X0.N_3406\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3));
\GRFPC0_FP_PIPELINE_10_REGDEPX_192_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8080000080ff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX_192_0_0\(1),
dataf => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_24821\,
datac => \GRFPC0.N_25016\,
datab => \GRFPC0.N_24539\,
dataa => \GRFPC0.FIFO.INST_0\(18));
GRFPU0_GRFPU_X0_UN78_BCO_LSB_RNI9QAO1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0001000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0\(4),
dataf => \GRFPU0.GRFPU_X0.L1_0_2\(3),
datae => \GRFPU0.GRFPU_X0.UN78_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(42),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(43));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf000aaaaf000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(59),
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.N_4105\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(7),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(7));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_1_1_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00080000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_1_1\(24),
dataf => \GRFPC0.N_25680\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datad => \GRFPC0.N_704\,
datac => \GRFPC0.N_25498\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN334_REGDEPX2_1\,
dataa => \GRFPC0.WR.CTRL.RS1V\);
\GRFPU0_GRFPU_X0_L1_0_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0cccccccc")
port map (
combout => N_82203,
dataf => \GRFPU0.GRFPU_X0.N_9500\,
datae => \GRFPU0.GRFPU_X0.N_13718\,
datad => \GRFPU0.GRFPU_X0.N_40\,
datac => \GRFPU0.GRFPU_X0.TZI2\(5),
datab => \GRFPU0.GRFPU_X0.N_13855_1\);
GRFPU0_GRFPU_X0_COMB_TMP316_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_8975\,
dataf => \GRFPU0.GRFPU_X0.N_6050_6\,
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(5));
GRFPU0_GRFPU_X0_VITER_FLUSH0_0_SQMUXA_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00cc00c0000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.FLUSH0_0_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.N_5678\,
datae => \GRFPU0.GRFPU_X0.N_4401\,
datad => \GRFPU0.GRFPU_X0.N_4438\,
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.EMIN\);
\GRFPC0_D_STLCK_RNO_2_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f2f2fff22222ff22")
port map (
combout => \GRFPC0.D.STLCK_0_0_24__G1_1\,
dataf => \GRFPC0.N_23371\,
datae => \GRFPC0.STDDEP_0_SQMUXA_25_I_1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(0),
datac => \GRFPC0.EX.CTRL.LD\,
datab => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_25_I\(0),
dataa => \GRFPC0.FP_PIPELINE.0.UN1_DEP\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf000aaaaf000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_27\(55),
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.N_4105\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(55),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(3));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8080ff8080808080")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_1\(6),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.N_704\,
datad => \GRFPC0.N_25823_2\,
datac => \GRFPC0.N_24750_1\,
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1653_REGDEPX2_2\,
dataa => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1653_REGDEPX2_0\);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_255_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffeca0eca0eca0")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_255_0_1\(1),
dataf => \GRFPC0.N_24404_1\,
datae => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_A0_1\(1),
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3813_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3842_REGDEPX2\,
datab => \GRFPC0.N_25406_1\,
dataa => \GRFPC0.N_24403_1\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_380_0_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc0000000000")
port map (
combout => \GRFPC0.N_25760_2\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.12.REGDEPX2_380_0_A2_2_1\(0),
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX2_380_0_A2_3_1\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(0));
\GRFPU0_GRFPU_X0_TZI_RNIMAJG2_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000530000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_9547\,
dataf => \GRFPU0.GRFPU_X0.N_9554\,
datae => \GRFPU0.GRFPU_X0.TZI\(20),
datad => \GRFPU0.GRFPU_X0.N_13638\,
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(29));
\GRFPU0_GRFPU_X0_L1_1_1_2_I_1_RNIK5CB2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0010000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_9793\,
dataf => \GRFPU0.GRFPU_X0.N_9804\,
datae => \GRFPU0.GRFPU_X0.UN93_BCO_LSB_0\,
datad => \GRFPU0.GRFPU_X0.N_14295_1\,
datac => \GRFPU0.GRFPU_X0.N_9793_2\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(12),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(13));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_230_0_A3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f22200000000")
port map (
combout => \GRFPC0.N_25507\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.N_706\,
datad => \GRFPC0.N_25516_2\,
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_18_0\(1),
datab => \GRFPC0.N_25497\,
dataa => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN771_REGDEPX2_2\);
\GRFPU0_GRFPU_X0_L1_0_5_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_9486\,
dataf => \GRFPU0.GRFPU_X0.N_9500\,
datae => \GRFPU0.GRFPU_X0.N_13718\,
datad => \GRFPU0.GRFPU_X0.N_40\,
datac => \GRFPU0.GRFPU_X0.TZI2\(5));
\GRFPC0_FP_PIPELINE_13_STDEP_536_3_I_A3_I_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000c0ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_536_3_I_A3_I_0\(0),
dataf => \GRFPC0.N_21274\,
datae => \GRFPC0.N_53\,
datad => \GRFPC0.N_21241\,
datac => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_19_2_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5555f8f055558800")
port map (
combout => \GRFPU0.GRFPU_X0.N_17323\,
dataf => \GRFPU0.GRFPU_X0.N_4105\,
datae => \GRFPU0.GRFPU_X0.N_4202\,
datad => \GRFPU0.GRFPU_X0.N_3638_1\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.V\,
dataa => \GRFPU0.GRFPU_X0.ST1.SIGN2\);
GRFPU0_GRFPU_X0_EXPOP_1_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000e1000000")
port map (
combout => \GRFPU0.GRFPU_X0.EXPOP_1_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datae => \GRFPU0.MULO.DRES_1\(121),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.MULO.MRES\(67),
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1));
GRFPU0_GRFPU_X0_COMB_UN23_RNDOP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
dataf => \GRFPU0.GRFPU_X0.N_6509\,
datae => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datac => \GRFPU0.GRFPU_X0.ITER.SIGN\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(8),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(68),
datac => \GRFPU0.MULO.DRES_1\(68));
GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_54_M2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"2222202202220022")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_54_N_3\,
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(6),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(6),
datad => \GRFPU0.GRFPU_X0.N_18527\,
datac => \GRFPU0.GRFPU_X0.N_11529\,
datab => \GRFPU0.GRFPU_X0.N_5673_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPC0_D_STDLCK_RNO_2_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfcfcfffffffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_11__G1_2\,
dataf => \GRFPC0.N_23396\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_23895\,
datac => \GRFPC0.N_21737\,
datab => \GRFPC0.STDDEP_0_SQMUXA_10\);
\GRFPC0_D_STLCK_RNO_8_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff8ff88f8f88888")
port map (
combout => \GRFPC0.D.STLCK_0_0_15__G1_1\,
dataf => \GRFPC0.N_594\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datad => \GRFPC0.N_21899\,
datac => \GRFPC0.N_21902\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
dataa => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_25_I_I_0\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"afbf0f3f0f3f0f3f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(34),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => \GRFPU0.GRFPU_X0.N_18663\,
datac => \GRFPU0.GRFPU_X0.N_19681\,
datab => \GRFPU0.MULO.MRES\(94),
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(34));
\GRFPU0_GRFPU_X0_COMB_EXPADDSUB_EXPT_1_A4_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0080008000800000")
port map (
combout => \GRFPU0.GRFPU_X0.N_46\,
dataf => \GRFPU0.GRFPU_X0.N_24\,
datae => \GRFPU0.GRFPU_X0.N_17\,
datad => \GRFPU0.GRFPU_X0.UN8_C\(10),
datac => \GRFPU0.GRFPU_X0.N_5226\,
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
dataa => \GRFPU0.GRFPU_X0.ST1.EXP1\(10));
GRFPC0_FP_PIPELINE_0_UN1_FPO_9_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_1\,
dataf => \FPO.IDOUT\(0),
datae => \FPO.IDOUT\(4),
datad => \GRFPC0.EX.CTRL.ID\(0),
datac => \GRFPC0.EX.CTRL.ID\(4));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc00000aaaaaaaa")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(30),
dataf => \GRFPC0.N_23670\,
datae => N_25,
datad => \GRFPC0.N_256\,
datac => \GRFPC0.EX.CTRL.PEND\,
datab => \GRFPC0.EX.CTRL.INST\(30),
dataa => \GRFPC0.EX.CTRL.PC\(30));
\GRFPC0_D_LDLCK_RNO_0_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000f888f000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_14__G1_0\,
dataf => \GRFPC0.N_25036\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datad => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_25_I_I_0\(0),
datac => \GRFPC0.N_25793_1\,
datab => \GRFPC0.N_22892_1\,
dataa => \GRFPC0.N_22370_3\);
\GRFPU0_GRFPU_X0_L4_3_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0f0aaccaacc")
port map (
combout => \GRFPU0.GRFPU_X0.L4_3\(3),
dataf => \GRFPU0.GRFPU_X0.L3_0\(5),
datae => \GRFPU0.GRFPU_X0.L1_5\(3),
datad => \GRFPU0.GRFPU_X0.N_6535\,
datac => \GRFPU0.GRFPU_X0.L1_4\(3),
datab => \GRFPU0.GRFPU_X0.N_6540\,
dataa => \GRFPU0.GRFPU_X0.L1_2\(3));
\GRFPC0_D_STDLCK_RNO_7_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff222f000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_3__G1_1\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_26\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => \GRFPC0.N_9476\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datab => N_245,
dataa => \GRFPC0.N_23478\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc00000aaaaaaaa")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(22),
dataf => \GRFPC0.N_23670\,
datae => N_25,
datad => \GRFPC0.N_253\,
datac => \GRFPC0.EX.CTRL.PEND\,
datab => \GRFPC0.EX.CTRL.INST\(22),
dataa => \GRFPC0.EX.CTRL.PC\(22));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0f3f0f3f0f3f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(24),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(24),
datad => \GRFPU0.GRFPU_X0.N_18663\,
datac => \GRFPU0.GRFPU_X0.N_19681\,
datab => \GRFPU0.MULO.MRES\(84));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f3300000f330f33")
port map (
combout => \GRFPU0.GRFPU_X0.N_282\,
dataf => \GRFPU0.GRFPU_X0.N_19546\,
datae => \GRFPU0.GRFPU_X0.N_18998\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(35),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(35));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3705ffff37053705")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(18),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.N_18191\,
datad => N_99921,
datac => \GRFPU0.GRFPU_X0.N_18663\,
datab => \GRFPU0.MULO.MRES\(79),
dataa => \GRFPU0.MULO.MRES\(78));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_RNO_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(9),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(69),
datac => \GRFPU0.MULO.DRES_1\(69));
\GRFPU0_GRFPU_X0_ITER_STATE_RNITM107_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000331100000301")
port map (
combout => \GRFPU0.GRFPU_X0.N_194\,
dataf => \GRFPU0.GRFPU_X0.N_134\,
datae => \GRFPU0.GRFPU_X0.N_3560_I\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(7),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(15));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M8_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc00000aaaaaaaa")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(20),
dataf => \GRFPC0.N_23670\,
datae => N_25,
datad => \GRFPC0.N_251\,
datac => \GRFPC0.EX.CTRL.PEND\,
datab => \GRFPC0.EX.CTRL.INST\(20),
dataa => \GRFPC0.EX.CTRL.PC\(20));
\GRFPC0_D_STDLCK_RNO_1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff1000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_6__G1_1\,
dataf => \GRFPC0.N_22080\,
datae => \GRFPC0.N_22406_I\,
datad => \GRFPC0.RFA.LD\,
datac => \GRFPC0.N_661_1\,
datab => N_176,
dataa => N_173);
\GRFPC0_D_STLCK_RNO_2_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffba30ba30ba30")
port map (
combout => \GRFPC0.D.STLCK_0_0_22__G1_1\,
dataf => \GRFPC0.N_23985\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_21454\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(0),
datab => \GRFPC0.N_21737\,
dataa => \GRFPC0.STDDEP_0_SQMUXA_10\);
\GRFPU0_GRFPU_X0_L4_2_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"22222222f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.L4_2\(2),
dataf => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(4),
datae => \GRFPU0.GRFPU_X0.L1_4_1\(3),
datad => \GRFPU0.GRFPU_X0.UN108_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.UN113_BCO_LSB\(15),
datab => \GRFPU0.GRFPU_X0.N_14195_1\,
dataa => \GRFPU0.GRFPU_X0.UN118_BCO_LSB_2\(15));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_7_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_4\,
dataf => \GRFPU0.GRFPU_X0.NXX_1_3_0\,
datae => \GRFPU0.GRFPU_X0.NXX_1_5\,
datad => \GRFPU0.MULO.MRES\(61),
datac => \GRFPU0.MULO.MRES\(63),
datab => \GRFPU0.MULO.MRES\(62),
dataa => \GRFPU0.MULO.MRES\(16));
GRFPU0_GRFPU_X0_COMB_SGNFINC_INC_1_M3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0000fff00000f0")
port map (
combout => N_80553,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1\,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datad => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(28));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff570357035703")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(9),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(9),
datad => N_99921,
datac => \GRFPU0.GRFPU_X0.N_18663\,
datab => \GRFPU0.MULO.MRES\(69),
dataa => \GRFPU0.MULO.MRES\(70));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(45),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(104),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(105),
datab => \GRFPU0.MULO.DRES_1\(105),
dataa => \GRFPU0.MULO.DRES_1S\(104));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(47),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(106),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(107),
datab => \GRFPU0.MULO.DRES_1\(107),
dataa => \GRFPU0.MULO.DRES_1S\(106));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ca00ff00ca00ca")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1_0_51__G0_0_A3_0_0\,
dataf => \GRFPU0.GRFPU_X0.N_19546\,
datae => \GRFPU0.GRFPU_X0.N_18998\,
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(51),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(51));
\GRFPC0_D_STLCK_RNO_2_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f444444444444444")
port map (
combout => \GRFPC0.D.STLCK_0_0_30__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(0),
datae => \GRFPC0.RFA.LD\,
datad => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN5169_DEP_2\,
datac => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1233_DEP_1\,
datab => \GRFPC0.N_23127\,
dataa => \GRFPC0.N_61_I\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccaaccaafff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(42),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(101),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(102),
datab => \GRFPU0.MULO.DRES_1S\(101),
dataa => \GRFPU0.MULO.DRES_1\(102));
GRFPU0_GRFPU_X0_COMB_UN138_RNDOP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff0f0fff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
dataf => \GRFPU0.GRFPU_X0.RNDOP_32\(0),
datae => \GRFPU0.MULO.MRES\(119),
datad => \GRFPU0.MULO.DRES_1\(119),
datac => \GRFPU0.MULO.MRES\(96));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_7_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff004000")
port map (
combout => \GRFPC0.N_25067\,
dataf => \GRFPC0.N_22983\,
datae => \GRFPC0.N_25063\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_22902_1\,
datab => \GRFPC0.N_25083\,
dataa => \GRFPC0.FIFO.INST_1\(17));
\GRFPC0_D_STDLCK_RNO_9_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000050f0103")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_10_1\,
dataf => \GRFPC0.N_23088\,
datae => \GRFPC0.N_25889\,
datad => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4976_DEP\,
datac => \GRFPC0.FP_PIPELINE.STDDEP_1_4\,
datab => \GRFPC0.WR.CTRL.RDWR\,
dataa => \GRFPC0.MEM.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O2_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffaafffeffaa")
port map (
combout => \GRFPC0.N_23041\,
dataf => \GRFPC0.N_23010\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_23012\,
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_1\(1),
dataa => \GRFPC0.N_23036\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_0_O4_RNI00I02_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffa080a080a080")
port map (
combout => \GRFPU0.GRFPU_X0.N_19563\,
dataf => \GRFPU0.GRFPU_X0.N_272\,
datae => \GRFPU0.GRFPU_X0.N_19554\,
datad => \GRFPU0.GRFPU_X0.N_19553\,
datac => \GRFPU0.GRFPU_X0.REST_2\(5),
datab => \GRFPU0.GRFPU_X0.N_3407\,
dataa => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPC0_D_STLCK_RNO_3_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff8fff888f8f8888")
port map (
combout => \GRFPC0.D.STLCK_0_0_9__G1_1\,
dataf => \GRFPC0.N_594\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datad => \GRFPC0.N_22707\,
datac => \GRFPC0.STDDEP_0_SQMUXA_14_I_1\,
datab => \GRFPC0.N_22706\,
dataa => \GRFPC0.N_59\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_0_1_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eeaaf0f0cc00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_0_1\(15),
dataf => \GRFPU0.GRFPU_X0.N_272\,
datae => \GRFPU0.GRFPU_X0.N_19582\,
datad => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_2\,
datac => \GRFPU0.GRFPU_X0.N_19561\,
datab => \FPI.OP1_RETO\(15),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(15));
\GRFPC0_FP_PIPELINE_4_0_REGDEPX_77_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1f0f0f0f11000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.0.REGDEPX_77_0_0\(0),
dataf => \GRFPC0.N_24837_1\,
datae => \GRFPC0.N_22429\,
datad => \GRFPC0.N_25011\,
datac => \GRFPC0.FIFO.INST_0\(18),
datab => \GRFPC0.FIFO.INST_0\(2),
dataa => \GRFPC0.FIFO.INST_0\(1));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"faeeaaaaf0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(30),
dataf => \GRFPU0.GRFPU_X0.N_18976\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW1\(30));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccc0c0ccaaaaaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.N_16991\,
dataf => N_99908_I_0,
datae => \GRFPU0.GRFPU_X0.N_4\,
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(6),
dataa => \GRFPU0.MULO.MRES\(66));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0307000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_2\(1),
dataf => \GRFPU0.GRFPU_X0.N_4260\,
datae => \GRFPU0.GRFPU_X0.N_18221\,
datad => \GRFPU0.GRFPU_X0.N_18219\,
datac => \GRFPU0.GRFPU_X0.C\(11),
datab => \GRFPU0.GRFPU_X0.C\(7),
dataa => \GRFPU0.GRFPU_X0.C\(1));
\GRFPC0_D_STDLCK_RNO_4_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffefffffffffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_4__G1_4\,
dataf => \GRFPC0.N_22631\,
datae => \GRFPC0.N_22689\,
datad => \GRFPC0.N_22636\,
datac => \GRFPC0.STDDEP_0_SQMUXA_14_I_1\,
datab => \GRFPC0.N_22707\,
dataa => \GRFPC0.N_22706\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_2_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3222300030003000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__N_5\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6\,
datae => \GRFPU0.GRFPU_X0.N_5834\,
datad => \GRFPU0.GRFPU_X0.N_5791\,
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(63),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFFN\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5accaaccaaccaacc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16459\,
dataf => N_32669,
datae => \GRFPU0.GRFPU_X0.COMB.EXP57\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(61),
dataa => \GRFPU0.GRFPU_X0.ITER.EXP\(9));
GRFPU0_GRFPU_X0_COMB_UN1_FLOP4_0_0_A3_0_RNIHANT9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000b0004000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_18441_I_0_G0_1\,
dataf => \GRFPU0.GRFPU_X0.N_18516\,
datae => \GRFPU0.GRFPU_X0.N_18523\,
datad => \GRFPU0.GRFPU_X0.N_18477\,
datac => \GRFPU0.GRFPU_X0.N_97\,
datab => \GRFPU0.GRFPU_X0.N_18449\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(3));
\GRFPC0_D_LDLCK_RNO_3_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffc000c000c000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_5__G1_0\,
dataf => \GRFPC0.N_21639_2\,
datae => \GRFPC0.N_22740_1\,
datad => \GRFPC0.N_22742_2\,
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN943_REGDEPX_2\,
datab => \GRFPC0.N_25355_2\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff5dfd")
port map (
combout => \GRFPU0.GRFPU_X0.N_10085\,
dataf => \GRFPU0.GRFPU_X0.N_19690\,
datae => \GRFPU0.GRFPU_X0.N_19692_1\,
datad => \GRFPU0.GRFPU_X0.N_73\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
dataa => N_35);
\GRFPC0_D_LDLCK_RNO_1_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff888f888f888")
port map (
combout => \GRFPC0.D.LDLCK_0_0_27__G1_1\,
dataf => \GRFPC0.N_25355_2\,
datae => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4375_REGDEPX\,
datad => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_25_I_I_0\(1),
datac => \GRFPC0.N_25793_1\,
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4360_REGDEPX\,
dataa => \GRFPC0.N_23988_1\);
GRFPU0_GRFPU_X0_ST3_RDY_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffafbfaffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.RDY_0_0_G0_2\,
dataf => \GRFPU0.GRFPU_X0.N_5756_1\,
datae => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\,
datad => \GRFPU0.GRFPU_X0.N_5820\,
datac => \GRFPU0.GRFPU_X0.N_5791\,
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
dataa => \GRFPU0.GRFPU_X0.ST2.RDY\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16733\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5),
datab => \GRFPU0.MULO.MRES\(73));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaf0aaf00000cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(1),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_17818\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
datab => \GRFPU0.MULO.MRES\(61),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(1));
GRFPU0_GRFPU_X0_SGNF_0_SQMUXA_57_I_A2_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_16\,
dataf => \FPI.OP1\(26),
datae => \FPI.OP1\(24),
datad => \FPI.OP1\(25),
datac => \FPI.OP1\(27));
\GRFPC0_FP_PIPELINE_6_REGDEPX_120_0_A2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00d0000000")
port map (
combout => \GRFPC0.N_22447\,
dataf => \GRFPC0.N_22426\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.FP_PIPELINE.6.0.CHECK_DEP.UN1983_REGDEPX\,
datab => \GRFPC0.FIFO.INST_0\(6),
dataa => \GRFPC0.FIFO.INST_0\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16729\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datab => \GRFPU0.MULO.MRES\(69));
\GRFPC0_D_LDLCK_RNO_0_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff88f888f888f8")
port map (
combout => \GRFPC0.D.LDLCK_0_0_24__G1_1\,
dataf => \GRFPC0.N_25795_1\,
datae => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4048_REGDEPX\,
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_25_I\(0),
datac => \GRFPC0.N_25793_1\,
datab => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4063_REGDEPX\,
dataa => \GRFPC0.N_24849_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaacc0000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(7),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.MULO.MRES\(67),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(7),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16728\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datac => \GRFPU0.MULO.MRES\(68),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(0));
GRFPU0_GRFPU_X0_SGNF_0_SQMUXA_57_I_A2_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_20\,
dataf => \FPI.OP1\(10),
datae => \FPI.OP1\(11),
datad => \FPI.OP1\(8),
datac => \FPI.OP1\(9));
\GRFPU0_GRFPU_X0_L4_6_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"44444444f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.L4_6\(3),
dataf => \GRFPU0.GRFPU_X0.N_9542\,
datae => \GRFPU0.GRFPU_X0.N_9548\,
datad => \GRFPU0.GRFPU_X0.N_9559\,
datac => \GRFPU0.GRFPU_X0.N_9547\,
datab => \GRFPU0.GRFPU_X0.L1_4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L1_5_4\(3));
\GRFPC0_FP_PIPELINE_11_REGDEPX_214_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff8888888")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX_214\(0),
dataf => \GRFPC0.FP_PIPELINE.11.REGDEPX_210\(0),
datae => \GRFPC0.N_24818\,
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3736_REGDEPX\,
datac => \GRFPC0.N_21627\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_0_0\(2),
dataa => \GRFPC0.N_9484\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16732\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datab => \GRFPU0.MULO.MRES\(72));
\GRFPC0_D_LDLCK_RNO_1_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff300030003000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_20__G1_0\,
dataf => \GRFPC0.N_25795_1\,
datae => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3424_REGDEPX\,
datad => \GRFPC0.N_9483\,
datac => \GRFPC0.N_23184_2\,
datab => N_97);
\GRFPC0_FP_PIPELINE_9_REGDEPX_176_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX_176\(0),
dataf => \GRFPC0.FP_PIPELINE.9.REGDEPX_174\(0),
datae => \GRFPC0.N_61_I\,
datad => \GRFPC0.N_9482\,
datac => N_97);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000acfc0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10109\,
dataf => \GRFPU0.GRFPU_X0.N_148\,
datae => \GRFPU0.GRFPU_X0.N_10086_1\,
datad => \GRFPU0.GRFPU_X0.N_7\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaf0aaf00000cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(5),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_17818\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
datab => \GRFPU0.MULO.MRES\(65),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaf0aaf00000cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(6),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_17818\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(6),
datab => \GRFPU0.MULO.MRES\(66),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(6));
\GRFPC0_FP_PIPELINE_0_STDEP_16_3_I_O2_I_A3_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff330f03ff220f02")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_16_3_I_O2_I_A3_1\(0),
dataf => \GRFPC0.N_114\,
datae => \GRFPC0.N_477\,
datad => \GRFPC0.N_21353\,
datac => \GRFPC0.N_470\,
datab => \GRFPC0.WR.CTRL.RDD\,
dataa => \GRFPC0.WR.CTRL.RD\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaf0aaf00000cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(0),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_17818\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(0),
datab => \GRFPU0.MULO.MRES\(60),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(0));
GRFPU0_GRFPU_X0_COMB_IEXC25_NE_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"7d7d77ddbebebbee")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.IEXC25_NE_2\,
dataf => \GRFPU0.GRFPU_X0.L4_7\(3),
datae => \GRFPU0.GRFPU_X0.L3_0_3\(5),
datad => \GRFPU0.GRFPU_X0.L3_0_5\(1),
datac => \GRFPU0.GRFPU_X0.L3_1_1\(1),
datab => \GRFPU0.GRFPU_X0.ITER.TZR\(2),
dataa => \GRFPU0.GRFPU_X0.ITER.TZR\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfffff0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(60),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_17818\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.MULO.MRES\(120),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(60),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(60));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaf0aaf00000cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(4),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_17818\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
datab => \GRFPU0.MULO.MRES\(64),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_6_1_1_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff222fffff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6_1_1\(43),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.GRFPU_X0.N_3560_I\,
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datac => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datab => \GRFPU0.GRFPU_X0.ITER.DP\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaf0aaf00000cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(3),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_17818\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(3),
datab => \GRFPU0.MULO.MRES\(63),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(3));
\GRFPC0_FP_PIPELINE_1_STDEP_52_3_I_O2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffffffff")
port map (
combout => \GRFPC0.N_22118\,
dataf => \GRFPC0.N_114\,
datae => \GRFPC0.N_22126\,
datad => \GRFPC0.WR.CTRL.RDD\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaf0aaf00000cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(2),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_17818\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
datab => \GRFPU0.MULO.MRES\(62),
dataa => \GRFPU0.GRFPU_X0.ITER.ND_I\(2));
\GRFPC0_FIFO_VCNT_1_RNO_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0c0ccc0c0cccc")
port map (
combout => \GRFPC0.FIFO.VCNT_1_0_0__G1_1_4304_I_1\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => N_47153,
datad => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datac => \GRFPC0.FIFO.VCNT_1\(1),
datab => N_35);
GRFPC0_RFA_RDWR_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000010")
port map (
combout => \GRFPC0.RFA.RDWR_0_0_G1_0_1554_A2_3\,
dataf => \GRFPC0.N_21965\,
datae => \GRFPC0.N_21108\,
datad => N_45119_I,
datac => \GRFPC0.FP_PIPELINE.VRFA.ST_1_1\,
datab => N_99,
dataa => N_39);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_RNIM8G2H_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_5755_1\,
dataf => \GRFPU0.GRFPU_X0.N_5758\,
datae => \GRFPU0.GRFPU_X0.N_5756_1\,
datad => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(4),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(3));
\GRFPC0_FP_PIPELINE_4_REGDEPX_88_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff1111111")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX_88\(0),
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX_84\(0),
datae => \GRFPC0.N_24818\,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1552_REGDEPX\,
datac => \GRFPC0.N_21627\,
datab => N_97,
dataa => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_25_I\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_180_IV_0_A2_6_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_6_1\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.N_21866\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datac => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_1\,
datab => \GRFPC0.N_505\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eca0eca00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_4__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.N_33\,
datac => \GRFPU0.GRFPU_X0.N_73\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(4));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M36_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5f5c0f0c53500300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(37),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_2_03\,
datac => \GRFPU0.GRFPU_X0.N_9666\,
datab => \GRFPU0.GRFPU_X0.N_9672\,
dataa => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(4));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eca0eca00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_10__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.N_33\,
datac => \GRFPU0.GRFPU_X0.N_73\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(10));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_I_M4_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccaacccaca")
port map (
combout => \GRFPU0.GRFPU_X0.N_18467\,
dataf => N_99909_I_0,
datae => \GRFPU0.GRFPU_X0.N_15611\,
datad => \GRFPU0.GRFPU_X0.COMB.UN13_ITER_OF\,
datac => \GRFPU0.GRFPU_X0.N_18449\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63),
dataa => \GRFPU0.GRFPU_X0.ITER.SIGN\);
\GRFPC0_D_STDLCK_RNO_0_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3fffffff3f3f")
port map (
combout => \GRFPC0.D.STDLCK_0_0_13__G1_2\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.N_21269\,
datad => \GRFPC0.N_21274\,
datac => \GRFPC0.N_23261\,
datab => \GRFPC0.N_23234\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eca0eca00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_9__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.N_33\,
datac => \GRFPU0.GRFPU_X0.N_73\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(9));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eca0eca00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_19__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.N_33\,
datac => \GRFPU0.GRFPU_X0.N_73\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(19));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eca0eca00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_15__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.N_33\,
datac => \GRFPU0.GRFPU_X0.N_73\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(15));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eca0eca00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_11__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.N_33\,
datac => \GRFPU0.GRFPU_X0.N_73\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(19),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(11));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eca0eca00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_6__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.N_33\,
datac => \GRFPU0.GRFPU_X0.N_73\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(6));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_11_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0cfcfcfc0c0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(4),
dataf => \GRFPU0.GRFPU_X0.VITER.DBUF_7_1_CO2\,
datae => \GRFPU0.GRFPU_X0.L2_0\(4),
datad => \GRFPU0.GRFPU_X0.L1_0_2\(3),
datac => \GRFPU0.GRFPU_X0.N_19742\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(4));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eca0eca00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_5__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.N_33\,
datac => \GRFPU0.GRFPU_X0.N_73\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(5));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M37_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5f5c0f0c53500300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(38),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_2_03\,
datac => \GRFPU0.GRFPU_X0.N_9666\,
datab => \GRFPU0.GRFPU_X0.N_9672\,
dataa => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(4));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_465_0_A2_5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_25166\,
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6767_REGDEPX2_2\,
datad => \FPI.FLOP\(6),
datac => \GRFPC0.N_23975\,
datab => \GRFPC0.N_24271\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eca0eca00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_8__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.N_33\,
datac => \GRFPU0.GRFPU_X0.N_73\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(8));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eca0eca00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_7__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.N_33\,
datac => \GRFPU0.GRFPU_X0.N_73\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_XX_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf0fffffcc00")
port map (
combout => N_93235,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(50),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(50),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(13),
datac => \GRFPU0.GRFPU_X0.N_18664\,
datab => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\);
GRFPC0_FP_PIPELINE_11_STDEP_452_SEL1_I_0_A2_I_I_A3_RNI04T69: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff4fffffffc")
port map (
combout => \GRFPC0.N_23495\,
dataf => \GRFPC0.N_104\,
datae => \GRFPC0.N_23389\,
datad => \GRFPC0.N_23415\,
datac => \GRFPC0.N_23491\,
datab => \GRFPC0.N_23382\,
dataa => \GRFPC0.N_664\);
GRFPC0_V_FSR_CEXC_6_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000008000a0")
port map (
combout => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
dataf => N_46992,
datae => \GRFPC0.FP_PIPELINE.UN25_HOLDN_1\,
datad => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datac => \GRFPC0.DIV.VALID\,
datab => \GRFPC0.WR2.CTRL.LD\,
dataa => \GRFPC0.V.FSR.AEXC_1_SQMUXA\);
GRFPC0_WR2_CTRL_STDFQ_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0100000001000100")
port map (
combout => N_44787,
dataf => CPO_EXCZ,
datae => \GRFPC0.WR.CTRL.LD\,
datad => \GRFPC0.WR.CTRL.STDFQ\,
datac => N_388,
datab => N_389,
dataa => N_39);
\GRFPC0_D_STLCK_RNO_1_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33110000331f000f")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_398_I_M_I_O2_1_0_TZ\(1),
dataf => \GRFPC0.N_571\,
datae => \GRFPC0.N_810\,
datad => \GRFPC0.N_449\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datab => \GRFPC0.N_502\,
dataa => \GRFPC0.N_505\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fefafcf0eeaacc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(31),
dataf => \GRFPU0.GRFPU_X0.N_154\,
datae => \GRFPU0.GRFPU_X0.N_19779\,
datad => \GRFPU0.GRFPU_X0.N_18976\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(31),
dataa => \GRFPU0.GRFPU_X0.ST1.RAW2\(31));
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cf0fcc000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10068\,
dataf => \GRFPU0.GRFPU_X0.N_18448\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.N_18440_I_0\,
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.EXC\(4));
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000d0f00000")
port map (
combout => \GRFPC0.N_21564\,
dataf => \GRFPC0.N_615\,
datae => \GRFPC0.N_858\,
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2698_DEP_1\,
datac => \GRFPC0.N_482\,
datab => \GRFPC0.N_473_1\,
dataa => \GRFPC0.EX.CTRL.RD\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_17_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0cfc0cfcfc0c0cfc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(5),
dataf => N_32333,
datae => \GRFPU0.GRFPU_X0.L4_1\(4),
datad => \GRFPU0.GRFPU_X0.N_9787\,
datac => \GRFPU0.GRFPU_X0.N_4623_2\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(5));
GRFPC0_RFA_ST_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000001")
port map (
combout => N_45011,
dataf => CPO_EXCZ,
datae => \GRFPC0.N_21934\,
datad => \GRFPC0.N_21108\,
datac => N_112,
datab => N_113,
dataa => N_39);
GRFPC0_EX_CTRL_RDWR_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000044004040")
port map (
combout => N_47179,
dataf => CPO_EXCZ,
datae => \FPI.START\,
datad => \GRFPC0.RFA.WRITE_RD\,
datac => \GRFPC0.RFA.RDWR\,
datab => N_35,
dataa => N_39);
\GRFPC0_INST_I_M2_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaaaccf0aaf0cc")
port map (
combout => \GRFPC0.N_23921\,
dataf => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datae => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_1\(3),
datab => \GRFPC0.FIFO.INST_0\(3),
dataa => N_81);
\GRFPC0_INST_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccaaaaf0ccf0")
port map (
combout => \GRFPC0.INST\(25),
dataf => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datae => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_0\(25),
datab => \GRFPC0.FIFO.INST_1\(25),
dataa => N_103);
\GRFPC0_INST_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaaaf0ccaaccf0")
port map (
combout => \GRFPC0.INST\(2),
dataf => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datae => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_1\(2),
dataa => N_80);
\GRFPC0_D_STLCK_RNO_1_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f332f2230332022")
port map (
combout => \GRFPC0.D.STLCK_0_0_20__G1_5\,
dataf => \GRFPC0.N_571\,
datae => \GRFPC0.N_765\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datac => \GRFPC0.N_490\,
datab => \GRFPC0.N_501\,
dataa => \GRFPC0.N_579\);
\GRFPC0_INST_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccaaaaf0ccf0")
port map (
combout => \GRFPC0.INST\(7),
dataf => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datae => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_0\(7),
datab => \GRFPC0.FIFO.INST_1\(7),
dataa => N_85);
\GRFPC0_INST_I_M2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaaaccf0aaf0cc")
port map (
combout => \GRFPC0.N_25334\,
dataf => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datae => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_1\(4),
datab => \GRFPC0.FIFO.INST_0\(4),
dataa => N_82);
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_O2_4_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"4445444454555454")
port map (
combout => \GRFPC0.N_25895\,
dataf => \GRFPC0.N_462\,
datae => \GRFPC0.N_514\,
datad => \GRFPC0.UN1_STDEP382\,
datac => \GRFPC0.N_533\,
datab => \GRFPC0.N_21502_2\,
dataa => \GRFPC0.N_21521\);
\GRFPC0_INST_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccaaaaf0ccf0")
port map (
combout => \GRFPC0.INST\(29),
dataf => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datae => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_0\(29),
datab => \GRFPC0.FIFO.INST_1\(29),
dataa => N_107);
\GRFPC0_INST_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccaaaaf0ccf0")
port map (
combout => \GRFPC0.INST\(10),
dataf => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datae => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_0\(10),
datab => \GRFPC0.FIFO.INST_1\(10),
dataa => N_88);
\GRFPC0_INST_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0aaaaccf0cc")
port map (
combout => \GRFPC0.INST\(12),
dataf => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datae => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_1\(12),
datab => \GRFPC0.FIFO.INST_0\(12),
dataa => N_90);
\GRFPC0_R_STATE_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0200020032003230")
port map (
combout => N_82237,
dataf => N_46992,
datae => \GRFPC0.FP_PIPELINE.V.STATE2_1\,
datad => \GRFPC0.R.STATE\(0),
datac => \GRFPC0.R.STATE\(1),
datab => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA\,
dataa => N_40);
\GRFPC0_INST_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccaaaaf0ccf0")
port map (
combout => \GRFPC0.INST\(24),
dataf => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datae => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_0\(24),
datab => \GRFPC0.FIFO.INST_1\(24),
dataa => N_102);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"afff0fff22220222")
port map (
combout => \GRFPU0.GRFPU_X0.N_18841_I\,
dataf => \GRFPU0.GRFPU_X0.N_18883\,
datae => \GRFPU0.GRFPU_X0.N_18880\,
datad => \GRFPU0.GRFPU_X0.N_7241\,
datac => \GRFPU0.GRFPU_X0.N_10059_I\,
datab => N_32396,
dataa => \FPI.FLOP\(1));
\GRFPC0_INST_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0aaaaccf0cc")
port map (
combout => \GRFPC0.INST\(11),
dataf => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datae => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_1\(11),
datab => \GRFPC0.FIFO.INST_0\(11),
dataa => N_89);
GRFPC0_UN1_STDDEP_0_SQMUXA_97_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000020000000000")
port map (
combout => \GRFPC0.N_22366\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datae => \GRFPC0.N_525\,
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datab => \GRFPC0.N_74_I_I\,
dataa => \GRFPC0.N_21818\);
\GRFPC0_INST_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccaaaaf0ccf0")
port map (
combout => \GRFPC0.INST\(0),
dataf => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datae => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_0\(0),
datab => \GRFPC0.FIFO.INST_1\(0),
dataa => N_78);
\GRFPC0_INST_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccaaaaf0ccf0")
port map (
combout => \GRFPC0.INST\(21),
dataf => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datae => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_0\(21),
datab => \GRFPC0.FIFO.INST_1\(21),
dataa => N_99);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_0_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1111111911191119")
port map (
combout => \GRFPU0.GRFPU_X0.N_18860_I_0_G0_2\,
dataf => \GRFPU0.GRFPU_X0.N_18954\,
datae => \GRFPU0.GRFPU_X0.N_18947\,
datad => \GRFPU0.GRFPU_X0.N_18882_1\,
datac => \FPI.OP2\(51),
datab => \FPI.OP2\(54),
dataa => \FPI.FLOP\(1));
\GRFPC0_INST_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccaaaaf0ccf0")
port map (
combout => \GRFPC0.INST\(31),
dataf => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datae => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_0\(31),
datab => \GRFPC0.FIFO.INST_1\(31),
dataa => N_109);
\GRFPC0_INST_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaaaf0ccaaccf0")
port map (
combout => \GRFPC0.INST\(26),
dataf => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datae => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_0\(26),
datab => \GRFPC0.FIFO.INST_1\(26),
dataa => N_104);
\GRFPC0_INST_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccaaaaf0ccf0")
port map (
combout => \GRFPC0.INST\(9),
dataf => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datae => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_0\(9),
datab => \GRFPC0.FIFO.INST_1\(9),
dataa => N_87);
\GRFPC0_INST_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccaaaaf0ccf0")
port map (
combout => \GRFPC0.INST\(1),
dataf => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datae => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_0\(1),
datab => \GRFPC0.FIFO.INST_1\(1),
dataa => N_79);
GRFPC0_FP_PIPELINE_RSDEC_RS1V8_I_0_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaaaf0ccaaccf0")
port map (
combout => \GRFPC0.N_23618\,
dataf => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datae => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_0\(6),
datab => \GRFPC0.FIFO.INST_1\(6),
dataa => N_84);
\GRFPC0_D_STLCK_RNO_3_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000cc0fcf")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_O2_6_1\(1),
dataf => \GRFPC0.N_689\,
datae => \GRFPC0.N_114\,
datad => \GRFPC0.N_21820\,
datac => \GRFPC0.N_21822\,
datab => \GRFPC0.WR.CTRL.RDD\);
\GRFPC0_INST_I_0_M3_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0aaaaccf0cc")
port map (
combout => \GRFPC0.N_23631\,
dataf => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datae => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_1\(8),
datab => \GRFPC0.FIFO.INST_0\(8),
dataa => N_86);
\GRFPC0_INST_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccaaaaf0ccf0")
port map (
combout => \GRFPC0.INST\(5),
dataf => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datae => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_0\(5),
datab => \GRFPC0.FIFO.INST_1\(5),
dataa => N_83);
\GRFPC0_INST_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccaaaaf0ccf0")
port map (
combout => \GRFPC0.INST\(27),
dataf => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datae => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_1\(27),
dataa => N_105);
\GRFPC0_INST_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccaaaaf0ccf0")
port map (
combout => \GRFPC0.INST\(28),
dataf => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datae => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_0\(28),
datab => \GRFPC0.FIFO.INST_1\(28),
dataa => N_106);
\GRFPC0_INST_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaaaccf0aaf0cc")
port map (
combout => \GRFPC0.INST\(19),
dataf => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datae => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_1\(19),
datab => \GRFPC0.FIFO.INST_0\(19),
dataa => N_97);
\GRFPC0_EX_CTRL_INST_RNO_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(11),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \FPI.FLOP\(6),
datac => \GRFPC0.EX.CTRL.INST\(11),
datab => N_158);
GRFPC0_RFA2_FLUSH_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffefc")
port map (
combout => \GRFPC0.FP_PIPELINE.FLUSH_1\,
dataf => \GRFPC0.N_9160\,
datae => \GRFPC0.N_9159\,
datad => \GRFPC0.N_9163\,
datac => \GRFPC0.PENDEXC_0_SQMUXA\,
datab => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
dataa => \GRFPC0.FP_PIPELINE.UN17_SHARE\);
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"28a07df5a0a0f5f5")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(8),
dataf => N_32604,
datae => N_32562,
datad => \FPI.OP1\(59),
datac => \FPI.OP1\(60),
datab => \FPI.OP1\(58),
dataa => \FPI.FLOP\(1));
\GRFPC0_R_FSR_AEXC_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0c0c0c0c0")
port map (
combout => \GRFPC0.R.FSR.AEXC_0_0_0__G1_0\,
dataf => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
datae => \GRFPC0.R.FSR.AEXC\(0),
datad => \GRFPC0.DIV.EXCT\(0),
datac => N_436,
datab => \GRFPC0.V.FSR.AEXC_0_SQMUXA\);
\GRFPC0_FP_PIPELINE_WREN_17_IV_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff30ff30ffffff30")
port map (
combout => \GRFPC0.FP_PIPELINE.WREN_17_IV\(1),
dataf => \GRFPC0.WR2.CTRL.RD\(0),
datae => \GRFPC0.WREN_2_SQMUXA\,
datad => \GRFPC0.WREN_0_SQMUXA_5\,
datac => \GRFPC0.WREN_1_SQMUXA_4\,
datab => \GRFPC0.DIV.RD\(0));
\GRFPC0_EX_CTRL_INST_RNO_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(6),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \FPI.FLOP\(1),
datac => \GRFPC0.EX.CTRL.INST\(6),
datab => N_153);
\GRFPC0_EX_CTRL_INST_RNITFJQJ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(0),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_223\,
datac => \GRFPC0.EX.CTRL.INST\(0),
datab => N_147);
\GRFPC0_EX_CTRL_INST_RNIU788K_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(29),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datac => \GRFPC0.EX.CTRL.INST\(29),
datab => N_176);
\GRFPC0_EX_CTRL_INST_RNIEN68K_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(25),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.V.STDATA_14\(25),
datac => \GRFPC0.EX.CTRL.INST\(25),
datab => N_172);
\GRFPC0_FP_PIPELINE_REN1_1_IV_0_O3_0_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03ff0303030303ff")
port map (
combout => \GRFPC0.N_25098\,
dataf => \GRFPC0.INST\(11),
datae => \GRFPC0.INST\(12),
datad => \GRFPC0.INST\(19),
datac => \GRFPC0.FP_PIPELINE.VFIFO.FULL_6\,
datab => \GRFPC0.FP_PIPELINE.VFIFO.FULL10\);
\GRFPC0_FP_PIPELINE_WREN_17_IV_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffc0ffc0")
port map (
combout => \GRFPC0.FP_PIPELINE.WREN_17_I\(0),
dataf => \GRFPC0.DIV.RD\(0),
datae => \GRFPC0.WREN_1_SQMUXA_4\,
datad => \GRFPC0.WREN_0_SQMUXA_5\,
datac => \GRFPC0.WREN_2_SQMUXA\,
datab => \GRFPC0.WR2.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_259_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00a0ccec")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_259\(1),
dataf => \GRFPC0.FP_PIPELINE.8.REGDEPX2_256\(1),
datae => \GRFPC0.N_703\,
datad => \GRFPC0.N_705\,
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3872_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3887_REGDEPX2\,
dataa => \GRFPC0.WR.CTRL.RS1V\);
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_O2_4_I_A3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000070000")
port map (
combout => \GRFPC0.N_674\,
dataf => \GRFPC0.N_22910\,
datae => \GRFPC0.N_841\,
datad => \GRFPC0.N_22157\,
datac => \GRFPC0.N_570\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
dataa => \GRFPC0.N_9474\);
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_A3_1_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A3_1_2\,
dataf => \GRFPC0.N_22173_I\,
datae => \GRFPC0.N_21227_2\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datac => \GRFPC0.N_74_I_I\);
\GRFPC0_FP_PIPELINE_3_STDEP_128_3_0_O2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"bfafafaf37050505")
port map (
combout => \GRFPC0.N_867\,
dataf => \GRFPC0.STDEP_2_SQMUXA_129\,
datae => \GRFPC0.N_644_2\,
datad => \GRFPC0.N_737_2\,
datac => \GRFPC0.N_114\,
datab => \GRFPC0.N_481\,
dataa => \GRFPC0.FP_PIPELINE.3.STDEP_128_SEL0_1\);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00008d8800000500")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1\(6),
dataf => \GRFPU0.GRFPU_X0.N_18957\,
datae => \GRFPU0.GRFPU_X0.N_18883\,
datad => \GRFPU0.GRFPU_X0.N_18948\,
datac => \GRFPU0.GRFPU_X0.N_18870\,
datab => N_32396,
dataa => \FPI.FLOP\(1));
GRFPU0_GRFPU_X0_COMB_UN1_FLOP4_10_0_A2_RNIRI2B6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000b0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_18442_I\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_18522\,
datad => \GRFPU0.GRFPU_X0.N_18523\,
datac => \GRFPU0.GRFPU_X0.N_7296\,
datab => \GRFPU0.GRFPU_X0.N_18449\,
dataa => \GRFPU0.GRFPU_X0.ST3.FLOP\(3));
\GRFPC0_D_STDLCK_RNO_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000330f3300")
port map (
combout => \GRFPC0.D.STDLCK_0_0_1__G1_6\,
dataf => \GRFPC0.N_674\,
datae => \GRFPC0.N_462\,
datad => \GRFPC0.N_675\,
datac => \GRFPC0.N_22126\,
datab => \GRFPC0.N_579\);
\GRFPC0_FP_PIPELINE_0_STDEP_82_0_IV_I_A3_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000d000")
port map (
combout => \GRFPC0.N_22875\,
dataf => \GRFPC0.N_22133\,
datae => N_40688,
datad => \GRFPC0.FP_PIPELINE.1.STDEP_56_SEL0\,
datac => \GRFPC0.N_22120\,
datab => \GRFPC0.N_22126\,
dataa => \GRFPC0.N_494\);
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_0_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"7fff7fff30f020a0")
port map (
combout => \GRFPC0.N_440\,
dataf => \GRFPC0.N_492\,
datae => \GRFPC0.N_749\,
datad => \GRFPC0.N_615\,
datac => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2024_DEP\,
datab => \GRFPC0.N_579\,
dataa => \GRFPC0.MEM.CTRL.RDWR\);
\GRFPC0_D_STLCK_RNO_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffdf3f0f3f0f3f0")
port map (
combout => \GRFPC0.N_428\,
dataf => \GRFPC0.N_742_1\,
datae => \GRFPC0.N_21419\,
datad => \GRFPC0.N_484\,
datac => \GRFPC0.N_730\,
datab => \GRFPC0.N_21353\,
dataa => \GRFPC0.WR.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_1_REGDEP104: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000800000004")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP104\,
dataf => RFI2_RD2ADDRZ(1),
datae => \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD_2_4\,
datad => \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD_2_1\,
datac => \GRFPC0.FP_PIPELINE.1.UN1_DIV.RD_2_3\,
datab => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
dataa => \GRFPC0.DIV.RD\(2));
GRFPU0_GRFPU_X0_COMB_UNPACK_UN23_DP_0_O2_0_RNIIIMLC: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"45ef00aa45450000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.OP2NX_0_0_N_6\,
dataf => \GRFPU0.GRFPU_X0.N_8869\,
datae => \GRFPU0.GRFPU_X0.N_7321\,
datad => \GRFPU0.GRFPU_X0.N_18957\,
datac => \GRFPU0.GRFPU_X0.N_18948\,
datab => \GRFPU0.GRFPU_X0.N_18870\,
dataa => \FPI.FLOP\(1));
\GRFPC0_FP_PIPELINE_REN1_1_IV_0_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff00ff00ca")
port map (
combout => RFI2_REN1Z,
dataf => N_423,
datae => \GRFPC0.N_22829\,
datad => \GRFPC0.N_25099\,
datac => \GRFPC0.FP_PIPELINE.UN1_VRFA.ST\,
datab => \GRFPC0.FP_PIPELINE.STDBL_1_1\,
dataa => \GRFPC0.N_23599_I_0\);
\GRFPC0_FP_PIPELINE_REN1_1_IV_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff00ca00ff")
port map (
combout => RFI1_REN1Z,
dataf => N_423,
datae => \GRFPC0.N_22829\,
datad => \GRFPC0.N_25099\,
datac => \GRFPC0.FP_PIPELINE.UN1_VRFA.ST\,
datab => \GRFPC0.FP_PIPELINE.STDBL_1_1\,
dataa => \GRFPC0.N_23599_I_0\);
\GRFPC0_FP_PIPELINE_5_STDEP_230_0_IV_I_O2_6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"888ff8ff888f888f")
port map (
combout => \GRFPC0.N_22514\,
dataf => \GRFPC0.N_21701\,
datae => N_40688,
datad => \GRFPC0.N_21948_1\,
datac => \GRFPC0.N_21616\,
datab => \GRFPC0.N_860\,
dataa => \GRFPC0.N_470\);
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c666c6660000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(10),
dataf => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_18749\,
datad => N_32426,
datac => \FPI.OP2\(61),
datab => \FPI.OP2\(62),
dataa => \FPI.FLOP\(1));
GRFPC0_RFA2_RS2DEP_RNO_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000030000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP18_I_M_0_2\,
dataf => \GRFPC0.N_23598_I_0\,
datae => \GRFPC0.FP_PIPELINE.1.REGDEP118\,
datad => \GRFPC0.FP_PIPELINE.1.UN1_WR2.CTRL.RD\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEP18\,
datab => \GRFPC0.WR2.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_REN2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fc00fc000000fc")
port map (
combout => RFI1_REN2Z,
dataf => \GRFPC0.N_23598_I_0\,
datae => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datad => \GRFPC0.FP_PIPELINE.UN1_VRFA.ST\,
datac => \GRFPC0.FP_PIPELINE.VFIFO.FULL_6\,
datab => \GRFPC0.FP_PIPELINE.VFIFO.FULL10\);
\GRFPC0_FP_PIPELINE_3_STDEP_136_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff7f7087f0077")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_136\(1),
dataf => \GRFPC0.FP_PIPELINE.3.STDEP_132\(1),
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datad => \GRFPC0.FP_PIPELINE.3.STDEP_136_SEL0\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A2_0\,
dataa => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1058_DEP\);
GRFPC0_RFA2_RS2SEL_RET_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c000")
port map (
combout => \GRFPC0.N_10562\,
dataf => \GRFPC0.UN1_WRENX10\,
datae => \GRFPC0.FP_PIPELINE.1.WR2EN10\,
datad => \GRFPC0.FP_PIPELINE.1.DIVEN10_4\,
datac => \GRFPC0.FP_PIPELINE.1.DIVEN10_3\,
datab => \GRFPC0.DIV.VALID\);
\GRFPC0_WR_RREG_EXCT_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0fc30f3c0ff00")
port map (
combout => N_27213,
dataf => \GRFPC0.N_24361\,
datae => \GRFPC0.N_24428\,
datad => \GRFPU0.GRFPU_X0.N_18290_I_0\,
datac => \GRFPC0.MEM.RREG.EXCT\(1),
datab => N_37);
\GRFPC0_WR_RREG_EXCT_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27215,
dataf => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.EXCT\(3),
datab => N_37);
\GRFPC0_WR_RREG_EXCT_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0fc30f3c0ff00")
port map (
combout => N_27216,
dataf => \GRFPC0.N_24361\,
datae => \GRFPC0.N_24428\,
datad => \GRFPU0.GRFPU_X0.N_18289_I_0\,
datac => \GRFPC0.MEM.RREG.EXCT\(4),
datab => N_37);
\GRFPC0_WR_RREG_EXCT_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0fc30f3c0ff00")
port map (
combout => N_27217,
dataf => \GRFPC0.N_24361\,
datae => \GRFPC0.N_24428\,
datad => \GRFPC0.FPO_I_6_I_0\(69),
datac => \GRFPC0.MEM.RREG.EXCT\(5),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3fcfff0c03000")
port map (
combout => N_27320,
dataf => \GRFPU0.GRFPU_X0.N_20294_I_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.EX.RREG.RES\(32),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3fcfff0c03000")
port map (
combout => N_27322,
dataf => \GRFPU0.GRFPU_X0.N_20274_I_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.EX.RREG.RES\(34),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3fcfff0c03000")
port map (
combout => N_27323,
dataf => \GRFPU0.GRFPU_X0.N_20295_I_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.EX.RREG.RES\(35),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3fcfff0c03000")
port map (
combout => N_27325,
dataf => \GRFPU0.GRFPU_X0.N_20275_I_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.EX.RREG.RES\(37),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3fcfff0c03000")
port map (
combout => N_27326,
dataf => \GRFPU0.GRFPU_X0.N_20296_I_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.EX.RREG.RES\(38),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3fcfff0c03000")
port map (
combout => N_27327,
dataf => \GRFPU0.GRFPU_X0.N_19153_I_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.EX.RREG.RES\(39),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3fcfff0c03000")
port map (
combout => N_27328,
dataf => \GRFPU0.GRFPU_X0.N_20289_I_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.EX.RREG.RES\(40),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3fcfff0c03000")
port map (
combout => N_27329,
dataf => \GRFPU0.GRFPU_X0.N_20297_I_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.EX.RREG.RES\(41),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3fcfff0c03000")
port map (
combout => N_27330,
dataf => \GRFPU0.GRFPU_X0.N_20271_I_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.EX.RREG.RES\(42),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3fcfff0c03000")
port map (
combout => N_27331,
dataf => \GRFPU0.GRFPU_X0.N_20290_I_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.EX.RREG.RES\(43),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3fcfff0c03000")
port map (
combout => N_27332,
dataf => \GRFPU0.GRFPU_X0.N_20298_I_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.EX.RREG.RES\(44),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3fcfff0c03000")
port map (
combout => N_27333,
dataf => \GRFPU0.GRFPU_X0.N_20272_I_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.EX.RREG.RES\(45),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3fcfff0c03000")
port map (
combout => N_27334,
dataf => \GRFPU0.GRFPU_X0.N_20291_I_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.EX.RREG.RES\(46),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3fcfff0c03000")
port map (
combout => N_27335,
dataf => \GRFPU0.GRFPU_X0.N_19240_I_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.EX.RREG.RES\(47),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3fcfff0c03000")
port map (
combout => N_27336,
dataf => \GRFPU0.GRFPU_X0.N_20273_I_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.EX.RREG.RES\(48),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3fcfff0c03000")
port map (
combout => N_27337,
dataf => \GRFPU0.GRFPU_X0.N_20292_I_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.EX.RREG.RES\(49),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3fcfff0c03000")
port map (
combout => N_27339,
dataf => \GRFPU0.GRFPU_X0.N_20285_I_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.EX.RREG.RES\(51),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3fcfff0c03000")
port map (
combout => N_27340,
dataf => \GRFPU0.GRFPU_X0.N_20293_I_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.EX.RREG.RES\(52),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3fcfff0c03000")
port map (
combout => N_27342,
dataf => \GRFPU0.GRFPU_X0.N_20286_I_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.EX.RREG.RES\(54),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3fcfff0c03000")
port map (
combout => N_27345,
dataf => \GRFPU0.GRFPU_X0.N_20287_I_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.EX.RREG.RES\(57),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f3fcfff0c03000")
port map (
combout => N_27348,
dataf => \GRFPU0.GRFPU_X0.N_20288_I_0\,
datae => \GRFPC0.N_82\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.EX.RREG.RES\(60),
datab => N_37);
\GRFPC0_MEM_RREG_RES_RNO_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f3c0fc30ff00")
port map (
combout => N_27351,
dataf => \GRFPC0.N_82\,
datae => \GRFPC0.N_24428\,
datad => \FPO.RES\(63),
datac => \GRFPC0.EX.RREG.RES\(63),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27384,
dataf => \GRFPU0.GRFPU_X0.N_20294_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RES\(32),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27386,
dataf => \GRFPU0.GRFPU_X0.N_20274_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RES\(34),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27387,
dataf => \GRFPU0.GRFPU_X0.N_20295_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RES\(35),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27389,
dataf => \GRFPU0.GRFPU_X0.N_20275_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RES\(37),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27390,
dataf => \GRFPU0.GRFPU_X0.N_20296_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RES\(38),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27391,
dataf => \GRFPU0.GRFPU_X0.N_19153_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RES\(39),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27392,
dataf => \GRFPU0.GRFPU_X0.N_20289_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RES\(40),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27393,
dataf => \GRFPU0.GRFPU_X0.N_20297_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RES\(41),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27394,
dataf => \GRFPU0.GRFPU_X0.N_20271_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RES\(42),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27395,
dataf => \GRFPU0.GRFPU_X0.N_20290_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RES\(43),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27396,
dataf => \GRFPU0.GRFPU_X0.N_20298_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RES\(44),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27397,
dataf => \GRFPU0.GRFPU_X0.N_20272_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RES\(45),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27398,
dataf => \GRFPU0.GRFPU_X0.N_20291_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RES\(46),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27399,
dataf => \GRFPU0.GRFPU_X0.N_19240_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RES\(47),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27400,
dataf => \GRFPU0.GRFPU_X0.N_20273_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RES\(48),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27401,
dataf => \GRFPU0.GRFPU_X0.N_20292_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RES\(49),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27403,
dataf => \GRFPU0.GRFPU_X0.N_20285_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RES\(51),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27404,
dataf => \GRFPU0.GRFPU_X0.N_20293_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RES\(52),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27406,
dataf => \GRFPU0.GRFPU_X0.N_20286_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RES\(54),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27409,
dataf => \GRFPU0.GRFPU_X0.N_20287_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RES\(57),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcf3fff030c000")
port map (
combout => N_27412,
dataf => \GRFPU0.GRFPU_X0.N_20288_I_0\,
datae => \GRFPC0.N_24361\,
datad => \GRFPC0.N_24428\,
datac => \GRFPC0.MEM.RREG.RES\(60),
datab => N_37);
\GRFPC0_WR_RREG_RES_RNO_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0fc30f3c0ff00")
port map (
combout => N_27415,
dataf => \GRFPC0.N_24361\,
datae => \GRFPC0.N_24428\,
datad => \FPO.RES\(63),
datac => \GRFPC0.MEM.RREG.RES\(63),
datab => N_37);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M3_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(0),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(2),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(1));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M4_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(2),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(1));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M5_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M6_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(3));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M7_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(4));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M8_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(5));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M9_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccaaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(9),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(7));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M10_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(9),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(10));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M11_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(9),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(11),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(10));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M12_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(9),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(11),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(10));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M13_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(11),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(10));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M14_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(11));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M15_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(15),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(12));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M16_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(15),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(13));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M17_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccaaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(15));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M18_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(15),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(18));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M19_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(18));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M20_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(18));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M21_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(18));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M22_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(22),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(19));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M23_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(23),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(22));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M24_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(24),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(23),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(22));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M25_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(24),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(23),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(22));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M26_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(24),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(23),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(26));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M27_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(24),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(27),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(26));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M28_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccaaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(27),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(26));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M29_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(27),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(26));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M30_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(30),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(27));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M31_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(31),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(30));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M32_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccaaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(32),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(31),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(30));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M33_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(32),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(31),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(30));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M34_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(32),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(34),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(31));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M35_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(32),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(35),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(34));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M36_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccaaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(35),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(34));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M37_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(37),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(35),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(34));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M38_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(38),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(37),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(35));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M39_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(38),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(37),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(36));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M40_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(40),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(38),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(37));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M41_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(40),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(38));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M42_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(42),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(40),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(39));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M43_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(42),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(40));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M44_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(42),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(44));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M45_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(42),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(45),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(44));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M46_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccaaaaf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(46),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(45),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(44));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M47_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(46),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(45),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(44));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M48_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(46),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(45));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M49_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(46));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M50_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccff00f0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(50));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M51_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccff00aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(50),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(51));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M52_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00aaaaf0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(50),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(52),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(51));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M53_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(0),
datae => \GRFPU0.GRFPU_X0.L4_4\(1),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(50),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(52),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(51),
dataa => \GRFPU0.GRFPU_X0.ST2.DIFF\(53));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M12_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdec7564b9a83120")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M13_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdecb9a875643120")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M14_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdecb9a875643120")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M15_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdecb9a875643120")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M16_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd9eac873516240")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M17_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd9eac873516240")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M18_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd9eac873516240")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M19_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd9eac873516240")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M20_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M21_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M22_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M23_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M24_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M25_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M26_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M27_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M28_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M29_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M30_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M31_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M32_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M33_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M34_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M35_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M36_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M37_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M38_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M39_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M40_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M41_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M42_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M43_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M44_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M45_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M46_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fedc7654ba983210")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M47_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fedc7654ba983210")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M48_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fedc7654ba983210")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M49_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fedc7654ba983210")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M50_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fedcba9876543210")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M51_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fedcba9876543210")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M39_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M47_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M52_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fedcba9876543210")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M53_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fedcba9876543210")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_0_03\,
datab => \GRFPU0.GRFPU_X0.L4_4\(3),
dataa => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M48_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7e6d5c4b3a29180")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(49),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M48_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_2_03\,
datab => \GRFPU0.GRFPU_X0.N_9666\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M49_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76dc54ba329810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(50),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M49_2_03\,
datab => \GRFPU0.GRFPU_X0.N_9666\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M50_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76dc54ba329810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(51),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M50_2_03\,
datab => \GRFPU0.GRFPU_X0.N_9666\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M51_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76dc54ba329810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(52),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M51_2_03\,
datab => \GRFPU0.GRFPU_X0.N_9666\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M52_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fedc7654ba983210")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(53),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M36_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M52_2_03\,
datab => \GRFPU0.GRFPU_X0.N_9666\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M53_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fedc7654ba983210")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(54),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M37_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M53_2_03\,
datab => \GRFPU0.GRFPU_X0.N_9666\,
dataa => \GRFPU0.GRFPU_X0.L4_4\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M54_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M55_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M56_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M57_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M58_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M59_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M60_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M61_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M62_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M63_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M64_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M65_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M66_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0aaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M67_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0ff00aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M68_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M69_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M70_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M71_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M72_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M73_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M74_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M75_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M76_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M77_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M78_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M79_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M80_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M81_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0aaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M82_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M83_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M84_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0aaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M85_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M86_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M87_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0aaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M88_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0ff00aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M89_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M90_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M91_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M92_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M93_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M94_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M95_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00aaaaccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.DIVROM0.RADDR\(0),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M96_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0aaaacccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M97_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datab => \GRFPU0.DIVROM0.RADDR\(0),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M98_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.DIVROM0.RADDR\(3),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M99_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00aaaacccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.DIVROM0.RADDR\(3),
datac => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(1),
dataa => \GRFPU0.DIVROM0.RADDR\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M100_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.RADDR\(3),
datab => \GRFPU0.DIVROM0.RADDR\(4),
dataa => \GRFPU0.DIVROM0.RADDR\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M101_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.RADDR\(3),
datab => \GRFPU0.DIVROM0.RADDR\(4),
dataa => \GRFPU0.DIVROM0.RADDR\(6));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M102_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.DIVROM0.RADDR\(6),
dataa => \GRFPU0.DIVROM0.RADDR\(7));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M51_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M52_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M53_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M54_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M55_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M56_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M57_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M58_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M59_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M60_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M61_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M62_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M63_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M64_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M65_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M66_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M67_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M68_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M69_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M70_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M71_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M72_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M73_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M74_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M75_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M76_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M77_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M78_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M79_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M80_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M81_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M82_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M83_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M84_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M85_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M86_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M87_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M88_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M89_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M90_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M91_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd9eac873516240")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M92_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd9eac873516240")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M93_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M94_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M39_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(39),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M39_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M40_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(40),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M40_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M41_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(41),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M41_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M42_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(42),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M42_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M43_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(43),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M43_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M44_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(44),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M44_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M45_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(45),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M45_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M46_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(46),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M46_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M47_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(47),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M48_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd97351eac86240")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(48),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M49_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd97351eac86240")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(49),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M50_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(50),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M51_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(51),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M52_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(52),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M53_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7e6b3a2d5c49180")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(53),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M54_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(54),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M55_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(55),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M56_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(56),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M57_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(57),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M58_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(58),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M54_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M55_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M56_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M57_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M58_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M59_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M60_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M61_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M62_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M63_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M64_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M65_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M66_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0aaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M67_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0ff00aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M68_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M69_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M70_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M71_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M72_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M73_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M74_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M75_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M76_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M77_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M78_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M79_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M80_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M81_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M82_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M83_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M84_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0aaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M85_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M86_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M87_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0aaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M88_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0ff00aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M89_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M90_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M91_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M92_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M93_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M94_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M95_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M96_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M97_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M98_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M99_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaf0f0ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M100_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0aaaaff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M101_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0aaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M102_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
dataa => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M51_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M52_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M53_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M54_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M55_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M56_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M57_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M58_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M59_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M60_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M61_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M62_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M63_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M64_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M65_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M66_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M67_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M68_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M69_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M70_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M71_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M72_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M73_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M74_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M75_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M76_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M77_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M78_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M79_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M80_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M81_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M82_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M83_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M84_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M85_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M86_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M87_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M88_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M89_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M90_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M91_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd9eac873516240")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M92_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd9eac873516240")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M93_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M94_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_0_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_0_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M39_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(39),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M39_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M40_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(40),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M40_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M41_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(41),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M41_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M42_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(42),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M42_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M43_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(43),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M43_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M44_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(44),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M44_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M45_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76ba32dc549810")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(45),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M45_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M47_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(47),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M48_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd97351eac86240")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(48),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M49_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd97351eac86240")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(49),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M50_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(50),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M51_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(51),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M52_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(52),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M53_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(53),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M54_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(54),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M55_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(55),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M56_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(56),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M57_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(57),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M58_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7b3d591e6a2c480")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(58),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M3_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00aaaaccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(22),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(21));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M4_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(22),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(21));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M5_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(25),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(23),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(22));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M6_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(26),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(25),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(24),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(23));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M7_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(27),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(26),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(25),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(24));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M8_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(28),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(27),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(26),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(25));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M9_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(28),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(27),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(26));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M10_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(28),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(27));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M11_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(31),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(29),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(28));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M12_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(31),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(30),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(29));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M13_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(33),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(31),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(30));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M14_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(33),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(32),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(31));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M15_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(35),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(33),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(32));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M16_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(35),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(34),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(33));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M17_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(35),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(34));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M18_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(36),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(35));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M19_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(39),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(37),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(36));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M20_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(39),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(38),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(37));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M21_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(39),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(38));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M22_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(40),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(39));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M23_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(41),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(40));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M24_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(42),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(41));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M25_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(43),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(42));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M26_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(44),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(43));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M27_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(45),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(44));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M28_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(46),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(45));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M29_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0ff00aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(46),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(49));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M30_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(49),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(50));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M12_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M13_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb9eca875316420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M14_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb9eca875316420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M15_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb9eca875316420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_22_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_23_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_24_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5b391e6c4a280")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_COMB_SHL_CNV_SHIFT2_2_25_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76dc54ba329810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M20_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76dc54ba329810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M21_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76dc54ba329810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M22_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe76dc54ba329810")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M23_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feba7632dc985410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M24_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feba7632dc985410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M25_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feba7632dc985410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M26_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"feba7632dc985410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M27_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M19_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M27_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M28_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M16_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M28_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M29_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M17_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M30_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M18_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M30_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M32_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(0),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(1),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(2),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(3));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M33_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(1),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(2),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(3),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(4));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M34_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(2),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(3),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(4),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(5));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M35_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(3),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(4),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(5),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(6));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M36_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(4),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(5),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(6),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(7));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M37_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(5),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(6),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(7),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(8));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M38_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(6),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(7),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(8),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(9));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M39_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(7),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(8),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(9),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(10));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M40_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(8),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(9),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(10),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(11));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M41_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(9),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(10),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(11),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(12));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M42_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(10),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(11),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(12),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(13));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M43_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(11),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(12),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(13),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(14));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M44_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(12),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(13),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(14),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(15));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M45_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(13),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(14),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(15),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(16));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M46_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(14),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(15),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(16),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(17));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M47_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(15),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(16),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(17),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(18));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M48_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(16),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(17),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(18),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(19));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M49_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccaaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(17),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(18),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(19));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M50_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(18),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(19));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M51_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(22),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(19));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M52_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(22),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(23));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M53_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(22),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(23),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(24));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M54_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(22),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(24),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(25));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M55_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(23),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(25),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(26));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M56_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(24),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(25),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(26),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(27));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M57_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(25),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(26),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(27),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(28));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M58_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccaaaaff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(26),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(27),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(28));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M59_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccaaaaff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(27),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(28));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M60_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(31),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(28));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M61_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(29),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(31),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(32));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M62_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(30),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(31),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(32),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(33));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M63_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(31),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(33),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(34));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M64_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(33),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(34),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(35));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M65_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(33),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(35),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(36));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M66_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(35),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(36),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(37));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M67_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(35),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(37),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(38));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M68_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(38),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(39));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M69_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(37),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(39),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(40));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M70_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(38),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(39),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(40),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(41));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M71_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(39),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(41),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(42));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M72_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(40),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(42),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(43));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M73_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(43),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(44));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M74_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(44),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(45));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M75_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(45),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(46));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M76_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(46),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(47));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M77_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(47),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(48));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M78_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(48),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(49));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M79_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(49),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(50));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M80_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0aaaacccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(49),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(51),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(50));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M29_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7e6b3a2d5c49180")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M30_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7e6b3a2d5c49180")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M31_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M32_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M33_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M34_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M35_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M36_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M37_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M38_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M39_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M40_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M41_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M42_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M43_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M44_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M45_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M46_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M47_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M48_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M49_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M50_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M51_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M52_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M53_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M54_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M55_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M56_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M57_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M58_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M59_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M60_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M61_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M62_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M63_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M64_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M65_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M66_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M67_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M68_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M69_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd97351eac86240")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M70_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd97351eac86240")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M71_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"febadc9876325410")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_0_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M72_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"efabcd8967234501")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_0_03\,
datac => N_32260,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(55));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M17_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbead9c873625140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(17),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M17_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M18_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbead9c873625140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M18_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M19_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbead9c873625140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(19),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M19_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M20_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbead9c873625140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(20),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M20_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M21_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbea7362d9c85140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(21),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M21_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M22_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbead9c873625140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(22),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M22_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M23_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbead9c873625140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(23),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M23_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M24_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbead9c873625140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(24),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M24_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M25_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbea7362d9c85140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(25),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M25_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M26_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbea7362d9c85140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(26),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M26_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M27_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbea7362d9c85140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(27),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M27_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M28_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbea7362d9c85140")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(28),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M28_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M29_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd9eac873516240")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(29),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M30_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd9eac873516240")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(30),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M31_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbd9eac873516240")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(31),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M32_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb97531eca86420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(32),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M33_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb97531eca86420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(33),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M34_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb97531eca86420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(34),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M35_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb97531eca86420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(35),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M36_4_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdb97531eca86420")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(36),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M84_2_03\,
datab => \GRFPU0.GRFPU_X0.ST2.REG\(56),
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f03ff000c00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(22),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_22__G5\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_22__G1\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f03ff000c00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(24),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_24__G5\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_24__G1\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f03ff000c00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(25),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_25__G5\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_25__G1\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f03ff000c00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(26),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_26__G5\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_26__G1\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f03ff000c00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(27),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_27__G5\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_27__G1\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f030c00ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(28),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_28__G5\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_28__G1\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f30303fff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(32),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.N_15645\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(0),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f30303fff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(33),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.N_15646\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(1),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f30303fff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(34),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.N_15647\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(2),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f30303fff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(35),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.N_15648\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(3),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f30303fff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(36),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.N_15649\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(4),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f30303fff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(37),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.N_15650\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(5),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f30303fff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(38),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.N_15651\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(6),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f30303fff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(39),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.N_15652\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(7),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f30303fff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(40),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.N_15653\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(8),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f30303fff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(41),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.N_15654\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(9),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f30303fff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(42),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.N_15655\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(10),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f30303fff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(43),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.N_15656\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(11),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f30303fff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(44),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.N_15657\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(12),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f30303fff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(45),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(45),
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(13),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f30303fff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(46),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(46),
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(14),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f30303fff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(47),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(47),
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(15),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f30303fff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(48),
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(16),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f30303fff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(49),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(49),
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(17),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f30303fff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(50),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(50),
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(18),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f30303fff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(51),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(51),
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(19),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3fff003030f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(52),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(52),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(20),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3fff003030f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(53),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(53),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(21),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3fff003030f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(54),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(54),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(22),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3fff003030f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(55),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(55),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(23),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3fff003030f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(56),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(56),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(24),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3fff003030f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(57),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(57),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(25),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3fff003030f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(58),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(58),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(26),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3fff003030f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(59),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(59),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(27),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3fff003030f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(60),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(60),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(28),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3fff003030f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(61),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(61),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(29),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3fff003030f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(62),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(62),
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(30),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0cfcfc0f00fff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(63),
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datae => \GRFPU0.GRFPU_X0.N_18443\,
datad => \GRFPU0.GRFPU_X0.UN1_INTO\(31),
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(2),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(2),
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(2),
datab => \FPI.OP1_RETO\(2));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffccccf000cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(3),
dataf => \GRFPU0.GRFPU_X0.N_15215\,
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.N_18983_I\,
datac => \GRFPU0.GRFPU_X0.N_19937\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(3));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(4),
dataf => \GRFPU0.GRFPU_X0.N_19927\,
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(4),
datab => \FPI.OP1_RETO\(4));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(5),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(5),
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(5),
datab => \FPI.OP1_RETO\(5));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(6),
dataf => \GRFPU0.GRFPU_X0.N_19933\,
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(6),
datab => \FPI.OP1_RETO\(6));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(7),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(7),
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(7),
datab => \FPI.OP1_RETO\(7));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf00000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(8),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_8__G1\,
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \FPI.OP1_RETO\(8),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(8));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(9),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(9),
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(9),
datab => \FPI.OP1_RETO\(9));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(10),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(10),
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(10),
datab => \FPI.OP1_RETO\(10));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(11),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(11),
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(11),
datab => \FPI.OP1_RETO\(11));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(12),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(12),
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(12),
datab => \FPI.OP1_RETO\(12));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf00000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(13),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(13),
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \FPI.OP1_RETO\(13),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(13));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(14),
dataf => \GRFPU0.GRFPU_X0.N_19915\,
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(14),
datab => \FPI.OP1_RETO\(14));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffccccf000cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(15),
dataf => \GRFPU0.GRFPU_X0.N_15227\,
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.N_18983_I\,
datac => \GRFPU0.GRFPU_X0.N_19923\,
datab => \GRFPU0.GRFPU_X0.N_19561\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(16),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(16),
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(16),
datab => \FPI.OP1_RETO\(16));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(17),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(17),
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(17),
datab => \FPI.OP1_RETO\(17));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf00000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_18__G1\,
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \FPI.OP1_RETO\(18),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(18));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf00000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(19),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(19),
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \FPI.OP1_RETO\(19),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(19));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0fff0ccf000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(20),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(20),
datae => \GRFPU0.GRFPU_X0.N_19779\,
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(20));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(21),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(21),
datae => \GRFPU0.GRFPU_X0.N_3476\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(1),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(33));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(24),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(24),
datae => \GRFPU0.GRFPU_X0.N_3476\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(4),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(36));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(25),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(25),
datae => \GRFPU0.GRFPU_X0.N_3476\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(37));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(26),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(26),
datae => \GRFPU0.GRFPU_X0.N_3476\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(6),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(38));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(28),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(28),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(8),
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(40));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(29),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(29),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(9),
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(41));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0fff0ffc0cf000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(30),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_3\(30),
datae => \GRFPU0.GRFPU_X0.N_291\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3\(10),
datac => \GRFPU0.GRFPU_X0.N_3476\,
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0fff0ffc0cf000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(31),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(31),
datae => \GRFPU0.GRFPU_X0.N_19896\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3\(11),
datac => \GRFPU0.GRFPU_X0.N_3476\,
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(32),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(32),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(12),
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(44));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(33),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(33),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(13),
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(45));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc000c00fcff0cff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(35),
dataf => \GRFPU0.GRFPU_X0.N_19890\,
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(15),
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(47));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(36),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(36),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(16),
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(48));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc000c00fcff0cff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(37),
dataf => \GRFPU0.GRFPU_X0.N_19889\,
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(17),
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(49));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(40),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(40),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(20),
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(52));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0f0cf0fc000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(42),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(42),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_3\(22),
datad => \GRFPU0.GRFPU_X0.N_19546\,
datac => \GRFPU0.GRFPU_X0.N_3476\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(42));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(43),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(43),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(23),
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(55));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(44),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(44),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(24),
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(56));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(45),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(45),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(25),
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(57));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc000c00fcff0cff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(47),
dataf => \GRFPU0.GRFPU_X0.N_19888\,
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(27),
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(59));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(48),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(28),
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(60));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc000c00fcff0cff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(49),
dataf => \GRFPU0.GRFPU_X0.N_19887\,
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(29),
datad => \GRFPU0.GRFPU_X0.N_3476\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(61));
GRFPC0_R_FSR_NONSTD_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc30fc30fcfc3030")
port map (
combout => \GRFPC0.R.FSR.NONSTD_0_0_G1\,
dataf => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datae => \FPI.NONSTD\,
datad => \GRFPC0.WR2.RREG.RES\(22),
datac => N_453,
datab => \GRFPC0.R.FSR.FCC_0_0_1__N_5\);
\GRFPC0_R_FSR_RD_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfc3030fc30fc30")
port map (
combout => \GRFPC0.R.FSR.RD_0_0_0__G1\,
dataf => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datae => \GRFPC0.WR2.RREG.RES\(30),
datad => \FPI.RNDMODE\(0),
datac => N_461,
datab => \GRFPC0.R.FSR.FCC_0_0_1__N_5\);
\GRFPC0_R_FSR_RD_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfc3030fc30fc30")
port map (
combout => \GRFPC0.R.FSR.RD_0_0_1__G1\,
dataf => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datae => \GRFPC0.WR2.RREG.RES\(31),
datad => \FPI.RNDMODE\(1),
datac => N_462,
datab => \GRFPC0.R.FSR.FCC_0_0_1__N_5\);
\GRFPC0_R_FSR_TEM_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc30fc30fcfc3030")
port map (
combout => \GRFPC0.R.FSR.TEM_0_0_0__G1\,
dataf => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datae => \GRFPC0.R.FSR.TEM\(0),
datad => \GRFPC0.WR2.RREG.RES\(23),
datac => N_454,
datab => \GRFPC0.R.FSR.FCC_0_0_1__N_5\);
\GRFPC0_R_FSR_TEM_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc30fc30fcfc3030")
port map (
combout => \GRFPC0.R.FSR.TEM_0_0_1__G1\,
dataf => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datae => \GRFPC0.R.FSR.TEM\(1),
datad => \GRFPC0.WR2.RREG.RES\(24),
datac => N_455,
datab => \GRFPC0.R.FSR.FCC_0_0_1__N_5\);
\GRFPC0_R_FSR_TEM_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc30fc30fcfc3030")
port map (
combout => \GRFPC0.R.FSR.TEM_0_0_2__G1\,
dataf => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datae => \GRFPC0.R.FSR.TEM\(2),
datad => \GRFPC0.WR2.RREG.RES\(25),
datac => N_456,
datab => \GRFPC0.R.FSR.FCC_0_0_1__N_5\);
\GRFPC0_R_FSR_TEM_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc30fc30fcfc3030")
port map (
combout => \GRFPC0.R.FSR.TEM_0_0_3__G1\,
dataf => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datae => \GRFPC0.R.FSR.TEM\(3),
datad => \GRFPC0.WR2.RREG.RES\(26),
datac => N_457,
datab => \GRFPC0.R.FSR.FCC_0_0_1__N_5\);
\GRFPC0_R_FSR_TEM_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc30fc30fcfc3030")
port map (
combout => \GRFPC0.R.FSR.TEM_0_0_4__G1\,
dataf => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datae => \GRFPC0.R.FSR.TEM\(4),
datad => \GRFPC0.WR2.RREG.RES\(27),
datac => N_458,
datab => \GRFPC0.R.FSR.FCC_0_0_1__N_5\);
\GRFPC0_R_STDATA_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333f0000000f000")
port map (
combout => \GRFPC0.R.STDATA_0_0_0__G1\,
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(0),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.N_23670\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(0),
datab => N_99870);
\GRFPC0_R_STDATA_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333f0000000f000")
port map (
combout => \GRFPC0.R.STDATA_0_0_1__G1\,
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(1),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.N_23670\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(1),
datab => N_99870);
\GRFPC0_R_STDATA_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(2),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(2),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(2),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(2));
\GRFPC0_R_STDATA_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(3),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(3),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(3),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(3));
\GRFPC0_R_STDATA_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(4),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(4),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(4),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(4));
\GRFPC0_R_STDATA_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(5),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(5),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(5),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(5));
\GRFPC0_R_STDATA_RNO_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(6),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(6),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(6),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(6));
\GRFPC0_R_STDATA_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(7),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(7),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(7),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(7));
\GRFPC0_R_STDATA_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfc0c0ff00ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(8),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(8),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(8),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(8));
\GRFPC0_R_STDATA_RNO_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(9),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(9),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(9),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(9));
\GRFPC0_R_STDATA_RNO_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(10),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(10),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.N_23670\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(10),
datab => \GRFPC0.EX.CTRL.PC\(10));
\GRFPC0_R_STDATA_RNO_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(11),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(11),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(11),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(11));
\GRFPC0_R_STDATA_RNO_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(12),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(12),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(12),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(12));
\GRFPC0_R_STDATA_RNO_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(13),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(13),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(13),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(13));
\GRFPC0_R_STDATA_RNO_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfc0c0ff00ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(14),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(14),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(14),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(14));
\GRFPC0_R_STDATA_RNO_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(15),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(15),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(15),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(15));
\GRFPC0_R_STDATA_RNO_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(16),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(16),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(16),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(16));
\GRFPC0_R_STDATA_RNO_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(17),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(17),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(17),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(17));
\GRFPC0_R_STDATA_RNO_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(18),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(18),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(18),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(18));
\GRFPC0_R_STDATA_RNO_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfc0c0ff00ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(19),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(19),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(19),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(19));
\GRFPC0_R_STDATA_RNO_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(20),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(20),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(20),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(20));
\GRFPC0_R_STDATA_RNO_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfc0c0ff00ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(21),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(21),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(21),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(21));
\GRFPC0_R_STDATA_RNO_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(22),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(22),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(22),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(22));
\GRFPC0_R_STDATA_RNO_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfc0c0ff00ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(23),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(23),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(23),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(23));
\GRFPC0_R_STDATA_RNO_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(24),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(24),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.N_23670\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(24),
datab => \GRFPC0.EX.CTRL.PC\(24));
\GRFPC0_R_STDATA_RNO_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(25),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(25),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(25),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(25));
\GRFPC0_R_STDATA_RNO_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(26),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(26),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(26),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(26));
\GRFPC0_R_STDATA_RNO_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(27),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(27),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(27),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(27));
\GRFPC0_R_STDATA_RNO_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(28),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(28),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(28),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(28));
\GRFPC0_R_STDATA_RNO_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(29),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(29),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(29),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(29));
\GRFPC0_R_STDATA_RNO_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfff00c0c0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(30),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(30),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_M8\(30),
datac => N_99870,
datab => \GRFPC0.DIV.PC\(30));
\GRFPC0_R_STDATA_RNO_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1\(31),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(31),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
datad => \GRFPC0.N_23670\,
datac => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(31),
datab => \GRFPC0.EX.CTRL.PC\(31));
\GRFPC0_R_FSR_FCC_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfc3030fc30fc30")
port map (
combout => \GRFPC0.R.FSR.FCC_0_0_0__N_6\,
dataf => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_SM0\,
datae => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M1\(0),
datad => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M0\(0),
datac => N_441,
datab => \GRFPC0.R.FSR.FCC_0_0_1__N_5\);
\GRFPC0_R_FSR_FCC_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfc3030fc30fc30")
port map (
combout => \GRFPC0.R.FSR.FCC_0_0_1__N_6\,
dataf => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_SM0\,
datae => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M1\(1),
datad => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M0\(1),
datac => N_442,
datab => \GRFPC0.R.FSR.FCC_0_0_1__N_5\);
\GRFPC0_EX_CTRL_INST_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(1),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_24039\,
datac => \GRFPC0.EX.CTRL.INST\(1),
datab => N_148);
\GRFPC0_EX_CTRL_INST_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(2),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_225\,
datac => \GRFPC0.EX.CTRL.INST\(2),
datab => N_149);
\GRFPC0_EX_CTRL_INST_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(3),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_226\,
datac => \GRFPC0.EX.CTRL.INST\(3),
datab => N_150);
\GRFPC0_EX_CTRL_INST_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(4),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_227\,
datac => \GRFPC0.EX.CTRL.INST\(4),
datab => N_151);
\GRFPC0_EX_CTRL_INST_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(5),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \FPI.FLOP\(0),
datac => \GRFPC0.EX.CTRL.INST\(5),
datab => N_152);
\GRFPC0_EX_CTRL_INST_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(7),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \FPI.FLOP\(2),
datac => \GRFPC0.EX.CTRL.INST\(7),
datab => N_154);
\GRFPC0_EX_CTRL_INST_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(8),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \FPI.FLOP\(3),
datac => \GRFPC0.EX.CTRL.INST\(8),
datab => N_155);
\GRFPC0_EX_CTRL_INST_RNO_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(9),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \FPI.FLOP\(4),
datac => \GRFPC0.EX.CTRL.INST\(9),
datab => N_156);
\GRFPC0_EX_CTRL_INST_RNO_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(10),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \FPI.FLOP\(5),
datac => \GRFPC0.EX.CTRL.INST\(10),
datab => N_157);
\GRFPC0_EX_CTRL_INST_RNO_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(12),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \FPI.FLOP\(7),
datac => \GRFPC0.EX.CTRL.INST\(12),
datab => N_159);
\GRFPC0_EX_CTRL_INST_RNO_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(13),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \FPI.FLOP\(8),
datac => \GRFPC0.EX.CTRL.INST\(13),
datab => N_160);
\GRFPC0_EX_CTRL_INST_RNIOFSMJ_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(14),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_235\,
datac => \GRFPC0.EX.CTRL.INST\(14),
datab => N_161);
\GRFPC0_EX_CTRL_INST_RNO_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(15),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_24487\,
datac => \GRFPC0.EX.CTRL.INST\(15),
datab => N_162);
\GRFPC0_EX_CTRL_INST_RNO_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(16),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_24488\,
datac => \GRFPC0.EX.CTRL.INST\(16),
datab => N_163);
\GRFPC0_EX_CTRL_INST_RNO_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(17),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_24489\,
datac => \GRFPC0.EX.CTRL.INST\(17),
datab => N_164);
\GRFPC0_EX_CTRL_INST_RNO_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.EX.CTRL.INST_0_0_18__G1\,
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.V.STDATA_14\(18),
datac => \GRFPC0.EX.CTRL.INST\(18),
datab => N_165);
\GRFPC0_EX_CTRL_INST_RNO_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(19),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_236\,
datac => \GRFPC0.EX.CTRL.INST\(19),
datab => N_166);
\GRFPC0_EX_CTRL_INST_RNO_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(21),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_222\,
datac => \GRFPC0.EX.CTRL.INST\(21),
datab => N_168);
\GRFPC0_EX_CTRL_INST_RNO_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(23),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_24034\,
datac => \GRFPC0.EX.CTRL.INST\(23),
datab => N_170);
\GRFPC0_EX_CTRL_INST_RNO_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(24),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.N_24035\,
datac => \GRFPC0.EX.CTRL.INST\(24),
datab => N_171);
\GRFPC0_EX_CTRL_INST_RNII378K_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(26),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.INST\(26),
datab => N_173);
\GRFPC0_EX_CTRL_INST_RNIMF78K_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(27),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datac => \GRFPC0.EX.CTRL.INST\(27),
datab => N_174);
\GRFPC0_EX_CTRL_INST_RNIQR78K_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(28),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.INST\(28),
datab => N_175);
\GRFPC0_EX_CTRL_INST_RNO_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ff00cccc")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(31),
dataf => \GRFPC0.N_23673\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.V.STDATA_14\(31),
datac => \GRFPC0.EX.CTRL.INST\(31),
datab => N_178);
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3cf03cf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(3),
dataf => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_14998\,
datad => N_32396,
datac => \FPI.OP2\(55),
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3cf03cf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(4),
dataf => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_14999\,
datad => N_32401,
datac => \FPI.OP2\(56),
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3cf03cf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(6),
dataf => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_18748\,
datad => N_32411,
datac => \FPI.OP2\(58),
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3cf03cf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(7),
dataf => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_18749\,
datad => N_32416,
datac => \FPI.OP2\(59),
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3cf03cf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(8),
dataf => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_18749\,
datad => N_32421,
datac => \FPI.OP2\(60),
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3cf03cf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(9),
dataf => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1_SN_N_4\,
datae => \GRFPU0.GRFPU_X0.N_18749\,
datad => N_32426,
datac => \FPI.OP2\(61),
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf00000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(1),
dataf => \GRFPU0.GRFPU_X0.N_79\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datad => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(9),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(2));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf00000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(2),
dataf => \GRFPU0.GRFPU_X0.N_18234\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datad => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(8),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(3));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf00000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(3),
dataf => \GRFPU0.GRFPU_X0.N_81\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datad => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(7),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(4));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf00000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(4),
dataf => \GRFPU0.GRFPU_X0.N_82\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datad => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(6),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(5));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccf00000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(5),
dataf => \GRFPU0.GRFPU_X0.N_18235\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datad => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(5),
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(6));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcfc00000cfc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(6),
dataf => \GRFPU0.GRFPU_X0.N_18236\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datad => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(4),
datac => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(7));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcfc00000cfc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(7),
dataf => \GRFPU0.GRFPU_X0.N_85\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datad => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(3),
datac => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(8));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcfc00000cfc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(8),
dataf => \GRFPU0.GRFPU_X0.N_86\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datad => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(2),
datac => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(9));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcfc00000cfc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(9),
dataf => \GRFPU0.GRFPU_X0.N_87\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datad => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(1),
datac => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(10));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffc000cf00c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(10),
dataf => \GRFPU0.GRFPU_X0.N_18237\,
datae => \GRFPU0.GRFPU_X0.UN1_VITER.EXP_1_SQMUXA\(0),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1_SN_N_3\,
datac => \GRFPU0.GRFPU_X0.VITER.EXP_1_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.ST1.EXP2\(10));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffeffee55545544")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(52),
dataf => \GRFPU0.GRFPU_X0.L3_0_7\(0),
datae => \GRFPU0.GRFPU_X0.N_17234\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(52),
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_A2_2_0\(52),
datab => \GRFPU0.GRFPU_X0.N_262\,
dataa => \GRFPU0.GRFPU_X0.N_3476\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0c3f0c3300ffcc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(53),
dataf => \GRFPU0.GRFPU_X0.L2_0_6\(4),
datae => N_82213,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(53),
datac => N_82225,
datab => \GRFPU0.GRFPU_X0.N_3476\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffcc33303300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(54),
dataf => \GRFPU0.GRFPU_X0.L3_0_7\(2),
datae => \GRFPU0.GRFPU_X0.N_19574\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(54),
datac => \GRFPU0.GRFPU_X0.N_19592_1\,
datab => \GRFPU0.GRFPU_X0.N_3476\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffc33333330")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(55),
dataf => \GRFPU0.GRFPU_X0.L3_0_7\(3),
datae => \GRFPU0.GRFPU_X0.N_19963\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(55),
datac => \GRFPU0.GRFPU_X0.N_19960\,
datab => \GRFPU0.GRFPU_X0.N_3476\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fff33330ccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(56),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(56),
datae => \GRFPU0.GRFPU_X0.L2_0_6\(4),
datad => \GRFPU0.GRFPU_X0.L1_2_5\(3),
datac => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L1_3\(3),
datab => \GRFPU0.GRFPU_X0.N_3476\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f030c00ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(30),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_1_1__G5\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_1_1__G1\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f030c00ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(31),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_1_2__G5\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_1_2__G1\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0cffff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(37),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_1_8__G1\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_1_8__G5\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0cffff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(41),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_12__G1\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_12__G5\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0cffff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(42),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_13__G1\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_13__G5\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0cffff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(43),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_14__G1\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_14__G5\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0cffff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(44),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_15__G1\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_15__G5\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0cffff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(45),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_16__G1\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_16__G5\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0cffff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(46),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_17__G1\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_17__G5\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0cffff03000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(47),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_18__G1\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_18__G5\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datab => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fcffff000c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(49),
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_20__G1\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datad => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datac => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\,
datab => \GRFPU0.GRFPU_X0.ST3.REG_V_0_20__G5\);
GRFPU0_GRFPU_X0_ST2_QSNAN_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10049\,
dataf => \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G0_0\,
datae => \GRFPU0.GRFPU_X0.N_5250\,
datad => \GRFPU0.GRFPU_X0.N_3499\,
datac => \GRFPU0.GRFPU_X0.N_3516\,
datab => \GRFPU0.GRFPU_X0.REST_2\(2));
\GRFPC0_D_STLCK_RNO_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0f0f0fc")
port map (
combout => \GRFPC0.D.STLCK_0_0_22__G1\,
dataf => \GRFPC0.N_23460\,
datae => \GRFPC0.FP_PIPELINE.0.STDEP_482_0_IV_0_A2_0_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.STDEP_482_0_IV_0_A2_0\(0),
datac => \GRFPC0.D.STLCK_0_0_22__G1_5\,
datab => \GRFPC0.N_9484\);
\GRFPC0_D_LDLCK_RNO_2_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0c0c0ff000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_10__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_0_0\(2),
datae => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1864_REGDEPX\,
datad => \GRFPC0.N_25795_1\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datab => \GRFPC0.N_9478\);
\GRFPC0_D_LDLCK_RNO_0_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffccfffffffc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_10__G1_4\,
dataf => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A2_1\(10),
datae => \GRFPC0.N_22593\,
datad => \GRFPC0.N_22589\,
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datab => \GRFPC0.D.LDLCK_0_0_10__G1_1\);
\GRFPC0_D_STLCK_RNO_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ecccfcfcffffffff")
port map (
combout => \GRFPC0.D.STLCK_0_0_18__G1\,
dataf => \GRFPC0.N_21916\,
datae => \GRFPC0.N_62\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1\(0),
datac => \GRFPC0.N_856\,
datab => \GRFPC0.D.STLCK_0_0_18__G1_3\,
dataa => \GRFPC0.N_9482\);
\GRFPC0_D_STLCK_RNO_4_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0cff00ff00ff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_6__G1_0\,
dataf => \GRFPC0.N_21454\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => \GRFPC0.D.STLCK_0_0_6__G1_TZ\,
datac => N_245,
datab => \GRFPC0.N_23478\);
\GRFPC0_D_STLCK_RNO_0_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0f0f0fcf0fcf0")
port map (
combout => \GRFPC0.D.STLCK_0_0_6__G1_4\,
dataf => \GRFPC0.N_62\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1\(0),
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datac => \GRFPC0.D.STLCK_0_0_6__G1_3\,
datab => \GRFPC0.N_9476\);
\GRFPC0_D_STLCK_RNO_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff8fff77ff07")
port map (
combout => \GRFPC0.D.STLCK_0_0_6__G1\,
dataf => \GRFPC0.N_18500\,
datae => \GRFPC0.FP_PIPELINE.3.STDEP_132\(0),
datad => \GRFPC0.D.STLCK_0_0_6__G1_4\,
datac => \GRFPC0.FP_PIPELINE.3.STDEP_136_SEL0\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A2_0\,
dataa => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1058_DEP\);
\GRFPC0_D_STLCK_RNO_1_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff000000ff")
port map (
combout => \GRFPC0.D.STLCK_0_0_8__G1_3\,
dataf => \GRFPC0.D.STLCK_0_0_8__G1_2\,
datae => \GRFPC0.FP_PIPELINE.4.STDEP_194_0_IV_0_A4_0_0\(0),
datad => \GRFPC0.N_22631\);
\GRFPC0_EX_CTRL_ID_RNO_2_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcfcfc")
port map (
combout => \GRFPC0.EX.CTRL.ID_0_0_7__G1_0_1663_TZ_2\,
dataf => N_45196_1,
datae => \GRFPC0.RFA.READ_RS1\,
datad => \GRFPC0.RFA2.RS1DEP\,
datac => \GRFPC0.RFA2.RS2DEP\,
datab => N_39);
\GRFPC0_EX_CTRL_ID_RNO_0_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0003")
port map (
combout => \GRFPC0.EX.CTRL.ID_0_0_7__G1_0_1663_TZ_4\,
dataf => \GRFPC0.EX.CTRL.ID_0_0_7__G1_0_1663_TZ_2\,
datae => \GRFPC0.FP_PIPELINE.UN6_FIFOV\,
datad => \GRFPC0.RFA2.FOP\(0),
datac => \GRFPC0.RFA2.FOP\(1),
datab => \GRFPC0.FPR.ALLOW\(2));
\GRFPC0_D_LDLCK_RNO_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffcf0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_13__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210\(1),
datae => \GRFPC0.N_22481\,
datad => \GRFPC0.N_22428\,
datac => \GRFPC0.D.LDLCK_0_0_13__G1_0\,
datab => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\);
\GRFPC0_FP_PIPELINE_0_STDEP_482_0_IV_0_A2_0_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c0ff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDEP_482_0_IV_0_A2_0_0\(0),
dataf => \GRFPC0.N_62\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datac => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_1\,
datab => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_0\);
GRFPC0_RFA_ST_RNO_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.RFA.ST_0_0_G1_0_1397_A2_0\,
dataf => N_109,
datae => N_108,
datad => N_101,
datac => N_99);
GRFPC0_RFA_ST_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c000c000c000000")
port map (
combout => N_45010,
dataf => N_45011,
datae => \GRFPC0.FP_PIPELINE.UN1_CPI\,
datad => \GRFPC0.RFA.ST_0_0_G1_0_1397_A2_0\,
datac => N_100,
datab => N_102);
GRFPC0_RFA_SEQERR_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0f0000000c")
port map (
combout => \GRFPC0.RFA.SEQERR_0_0_G1_0_1460_A2_0\,
dataf => N_45055,
datae => \GRFPC0.N_21108\,
datad => \GRFPC0.N_23695\,
datac => N_39,
datab => \GRFPC0.FP_PIPELINE.UN26_OP\);
GRFPC0_RFA_SEQERR_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000300")
port map (
combout => N_45054,
dataf => CPO_EXCZ,
datae => \GRFPC0.N_21965\,
datad => \GRFPC0.RFA.SEQERR_0_0_G1_0_1460_A2_0\,
datac => N_112,
datab => N_113);
GRFPC0_RFA_STDFQ_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPC0.RFA.STDFQ_0_0_G1_0_1528_A2_0\,
dataf => N_97,
datae => N_101,
datad => N_99);
GRFPC0_RFA_STDFQ_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000003000000000")
port map (
combout => N_45102,
dataf => N_45102_11,
datae => \GRFPC0.N_21965\,
datad => \GRFPC0.N_21108\,
datac => \GRFPC0.RFA.STDFQ_0_0_G1_0_1528_A2_0\,
datab => N_39);
GRFPC0_RFA_RDD_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPC0.RFA.RDD_0_0_G1_0_1586_A2_0\,
dataf => N_97,
datae => N_101,
datad => N_99);
GRFPC0_RFA_RDD_0_0_G1_0_1586_A2_11_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.RFA.RDD_0_0_G1_0_1586_A2_11_2\,
dataf => N_100,
datae => N_108,
datad => N_109,
datac => N_98);
GRFPC0_VEX_CTRL_RDWR_0_SQMUXA_I_A2_1_RNIM4EU1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000300000")
port map (
combout => N_45102_11,
dataf => CPO_EXCZ,
datae => \GRFPC0.RFA.RDD_0_0_G1_0_1586_A2_11_2\,
datad => N_112,
datac => N_102,
datab => N_113);
GRFPC0_RFA_RDD_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000003000000000")
port map (
combout => N_45139,
dataf => N_45102_11,
datae => \GRFPC0.N_21965\,
datad => \GRFPC0.N_21108\,
datac => \GRFPC0.RFA.RDD_0_0_G1_0_1586_A2_0\,
datab => N_39);
GRFPC0_RFA_AFSR_RNO_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003000000")
port map (
combout => \GRFPC0.RFA.AFSR_0_0_G1_0_1639_A2_4\,
dataf => N_101,
datae => N_108,
datad => N_97,
datac => N_100,
datab => N_98);
GRFPC0_RFA_AFSR_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.RFA.AFSR_0_0_G1_0_1639_A2_6\,
dataf => \GRFPC0.RFA.AFSR_0_0_G1_0_1639_A2_4\,
datae => N_112,
datad => N_109,
datac => N_39,
datab => N_102);
GRFPC0_RFA_AFSR_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => N_45173,
dataf => CPO_EXCZ,
datae => \GRFPC0.N_21965\,
datad => \GRFPC0.N_21108\,
datac => N_113,
datab => \GRFPC0.RFA.AFSR_0_0_G1_0_1639_A2_6\);
\GRFPC0_DIV_RESULT_0_0_24__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffccfff0ff00")
port map (
combout => \FPO.RES\(24),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_1\,
datad => \GRFPC0.DIV.RESULT_0_0_24__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(24),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(24));
\GRFPC0_DIV_RESULT_0_0_5__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffccfff0ff00")
port map (
combout => \FPO.RES\(5),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_0\,
datad => \GRFPC0.DIV.RESULT_0_0_5__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(5),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(5));
GRFPC0_FP_PIPELINE_12_0_CHECK_DEP_UN3823_REGDEPX_I_0_O3_I_A2_RNII6A21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPC0.N_23366\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_24875\,
datad => \GRFPC0.FIFO.INST_0\(19));
\GRFPC0_D_STLCK_RNO_5_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000ffffc000c000")
port map (
combout => \GRFPC0.D.STLCK_0_0_3__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datae => \GRFPC0.N_22820\,
datad => \GRFPC0.N_59\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datab => \GRFPC0.N_9474\);
\GRFPC0_D_STLCK_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccccccffcfcfcf")
port map (
combout => \GRFPC0.D.STLCK_0_0_3__G1\,
dataf => \GRFPC0.N_22867\,
datae => \GRFPC0.N_62\,
datad => \GRFPC0.N_22910\,
datac => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O3_4_1\(1),
datab => \GRFPC0.D.STLCK_0_0_3__G1_3\);
\GRFPC0_D_STLCK_RNO_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O3_4_1\(1),
dataf => \GRFPC0.FP_PIPELINE.1.STDEP_78_I_M_I_O3_4_0\(1),
datae => \GRFPC0.N_21951_1\,
datad => \GRFPC0.N_35_I\,
datac => \GRFPC0.N_675\,
datab => \GRFPC0.N_470\);
GRFPC0_WR_RREG_RESV_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0c00000ccc")
port map (
combout => \GRFPC0.N_10571\,
dataf => \GRFPC0.FP_PIPELINE.UN1_PENDEXC_1\,
datae => \GRFPC0.N_102\,
datad => \GRFPC0.FP_PIPELINE.UN1_CPI_6\,
datac => N_37,
datab => N_35);
\GRFPC0_D_STLCK_RNO_3_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc0c0c0")
port map (
combout => \GRFPC0.D.STLCK_0_0_13__G1_1\,
dataf => \GRFPC0.N_22063\,
datae => \GRFPC0.N_594\,
datad => \GRFPC0.N_22406_I\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datab => \GRFPC0.N_22468_1\);
\GRFPC0_D_STLCK_RNO_1_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3f0f0fffff0f0")
port map (
combout => \GRFPC0.D.STLCK_0_0_13__G1_3\,
dataf => \GRFPC0.FP_PIPELINE.6.0.CHECK_DEP.DEP_2_I\(1),
datae => \GRFPC0.N_22080\,
datad => \GRFPC0.FIFO.INST_0_M_11\(25),
datac => \GRFPC0.D.STLCK_0_0_13__G1_2\,
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\);
\GRFPC0_D_STLCK_RNO_0_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffc0ffc0")
port map (
combout => \GRFPC0.D.STLCK_0_0_13__G1_5\,
dataf => \GRFPC0.N_62\,
datae => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_A2_3_0\(1),
datad => \GRFPC0.D.STLCK_0_0_13__G1_3\,
datac => \GRFPC0.N_23512\,
datab => \GRFPC0.STDDEP_0_SQMUXA_118\);
\GRFPC0_D_STLCK_RNO_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffeffff0100")
port map (
combout => \GRFPC0.D.STLCK_0_0_13__G1\,
dataf => \GRFPC0.FP_PIPELINE.6.STDEP_252\(1),
datae => \GRFPC0.D.STLCK_0_0_13__G1_5\,
datad => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datab => \GRFPC0.N_546\,
dataa => \GRFPC0.N_106_I\);
\GRFPC0_D_STDLCK_RNO_7_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_15__G1_2\,
dataf => \GRFPC0.N_23122\,
datae => \GRFPC0.N_23136\,
datad => \GRFPC0.D.STDLCK_0_0_15__G1_0\,
datac => \GRFPC0.N_18394_1\,
datab => \GRFPC0.EX.CTRL.RDWR\);
\GRFPC0_D_STDLCK_RNO_4_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffff0300")
port map (
combout => \GRFPC0.D.STDLCK_0_0_15__G1_3\,
dataf => \GRFPC0.N_114\,
datae => \GRFPC0.D.STDLCK_0_0_15__G1_2\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_10_2_0\,
datac => \GRFPC0.N_23088\,
datab => \GRFPC0.FP_PIPELINE.STDDEP_1_4\);
\GRFPC0_D_STDLCK_RNO_0_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff33ffffff30")
port map (
combout => \GRFPC0.D.STDLCK_0_0_15__G1_5\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_174\,
datae => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_10_7\,
datad => \GRFPC0.D.STDLCK_0_0_15__G1_3\,
datac => \GRFPC0.N_18829\,
datab => \GRFPC0.N_23088\);
\GRFPC0_D_STDLCK_RNO_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffeac0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_15__G1\,
dataf => \GRFPC0.D.STDLCK_0_0_15__G1_5\,
datae => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_10\,
datad => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datac => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datab => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_10_4\,
dataa => \GRFPC0.N_9468\);
\GRFPC0_D_STDLCK_RNO_8_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_10_2_0\,
dataf => \GRFPC0.N_25889\,
datae => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4976_DEP\,
datad => \GRFPC0.WR.CTRL.RDD\,
datac => \GRFPC0.WR.CTRL.RDWR\,
datab => \GRFPC0.MEM.CTRL.RDWR\);
\GRFPC0_D_STDLCK_RNO_1_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_10\,
dataf => \GRFPC0.N_22173_I\,
datae => \GRFPC0.N_362\,
datad => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4940_DEP\,
datac => \GRFPC0.N_458\,
datab => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_10_3\);
\GRFPC0_D_STDLCK_RNO_1_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30000000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_10__G1_0\,
dataf => \GRFPC0.N_23515_I\,
datae => \GRFPC0.RFA.LD\,
datad => N_174,
datac => \GRFPC0.N_801\,
datab => N_173);
\GRFPC0_D_STDLCK_RNO_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff3f0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_10__G1\,
dataf => \GRFPC0.N_756\,
datae => \GRFPC0.N_755\,
datad => \GRFPC0.N_580\,
datac => \GRFPC0.D.STDLCK_0_0_10__G1_2\,
datab => \GRFPC0.N_490\);
\GRFPC0_D_STDLCK_RNO_1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00030000ffffffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_5__G1_0\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_24_I_1\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => N_245,
datac => N_243,
datab => \GRFPC0.STDDEP_0_SQMUXA_13_I_O4_1_0\);
\GRFPC0_D_STDLCK_RNO_0_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffccffffffcf")
port map (
combout => \GRFPC0.D.STDLCK_0_0_5__G1_3\,
dataf => \GRFPC0.N_841\,
datae => \GRFPC0.N_21676\,
datad => \GRFPC0.N_21617\,
datac => \GRFPC0.N_21612\,
datab => \GRFPC0.D.STDLCK_0_0_5__G1_0\);
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_A2_1_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0c00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_136_IV_0_A2_1\,
dataf => \GRFPC0.N_21701\,
datae => \GRFPC0.N_21636\,
datad => \GRFPC0.N_21617\,
datac => \GRFPC0.N_860\,
datab => \GRFPC0.N_9478\);
\GRFPC0_FP_PIPELINE_9_STDEP_376_3_I_A2_0_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030300030")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_I_A2_0_1\(0),
dataf => \GRFPC0.N_670\,
datae => \GRFPC0.N_449\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datac => \GRFPC0.N_494\,
datab => \GRFPC0.N_500\);
\GRFPC0_FP_PIPELINE_9_STDEP_376_3_I_A2_1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cfcf00cf")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_376_3_I_A2_1\(0),
dataf => \GRFPC0.N_670\,
datae => \GRFPC0.N_449\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datac => \GRFPC0.N_494\,
datab => \GRFPC0.N_500\);
\GRFPC0_D_STLCK_RNO_0_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0fff0fff0")
port map (
combout => \GRFPC0.D.STLCK_0_0_16__G1_3\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1\(0),
datae => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datad => \GRFPC0.N_22282\,
datac => \GRFPC0.D.STLCK_0_0_16__G1_1\,
datab => \GRFPC0.N_9481\);
\GRFPC0_D_LDLCK_RNO_0_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcfff0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_5__G1_6\,
dataf => \GRFPC0.D.LDLCK_0_0_5__G1_2\,
datae => \GRFPC0.N_21638_1\,
datad => \GRFPC0.D.LDLCK_0_0_5__G1_3\,
datac => \GRFPC0.N_25340\,
datab => \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN824_REGDEPX\);
\GRFPC0_D_LDLCK_RNO_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_12__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210\(0),
datae => \GRFPC0.N_22447\,
datad => \GRFPC0.D.LDLCK_0_0_12__G1_4\,
datac => \GRFPC0.N_22445_1\,
datab => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_113_0_A4_0\(1));
GRFPC0_EX_CTRL_DIV_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0cc0000000000000")
port map (
combout => \GRFPC0.EX.CTRL.DIV_0_0_G1\,
dataf => \GRFPC0.DIVI_0_SQMUXA_8\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_9_5\(0),
datad => \FPI.FLOP\(1),
datac => \FPI.FLOP\(0),
datab => N_35);
\GRFPC0_MEM_CTRL_ID_RNIUALJ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ffff0ffff0ffff0")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.EXCT_1_1756_O4_0_3\,
dataf => \GRFPC0.FPR.ID\(1),
datae => \GRFPC0.FPR.ID\(0),
datad => \GRFPC0.MEM.CTRL.ID\(1),
datac => \GRFPC0.MEM.CTRL.ID\(0));
\GRFPC0_MEM_CTRL_ID_RNI6RLJ_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ffff0ffff0ffff0")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.EXCT_1_1756_O4_0_2\,
dataf => \GRFPC0.FPR.ID\(3),
datae => \GRFPC0.FPR.ID\(2),
datad => \GRFPC0.MEM.CTRL.ID\(3),
datac => \GRFPC0.MEM.CTRL.ID\(2));
\GRFPC0_MEM_CTRL_ID_RNIEBMJ_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ffff0ffff0ffff0")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.EXCT_1_1756_O4_0_1\,
dataf => \GRFPC0.FPR.ID\(5),
datae => \GRFPC0.FPR.ID\(4),
datad => \GRFPC0.MEM.CTRL.ID\(5),
datac => \GRFPC0.MEM.CTRL.ID\(4));
\GRFPC0_MEM_CTRL_ID_RNI9NU42_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffcf")
port map (
combout => \GRFPC0.N_24428\,
dataf => \GRFPC0.FP_PIPELINE.VWR.RREG.EXCT_1_1756_O4_0_1\,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.EXCT_1_1756_O4_0_3\,
datad => \GRFPC0.FP_PIPELINE.VWR.RREG.EXCT_1_1756_O4_0_2\,
datac => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.MEM.CTRL.ID\(7));
GRFPC0_FIFO_FULL_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333330300000000")
port map (
combout => \GRFPC0.FIFO.FULL_0_0_G1\,
dataf => \GRFPC0.FIFO.FULL_0_0_G1_1\,
datae => CPO_EXCZ,
datad => \GRFPC0.FP_PIPELINE.VFIFO.FULL_6\,
datac => \GRFPC0.VFIFO.FULL_3_SQMUXA_0\,
datab => \GRFPC0.DIV.EXC_MB_2_I_0\);
\GRFPC0_R_FSR_FTT_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000f000ff0000")
port map (
combout => \GRFPC0.R.FSR.FTT_0_0_1__G1\,
dataf => \GRFPC0.V.FSR.FTT_1_SQMUXA_2\,
datae => \GRFPC0.V.FSR.FTT_1_SQMUXA_1\,
datad => \GRFPC0.WR2.CTRL.SEQERR\,
datac => \GRFPC0.R.FSR.FTT\(1));
GRFPC0_FP_PIPELINE_V_STDATA_1S2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM8\,
dataf => \GRFPC0.N_23712\,
datae => N_99870,
datad => N_99867,
datac => \GRFPC0.MEM.CTRL.PEND\,
datab => \GRFPC0.WR.CTRL.PEND\);
\GRFPC0_DIV_RESULT_0_0_13__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \FPO.RES\(13),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_0\,
datad => \GRFPC0.DIV.RESULT_0_0_13__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(13),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(13));
GRFPU0_GRFPU_X0_SGNF_2_SQMUXA_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0fffcff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18746\,
dataf => \GRFPU0.GRFPU_X0.N_18833\,
datae => \GRFPU0.GRFPU_X0.N_18768\,
datad => \GRFPU0.GRFPU_X0.N_10059_I\,
datac => \FPI.FLOP\(1),
datab => \FPI.NONSTD\);
GRFPU0_GRFPU_X0_SGNF_2_SQMUXA_I_A2_RNIBUAPF_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff3fffff0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_21\,
dataf => \GRFPU0.GRFPU_X0.N_18833\,
datae => \GRFPU0.GRFPU_X0.N_18837\,
datad => \GRFPU0.GRFPU_X0.N_18831\,
datac => \GRFPU0.GRFPU_X0.N_10059_I\,
datab => \FPI.FLOP\(1));
\GRFPC0_DIV_RESULT_0_0_22__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffccfff0ff00")
port map (
combout => \FPO.RES\(22),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_1\,
datad => \GRFPC0.DIV.RESULT_0_0_22__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(22),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(22));
GRFPU0_GRFPU_X0_SGNF_2_SQMUXA_I_A2_RNIBUAPF: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff3fffff3f3f")
port map (
combout => \GRFPU0.GRFPU_X0.N_18750\,
dataf => \GRFPU0.GRFPU_X0.N_18833\,
datae => \GRFPU0.GRFPU_X0.N_18837\,
datad => \GRFPU0.GRFPU_X0.N_18831\,
datac => \GRFPU0.GRFPU_X0.N_10059_I\,
datab => \FPI.FLOP\(1));
GRFPC0_D_FSTLCK_RNO_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff0ff00")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1_9\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => \GRFPC0.EX.CTRL.STDFQ\,
datac => \GRFPC0.EX.CTRL.AFSR\);
GRFPC0_D_FSTLCK_RNO_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.D.FSTLCK_0_0_G1_13\,
dataf => \GRFPC0.N_10575_2\,
datae => \GRFPC0.FP_PIPELINE.FIFOV2\,
datad => \GRFPC0.D.FSTLCK_0_0_G1_9\,
datac => \GRFPC0.D.FSTLCK_0_0_G1_8\,
datab => \GRFPC0.D.FSTLCK_0_0_G1_7\);
\GRFPC0_D_LDLCK_RNO_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcf3f0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_21__G1\,
dataf => \GRFPC0.FP_PIPELINE.10.REGDEPX2_320\(1),
datae => \GRFPC0.FP_PIPELINE.10.REGDEPX_197\(1),
datad => \GRFPC0.FP_PIPELINE.10.REGDEPX_192\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_3\(1),
datab => \GRFPC0.FP_PIPELINE.0.UN1_OP\);
\GRFPC0_D_STDLCK_RNO_5_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_13_1\,
dataf => \GRFPC0.N_469\,
datae => \GRFPC0.WR.CTRL.RDD\,
datad => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(2));
\GRFPC0_D_STDLCK_RNO_2_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_13_4\,
dataf => \GRFPC0.FP_PIPELINE.12.STDEP_496_SEL0_1\,
datae => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_13_4\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_13_1\,
datac => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_13_4\,
datab => \GRFPC0.STDDEP_0_SQMUXA_25_I_1\);
\GRFPC0_D_STDLCK_RNO_9_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_13_2\,
dataf => \GRFPC0.FP_PIPELINE.12.STDEP_496_SEL0_1\,
datae => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_13_4\,
datad => \GRFPC0.FP_PIPELINE.12.STDEP_488_SEL0_1\,
datac => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_13_4\,
datab => \GRFPC0.STDDEP_0_SQMUXA_25_I_1\);
\GRFPC0_D_STDLCK_RNO_1_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_13_6\,
dataf => \GRFPC0.N_22173_I\,
datae => \GRFPC0.N_362\,
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3956_DEP\,
datac => \GRFPC0.N_458\,
datab => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_13_4_0\);
\GRFPC0_D_STDLCK_RNO_0_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff030fffff000")
port map (
combout => \GRFPC0.D.STDLCK_0_0_12__G1_4\,
dataf => \GRFPC0.UN1_STDDEP_0_SQMUXA_101\,
datae => \GRFPC0.D.STDLCK_0_0_12__G1_3\,
datad => \GRFPC0.N_18814\,
datac => \GRFPC0.FP_PIPELINE.12.STDEP_496_SEL0_1\,
datab => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_13_4\);
\GRFPC0_D_STDLCK_RNO_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffceff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_12__G1\,
dataf => \GRFPC0.D.STDLCK_0_0_12__G1_4\,
datae => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_13_6\,
datad => \GRFPC0.STDDEP_0_SQMUXA_128_I_1\,
datac => \GRFPC0.N_114\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_290_IV_3_0\,
dataa => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_13_4\);
\GRFPC0_D_STDLCK_RNO_6_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_13\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_13_1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datac => \GRFPC0.STDDEP_0_SQMUXA_25_I_1\,
datab => \GRFPC0.EX.CTRL.RDWR\);
GRFPC0_WR2_RREG_RESV_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPC0.N_10569\,
dataf => \GRFPC0.N_315\,
datae => \GRFPC0.N_173\,
datad => N_35);
\GRFPC0_D_LDLCK_RNO_0_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff0f0f0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_11__G1_3\,
dataf => \GRFPC0.N_21641\,
datae => \GRFPC0.FP_PIPELINE.5.0.REGDEPX_95\(1),
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.D.LDLCK_0_0_11__G1_1\);
\GRFPC0_D_STLCK_RNO_1_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f000f000f00")
port map (
combout => \GRFPC0.D.STLCK_0_0_26__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(0),
datae => \GRFPC0.RFA.LD\,
datad => \GRFPC0.N_21331\,
datac => \GRFPC0.N_61_I\,
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4513_DEP\);
\GRFPC0_D_STLCK_RNO_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcfcfc")
port map (
combout => \GRFPC0.D.STLCK_0_0_26__G1\,
dataf => \GRFPC0.N_23284\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1\(0),
datad => \GRFPC0.N_21281\,
datac => \GRFPC0.D.STLCK_0_0_26__G1_3\,
datab => \GRFPC0.N_23270\);
\GRFPC0_D_STLCK_RNO_2_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPC0.D.STLCK_0_0_19__G1_1\,
dataf => \GRFPC0.D.STLCK_0_0_19__G3\,
datae => \GRFPC0.N_594\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datac => \GRFPC0.N_680\,
datab => \GRFPC0.N_854\);
\GRFPC0_D_LDLCK_RNO_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_9__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_4\(1),
datae => \GRFPC0.D.LDLCK_0_0_9__G3\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_3\(1));
\GRFPC0_D_STLCK_RNO_5_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc0c0c0")
port map (
combout => \GRFPC0.D.STLCK_0_0_21__G1_1\,
dataf => \GRFPC0.N_23550\,
datae => \GRFPC0.N_594\,
datad => \GRFPC0.N_23515_I\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datab => \GRFPC0.N_96_1\);
\GRFPC0_D_STLCK_RNO_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffffffff")
port map (
combout => \GRFPC0.D.STLCK_0_0_21__G1\,
dataf => \GRFPC0.N_23511\,
datae => \GRFPC0.N_23542\,
datad => \GRFPC0.N_23551\,
datac => \GRFPC0.N_23543\,
datab => \GRFPC0.D.STLCK_0_0_21__G1_2\);
\GRFPC0_D_LDLCK_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_0__G1\,
dataf => \GRFPC0.D.LDLCK_0_0_0__G3\,
datae => \GRFPC0.D.LDLCK_0_0_0__G1_4\,
datad => \GRFPC0.N_25067\);
\GRFPC0_D_STLCK_RNO_9_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffccffcfcfcccc")
port map (
combout => \GRFPC0.D.STLCK_0_0_27__G1_1\,
dataf => \GRFPC0.N_594\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datad => \GRFPC0.N_23261\,
datac => \GRFPC0.N_23234\,
datab => \GRFPC0.N_21322\);
\GRFPC0_D_STLCK_RNO_2_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00fcffff00f0")
port map (
combout => \GRFPC0.D.STLCK_0_0_27__G1_3\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.D.STLCK_0_0_27__G1_1\,
datad => N_99872,
datac => \GRFPC0.N_106_I\,
datab => \GRFPC0.EX.CTRL.RD\(0));
\GRFPC0_D_STLCK_RNO_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffccc")
port map (
combout => \GRFPC0.D.STLCK_0_0_27__G1\,
dataf => \GRFPC0.N_21262\,
datae => \GRFPC0.N_21329\,
datad => \GRFPC0.N_62\,
datac => \GRFPC0.N_21281\,
datab => \GRFPC0.D.STLCK_0_0_27__G1_3\);
\GRFPC0_D_STLCK_RNO_13_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => \GRFPC0.N_121\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.N_21246\,
datad => \GRFPC0.N_21257\,
datac => N_99872,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0));
\GRFPC0_D_STLCK_RNO_12_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_122\,
dataf => \GRFPC0.N_21951_1\,
datae => \GRFPC0.N_21246\,
datad => \GRFPC0.N_21257\,
datac => \GRFPC0.FP_PIPELINE.13.STDEP_558_I_M_I_A3_10_0\(1),
datab => \GRFPC0.N_53\);
\GRFPC0_D_STDLCK_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffecffccff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_4__G1\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_182\,
datae => \GRFPC0.N_22173_I\,
datad => \GRFPC0.STDDEP_0_SQMUXA_131_I_1\,
datac => \GRFPC0.STDEP_2_SQMUXA_133\,
datab => \GRFPC0.D.STDLCK_0_0_4__G1_7\,
dataa => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_5_7_1\);
\GRFPC0_D_STDLCK_RNO_7_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_5_0\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4));
\GRFPC0_D_STDLCK_RNO_6_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03000f003300ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_5_2\,
dataf => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1386_DEP\,
datae => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\,
datad => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_5_0\,
datac => \GRFPC0.EX.CTRL.RDWR\,
datab => \GRFPC0.MEM.CTRL.RDWR\);
\GRFPC0_D_STDLCK_RNO_3_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_5\,
dataf => \GRFPC0.N_114\,
datae => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_5_2\,
datad => \GRFPC0.WR.CTRL.RDD\);
\GRFPC0_D_STDLCK_RNO_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"030f33ff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_5_7_1\,
dataf => \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL0_1\,
datae => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1386_DEP\,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\,
datac => \GRFPC0.EX.CTRL.RDWR\,
datab => \GRFPC0.MEM.CTRL.RDWR\);
\GRFPC0_D_STDLCK_RNO_2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_5\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1386_DEP\,
datad => \GRFPC0.N_106_I\,
datac => \GRFPC0.EX.CTRL.RDWR\);
\GRFPC0_D_STLCK_RNO_1_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccfffcffccccfcfc")
port map (
combout => \GRFPC0.D.STLCK_0_0_9__G1_3\,
dataf => \GRFPC0.N_22644\,
datae => \GRFPC0.N_22639\,
datad => \GRFPC0.N_22631\,
datac => \GRFPC0.N_21277_1\,
datab => \GRFPC0.D.STLCK_0_0_9__G1_1\);
\GRFPC0_D_STLCK_RNO_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffff0300")
port map (
combout => \GRFPC0.D.STLCK_0_0_9__G1\,
dataf => \GRFPC0.FP_PIPELINE.4.STDEP_172\(1),
datae => \GRFPC0.D.STLCK_0_0_9__G1_5\,
datad => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datac => \GRFPC0.N_22636\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0));
GRFPC0_D_FLDLCK_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.D.FLDLCK_0_0_G1\,
dataf => \GRFPC0.N_10567_2\,
datae => \GRFPC0.FP_PIPELINE.VRFA.RDWR_1\,
datad => \GRFPC0.N_10575_2\,
datac => \GRFPC0.N_21133\,
datab => \GRFPC0.D.FLDLCK_0_0_G1_3\);
\GRFPC0_D_STDLCK_RNO_0_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff3fff0fff0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_9__G1_1\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_548\,
datad => \GRFPC0.N_680\,
datac => \GRFPC0.N_854\,
datab => \GRFPC0.FIFO.INST_1\(19));
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_A2_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0000000cccccccc")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A2_0_0\,
dataf => \GRFPC0.N_25899\,
datae => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN3628_DEP\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_268_IV_0_A3_2_0\,
datac => \GRFPC0.N_21725\,
datab => \GRFPC0.N_21721\);
\GRFPC0_D_LDLCK_RNO_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_16__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270\(0),
datae => \GRFPC0.D.LDLCK_0_0_16__G1_3\,
datad => \GRFPC0.N_22274\,
datac => \GRFPC0.N_23348_1\,
datab => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2711_REGDEPX\);
\GRFPC0_WR_CTRL_ID_RNIMRR51_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ffff0ffff0ffff0")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_63__G4_3\,
dataf => \GRFPC0.FPR.ID\(1),
datae => \GRFPC0.FPR.ID\(0),
datad => \GRFPC0.WR.CTRL.ID\(1),
datac => \GRFPC0.WR.CTRL.ID\(0));
\GRFPC0_WR_CTRL_ID_RNIURS51_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ffff0ffff0ffff0")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_63__G4_2\,
dataf => \GRFPC0.FPR.ID\(3),
datae => \GRFPC0.FPR.ID\(2),
datad => \GRFPC0.WR.CTRL.ID\(3),
datac => \GRFPC0.WR.CTRL.ID\(2));
\GRFPC0_WR_CTRL_ID_RNI6ST51_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ffff0ffff0ffff0")
port map (
combout => \GRFPC0.WR.RREG.RES_0_0_63__G4_1\,
dataf => \GRFPC0.FPR.ID\(5),
datae => \GRFPC0.FPR.ID\(4),
datad => \GRFPC0.WR.CTRL.ID\(5),
datac => \GRFPC0.WR.CTRL.ID\(4));
\GRFPC0_WR_CTRL_ID_RNITRN44_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffcf")
port map (
combout => \GRFPC0.N_24361\,
dataf => \GRFPC0.WR.RREG.RES_0_0_63__G4_1\,
datae => \GRFPC0.WR.RREG.RES_0_0_63__G4_3\,
datad => \GRFPC0.WR.RREG.RES_0_0_63__G4_2\,
datac => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.WR.CTRL.ID\(7));
GRFPC0_FP_PIPELINE_UN68_HOLDN_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN68_HOLDN_3\,
dataf => \GRFPC0.DIV.EXEC\,
datae => \GRFPC0.DIV.VALID\,
datad => \GRFPC0.WR2.CTRL.DIV\,
datac => \GRFPC0.WR2.CTRL.RDWR\,
datab => N_37);
GRFPC0_FP_PIPELINE_VDIV_VALID2_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID2_3\,
dataf => \GRFPC0.FPR.ID\(2),
datae => \GRFPC0.FPR.ID\(5),
datad => \GRFPC0.DIV.ID\(2),
datac => \GRFPC0.DIV.ID\(5));
GRFPC0_FP_PIPELINE_VDIV_VALID2_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c00c300300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID2_6\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.VALID2_3\,
datae => \GRFPC0.FPR.ID\(3),
datad => \GRFPC0.FPR.ID\(4),
datac => \GRFPC0.DIV.ID\(4),
datab => \GRFPC0.DIV.ID\(3));
GRFPC0_FP_PIPELINE_VDIV_VALID2_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00000f00f00000f")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID2_2\,
dataf => \GRFPC0.FPR.ID\(1),
datae => \GRFPC0.FPR.ID\(0),
datad => \GRFPC0.DIV.ID\(0),
datac => \GRFPC0.DIV.ID\(1));
GRFPC0_FP_PIPELINE_VDIV_VALID2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.VALID2_6\,
datae => \GRFPC0.FP_PIPELINE.VDIV.VALID2_2\,
datad => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.DIV.ID\(7));
\GRFPC0_D_STDLCK_RNO_3_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffffffc0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_3__G1_5\,
dataf => \GRFPC0.N_114\,
datae => \GRFPC0.D.STDLCK_0_0_3__G1_3\,
datad => \GRFPC0.STDDEP_0_SQMUXA_114\,
datac => \GRFPC0.FP_PIPELINE.0.RESV6_I_M_6_3\,
datab => \GRFPC0.FP_PIPELINE.3.STDEP_136_SEL0_1\);
\GRFPC0_D_STDLCK_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcffcc")
port map (
combout => \GRFPC0.D.STDLCK_0_0_3__G1\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_179\,
datae => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_6_5_1\,
datad => \GRFPC0.STDDEP_0_SQMUXA_139\,
datac => \GRFPC0.STDEP_2_SQMUXA_129\,
datab => \GRFPC0.D.STDLCK_0_0_3__G1_7\);
\GRFPC0_D_STLCK_RNO_6_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f00000f0000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_31__G1_1\,
dataf => \GRFPC0.N_106_I\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => N_241,
datac => \GRFPC0.STDDEP_0_SQMUXA_I_I_A2_1\);
\GRFPC0_D_STLCK_RNO_2_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.D.STLCK_0_0_31__G1_3\,
dataf => \GRFPC0.N_23059\,
datae => \GRFPC0.N_23089\,
datad => \GRFPC0.D.STLCK_0_0_31__G1_1\,
datac => \GRFPC0.N_23127\,
datab => \GRFPC0.N_59\);
\GRFPC0_D_STDLCK_RNO_1_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffffff00")
port map (
combout => \GRFPC0.D.STDLCK_0_0_7__G1_4\,
dataf => \GRFPC0.N_149\,
datae => \GRFPC0.D.STDLCK_0_0_7__G1_2\,
datad => \GRFPC0.N_21866\,
datac => \GRFPC0.N_690\,
datab => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_1\);
\GRFPC0_D_STDLCK_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffbfff3fffafff0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_7__G1\,
dataf => N_61057_TZ,
datae => \GRFPC0.N_461\,
datad => \GRFPC0.D.STDLCK_0_0_7__G1_4\,
datac => \GRFPC0.N_21884\,
datab => \GRFPC0.N_690\,
dataa => \GRFPC0.N_9480\);
\GRFPC0_D_LDLCK_RNO_1_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffc0ffc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_30__G1_1\,
dataf => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4999_REGDEPX\,
datae => \GRFPC0.N_24849_1\,
datad => \GRFPC0.N_24855\,
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4984_REGDEPX\,
datab => \GRFPC0.N_25795_1\);
\GRFPC0_D_STLCK_RNO_1_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcc000c00")
port map (
combout => \GRFPC0.D.STLCK_0_0_30__G1_2\,
dataf => \GRFPC0.D.STLCK_0_0_30__G1_0\,
datae => \GRFPC0.N_106_I\,
datad => \GRFPC0.EX.CTRL.LD\,
datac => N_241,
datab => \GRFPC0.STDDEP_0_SQMUXA_I_I_A2_1\);
\GRFPC0_D_STLCK_RNO_0_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffccc")
port map (
combout => \GRFPC0.D.STLCK_0_0_30__G1_5\,
dataf => \GRFPC0.N_23102\,
datae => \GRFPC0.N_23119\,
datad => \GRFPC0.N_22837\,
datac => \GRFPC0.N_23122\,
datab => \GRFPC0.D.STLCK_0_0_30__G1_2\);
\GRFPC0_D_STLCK_RNO_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff7fffffa020")
port map (
combout => \GRFPC0.D.STLCK_0_0_30__G1\,
dataf => \GRFPC0.FP_PIPELINE.15.STDEP_612\(0),
datae => \GRFPC0.D.STLCK_0_0_30__G1_5\,
datad => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_20\(0),
datab => \GRFPC0.N_18394_1\,
dataa => \GRFPC0.EX.CTRL.RDWR\);
\GRFPC0_D_STDLCK_RNO_6_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_10_1\,
dataf => \GRFPC0.N_505\,
datae => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.RFA.LD\,
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN5169_DEP_2\,
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1233_DEP_1\);
\GRFPC0_D_STDLCK_RNO_2_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000003000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_10_4\,
dataf => \GRFPC0.N_23122\,
datae => \GRFPC0.N_23136\,
datad => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_20\(0),
datac => \GRFPC0.FP_PIPELINE.0.RESV14_I_M_10_1\,
datab => \GRFPC0.FP_PIPELINE.STDDEP_1_4\);
\GRFPC0_D_STLCK_RNO_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff300030003000")
port map (
combout => \GRFPC0.D.STLCK_0_0_0__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(0),
datae => \GRFPC0.N_22975_I\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datac => \GRFPC0.N_9453\,
datab => \GRFPC0.N_61_I\);
\GRFPC0_D_STDLCK_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcc00fcf0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_0__G1_3\,
dataf => \GRFPC0.D.STDLCK_0_0_0__G1_1\,
datae => \GRFPC0.STDEP_0_SQMUXA_81_2_I\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX\,
datab => \GRFPC0.STDDEP_0_SQMUXA_108_0_A2_0_A2_0\);
\GRFPC0_R_FSR_CEXC_RNO_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0c0c0c0c0c0c0")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_1__G1_0\,
dataf => \GRFPC0.V.FSR.CEXC_1_SQMUXA\,
datae => \GRFPC0.R.FSR.TEM\(1),
datad => \GRFPC0.DIV.EXCT\(1),
datac => \GRFPC0.V.FSR.AEXC_0_SQMUXA\,
datab => N_432);
\GRFPC0_R_FSR_CEXC_RNO_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff000ffff0000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_1__G1_1\,
dataf => \GRFPC0.V.FSR.CEXC_2_SQMUXA\,
datae => \GRFPC0.R.FSR.CEXC_0_0_1__G1_0\,
datad => \GRFPC0.R.FSR.TEM\(1),
datac => \GRFPC0.WR2.RREG.EXCT\(1));
\GRFPC0_D_STLCK_RNO_1_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffc000c000c000")
port map (
combout => \GRFPC0.D.STLCK_0_0_7__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datae => \GRFPC0.STDDEP_0_SQMUXA_26\,
datad => \GRFPC0.N_9476\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datab => \GRFPC0.N_59\);
\GRFPC0_D_STLCK_RNO_0_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff33ff33ff33fff3")
port map (
combout => \GRFPC0.D.STLCK_0_0_7__G1_2\,
dataf => \GRFPC0.STDEP_0_SQMUXA_81_2_I\,
datae => \GRFPC0.STDEP_0_SQMUXA_98_0\,
datad => \GRFPC0.D.STLCK_0_0_7__G1_0\,
datac => \GRFPC0.FP_PIPELINE.3.1.CHECK_DEP.UN1120_REGDEPX\,
datab => \GRFPC0.N_18122\);
\GRFPC0_D_STLCK_RNO_1_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000c000c000ffff")
port map (
combout => \GRFPC0.D.STLCK_0_0_25__G1_0\,
dataf => \GRFPC0.STDEP_0_SQMUXA_9\,
datae => \GRFPC0.STDDEP_0_SQMUXA_25_I_1\,
datad => \GRFPC0.N_59\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datab => \GRFPC0.N_9465\);
\GRFPC0_D_STLCK_RNO_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffefefefff")
port map (
combout => \GRFPC0.D.STLCK_0_0_25__G1\,
dataf => \GRFPC0.FP_PIPELINE.12.STDEP_496\(1),
datae => \GRFPC0.STDDEP_0_SQMUXA_128_I_1\,
datad => \GRFPC0.STDEP_0_SQMUXA_136_2\,
datac => \GRFPC0.N_18232\,
datab => \GRFPC0.N_23336\,
dataa => \GRFPC0.D.STLCK_0_0_25__G1_1\);
\GRFPC0_DIV_RESULT_0_0_8__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \FPO.RES\(8),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_0\,
datad => \GRFPC0.DIV.RESULT_0_0_8__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(8),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(8));
\GRFPC0_R_FSR_AEXC_RNO_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0c0c0c0c0")
port map (
combout => \GRFPC0.R.FSR.AEXC_0_0_3__G1_0\,
dataf => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
datae => \GRFPC0.R.FSR.AEXC\(3),
datad => \GRFPC0.DIV.EXCT\(3),
datac => \GRFPC0.V.FSR.AEXC_0_SQMUXA\,
datab => N_439);
\GRFPC0_DIV_RESULT_0_0_4__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \FPO.RES\(4),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_0\,
datad => \GRFPC0.DIV.RESULT_0_0_4__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(4),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(4));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_A3_0_6__G0_0\,
dataf => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_0_14_4\(4),
datae => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_0_14_2\(4),
datad => \FPI.OP1\(51),
datac => \FPI.OP1\(33),
datab => \FPI.OP1\(47));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf00000f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1\(6),
dataf => \GRFPU0.GRFPU_X0.N_18831\,
datae => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_A3_0_6__G0_2\,
datad => N_32589,
datac => \GRFPU0.GRFPU_X0.N_18805\,
datab => \FPI.FLOP\(1));
\GRFPC0_DIV_RESULT_0_0_31__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \FPO.RES\(31),
dataf => N_99904_1,
datae => \GRFPU0.GRFPU_X0.N_400_1\,
datad => \GRFPC0.DIV.RESULT_0_0_31__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(31),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(31));
\GRFPC0_RFA2_FID_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \GRFPC0.FID_1\(3),
dataf => \GRFPC0.N_9160\,
datae => \GRFPC0.N_9159\,
datad => \GRFPC0.FID_1_IV_0_3__G0_1\,
datac => \GRFPC0.EX.CTRL.ID\(3),
datab => \GRFPC0.MEM.CTRL.ID\(3));
GRFPC0_RFA2_RS1SEL_RET_2_RNIKO4O3_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => N_99877,
dataf => \GRFPC0.RFA2.RS1SEL\(7),
datae => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL\(3));
GRFPC0_FP_PIPELINE_1_REGDEP160_0_RNI4M595: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.FPUSEL_1\(1),
dataf => \GRFPC0.FPUSEL_1_2\(1),
datae => \GRFPC0.FPUSEL_1_0_1__G0_3_1\,
datad => \GRFPC0.FPUSEL_1_0_1__G0_3_0\,
datac => \GRFPC0.N_155_1\,
datab => N_37);
GRFPC0_FP_PIPELINE_VDIV_VALID_7_F1_A0_C_RNIJTVV2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fc00f000fc00fc")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
dataf => \GRFPC0.FP_PIPELINE.UN29_WREN_1\,
datae => CPO_EXCZ,
datad => \GRFPC0.VDIV.EXEC_0_SQMUXA\,
datac => \GRFPC0.DIV.EXEC_0_0_G0_2_0\,
datab => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F1_A0_C\);
\GRFPC0_RFA2_FOP_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f30000000000000")
port map (
combout => \GRFPC0.N_10564\,
dataf => \GRFPC0.N_23789\,
datae => \GRFPC0.RFA2.FOP_0_0_A2_0_0__G0_3\,
datad => \GRFPC0.INST\(5),
datac => \GRFPC0.N_23618\,
datab => \GRFPC0.INST\(10));
GRFPC0_RFA_READ_RS1_RNO_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.RFA.READ_RS1_0_0_G3\,
dataf => \GRFPC0.N_23778_2\,
datae => \GRFPC0.N_23783\,
datad => \GRFPC0.N_23771\,
datac => \GRFPC0.RFA.WRITE_RD_0_0_I1_I_1\,
datab => \GRFPC0.INST\(10));
GRFPC0_FP_PIPELINE_RSDEC_RS1V_I_I_A2_0_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_I_A2_0_4\,
dataf => \GRFPC0.N_23778_2\,
datae => \GRFPC0.N_23795\,
datad => \GRFPC0.N_23618\,
datac => \GRFPC0.INST\(10),
datab => \GRFPC0.INST\(19));
GRFPC0_RFA_READ_RS1_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.RFA.READ_RS1_0_0_G1_0\,
dataf => \GRFPC0.RFA.READ_RS1_0_0_G3\,
datae => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_I_A2_0_4\,
datad => \GRFPC0.N_23783\,
datac => \GRFPC0.RFA.WRITE_RD_0_0_I1_I_1\,
datab => \GRFPC0.INST\(5));
GRFPC0_RFA_READ_RS1_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30000000")
port map (
combout => \GRFPC0.RFA.READ_RS1_0_0_G1\,
dataf => \GRFPC0.RFA.READ_RS1_0_0_G1_0\,
datae => \GRFPC0.N_23789\,
datad => \GRFPC0.FP_PIPELINE.RSDEC.RS1V_I_I_A2_1_1\,
datac => \GRFPC0.N_23783\,
datab => \GRFPC0.INST\(9));
GRFPC0_VWR2_RREG_RES_2_SQMUXA_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPC0.VWR2.RREG.RES_2_SQMUXA_1\,
dataf => \GRFPC0.N_24361\,
datae => \GRFPC0.WR.CTRL.LD\,
datad => N_37);
\GRFPC0_FIFO_WR_RNO_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3300030033000000")
port map (
combout => \GRFPC0.FIFO.WR_0_0_0__G1_0\,
dataf => \GRFPC0.VFIFO.WR_1_SQMUXA\,
datae => \GRFPC0.VFIFO.WR_0_SQMUXA_1\,
datad => \GRFPC0.FP_PIPELINE.VFIFO.RD10\,
datac => \GRFPC0.FIFO.WR\(0),
datab => \GRFPC0.DIV.EXC_MB_2_I_0\);
\GRFPC0_FIFO_WR_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffffff30")
port map (
combout => \GRFPC0.FIFO.WR_0_0_0__G1\,
dataf => N_82238,
datae => \GRFPC0.FIFO.WR_0_0_0__G3\,
datad => \GRFPC0.FIFO.WR_0_0_0__G1_0\,
datac => \GRFPC0.FIFO.WR\(0),
datab => \GRFPC0.DIV.EXC_MB_2_I_0\);
GRFPC0_VFIFO_FULL_3_SQMUXA_0_RNI4NJ82: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffc0c0c0")
port map (
combout => \GRFPC0.FIFO.RD_0_0_0__G1_0\,
dataf => CPO_EXCZ,
datae => \GRFPC0.N_23766\,
datad => \GRFPC0.VFIFO.FULL_3_SQMUXA_0\,
datac => \GRFPC0.FIFO_INC_5_SQMUXA\,
datab => \GRFPC0.FIFO.RD_I_M_1\(0));
GRFPC0_WR2_CTRL_SEQERR_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000030003000")
port map (
combout => N_44766,
dataf => CPO_EXCZ,
datae => \GRFPC0.WR.CTRL.LD\,
datad => \GRFPC0.WR.CTRL.SEQERR\,
datac => \GRFPC0.WR2.CTRL.AFSR_0_0_G1_0_1123_A2_4_0\,
datab => N_389);
\GRFPC0_R_FSR_CEXC_RNO_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0c0c0c0c0c0c0")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_0__G1_0\,
dataf => \GRFPC0.V.FSR.CEXC_1_SQMUXA\,
datae => \GRFPC0.R.FSR.TEM\(0),
datad => \GRFPC0.DIV.EXCT\(0),
datac => \GRFPC0.V.FSR.AEXC_0_SQMUXA\,
datab => N_431);
\GRFPC0_DIV_RESULT_0_0_7__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffccfff0ff00")
port map (
combout => \FPO.RES\(7),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_0\,
datad => \GRFPC0.DIV.RESULT_0_0_7__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(7),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(7));
\GRFPC0_R_FSR_CEXC_RNO_3_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0c0c0c0c0c0c0")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_4__G1_0\,
dataf => \GRFPC0.V.FSR.CEXC_1_SQMUXA\,
datae => \GRFPC0.R.FSR.TEM\(4),
datad => \GRFPC0.DIV.EXCT\(4),
datac => \GRFPC0.V.FSR.AEXC_0_SQMUXA\,
datab => N_435);
\GRFPC0_D_STDLCK_RNO_2_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3f3f3fff0f0f0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_2__G1_1\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_87_1\,
datae => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A2_0\,
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN730_DEP\,
datac => \GRFPC0.N_21515\,
datab => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_D_STDLCK_RNO_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000c00")
port map (
combout => \GRFPC0.D.STDLCK_0_0_2__G1_2\,
dataf => \GRFPC0.D.STDLCK_0_0_2__G1_1\,
datae => \GRFPC0.N_543_1\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_2\,
datac => \GRFPC0.FIFO.INST_0\(26),
datab => \GRFPC0.FIFO.INST_0\(27));
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_O2_1_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3330333333303330")
port map (
combout => \GRFPC0.N_25896\,
dataf => \GRFPC0.N_514\,
datae => \GRFPC0.UN1_STDEP382\,
datad => \GRFPC0.N_533\,
datac => \GRFPC0.N_21502_2\,
datab => \GRFPC0.N_21521\);
\GRFPC0_D_STDLCK_RNO_0_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fffffffcffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_2__G1_5\,
dataf => \GRFPC0.N_25895\,
datae => \GRFPC0.N_25896\,
datad => \GRFPC0.N_21502\,
datac => \GRFPC0.D.STDLCK_0_0_2__G1_2\,
datab => \GRFPC0.N_655\);
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_A2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_21499\,
dataf => \GRFPC0.N_22173_I\,
datae => \GRFPC0.N_805\,
datad => \GRFPC0.N_21524\,
datac => \GRFPC0.N_481\,
datab => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_2_0\(1));
\GRFPC0_D_STDLCK_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPC0.D.STDLCK_0_0_2__G1\,
dataf => \GRFPC0.N_21499\,
datae => \GRFPC0.N_21496\,
datad => \GRFPC0.N_139\,
datac => \GRFPC0.D.STDLCK_0_0_2__G1_5\);
\GRFPC0_D_STDLCK_RNO_1_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00300000ffffffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_8__G1_0\,
dataf => \GRFPC0.N_60\,
datae => \GRFPC0.RFA.LD\,
datad => N_174,
datac => \GRFPC0.N_801\,
datab => N_173);
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_A3_1_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A3_1\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4));
\GRFPC0_D_STDLCK_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffffffc")
port map (
combout => \GRFPC0.D.STDLCK_0_0_8__G1\,
dataf => \GRFPC0.N_113\,
datae => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A3_1_2\,
datad => \GRFPC0.N_65\,
datac => \GRFPC0.N_21200\,
datab => \GRFPC0.D.STDLCK_0_0_8__G1_2\);
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f030f0f00000000")
port map (
combout => \GRFPC0.N_21563\,
dataf => \GRFPC0.N_858\,
datae => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2698_DEP_1\,
datad => \GRFPC0.N_473_1\,
datac => \GRFPC0.N_579\,
datab => \GRFPC0.EX.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2_8_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3ff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_8_0\,
dataf => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4612_DEP\,
datae => \GRFPC0.N_481\,
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2698_DEP_1\,
datac => \GRFPC0.N_473_1\,
datab => \GRFPC0.EX.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_O2_4_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfcffffcccc")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_O2_4_1\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datae => \GRFPC0.N_21539\,
datad => \GRFPC0.N_23842\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_8_0\,
datab => \GRFPC0.N_661\);
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0000003f000000")
port map (
combout => \GRFPC0.N_21572\,
dataf => \GRFPC0.N_22173_I\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_A2_7_0\,
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4612_DEP\,
datab => \GRFPC0.N_481\);
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_A2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fc00fc00fc0000")
port map (
combout => \GRFPC0.N_21577\,
dataf => \GRFPC0.N_21572\,
datae => \GRFPC0.FP_PIPELINE.0.STDDEP_334_IV_0_O2_4_1\,
datad => \GRFPC0.N_858\,
datac => \GRFPC0.N_23806\,
datab => \GRFPC0.N_23802\);
\GRFPC0_D_STDLCK_RNO_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPC0.D.STDLCK_0_0_14__G1\,
dataf => \GRFPC0.N_21577\,
datae => \GRFPC0.N_21589\,
datad => \GRFPC0.N_21564\,
datac => \GRFPC0.N_21539\,
datab => \GRFPC0.N_21579\,
dataa => \GRFPC0.D.STDLCK_0_0_14__G1_4\);
\GRFPC0_D_LDLCK_RNO_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcfff3fff0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_29__G1\,
dataf => \GRFPC0.FP_PIPELINE.14.REGDEPX2_449\(1),
datae => \GRFPC0.FP_PIPELINE.14.REGDEPX2_445\(1),
datad => \GRFPC0.D.LDLCK_0_0_29__G1_3\,
datac => \GRFPC0.N_24943\,
datab => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\);
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_O2_3_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f3f3f0fcf3ff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O2_3_1\,
dataf => \GRFPC0.N_22133\,
datae => \GRFPC0.N_841\,
datad => \GRFPC0.N_74_I_I\,
datac => \GRFPC0.N_22157\,
datab => \GRFPC0.N_570\);
\GRFPC0_D_STDLCK_RNO_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0cff0cff0cff00")
port map (
combout => \GRFPC0.D.STDLCK_0_0_1__G1_6_0\,
dataf => \GRFPC0.N_22196\,
datae => \GRFPC0.FP_PIPELINE.0.STDDEP_48_IV_0_O2_3_1\,
datad => \GRFPC0.D.STDLCK_0_0_1__G1_6\,
datac => \GRFPC0.N_675\,
datab => \GRFPC0.N_22126\);
\GRFPC0_D_STDLCK_RNO_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000ffffffffffff")
port map (
combout => \GRFPC0.D.STDLCK_0_0_1__G1_1\,
dataf => \GRFPC0.N_22820\,
datae => \GRFPC0.N_22819\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datac => \GRFPC0.N_9474\);
\GRFPC0_D_STDLCK_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00ff0c")
port map (
combout => \GRFPC0.D.STDLCK_0_0_1__G1\,
dataf => \GRFPC0.D.STDLCK_0_0_1__G1_6_0\,
datae => \GRFPC0.N_674\,
datad => \GRFPC0.D.STDLCK_0_0_1__G1_4\,
datac => \GRFPC0.N_615\,
datab => \GRFPC0.N_675\);
\GRFPC0_D_STLCK_RNO_6_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f3000000")
port map (
combout => \GRFPC0.N_22869\,
dataf => \GRFPC0.N_22118\,
datae => \GRFPC0.N_35_I\,
datad => \GRFPC0.N_22125\,
datac => \GRFPC0.N_22126\,
datab => \GRFPC0.N_494\);
\GRFPC0_D_STLCK_RNO_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000300000003000")
port map (
combout => \GRFPC0.N_22867\,
dataf => \GRFPC0.N_22133\,
datae => \GRFPC0.N_742_1\,
datad => \GRFPC0.N_35_I\,
datac => \GRFPC0.N_22125\,
datab => \GRFPC0.N_68_I\);
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_A2_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.N_22196\,
dataf => \GRFPC0.N_22133\,
datae => \GRFPC0.N_22173_I\,
datad => \GRFPC0.N_481\,
datac => \GRFPC0.N_570\);
\GRFPC0_FP_PIPELINE_0_STDEP_122_0_IV_I_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003000000")
port map (
combout => \GRFPC0.N_21474\,
dataf => \GRFPC0.N_61_I\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datad => \GRFPC0.N_9475_1\,
datac => N_107,
datab => N_106);
\GRFPC0_D_STLCK_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3000ffffffcf")
port map (
combout => \GRFPC0.D.STLCK_0_0_4__G1\,
dataf => \GRFPC0.N_40\,
datae => \GRFPC0.D.STLCK_0_0_4__G1_5\,
datad => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datab => \GRFPC0.FP_PIPELINE.2.STDEP_110_0_IV_0_O3_2_0\(0));
\GRFPC0_D_STLCK_RNO_2_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3000")
port map (
combout => \GRFPC0.D.STLCK_0_0_10__G1_1\,
dataf => \GRFPC0.N_22564\,
datae => \GRFPC0.N_23281\,
datad => \GRFPC0.N_9478\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datab => \GRFPC0.N_61_I\);
\GRFPC0_D_STLCK_RNO_1_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0c00ffff0f00")
port map (
combout => \GRFPC0.D.STLCK_0_0_10__G1_2\,
dataf => N_99871,
datae => \GRFPC0.D.STLCK_0_0_10__G1_1\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.STDDEP_0_SQMUXA_123_I_I_A2_I_O2_0\,
datab => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_D_STLCK_RNO_0_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0cffffff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_10__G1_4\,
dataf => \GRFPC0.N_571\,
datae => \GRFPC0.N_22588\,
datad => \GRFPC0.D.STLCK_0_0_10__G1_2\,
datac => \GRFPC0.N_21612\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0));
\GRFPC0_FP_PIPELINE_5_STDEP_234_0_IV_I_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f300f3f300000000")
port map (
combout => \GRFPC0.N_23289\,
dataf => \GRFPC0.N_22514\,
datae => \GRFPC0.N_104\,
datad => \GRFPC0.FP_PIPELINE.5.STDEP_234_0_IV_I_O2_3_0\(0),
datac => \GRFPC0.N_21612\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0));
\GRFPC0_D_STLCK_RNO_0_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0fff0fff0")
port map (
combout => \GRFPC0.D.STLCK_0_0_14__G1_5\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1\(0),
datae => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datad => \GRFPC0.N_22360\,
datac => \GRFPC0.D.STLCK_0_0_14__G1_3\,
datab => \GRFPC0.N_9480\);
\GRFPC0_D_STLCK_RNO_6_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0fff0f0")
port map (
combout => \GRFPC0.D.STLCK_0_0_15__G1_3\,
dataf => \GRFPC0.N_22377\,
datae => \GRFPC0.N_21866\,
datad => N_40557,
datac => \GRFPC0.D.STLCK_0_0_15__G1_1\);
\GRFPC0_D_STLCK_RNO_1_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0fff0fff0")
port map (
combout => \GRFPC0.D.STLCK_0_0_15__G1_5\,
dataf => \GRFPC0.N_62\,
datae => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datad => \GRFPC0.N_22380\,
datac => \GRFPC0.D.STLCK_0_0_15__G1_3\,
datab => \GRFPC0.N_9480\);
\GRFPC0_D_STLCK_RNO_7_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000ffffc000c000")
port map (
combout => \GRFPC0.D.STLCK_0_0_23__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datae => \GRFPC0.N_21737\,
datad => \GRFPC0.N_9484\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datab => \GRFPC0.N_59\);
\GRFPC0_D_STLCK_RNO_0_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffffff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_23__G1_9\,
dataf => \GRFPC0.N_62\,
datae => \GRFPC0.D.STLCK_0_0_23__G1_7\,
datad => \GRFPC0.N_23439\,
datac => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datab => \GRFPC0.N_9484\);
\GRFPC0_D_STLCK_RNO_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0008000")
port map (
combout => \GRFPC0.D.STLCK_0_0_23__G1\,
dataf => \GRFPC0.D.STLCK_0_0_23__G1_9\,
datae => \GRFPC0.N_22173_I\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datac => \GRFPC0.N_23495\,
datab => \GRFPC0.FP_PIPELINE.11.STDEP_478_I_M_I_A2_4_1\(1),
dataa => \GRFPC0.N_481\);
\GRFPC0_D_STLCK_RNO_0_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000300")
port map (
combout => \GRFPC0.D.STLCK_0_0_24__G1_3\,
dataf => \GRFPC0.D.STLCK_0_0_24__G1_2\,
datae => N_99871,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_23324\,
datab => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_D_STLCK_RNO_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffefeedfddcfcc")
port map (
combout => \GRFPC0.D.STLCK_0_0_24__G1\,
dataf => \GRFPC0.N_18320\,
datae => \GRFPC0.N_18322\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1\(0),
datac => \GRFPC0.STDDEP_0_SQMUXA_128_I_1\,
datab => \GRFPC0.D.STLCK_0_0_24__G1_3\,
dataa => \GRFPC0.N_18319\);
\GRFPC0_DIV_RESULT_0_0_0__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \FPO.RES\(0),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_0\,
datad => \GRFPC0.DIV.RESULT_0_0_0__G5\,
datac => \FPO.CC\(0),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(0));
\GRFPC0_DIV_RESULT_0_0_2__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffccfff0ff00")
port map (
combout => \FPO.RES\(2),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_0\,
datad => \GRFPC0.DIV.RESULT_0_0_2__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(2),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(2));
\GRFPC0_DIV_RESULT_0_0_3__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffccfff0ff00")
port map (
combout => \FPO.RES\(3),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_0\,
datad => \GRFPC0.DIV.RESULT_0_0_3__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(3),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(3));
\GRFPC0_DIV_RESULT_0_0_6__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \FPO.RES\(6),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_0\,
datad => \GRFPC0.DIV.RESULT_0_0_6__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(6),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(6));
\GRFPC0_DIV_RESULT_0_0_9__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \FPO.RES\(9),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_0\,
datad => \GRFPC0.DIV.RESULT_0_0_9__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(9),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(9));
\GRFPC0_DIV_RESULT_0_0_10__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \FPO.RES\(10),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_0\,
datad => \GRFPC0.DIV.RESULT_0_0_10__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(10),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(10));
\GRFPC0_DIV_RESULT_0_0_12__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \FPO.RES\(12),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_0\,
datad => \GRFPC0.DIV.RESULT_0_0_12__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(12),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(12));
\GRFPC0_DIV_RESULT_0_0_14__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \FPO.RES\(14),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_0\,
datad => \GRFPC0.DIV.RESULT_0_0_14__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(14),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(14));
\GRFPC0_DIV_RESULT_0_0_17__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \FPO.RES\(17),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_0\,
datad => \GRFPC0.DIV.RESULT_0_0_17__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(17),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(17));
\GRFPC0_DIV_RESULT_0_0_18__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \FPO.RES\(18),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_0\,
datad => \GRFPC0.DIV.RESULT_0_0_18__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(18),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(18));
\GRFPC0_DIV_RESULT_0_0_19__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \FPO.RES\(19),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_0\,
datad => \GRFPC0.DIV.RESULT_0_0_19__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(19),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(19));
\GRFPC0_DIV_RESULT_0_0_20__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \FPO.RES\(20),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_0\,
datad => \GRFPC0.DIV.RESULT_0_0_20__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(20),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(20));
\GRFPC0_DIV_RESULT_0_0_21__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \FPO.RES\(21),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_1\,
datad => \GRFPC0.DIV.RESULT_0_0_21__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(21),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(21));
\GRFPC0_DIV_RESULT_0_0_23__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffccfff0ff00")
port map (
combout => \FPO.RES\(23),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_1\,
datad => \GRFPC0.DIV.RESULT_0_0_23__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(23),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(23));
\GRFPC0_DIV_RESULT_0_0_27__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffccfff0ff00")
port map (
combout => \FPO.RES\(27),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_1\,
datad => \GRFPC0.DIV.RESULT_0_0_27__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(27),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(27));
\GRFPC0_DIV_RESULT_0_0_28__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \FPO.RES\(28),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_1\,
datad => \GRFPC0.DIV.RESULT_0_0_28__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(28),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(28));
\GRFPC0_DIV_RESULT_0_0_29__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \FPO.RES\(29),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_1\,
datad => \GRFPC0.DIV.RESULT_0_0_29__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(29),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(29));
GRFPC0_RFA_RDWR_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000300000")
port map (
combout => N_45120,
dataf => CPO_EXCZ,
datae => \GRFPC0.RFA.RDWR_0_0_G1_0_1554_A2_3\,
datad => N_112,
datac => N_102,
datab => N_113);
GRFPC0_WR2_CTRL_AFSR_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000030003000")
port map (
combout => N_44776,
dataf => CPO_EXCZ,
datae => \GRFPC0.WR.CTRL.LD\,
datad => \GRFPC0.WR.CTRL.AFSR\,
datac => \GRFPC0.WR2.CTRL.AFSR_0_0_G1_0_1123_A2_4_0\,
datab => N_389);
GRFPC0_WR2_CTRL_AFSR_0_0_G1_0_1123_A2_4_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff0000")
port map (
combout => \GRFPC0.WR2.CTRL.AFSR_0_0_G1_0_1123_A2_4_0\,
dataf => N_388,
datae => N_35,
datad => N_39);
\GRFPC0_D_STLCK_RNO_2_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff0fffc")
port map (
combout => \GRFPC0.D.STLCK_0_0_29__G1_3\,
dataf => \GRFPC0.N_23208\,
datae => \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0\,
datad => \GRFPC0.D.STLCK_0_0_29__G1_0\,
datac => \GRFPC0.N_23199\,
datab => \GRFPC0.N_106_I\);
\GRFPC0_D_STLCK_RNO_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffefefeffdcdcdc")
port map (
combout => \GRFPC0.D.STLCK_0_0_29__G1\,
dataf => \GRFPC0.N_23174\,
datae => \GRFPC0.N_62\,
datad => \GRFPC0.FP_PIPELINE.14.STDEP_598_I_M_I_A3_0\(1),
datac => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datab => \GRFPC0.D.STLCK_0_0_29__G1_5\,
dataa => \GRFPC0.N_23152\);
\GRFPC0_D_STLCK_RNO_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcfcfc")
port map (
combout => \GRFPC0.D.STLCK_0_0_12__G1\,
dataf => \GRFPC0.FP_PIPELINE.6.STDEP_256\(0),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1_1\(0),
datad => \GRFPC0.FP_PIPELINE.6.STDEP_278_I_M_I_A2_3_0\(1),
datac => \GRFPC0.D.STLCK_0_0_12__G1_2\,
datab => \GRFPC0.N_22452\);
\GRFPC0_D_STLCK_RNO_4_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_22753\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datae => \GRFPC0.N_59\,
datad => \GRFPC0.N_9475_1\,
datac => N_107,
datab => N_106);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_0_0_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\(5),
dataf => \GRFPC0.FIFO.INST_1\(19),
datae => \GRFPC0.FIFO.INST_1\(29),
datad => \GRFPC0.FIFO.INST_1\(28),
datac => \GRFPC0.FIFO.INST_1\(26),
datab => \GRFPC0.FIFO.INST_1\(27));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff000000")
port map (
combout => \GRFPC0.N_25336\,
dataf => N_40557,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\(5));
\GRFPC0_D_STLCK_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffff0300")
port map (
combout => \GRFPC0.D.STLCK_0_0_5__G1\,
dataf => \GRFPC0.FP_PIPELINE.2.STDEP_92\(1),
datae => \GRFPC0.D.STLCK_0_0_5__G1_5\,
datad => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datac => \GRFPC0.FP_PIPELINE.2.STDEP_118_I_M_I_O3_2_0\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0));
\GRFPC0_D_LDLCK_RNO_0_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_31__G1_2\,
dataf => \GRFPC0.N_23117\,
datae => \GRFPC0.N_23131\,
datad => \GRFPC0.N_25603\,
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4984_REGDEPX\,
datab => \GRFPC0.N_23988_1\);
\GRFPC0_D_LDLCK_RNO_1_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffc0ffc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_28__G1_1\,
dataf => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4672_REGDEPX\,
datae => \GRFPC0.N_25795_1\,
datad => \GRFPC0.N_23184\,
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4687_REGDEPX\,
datab => \GRFPC0.N_24849_1\);
\GRFPC0_D_LDLCK_RNO_0_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfffcccccffcc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_28__G1_4\,
dataf => \GRFPC0.FP_PIPELINE.14.0.REGDEPX_257\(0),
datae => \GRFPC0.N_23177\,
datad => \GRFPC0.N_23345_1\,
datac => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datab => \GRFPC0.D.LDLCK_0_0_28__G1_1\);
\GRFPC0_D_LDLCK_RNO_0_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffc000c000c000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_25__G1_3\,
dataf => \GRFPC0.FP_PIPELINE.12.0.REGDEPX_221\(1),
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_22253\,
datab => \GRFPC0.FP_PIPELINE.12.1.CHECK_DEP.UN3959_REGDEPX\);
\GRFPC0_D_LDLCK_RNO_0_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_23__G1_4\,
dataf => \GRFPC0.N_23417\,
datae => \GRFPC0.D.LDLCK_0_0_23__G1_2\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_22253\,
datab => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3647_REGDEPX\);
\GRFPC0_D_LDLCK_RNO_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_14__G1\,
dataf => \GRFPC0.N_24709\,
datae => \GRFPC0.N_25034\,
datad => \GRFPC0.D.LDLCK_0_0_14__G1_0\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datab => \GRFPC0.N_25064\);
\GRFPC0_D_LDLCK_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPC0.D.LDLCK_0_0_8__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_9\(0),
datae => \GRFPC0.D.LDLCK_0_0_8__G3\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_8\(0));
\GRFPC0_D_LDLCK_RNO_0_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffc0ffc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G1_1\,
dataf => \GRFPC0.N_25355_2\,
datae => \GRFPC0.N_25344_1\,
datad => \GRFPC0.N_25343\,
datac => \GRFPC0.N_25341_1\,
datab => \GRFPC0.N_21639_2\);
\GRFPC0_D_LDLCK_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffccfcc")
port map (
combout => \GRFPC0.D.LDLCK_0_0_7__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_120\(1),
datae => \GRFPC0.FP_PIPELINE.3.1.REGDEPX_65\(1),
datad => \GRFPC0.FP_PIPELINE.3.0.REGDEPX_60\(1),
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datab => \GRFPC0.D.LDLCK_0_0_7__G1_1\);
\GRFPC0_D_LDLCK_RNO_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_6__G1\,
dataf => \GRFPC0.N_24712\,
datae => \GRFPC0.N_24725\,
datad => \GRFPC0.D.LDLCK_0_0_6__G1_0\,
datac => \GRFPC0.N_25344_1\,
datab => \GRFPC0.N_24849_1\);
\GRFPC0_R_FSR_CEXC_RNO_2_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0c0c0c0c0c0c0")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_3__G1_0\,
dataf => \GRFPC0.V.FSR.CEXC_1_SQMUXA\,
datae => \GRFPC0.R.FSR.TEM\(3),
datad => \GRFPC0.DIV.EXCT\(3),
datac => \GRFPC0.V.FSR.AEXC_0_SQMUXA\,
datab => N_434);
\GRFPC0_R_FSR_CEXC_RNO_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffcf0")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_3__G1_3\,
dataf => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_13_M\(3),
datae => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_12_M\(3),
datad => \GRFPC0.V.FSR.CEXC_6_SQMUXA\,
datac => \GRFPC0.R.FSR.CEXC_0_0_3__G1_0\,
datab => \GRFPC0.DIV.EXCT\(3));
\GRFPC0_R_FSR_CEXC_RNO_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcfc00000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_3__G1_4\,
dataf => \GRFPC0.R.FSR.CEXC_0_0_3__G1_3\,
datae => \GRFPC0.V.FSR.CEXC_5_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
datac => \GRFPC0.WR2.RREG.RESV\,
datab => \GRFPC0.WR2.RREG.EXCT\(3));
\GRFPC0_R_FSR_CEXC_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_3__G1\,
dataf => \GRFPC0.R.FSR.CEXC_0_0_3__G1_4\,
datae => \GRFPC0.V.FSR.CEXC_0_SQMUXA_2\,
datad => \GRFPC0.V.FSR.CEXC_4_SQMUXA_1\,
datac => \GRFPC0.WR2.RREG.RES\(3),
datab => \GRFPC0.R.FSR.CEXC\(3));
\GRFPC0_R_FSR_CEXC_RNO_2_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0c0c0c0c0c0c0")
port map (
combout => \GRFPC0.R.FSR.CEXC_0_0_2__G1_0\,
dataf => \GRFPC0.V.FSR.CEXC_1_SQMUXA\,
datae => \GRFPC0.R.FSR.TEM\(2),
datad => \GRFPC0.DIV.EXCT\(2),
datac => \GRFPC0.V.FSR.AEXC_0_SQMUXA\,
datab => N_433);
\GRFPC0_RFA2_FID_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \GRFPC0.FID_1\(5),
dataf => \GRFPC0.N_9160\,
datae => \GRFPC0.N_9159\,
datad => \GRFPC0.FID_1_IV_0_5__G0_1\,
datac => \GRFPC0.EX.CTRL.ID\(5),
datab => \GRFPC0.MEM.CTRL.ID\(5));
\GRFPC0_RFA2_FID_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \GRFPC0.FID_1\(4),
dataf => \GRFPC0.N_9160\,
datae => \GRFPC0.N_9159\,
datad => \GRFPC0.FID_1_IV_0_4__G0_1\,
datac => \GRFPC0.EX.CTRL.ID\(4),
datab => \GRFPC0.MEM.CTRL.ID\(4));
\GRFPC0_RFA2_FID_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \GRFPC0.FID_1\(2),
dataf => \GRFPC0.N_9160\,
datae => \GRFPC0.N_9159\,
datad => \GRFPC0.FID_1_IV_0_2__G0_1\,
datac => \GRFPC0.EX.CTRL.ID\(2),
datab => \GRFPC0.MEM.CTRL.ID\(2));
\GRFPC0_RFA2_FID_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \GRFPC0.FID_1\(1),
dataf => \GRFPC0.N_9160\,
datae => \GRFPC0.N_9159\,
datad => \GRFPC0.FID_1_IV_0_1__G0_1\,
datac => \GRFPC0.EX.CTRL.ID\(1),
datab => \GRFPC0.MEM.CTRL.ID\(1));
\GRFPC0_RFA2_FID_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \GRFPC0.FID_1\(0),
dataf => \GRFPC0.N_9160\,
datae => \GRFPC0.N_9159\,
datad => \GRFPC0.FID_1_IV_0_0__G0_1\,
datac => \GRFPC0.EX.CTRL.ID\(0),
datab => \GRFPC0.MEM.CTRL.ID\(0));
\GRFPC0_RFA2_FOP_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.N_10565\,
dataf => \GRFPC0.RFA2.FOP_0_0_0_1__N_4\,
datae => \GRFPC0.RFA2.FOP_0_0_0_1__G1\,
datad => \GRFPC0.RFA2.FOP_0_0_0_1__G0_0_A4_0_4\,
datac => \GRFPC0.N_23789\,
datab => \GRFPC0.RFA.WRITE_RD_0_0_I1_I_1\);
\GRFPC0_FPR_ID_RNIQ51N_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ffff0ffff0ffff0")
port map (
combout => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_3\,
dataf => \GRFPC0.EX.CTRL.ID\(1),
datae => \GRFPC0.EX.CTRL.ID\(2),
datad => \GRFPC0.FPR.ID\(1),
datac => \GRFPC0.FPR.ID\(2));
\GRFPC0_EX_CTRL_ID_RNIUL1N_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff0ffffffff0ff0")
port map (
combout => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_1\,
dataf => \GRFPC0.EX.CTRL.ID\(0),
datae => \GRFPC0.FPR.ID\(0),
datad => \GRFPC0.FPR.ID\(5),
datac => \GRFPC0.EX.CTRL.ID\(5));
\GRFPC0_FPR_ID_RNI262N_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ffff0ffff0ffff0")
port map (
combout => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_2\,
dataf => \GRFPC0.EX.CTRL.ID\(3),
datae => \GRFPC0.EX.CTRL.ID\(4),
datad => \GRFPC0.FPR.ID\(3),
datac => \GRFPC0.FPR.ID\(4));
\GRFPC0_EX_CTRL_ID_RNITMOG2_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffcf")
port map (
combout => \GRFPC0.N_82\,
dataf => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_3\,
datae => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_2\,
datad => \GRFPC0.EX.RREG.EXCT_0_0_0__G0_I_O4_1\,
datac => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.EX.CTRL.ID\(7));
\GRFPC0_RFA2_FOP_RNO_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300300000000000")
port map (
combout => \GRFPC0.RFA2.FOP_0_0_0_1__G0_0_A4_1\,
dataf => \GRFPC0.N_23631\,
datae => \GRFPC0.INST\(5),
datad => \GRFPC0.INST\(7),
datac => \GRFPC0.N_23618\,
datab => \GRFPC0.INST\(10));
\GRFPC0_RFA2_FOP_RNO_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.RFA2.FOP_0_0_0_1__N_4\,
dataf => \GRFPC0.N_23789\,
datae => \GRFPC0.RFA2.FOP_0_0_0_1__G0_0_A4_1\,
datad => \GRFPC0.N_23783\,
datac => \GRFPC0.RFA.WRITE_RD_0_0_I1_I_1\,
datab => \GRFPC0.INST\(9));
\GRFPC0_INST_RNIDJ9B_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.RFA2.FOP_0_0_0_1__G1_2\,
dataf => \GRFPC0.INST\(12),
datae => \GRFPC0.INST\(9),
datad => \GRFPC0.INST\(11),
datac => \GRFPC0.INST\(10));
GRFPU0_GRFPU_X0_COMB_MULBP_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccc0000c0000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
dataf => \GRFPU0.GRFPU_X0.N_7363\,
datae => \FPI.START\,
datad => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_3\,
datac => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_4\,
datab => \GRFPU0.GRFPU_X0.ITER.ALLOW\(1));
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_O3_1_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3fffffffffff")
port map (
combout => \GRFPC0.N_53\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(2),
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_6_REGDEPX_120_0_A2_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000c0")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX_120_0_A2_1_0\(0),
dataf => \GRFPC0.FIFO.INST_0\(19),
datae => \GRFPC0.FIFO.INST_0\(29),
datad => \GRFPC0.FIFO.INST_0\(26),
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28));
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_A3_3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_A3_3_0\,
dataf => \GRFPC0.N_60\,
datae => \GRFPC0.RFA.LD\,
datad => N_174,
datac => \GRFPC0.N_801\,
datab => N_173);
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_O3_0_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffccfccccfccfc")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_202_IV_0_O3_0_1\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datad => \GRFPC0.N_55\,
datac => \GRFPC0.N_505\,
datab => \GRFPC0.N_120\);
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0c0c000c0c000")
port map (
combout => \GRFPC0.N_21212\,
dataf => \GRFPC0.N_149\,
datae => \GRFPC0.N_13\,
datad => \GRFPC0.N_15\,
datac => \GRFPC0.N_55\,
datab => \GRFPC0.MEM.CTRL.RDWR\);
GRFPU0_GRFPU_X0_UN123_BCO_LSB_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000035")
port map (
combout => \GRFPU0.GRFPU_X0.UN123_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.N_18314\,
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(3),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(5),
datac => \GRFPU0.MULO.MRES\(120),
datab => \GRFPU0.MULO.DRES_1\(103),
dataa => \GRFPU0.MULO.DRES_1S\(102));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f0000fccfcccc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_1__G0_0\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(50));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff00000cffccccc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_2__G0_0\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => N_32260,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(51));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_1_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0ffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_1\(13),
dataf => \GRFPU0.GRFPU_X0.N_19897\,
datae => \GRFPU0.GRFPU_X0.N_19949\,
datad => \GRFPU0.GRFPU_X0.N_391\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
datab => \FPI.OP1_RETO\(13));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_1_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0ffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_0_1\(19),
dataf => \GRFPU0.GRFPU_X0.N_19897\,
datae => \GRFPU0.GRFPU_X0.N_19944\,
datad => \GRFPU0.GRFPU_X0.N_391\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19),
datab => \FPI.OP1_RETO\(19));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffffffc0")
port map (
combout => \GRFPU0.GRFPU_X0.N_71\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(22),
datae => \GRFPU0.GRFPU_X0.N_19984\,
datad => \GRFPU0.GRFPU_X0.N_19982\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datab => \GRFPU0.GRFPU_X0.N_19546\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_0_0_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0ff0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_0\(52),
dataf => \GRFPU0.GRFPU_X0.N_15611\,
datae => \GRFPU0.GRFPU_X0.N_53\,
datad => \GRFPU0.GRFPU_X0.N_6806\,
datac => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_0_A2_0_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f00000000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_48\,
dataf => \GRFPU0.GRFPU_X0.N_18195\,
datae => \GRFPU0.GRFPU_X0.N_78_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(52));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_0_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(52),
dataf => \GRFPU0.GRFPU_X0.N_48\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1\(52),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_0\(52),
datac => \GRFPU0.GRFPU_X0.N_15611\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_3_1\(52));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(41),
dataf => \GRFPU0.GRFPU_X0.N_19668\,
datae => \GRFPU0.GRFPU_X0.N_18976\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(41),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(41));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(41),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(41),
datae => \GRFPU0.GRFPU_X0.N_291\,
datad => \GRFPU0.GRFPU_X0.N_19779\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(41));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(40),
dataf => \GRFPU0.GRFPU_X0.N_19668\,
datae => \GRFPU0.GRFPU_X0.N_18976\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(40),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(40));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(40),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(40),
datae => \GRFPU0.GRFPU_X0.N_291\,
datad => \GRFPU0.GRFPU_X0.N_19779\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(40));
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_16_RNISUJB2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000300030003ff03")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_9_0\(4),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(17),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(16),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(48));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff00f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(48),
dataf => \GRFPU0.GRFPU_X0.N_19779\,
datae => \GRFPU0.GRFPU_X0.N_18976\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(48),
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(48));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0ffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(48),
dataf => \GRFPU0.GRFPU_X0.N_154\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(48),
datad => \GRFPU0.GRFPU_X0.N_19896\,
datac => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffcf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(55),
dataf => \GRFPU0.GRFPU_X0.N_19958\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => N_40510,
datac => \GRFPU0.GRFPU_X0.N_19959\,
datab => \GRFPU0.GRFPU_X0.UN8_C\(3));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff000cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(53),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(53),
datae => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datad => \GRFPU0.GRFPU_X0.N_19592_1\,
datac => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.EXP1\(1));
\GRFPU0_GRFPU_X0_ITER_TZR_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30f0cf0fffc0003f")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_1__N_6\,
dataf => \GRFPU0.GRFPU_X0.L4_6\(0),
datae => \GRFPU0.GRFPU_X0.L4_6\(1),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ITER.ODDEXP\);
\GRFPC0_DIV_RESULT_0_0_11__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \FPO.RES\(11),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_0\,
datad => \GRFPC0.DIV.RESULT_0_0_11__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(11),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(11));
\GRFPC0_DIV_RESULT_0_0_1__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \FPO.RES\(1),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_0\,
datad => \GRFPC0.DIV.RESULT_0_0_1__G5\,
datac => \FPO.CC\(1),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(1));
GRFPU0_GRFPU_X0_COMB_VST1_V2_1_RNIA9R14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_10059_I\,
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VST1.V2\,
datad => \GRFPU0.GRFPU_X0.N_5539\,
datac => \FPI.START\,
datab => \GRFPU0.GRFPU_X0.ITER.ALLOW\(2));
\GRFPU0_GRFPU_X0_L1_2_2_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_9671\,
dataf => \GRFPU0.GRFPU_X0.N_9678\,
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(32),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(31),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(30));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNIQCIH1_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.L3_2\(5),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(24),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(22),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(23));
\GRFPU0_GRFPU_X0_ITER_R_I_RNIFN7A1_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.L3_2_1\(5),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(36));
GRFPU0_GRFPU_X0_UN153_BCO_LSB_RNIDN5H3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0\(5),
dataf => \GRFPU0.GRFPU_X0.N_6535\,
datae => \GRFPU0.GRFPU_X0.L1_2\(3),
datad => \GRFPU0.GRFPU_X0.L3_2_1\(5),
datac => \GRFPU0.GRFPU_X0.UN153_BCO_LSB\(15));
\GRFPU0_GRFPU_X0_TZI2_RNI9LDJ2_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_3\(3),
dataf => \GRFPU0.GRFPU_X0.UN48_BCO_LSB_0\,
datae => \GRFPU0.GRFPU_X0.N_13805_I_0\,
datad => \GRFPU0.GRFPU_X0.L1_2_1\(3),
datac => \GRFPU0.GRFPU_X0.TZI2\(23),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(30));
\GRFPC0_DIV_RESULT_0_0_15__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \FPO.RES\(15),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_0\,
datad => \GRFPC0.DIV.RESULT_0_0_15__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(15),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(15));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30fffcff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18859_I\,
dataf => \GRFPU0.GRFPU_X0.N_18859_I_0_G0_2\,
datae => \GRFPU0.GRFPU_X0.N_18954\,
datad => \GRFPU0.GRFPU_X0.N_18948\,
datac => \GRFPU0.GRFPU_X0.N_18870\,
datab => \FPI.FLOP\(1));
\GRFPC0_DIV_RESULT_0_0_30__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfff0ffccff00ff")
port map (
combout => \FPO.RES\(30),
dataf => N_99904_1,
datae => \GRFPU0.GRFPU_X0.N_400_1\,
datad => N_45853,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(30),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(30));
\GRFPU0_GRFPU_X0_ITER_ND_I_RNITJCI1_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_10_1\(3),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(41),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(43),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(12),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(14));
\GRFPU0_GRFPU_X0_L3_0_4_2_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_4_2\(5),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(39),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(37),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(38),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(36));
\GRFPU0_GRFPU_X0_L3_0_4_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_9542\,
dataf => \GRFPU0.GRFPU_X0.N_9548\,
datae => \GRFPU0.GRFPU_X0.N_9547\,
datad => \GRFPU0.GRFPU_X0.N_9549\,
datac => \GRFPU0.GRFPU_X0.L3_0_4_2\(5));
\GRFPU0_GRFPU_X0_L2_0_4_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_9548\,
dataf => \GRFPU0.GRFPU_X0.N_9559\,
datae => \GRFPU0.GRFPU_X0.N_9595\,
datad => \GRFPU0.GRFPU_X0.N_9548_2\,
datac => \GRFPU0.GRFPU_X0.N_13675_1\);
GRFPU0_GRFPU_X0_ST2_EMINM1_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccc0c0cc00c000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10079\,
dataf => \GRFPU0.GRFPU_X0.ST2.EMINM1_0_0_G0_I_A4_1\,
datae => \GRFPU0.GRFPU_X0.N_44\,
datad => \GRFPU0.GRFPU_X0.N_46\,
datac => N_60909,
datab => \GRFPU0.GRFPU_X0.N_5250\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNIGSI79_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000003000")
port map (
combout => \GRFPU0.GRFPU_X0.N_191\,
dataf => \GRFPU0.GRFPU_X0.N_6509_I_M\,
datae => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G2\,
datad => \GRFPU0.GRFPU_X0.N_236\,
datac => \GRFPU0.GRFPU_X0.N_191_5\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(24));
GRFPU0_GRFPU_X0_VALLOW_5_SQMUXA_0_O2_RNIJLVSF: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0f0c0f00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18203\,
dataf => \GRFPU0.GRFPU_X0.N_191\,
datae => \GRFPU0.GRFPU_X0.N_188\,
datad => \GRFPU0.GRFPU_X0.N_172\,
datac => \GRFPU0.GRFPU_X0.N_5673_0\,
datab => \GRFPU0.GRFPU_X0.N_128\);
\GRFPU0_GRFPU_X0_L3_0_3_1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0003ffff")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3_1\(5),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(38));
\GRFPU0_GRFPU_X0_L3_0_3_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3\(5),
dataf => \GRFPU0.GRFPU_X0.L2_0_5\(4),
datae => \GRFPU0.GRFPU_X0.L1_2_3\(3),
datad => \GRFPU0.GRFPU_X0.L3_0_3_1\(5),
datac => \GRFPU0.GRFPU_X0.UN53_BCO_LSB\(15));
\GRFPU0_GRFPU_X0_ITER_R_I_RNIRPVC1_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_7_0\(4),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(23));
\GRFPU0_GRFPU_X0_BCO_MSB_2_5_I_1_RNI119B2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_5\(4),
dataf => \GRFPU0.GRFPU_X0.N_9486\,
datae => \GRFPU0.GRFPU_X0.N_9487\,
datad => \GRFPU0.GRFPU_X0.N_13695_1\,
datac => \GRFPU0.GRFPU_X0.L2_0_7_0\(4));
GRFPU0_GRFPU_X0_COMB_VST3_REG59_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fffffffcffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG59_2\,
dataf => \GRFPU0.GRFPU_X0.N_19700\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__I3_I_3\,
datad => \GRFPU0.GRFPU_X0.N_5806\,
datac => \GRFPU0.GRFPU_X0.N_6798\,
datab => \GRFPU0.GRFPU_X0.N_162_I\);
GRFPU0_GRFPU_X0_COMB_VCS_DP_1_I_0_I_O2_1_RNII93R3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffff0030")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VCS_DP_1_I_0_I_0_G0_0_0\,
dataf => \GRFPU0.GRFPU_X0.N_19691\,
datae => \GRFPU0.GRFPU_X0.COMB.VCS_DP_1_I_0_I_0_N_5\,
datad => \GRFPU0.GRFPU_X0.N_19705\,
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(1));
GRFPU0_GRFPU_X0_COMB_VCS_DP_1_I_0_I_O2_1_RNIBALF5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffc0c0ffffc000")
port map (
combout => \GRFPU0.MULI.DP\,
dataf => \GRFPU0.GRFPU_X0.N_19700\,
datae => \GRFPU0.GRFPU_X0.COMB.VCS_DP_1_I_0_I_0_G0_0_0\,
datad => \GRFPU0.GRFPU_X0.N_19705\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.DP\);
GRFPU0_GRFPU_X0_COMB_CNV_SHIFT214_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_2\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
datab => \GRFPU0.GRFPU_X0.ST2.RDY\);
GRFPU0_GRFPU_X0_COMB_CNV_SHIFT214: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000030c000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214_2\,
datae => \GRFPU0.GRFPU_X0.N_5777_I_I_O2_I_O2_2_0_0\,
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(3));
GRFPU0_GRFPU_X0_UN1_RNDOP_2_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18527\,
dataf => \GRFPU0.GRFPU_X0.N_11529\,
datae => \GRFPU0.GRFPU_X0.N_18572\,
datad => \GRFPU0.GRFPU_X0.N_18570\,
datac => \GRFPU0.GRFPU_X0.COMB.RMND_13\(0),
datab => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_A2_1_1\);
GRFPU0_GRFPU_X0_UN1_RNDOP_2_I_A2_1_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_RNDOP_2_I_A2_1_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datae => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datad => \GRFPU0.GRFPU_X0.ITER.LOB\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(1));
\GRFPU0_GRFPU_X0_ITER_STATE_RNIQCI11_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0f0f0f0f0")
port map (
combout => N_99921,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(19),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(7));
\GRFPU0_GRFPU_X0_ITER_TZR_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f0ff0c3c33c3c")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_5__N_6\,
dataf => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_4__N_6\,
datae => \GRFPU0.GRFPU_X0.N_9542\,
datad => \GRFPU0.GRFPU_X0.L4_6\(4),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\);
GRFPU0_GRFPU_X0_ST3_INF_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcfffffcfc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.INF_0_0_G0_2\,
dataf => \GRFPU0.GRFPU_X0.UN1_ST2.FLTYPE2_8\,
datae => \GRFPU0.GRFPU_X0.N_6206\,
datad => \GRFPU0.GRFPU_X0.N_5820\,
datac => \GRFPU0.GRFPU_X0.N_5773\,
datab => \GRFPU0.GRFPU_X0.ST2.INF\);
GRFPU0_GRFPU_X0_ST3_INF_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffccfc0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10037\,
dataf => \GRFPU0.GRFPU_X0.ST3.INF_0_0_G0_2\,
datae => \GRFPU0.GRFPU_X0.N_5768\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__I3_I_3\,
datac => \GRFPU0.GRFPU_X0.VST3.EXC_0_SQMUXA_0\,
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(6));
\GRFPU0_GRFPU_X0_ST3_EXC_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1\(1),
dataf => \GRFPU0.GRFPU_X0.N_5755_1\,
datae => \GRFPU0.GRFPU_X0.N_5757\,
datad => \GRFPU0.GRFPU_X0.ST2.EXC\(1));
GRFPU0_GRFPU_X0_ST2_ZERO_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc0c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G0_I_A2_1\,
dataf => \GRFPU0.GRFPU_X0.VST2.INF_1_SQMUXA_1\,
datae => \GRFPU0.GRFPU_X0.N_3407\,
datad => \GRFPU0.GRFPU_X0.REST_1_2\(7),
datac => \GRFPU0.GRFPU_X0.N_3638_1\,
datab => \GRFPU0.GRFPU_X0.ST1.V\);
GRFPU0_GRFPU_X0_ST2_ZERO_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10045\,
dataf => \GRFPU0.GRFPU_X0.ST2.ZERO_0_0_G0_I_A2_1\,
datae => \GRFPU0.GRFPU_X0.N_3475\,
datad => \GRFPU0.GRFPU_X0.N_3516\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7));
\GRFPU0_GRFPU_X0_ITER_STATE_RNIOQIT_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccfffcf0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(16));
\GRFPU0_GRFPU_X0_ITER_STATE_RNIAOPD3_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0ccffffffff")
port map (
combout => N_99920,
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_21\,
datae => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_62_1\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(13));
\GRFPU0_GRFPU_X0_ITER_STATE_RNI2G9T_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_64_2\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(19),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(7));
\GRFPU0_GRFPU_X0_ITER_STATE_RNIS7IQ1_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_21\,
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_64_2\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(16));
\GRFPU0_GRFPU_X0_ST3_EXC_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0fffff0f0")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1\(0),
dataf => \GRFPU0.GRFPU_X0.N_5755_1\,
datae => \GRFPU0.GRFPU_X0.VST3.EXC_1_IV_0_0__G0_1\,
datad => \GRFPU0.GRFPU_X0.N_5757\,
datac => \GRFPU0.GRFPU_X0.N_5937_1\,
datab => \GRFPU0.GRFPU_X0.ST2.EXC\(0));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300ff000f00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18752_I\,
dataf => \GRFPU0.GRFPU_X0.N_18831\,
datae => \GRFPU0.GRFPU_X0.N_18829\,
datad => \GRFPU0.GRFPU_X0.N_18752_I_0_G0_0\,
datac => \GRFPU0.GRFPU_X0.N_18808\,
datab => \FPI.FLOP\(1));
\GRFPC0_DIV_RESULT_0_0_16__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \FPO.RES\(16),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_0\,
datad => \GRFPC0.DIV.RESULT_0_0_16__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(16),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(16));
\GRFPC0_DIV_RESULT_0_0_26__G3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffccfff0ff00")
port map (
combout => \FPO.RES\(26),
dataf => N_99904_0,
datae => \GRFPU0.GRFPU_X0.N_400_1\,
datad => \GRFPC0.DIV.RESULT_0_0_26__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.MSGNF\(26),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(26));
GRFPU0_GRFPU_X0_ST3_V_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c00000c0000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10189\,
dataf => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.ST3.V_0_0_G5\,
datad => \GRFPU0.GRFPU_X0.N_5790\,
datac => \GRFPU0.GRFPU_X0.ST2.V\,
datab => N_35);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff00f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(43),
dataf => \GRFPU0.GRFPU_X0.N_19779\,
datae => \GRFPU0.GRFPU_X0.N_18976\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(43),
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(43));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0ffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(43),
dataf => \GRFPU0.GRFPU_X0.N_154\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(43),
datad => \GRFPU0.GRFPU_X0.N_19896\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff00f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(44),
dataf => \GRFPU0.GRFPU_X0.N_19779\,
datae => \GRFPU0.GRFPU_X0.N_18976\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(44),
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(44));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0ffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(44),
dataf => \GRFPU0.GRFPU_X0.N_154\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(44),
datad => \GRFPU0.GRFPU_X0.N_19896\,
datac => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_A2_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33ff0fff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19973\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_2\(18),
datae => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_0_A2_0\(15),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cfc0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_18__G1\,
dataf => \GRFPU0.GRFPU_X0.N_19973\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18));
\GRFPU0_GRFPU_X0_ITER_TZR_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ffff000f0000fff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_0__N_7\,
dataf => \GRFPU0.GRFPU_X0.L4_6\(0),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.ODDEXP\);
\GRFPC0_D_STLCK_RNO_4_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffff00ff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_20__G1_2\,
dataf => \GRFPC0.N_23522_I\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.D.STLCK_0_0_20__G1_1\,
datac => \GRFPC0.N_22777\,
datab => \GRFPC0.FP_PIPELINE.0.STDEP_442_0_IV_I_O3_0_1\(0));
\GRFPC0_D_STLCK_RNO_0_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffffff00")
port map (
combout => \GRFPC0.D.STLCK_0_0_20__G1_7\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => \GRFPC0.D.STLCK_0_0_20__G1_5\,
datad => \GRFPC0.D.STLCK_0_0_20__G1_4\,
datac => \GRFPC0.N_23514\,
datab => \GRFPC0.N_9483\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNIE8HG1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf00000cc000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_13398_I\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.V\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(5));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_1\(63),
dataf => \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__N_4\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__N_6\,
datad => \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__N_5\,
datac => \GRFPU0.GRFPU_X0.N_5987\,
datab => \GRFPU0.GRFPU_X0.ITER.SIGN\);
GRFPU0_GRFPU_X0_ST2_V_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_102_I\,
dataf => \GRFPU0.GRFPU_X0.N_128\,
datae => \GRFPU0.GRFPU_X0.N_19671\,
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => N_35);
GRFPU0_GRFPU_X0_ST3_ZERO_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.ZERO_0_0_G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_5820\,
datae => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(7),
datad => \GRFPU0.GRFPU_X0.ST2.ZERO\);
GRFPU0_GRFPU_X0_ST3_ZERO_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcfcfc")
port map (
combout => \GRFPU0.GRFPU_X0.N_10043\,
dataf => \GRFPU0.GRFPU_X0.N_5775\,
datae => \GRFPU0.GRFPU_X0.N_5768\,
datad => \GRFPU0.GRFPU_X0.UN1_ST2.FLTYPE2_6\(0),
datac => \GRFPU0.GRFPU_X0.N_5940\,
datab => \GRFPU0.GRFPU_X0.ST3.ZERO_0_0_G0_0\);
GRFPU0_GRFPU_X0_ST3_EMIN_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1_0_A2_7_G0_2\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(62));
GRFPU0_GRFPU_X0_ST3_EMIN_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1\,
dataf => \GRFPU0.GRFPU_X0.N_18419\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1_0_A2_7_G0_2\,
datad => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40LTO9_1\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cfc0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_8__G1\,
dataf => \GRFPU0.GRFPU_X0.N_19954\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6\,
datae => \GRFPU0.GRFPU_X0.N_5834\,
datad => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\,
datac => \GRFPU0.GRFPU_X0.ST2.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ST2.RNDMODE\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_3_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff000fccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(52),
dataf => \GRFPU0.GRFPU_X0.N_18983_I\,
datae => \GRFPU0.GRFPU_X0.N_18969\,
datad => N_40510,
datac => \GRFPU0.GRFPU_X0.UN8_C\(0),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(52));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00c0c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(52),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(52),
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_19546\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(52));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffffffc0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19889\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(37),
datae => \GRFPU0.GRFPU_X0.N_280\,
datad => \GRFPU0.GRFPU_X0.N_279\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datab => \GRFPU0.GRFPU_X0.N_19546\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffffffc0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19890\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(35),
datae => \GRFPU0.GRFPU_X0.N_283\,
datad => \GRFPU0.GRFPU_X0.N_282\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datab => \GRFPU0.GRFPU_X0.N_19546\);
GRFPU0_GRFPU_X0_VITER_R_I_1_SQMUXA_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc03000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datad => \GRFPU0.MULO.MRES\(67),
datac => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(33),
dataf => \GRFPU0.GRFPU_X0.N_19668\,
datae => \GRFPU0.GRFPU_X0.N_18976\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(33),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(33));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(33),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(33),
datae => \GRFPU0.GRFPU_X0.N_291\,
datad => \GRFPU0.GRFPU_X0.N_19779\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(33));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(39),
dataf => \GRFPU0.GRFPU_X0.N_19668\,
datae => \GRFPU0.GRFPU_X0.N_18976\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(39),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(39));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(39),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_2\(39),
datae => \GRFPU0.GRFPU_X0.N_291\,
datad => \GRFPU0.GRFPU_X0.N_19779\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(39));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffccfff0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_3\(30),
dataf => \GRFPU0.GRFPU_X0.N_19779\,
datae => \GRFPU0.GRFPU_X0.N_19668\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1\(30),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(30));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_2\(27),
dataf => \GRFPU0.GRFPU_X0.N_19668\,
datae => \GRFPU0.GRFPU_X0.N_18976\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_0\(27),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \FPI.OP1_RETO\(27));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(27),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_2\(27),
datae => \GRFPU0.GRFPU_X0.N_291\,
datad => \GRFPU0.GRFPU_X0.N_19779\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(27));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfff0ffccff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_2\(50),
dataf => \GRFPU0.GRFPU_X0.N_19668\,
datae => \GRFPU0.GRFPU_X0.N_18976\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_0\(50),
datac => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(50));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(50),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0_2\(50),
datae => \GRFPU0.GRFPU_X0.N_291\,
datad => \GRFPU0.GRFPU_X0.N_19779\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(50));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_34: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00000f00f00000f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_34\,
dataf => \GRFPU0.DIVROM0.RADDR\(2),
datae => \GRFPU0.DIVROM0.RADDR\(6),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_43: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0300c0300000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_43\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_34\,
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(1),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f00000000f00f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_20\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_33: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0300c0300000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_33\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_20\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_5\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_47: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c300000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_47\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_33\,
datae => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_43\,
datad => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_5\,
datac => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_18\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_32: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0300c0300000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_32\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_18\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f00000000f00f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_16\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_31: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0300c0300000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_31\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_16\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f00000000f00f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_7\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f00000000f00f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_6\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_38: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c300000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_38\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_0\,
datae => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_7\,
datad => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_6\,
datac => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f00000000f00f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_15\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f00000000f00f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_14\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f00000000f00f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_12\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_29: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0300c0300000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_29\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_12\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f00000000f00f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_10\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_28: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0300c0300000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_28\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_10\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_8\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0300c0300000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_27\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_3\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0300c0300000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_24\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f00000000f00f")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datae => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_44: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0300c0300000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_44\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_37\,
datae => \GRFPU0.DIVROM0.RADDR\(5),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48));
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA_48: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_48\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_44\,
datae => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_27\,
datad => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_29\,
datac => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_28\,
datab => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_15\,
dataa => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_14\);
GRFPU0_GRFPU_X0_VITER_SGNFEQ_0_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_48\,
datae => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_47\,
datad => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_38\,
datac => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_32\,
datab => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA_31\,
dataa => \GRFPU0.GRFPU_X0.N_5673_0\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0f0f0ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(24),
dataf => \GRFPU0.GRFPU_X0.N_19779\,
datae => \GRFPU0.GRFPU_X0.N_18976\,
datad => \FPI.OP1_RETO\(24),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(24));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcccfffff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(24),
dataf => \GRFPU0.GRFPU_X0.N_154\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(24),
datad => \GRFPU0.GRFPU_X0.N_19896\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24));
GRFPU0_GRFPU_X0_COMB_SWAP_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
dataf => \GRFPU0.GRFPU_X0.C\(11),
datae => \GRFPU0.GRFPU_X0.N_3444\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG88\,
datac => \GRFPU0.GRFPU_X0.COMB.UN1_ST1.FLOP_55_0_A2_0\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(0));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNIHJJG_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST1.FLOP_55_0_A2_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(6));
GRFPU0_GRFPU_X0_COMB_VST2_REG36_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0ccf0fcf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG36_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST1.FLOP_55_0_A2_0\,
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(8));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNIT6711_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_3444\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(6));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff00f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(34),
dataf => \GRFPU0.GRFPU_X0.N_19779\,
datae => \GRFPU0.GRFPU_X0.N_18976\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(34),
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(34));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0ffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(34),
dataf => \GRFPU0.GRFPU_X0.N_154\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(34),
datad => \GRFPU0.GRFPU_X0.N_19896\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0f0f0ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(26),
dataf => \GRFPU0.GRFPU_X0.N_19779\,
datae => \GRFPU0.GRFPU_X0.N_18976\,
datad => \FPI.OP1_RETO\(26),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(26));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcccfffff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(26),
dataf => \GRFPU0.GRFPU_X0.N_154\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(26),
datad => \GRFPU0.GRFPU_X0.N_19896\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0f0f0ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(21),
dataf => \GRFPU0.GRFPU_X0.N_19779\,
datae => \GRFPU0.GRFPU_X0.N_18976\,
datad => \FPI.OP1_RETO\(21),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(21));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcccfffff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(21),
dataf => \GRFPU0.GRFPU_X0.N_154\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(21),
datad => \GRFPU0.GRFPU_X0.N_19896\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff00f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(46),
dataf => \GRFPU0.GRFPU_X0.N_19779\,
datae => \GRFPU0.GRFPU_X0.N_18976\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(46),
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(46));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0ffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(46),
dataf => \GRFPU0.GRFPU_X0.N_154\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(46),
datad => \GRFPU0.GRFPU_X0.N_19896\,
datac => \GRFPU0.DIVROM0.RADDR\(2),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0f0f0ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(28),
dataf => \GRFPU0.GRFPU_X0.N_19779\,
datae => \GRFPU0.GRFPU_X0.N_18976\,
datad => \FPI.OP1_RETO\(28),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(28));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcccfffff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(28),
dataf => \GRFPU0.GRFPU_X0.N_154\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(28),
datad => \GRFPU0.GRFPU_X0.N_19896\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0f0f0ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(23),
dataf => \GRFPU0.GRFPU_X0.N_19779\,
datae => \GRFPU0.GRFPU_X0.N_18976\,
datad => \FPI.OP1_RETO\(23),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(23));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcccfffff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(23),
dataf => \GRFPU0.GRFPU_X0.N_154\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_0\(23),
datad => \GRFPU0.GRFPU_X0.N_19896\,
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff3fff0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19887\,
dataf => \GRFPU0.GRFPU_X0.N_274\,
datae => \GRFPU0.GRFPU_X0.N_18976\,
datad => \GRFPU0.GRFPU_X0.N_271\,
datac => \GRFPU0.GRFPU_X0.N_273\,
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(49));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff3fff0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19888\,
dataf => \GRFPU0.GRFPU_X0.N_278\,
datae => \GRFPU0.GRFPU_X0.N_18976\,
datad => \GRFPU0.GRFPU_X0.N_19991\,
datac => \GRFPU0.GRFPU_X0.N_277\,
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(47));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000003000")
port map (
combout => \GRFPU0.GRFPU_X0.N_278\,
dataf => \GRFPU0.GRFPU_X0.N_19814\,
datae => \GRFPU0.GRFPU_X0.N_19815\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datac => \GRFPU0.GRFPU_X0.N_19546\,
datab => \GRFPU0.GRFPU_X0.N_19547\);
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000003000")
port map (
combout => \GRFPU0.GRFPU_X0.N_274\,
dataf => \GRFPU0.GRFPU_X0.N_19812\,
datae => \GRFPU0.GRFPU_X0.N_19811\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datac => \GRFPU0.GRFPU_X0.N_19546\,
datab => \GRFPU0.GRFPU_X0.N_19547\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_A2_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003000f00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19954\,
dataf => \GRFPU0.GRFPU_X0.N_19804\,
datae => \GRFPU0.GRFPU_X0.N_19777\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_I_A2_0\(8),
datac => \GRFPU0.GRFPU_X0.N_19802_1\,
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A5_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000003000")
port map (
combout => \GRFPU0.GRFPU_X0.N_116\,
dataf => \GRFPU0.GRFPU_X0.N_18216\,
datae => \GRFPU0.GRFPU_X0.N_18219\,
datad => \GRFPU0.GRFPU_X0.C\(11),
datac => \GRFPU0.GRFPU_X0.C\(10),
datab => \GRFPU0.GRFPU_X0.C\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_1\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_2_0\(1),
datae => \GRFPU0.GRFPU_X0.N_116\,
datad => \GRFPU0.GRFPU_X0.C\(11),
datac => \GRFPU0.GRFPU_X0.C\(10),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
GRFPU0_GRFPU_X0_VITER_DBUF_1_SQMUXA_3_I_A3_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.DBUF_1_SQMUXA_3_I_A3_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.V\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(24));
\GRFPU0_GRFPU_X0_ST2_DIFF_RNI4TIH1_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_0_0\(4),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(38),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(40));
\GRFPU0_GRFPU_X0_L3_0_1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_1\(5),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(28));
\GRFPU0_GRFPU_X0_L3_0_1_RNI98OC5_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_9787\,
dataf => \GRFPU0.GRFPU_X0.N_9793\,
datae => \GRFPU0.GRFPU_X0.N_9792\,
datad => \GRFPU0.GRFPU_X0.N_14255_1\,
datac => \GRFPU0.GRFPU_X0.N_9794_2\,
datab => \GRFPU0.GRFPU_X0.L3_0_1\(5));
GRFPU0_GRFPU_X0_COMB_VST3_RDY9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_5774\,
dataf => \GRFPU0.GRFPU_X0.ST2.EXPT\(1),
datae => \GRFPU0.GRFPU_X0.ST2.EXPT\(0),
datad => \GRFPU0.GRFPU_X0.ST2.EXPT\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A5_3_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A5_3_1\(0),
dataf => \GRFPU0.GRFPU_X0.C\(11),
datae => \GRFPU0.GRFPU_X0.C\(10),
datad => \GRFPU0.GRFPU_X0.C\(1),
datac => \GRFPU0.GRFPU_X0.C\(0),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A5_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000300")
port map (
combout => \GRFPU0.GRFPU_X0.N_108\,
dataf => \GRFPU0.GRFPU_X0.N_18219\,
datae => \GRFPU0.GRFPU_X0.C\(11),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A5_2_1\(0),
datac => \GRFPU0.GRFPU_X0.C\(10),
datab => \GRFPU0.GRFPU_X0.C\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_1\(0),
dataf => \GRFPU0.GRFPU_X0.N_18242\,
datae => \GRFPU0.GRFPU_X0.N_108\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A5_3_1\(0),
datac => \GRFPU0.GRFPU_X0.N_18216\,
datab => \GRFPU0.GRFPU_X0.N_18219\);
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A5_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A5_1\(0),
dataf => \GRFPU0.GRFPU_X0.C\(10),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datac => \GRFPU0.GRFPU_X0.ST1.EXP1\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_1\(0),
datae => \GRFPU0.GRFPU_X0.N_18241\,
datad => \GRFPU0.GRFPU_X0.N_72\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A5_1_0\(0),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A5_1\(0));
GRFPU0_GRFPU_X0_VST2_REG_1_SQMUXA_2_RNI0PGC2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19668\,
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datae => \GRFPU0.GRFPU_X0.N_19549\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datac => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_2\);
\GRFPC0_D_STLCK_RNO_3_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff300030003000")
port map (
combout => \GRFPC0.D.STLCK_0_0_28__G1_0\,
dataf => \GRFPC0.N_661\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(0),
datad => \GRFPC0.N_9467\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datab => \GRFPC0.N_61_I\);
\GRFPC0_D_STLCK_RNO_0_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0cffffff0c0c")
port map (
combout => \GRFPC0.D.STLCK_0_0_28__G1_4\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.D.STLCK_0_0_28__G1_2\,
datad => \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0\,
datac => \GRFPC0.N_23177\,
datab => \GRFPC0.N_23345_1\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_0_3_1_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_3_1\(52),
dataf => \GRFPU0.GRFPU_X0.N_78_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_3_TZ\(52),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\);
GRFPU0_GRFPU_X0_ITER_V_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c000f000cc00ff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.V_0_0_G0_3_1\,
dataf => \GRFPU0.GRFPU_X0.N_5987\,
datae => \GRFPU0.GRFPU_X0.N_163\,
datad => \GRFPU0.GRFPU_X0.N_6736\,
datac => \GRFPU0.GRFPU_X0.N_5673_0\,
datab => \GRFPU0.GRFPU_X0.N_19671\);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003030f030")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_5__G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_18781\,
datae => \GRFPU0.GRFPU_X0.N_18772\,
datad => \FPI.OP1\(51),
datac => \FPI.OP1\(54),
datab => \FPI.FLOP\(1));
GRFPU0_GRFPU_X0_INC_0_SQMUXA_2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000fc00")
port map (
combout => N_80260,
dataf => \GRFPU0.GRFPU_X0.COMB.RNDM_1\(0),
datae => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datad => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(19),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(18));
GRFPC0_MEM_CTRL_SEQERR_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030f00000")
port map (
combout => N_47188,
dataf => N_44987,
datae => N_47188_2,
datad => \GRFPC0.FP_PIPELINE.ORV.TMP\,
datac => \GRFPC0.EX.CTRL.SEQERR\,
datab => N_39);
GRFPC0_MEM_CTRL_RDWR_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030f00000")
port map (
combout => N_47189,
dataf => N_44987,
datae => N_47188_2,
datad => \GRFPC0.FP_PIPELINE.ORV.TMP\,
datac => \GRFPC0.EX.CTRL.RDWR\,
datab => N_39);
GRFPC0_MEM_CTRL_DIV_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030f00000")
port map (
combout => N_47190,
dataf => N_44987,
datae => N_47188_2,
datad => \GRFPC0.FP_PIPELINE.ORV.TMP\,
datac => \GRFPC0.EX.CTRL.DIV\,
datab => N_39);
GRFPC0_MEM_CTRL_CCWR_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030f00000")
port map (
combout => N_47191,
dataf => N_44987,
datae => N_47188_2,
datad => \GRFPC0.FP_PIPELINE.ORV.TMP\,
datac => \GRFPC0.EX.CTRL.CCWR\,
datab => N_39);
GRFPC0_MEM_CTRL_AFSR_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030f00000")
port map (
combout => N_47192,
dataf => N_44987,
datae => N_47188_2,
datad => \GRFPC0.FP_PIPELINE.ORV.TMP\,
datac => \GRFPC0.EX.CTRL.AFSR\,
datab => N_39);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_RNIUR6SE_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => N_47157,
dataf => N_47157_2,
datae => CPO_LDLOCKZ,
datad => N_47098,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6_4_0\,
datab => \GRFPC0.FIFO.WR\(0));
\GRFPC0_FIFO_VCNT_0_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000003000f0")
port map (
combout => N_47283,
dataf => N_47103,
datae => N_47093,
datad => N_47101,
datac => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_0\,
datab => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_A6_1_0\);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_RNIUR6SE: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000003000000000")
port map (
combout => N_47103,
dataf => N_47157_2,
datae => CPO_LDLOCKZ,
datad => N_47098,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6_4_0\,
datab => \GRFPC0.FIFO.WR\(0));
GRFPC0_EX_CTRL_CCWR_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => N_45038,
dataf => N_47178_2,
datae => \FPI.START_2\,
datad => \FPI.START_1\,
datac => \FPI.START_3\,
datab => \GRFPC0.EX.CTRL.CCWR_0_0_G1_0_1438_A2_1\);
\GRFPC0_V_STDATA_14_I_M2_RNIR09T2_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0cffff00000000")
port map (
combout => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1061_I_A5_0\,
dataf => N_44738_1,
datae => \FPI.FLOP\(1),
datad => \FPI.FLOP\(7),
datac => \FPI.FLOP\(2),
datab => \FPI.FLOP\(3));
GRFPC0_RFA_RDD_RNI9PEKJ: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ccf0cc00000000")
port map (
combout => N_47178,
dataf => N_47178_2,
datae => \GRFPC0.EX.CTRL.RDD_0_0_G1_0_0_1061_I_A5_0\,
datad => \FPI.START\,
datac => \GRFPC0.V.STDATA_14\(31),
datab => \GRFPC0.RFA.RDD\);
GRFPC0_RFA_LD_RNO_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ff000000000000")
port map (
combout => \GRFPC0.RFA.LD_0_0_G1_0_1612_A2_0\,
dataf => N_109,
datae => N_108,
datad => N_98,
datac => N_97);
GRFPC0_RFA_LD_RNO_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.RFA.LD_0_0_G1_0_1612_A2_1\,
dataf => N_100,
datae => N_102,
datad => N_101,
datac => N_99);
GRFPC0_RFA_LD_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.RFA.LD_0_0_G1_0_1612_A2_3\,
dataf => \GRFPC0.RFA.LD_0_0_G1_0_1612_A2_1\,
datae => \GRFPC0.RFA.LD_0_0_G1_0_1612_A2_0\,
datad => N_112,
datac => N_113);
GRFPC0_RFA_LD_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000030")
port map (
combout => N_45157,
dataf => CPO_EXCZ,
datae => \GRFPC0.N_21965\,
datad => \GRFPC0.N_21108\,
datac => \GRFPC0.RFA.LD_0_0_G1_0_1612_A2_3\,
datab => N_39);
GRFPC0_WR_CTRL_DIV_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003000f000")
port map (
combout => N_47185,
dataf => N_44904,
datae => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
datad => \GRFPC0.MEM.CTRL.DIV\,
datac => N_35,
datab => N_39);
GRFPC0_WR_CTRL_CCWR_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003000f000")
port map (
combout => N_47186,
dataf => N_44904,
datae => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
datad => \GRFPC0.MEM.CTRL.CCWR\,
datac => N_35,
datab => N_39);
GRFPC0_WR_CTRL_SEQERR_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003000f000")
port map (
combout => N_47183,
dataf => N_44904,
datae => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
datad => \GRFPC0.MEM.CTRL.SEQERR\,
datac => N_35,
datab => N_39);
GRFPC0_WR_CTRL_AFSR_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003000f000")
port map (
combout => N_47187,
dataf => N_44904,
datae => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
datad => \GRFPC0.MEM.CTRL.AFSR\,
datac => N_35,
datab => N_39);
GRFPC0_WR_CTRL_RDWR_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003000f000")
port map (
combout => N_47184,
dataf => N_44904,
datae => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
datad => \GRFPC0.MEM.CTRL.RDWR\,
datac => N_35,
datab => N_39);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18860_I\,
dataf => \GRFPU0.GRFPU_X0.N_18860_I_0_G0_2\,
datae => \GRFPU0.GRFPU_X0.N_18883\,
datad => \GRFPU0.GRFPU_X0.N_18948\,
datac => \FPI.OP2\(52),
datab => \FPI.OP2\(53));
\GRFPU0_GRFPU_X0_VST2_EXC_13_I_M_2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000003f0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.EXC_13_I_M_2\(4),
dataf => \GRFPU0.GRFPU_X0.VST2.EXC_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.UN1_VITER.EXP28\,
datad => \GRFPU0.GRFPU_X0.ST2.QSNAN_0_0_G1\,
datac => \GRFPU0.GRFPU_X0.UN1_REST_3\,
datab => \GRFPU0.GRFPU_X0.N_5250\);
\GRFPU0_GRFPU_X0_ST2_EXC_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10113\,
dataf => \GRFPU0.GRFPU_X0.ST2.EXC_0_0_4__G0_0\,
datae => \GRFPU0.GRFPU_X0.VST2.EXC_13_I_M_2\(4),
datad => \GRFPU0.GRFPU_X0.UN1_VST2.EXC_1_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.N_3516\,
datab => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__N_7_1\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ccf00000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10108\,
dataf => \GRFPU0.GRFPU_X0.N_148\,
datae => \GRFPU0.GRFPU_X0.N_10086_1\,
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(1),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(2));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10091\,
dataf => \GRFPU0.GRFPU_X0.N_148\,
datae => \GRFPU0.GRFPU_X0.N_10086_1\,
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(19),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(18));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ccf00000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10087\,
dataf => \GRFPU0.GRFPU_X0.N_148\,
datae => \GRFPU0.GRFPU_X0.N_10086_1\,
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(23));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10086\,
dataf => \GRFPU0.GRFPU_X0.N_148\,
datae => \GRFPU0.GRFPU_X0.N_10086_1\,
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(23));
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000cc0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10069\,
dataf => \GRFPU0.GRFPU_X0.N_18448\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.N_18440_I_0\,
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.EXC\(5));
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000cc0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10066\,
dataf => \GRFPU0.GRFPU_X0.N_18448\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.N_18440_I_0\,
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.EXC\(2));
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000cc0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10065\,
dataf => \GRFPU0.GRFPU_X0.N_18448\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.N_18440_I_0\,
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.EXC\(1));
GRFPU0_GRFPU_X0_COMB_EXP38_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f000ff0000")
port map (
combout => N_99625,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datad => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0),
datac => \GRFPU0.GRFPU_X0.ITER.NORM\);
GRFPC0_MEM_CTRL_LD_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => N_44946,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_35,
datad => N_39);
GRFPC0_WR2_CTRL_LD_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => N_44808,
dataf => \GRFPC0.WR.CTRL.LD\,
datae => N_35,
datad => N_39);
GRFPC0_WR_CTRL_LD_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => N_44868,
dataf => \GRFPC0.MEM.CTRL.LD\,
datae => N_35,
datad => N_39);
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0c0c0c0c0c000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10075\,
dataf => \GRFPU0.GRFPU_X0.N_42\,
datae => \GRFPU0.GRFPU_X0.N_44\,
datad => \GRFPU0.GRFPU_X0.N_43\,
datac => \GRFPU0.GRFPU_X0.N_5250\,
datab => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0__G0_0_0\);
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10077\,
dataf => \GRFPU0.GRFPU_X0.N_44\,
datae => N_60909,
datad => \GRFPU0.GRFPU_X0.N_5250\,
datac => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0__G0_0_0\);
\GRFPU0_GRFPU_X0_COMB_EXPADDSUB_EXPT_1_A4_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000003000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18275\,
dataf => \GRFPU0.GRFPU_X0.N_17\,
datae => \GRFPU0.GRFPU_X0.N_16\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\,
datac => \GRFPU0.GRFPU_X0.UN8_C\(10),
datab => \GRFPU0.GRFPU_X0.UN8_C\(1));
\GRFPU0_GRFPU_X0_COMB_EXPADDSUB_EXPT_1_O4_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00ff0fff")
port map (
combout => \GRFPU0.GRFPU_X0.N_28\,
dataf => \GRFPU0.GRFPU_X0.N_19\,
datae => \GRFPU0.GRFPU_X0.N_16\,
datad => \GRFPU0.GRFPU_X0.UN8_C\(10),
datac => \GRFPU0.GRFPU_X0.UN8_C\(1));
\GRFPU0_GRFPU_X0_ST2_EXPT_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10076\,
dataf => \GRFPU0.GRFPU_X0.ST2.EMINM1_0_0_G0_I_A4_1\,
datae => \GRFPU0.GRFPU_X0.N_46\,
datad => \GRFPU0.GRFPU_X0.N_5250\,
datac => \GRFPU0.GRFPU_X0.ST2.EXPT_0_0_0__G0_0_0\);
\GRFPU0_GRFPU_X0_ST2_RNDMODE_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_10180\,
dataf => \GRFPU0.GRFPU_X0.N_4245\,
datae => \GRFPU0.GRFPU_X0.VST2.INF_3_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(1));
\GRFPU0_GRFPU_X0_ST2_RNDMODE_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_10179\,
dataf => \GRFPU0.GRFPU_X0.N_4245\,
datae => \GRFPU0.GRFPU_X0.VST2.INF_3_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(0));
GRFPU0_GRFPU_X0_COMB_UN1_VITER_FLUSH0_2_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcfcfffffccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.ADDOF_1\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ADDI3\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_VST4.ADDOF_0\,
datac => \GRFPU0.GRFPU_X0.COMB.ADDI2\,
datab => \GRFPU0.GRFPU_X0.COMB.UN1_VITER.FLUSH0_2_SQMUXA_0\);
\GRFPU0_GRFPU_X0_ST3_FLOP_RNIS6184_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"303000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_97\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_0_I_A2_0_3\(1),
datae => \GRFPU0.GRFPU_X0.N_18449\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(5));
GRFPU0_GRFPU_X0_COMB_UN1_FLOP4_10_0_A3_0_RNI80CM4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.SEL_0_0_0_0__G0_0_TZ_0\,
dataf => \GRFPU0.GRFPU_X0.N_97\,
datae => \GRFPU0.GRFPU_X0.N_18515\,
datad => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_10_0_A3_0\);
\GRFPC0_EX_CTRL_VCNT_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"330f0000330f330f")
port map (
combout => \GRFPC0.EX.CTRL.VCNT_0_0_0__G1\,
dataf => \GRFPC0.FP_PIPELINE.CNTX14_0\,
datae => \GRFPC0.FP_PIPELINE.UN4_CNTX\(1),
datad => \GRFPC0.FIFO.RD_0\(0),
datac => \GRFPC0.FIFO.VCNT_0\(0),
datab => \GRFPC0.FIFO.VCNT_1\(0));
\GRFPC0_EX_CTRL_VCNT_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf00000ccf0330f")
port map (
combout => \GRFPC0.EX.CTRL.VCNT_0_0_1__G1\,
dataf => \GRFPC0.FP_PIPELINE.CNTX14_0\,
datae => \GRFPC0.FP_PIPELINE.UN4_CNTX\(1),
datad => \GRFPC0.FIFO.RD_0\(0),
datac => \GRFPC0.FIFO.VCNT_0\(0),
datab => \GRFPC0.FIFO.VCNT_1\(0));
GRFPU0_GRFPU_X0_ITER_NORM_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ccccfccc")
port map (
combout => N_26926,
dataf => \GRFPU0.GRFPU_X0.N_5673_0\,
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.GRFPU_X0.N_4438\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.NORM\);
\GRFPU0_GRFPU_X0_ST3_FARRES_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(0),
dataf => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(56),
datae => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
\GRFPU0_GRFPU_X0_ST3_FARRES_RNO_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(55),
dataf => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(1),
datae => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\);
GRFPU0_GRFPU_X0_ST3_STICKY_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10071\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY\);
GRFPC0_FP_PIPELINE_FPUSTART_7_2_RNIP4U7H: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => N_46865,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datad => \FPI.START_2\,
datac => \GRFPC0.EX.CTRL.RD_0_0_0__G1_0_3942_I_O4_2\,
datab => \FPI.START_1\);
GRFPU0_GRFPU_X0_COMB_SGNFINC_INC_1_M1_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000f000")
port map (
combout => N_80552,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1\,
datae => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(28),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(29));
GRFPU0_GRFPU_X0_EXPDEC_DP_0_SQMUXA_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000ff00ff00")
port map (
combout => N_99660,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => N_28274,
datad => \GRFPU0.GRFPU_X0.N_8975\);
\GRFPU0_GRFPU_X0_BIAS_4_0_0_A2_0_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => N_80264,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__I3_I_3\,
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(1));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80208,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(27),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(28));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80207,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(26),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(27));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_80204,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(26),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(25));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80203,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(24),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(25));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80200,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(23),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(24));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_80199,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(23),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(22));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80196,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(21),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(22));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80195,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(20),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(21));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80192,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(19),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(20));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80191,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(18),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(19));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80188,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(17),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(18));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80187,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(16),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(17));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80184,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(15),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(16));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80183,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(14),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(15));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_80180,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(14),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(13));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80179,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(12),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(13));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80176,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(11),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(12));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80175,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(10),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(11));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80172,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(9),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(10));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80171,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(8),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(9));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80168,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(7),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(8));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80167,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(6),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(7));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80164,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(5),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(6));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80163,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(4),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(5));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => N_80159,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(3),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(4));
\GRFPU0_GRFPU_X0_S3ADDI_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_80158,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(3),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(2));
GRFPU0_GRFPU_X0_ST1_V_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.V_0_0_G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_181_I_I\,
datae => \FPI.FLUSH\,
datad => N_35);
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_16__G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_19690\,
datae => \GRFPU0.GRFPU_X0.N_19692_1\,
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(16),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(17));
GRFPU0_GRFPU_X0_VST2_REG_2_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000c0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4105\,
dataf => \GRFPU0.GRFPU_X0.N_4175\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.V\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6));
\GRFPU0_GRFPU_X0_ITER_TZR_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0000ff00ffff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_6\,
dataf => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__G4\,
datae => \GRFPU0.GRFPU_X0.L4_6\(2),
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\);
GRFPU0_GRFPU_X0_COMB_ANDV_TMP_RNIDPNG4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333333300000003")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.DIFFN_0_0_G0_0\,
dataf => \GRFPU0.GRFPU_X0.N_5850\,
datae => \GRFPU0.GRFPU_X0.N_18213\,
datad => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_0\,
datac => \GRFPU0.GRFPU_X0.C\(11),
datab => \GRFPU0.GRFPU_X0.COMB.VST2.ADD_1_1\);
GRFPU0_GRFPU_X0_ST2_INF_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff3fffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1\,
dataf => \GRFPU0.GRFPU_X0.VST2.REG_4_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_4245\,
datad => \GRFPU0.GRFPU_X0.VST2.INF_3_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.N_3504_1\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6));
\GRFPC0_FP_PIPELINE_0_STDEP_282_0_IV_I_A2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_22454\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(0),
datae => \GRFPC0.RFA.LD\,
datad => \GRFPC0.N_661_1\,
datac => N_176,
datab => N_173);
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_2_0_TZ_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3333fff03030")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_2_0_TZ_0\(1),
dataf => \GRFPU0.GRFPU_X0.N_18219\,
datae => \GRFPU0.GRFPU_X0.N_18252\,
datad => \GRFPU0.GRFPU_X0.N_18238\,
datac => \GRFPU0.GRFPU_X0.C\(0),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_2_0\(1),
dataf => \GRFPU0.GRFPU_X0.N_4260\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_2_0_TZ_0\(1),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_1_A5_6_1_0\(1),
datac => \GRFPU0.GRFPU_X0.C\(11),
datab => \GRFPU0.GRFPU_X0.C\(10));
\GRFPC0_D_LDLCK_RNO_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff003000000000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_0__G1_0\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datae => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_0\(0),
datad => N_97,
datac => \GRFPC0.N_9453\,
datab => \GRFPC0.N_61_I\);
\GRFPU0_GRFPU_X0_COMB_CCV_8_0_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0fcf0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.CCV_8_0_1\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.CCV_8_0_1_0\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SIGN1_2\,
datad => \GRFPU0.GRFPU_X0.ST1.OP2NX\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfc0c0c0cfc0c0c")
port map (
combout => D_N_7_I,
dataf => N_82230,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1__G1_1\,
datad => \GRFPU0.GRFPU_X0.N_394\,
datac => \GRFPU0.GRFPU_X0.N_19546\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1__G5\);
\GRFPU0_GRFPU_X0_COMB_CCV_8_0_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.CCV_8_0_1_0\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.CCV12\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7));
\GRFPU0_GRFPU_X0_COMB_CCV_8_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000f030")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.CCV_8_0_1\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.CCV_8_0_1_0\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SIGN1_2\,
datad => \GRFPU0.GRFPU_X0.ST1.OP2NX\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfc0c0ff00ff00")
port map (
combout => N_67748,
dataf => \GRFPU0.GRFPU_X0.N_19546\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(0),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_D_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ff00ff00")
port map (
combout => N_67744,
dataf => \GRFPU0.GRFPU_X0.N_19547\,
datae => \GRFPU0.GRFPU_X0.N_18969\,
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(0),
datac => \FPI.OP1_RETO\(0));
\GRFPU0_GRFPU_X0_ITER_STATE_RNI016L5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000c00")
port map (
combout => \GRFPU0.GRFPU_X0.N_11529\,
dataf => \GRFPU0.GRFPU_X0.G_16_0_O2_0\,
datae => \GRFPU0.GRFPU_X0.COMB.RMND_13\(0),
datad => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datac => \GRFPU0.GRFPU_X0.ITER.LOB\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A2_4_3_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000c0c000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A2_4_3\(2),
dataf => \GRFPC0.N_22821\,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_22812\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A2_4_0\(2),
datab => \GRFPC0.N_22823\);
\GRFPC0_D_LDLCK_RNO_0_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccffffcfccffff")
port map (
combout => \GRFPC0.D.LDLCK_0_0_2__G1_TZ_0\,
dataf => \GRFPC0.N_22810\,
datae => \GRFPC0.N_22821\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_22812\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_OP\);
\GRFPC0_D_LDLCK_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0ff0000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_2__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60\(0),
datae => \GRFPC0.D.LDLCK_0_0_2__G1_TZ_0\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A2_4_3\(2),
datac => \GRFPC0.N_22810\,
datab => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A2_4_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f003f3f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A2_4_1\(3),
dataf => \GRFPC0.N_22824\,
datae => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN616_REGDEPX\,
datad => \GRFPC0.N_22433_1\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_0_0\(3),
datab => \GRFPC0.N_9474\);
\GRFPC0_D_LDLCK_RNO_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccffffcfccffff")
port map (
combout => \GRFPC0.D.LDLCK_0_0_3__G1_TZ_0\,
dataf => \GRFPC0.N_22809\,
datae => \GRFPC0.N_22822\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_22813\,
datab => \GRFPC0.FP_PIPELINE.0.UN1_OP\);
\GRFPC0_D_LDLCK_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0ff0000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_3__G1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60\(1),
datae => \GRFPC0.D.LDLCK_0_0_3__G1_TZ_0\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A2_4_3\(3),
datac => \GRFPC0.N_22809\,
datab => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A2_1_0_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030f0f03000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A2_1\(10),
dataf => N_99871,
datae => \GRFPC0.N_22902_1\,
datad => \GRFPC0.STDDEP_0_SQMUXA_123_I_I_A2_I_O2_0\,
datac => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.DEP_1\(0),
datab => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1760_REGDEPX\);
GRFPU0_GRFPU_X0_UN1_VST2_EXC_0_SQMUXA_2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0fff00000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VST2.EXC_0_SQMUXA_2_1\,
dataf => \GRFPU0.GRFPU_X0.N_5250\,
datae => \GRFPU0.GRFPU_X0.N_3407\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003030f030")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_5__G1\,
dataf => \GRFPU0.GRFPU_X0.N_18867\,
datae => \GRFPU0.GRFPU_X0.N_18882_1\,
datad => \FPI.OP2\(51),
datac => \FPI.OP2\(54),
datab => \FPI.FLOP\(1));
\GRFPC0_FP_PIPELINE_3_STDEP_150_0_IV_TZ_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"003f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.0.STDEP_145_0_IV_M_1_0\(0),
dataf => \GRFPC0.FP_PIPELINE.3.1.CHECK_DEP.UN1120_REGDEPX\,
datae => \GRFPC0.N_22237\,
datad => \GRFPC0.FIFO.INST_1\(19),
datac => \GRFPC0.FIFO.INST_1\(12),
datab => \GRFPC0.FIFO.INST_1\(8));
\GRFPC0_D_STLCK_RNO_5_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff000000000000")
port map (
combout => \GRFPC0.D.STLCK_0_0_6__G1_TZ\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datae => \GRFPC0.N_9476\,
datad => \GRFPC0.N_61_I\,
datac => \GRFPC0.N_59\);
\GRFPC0_FP_PIPELINE_9_STDEP_390_0_IV_TZ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffcfffffffcff")
port map (
combout => \GRFPC0.FP_PIPELINE.9.STDEP_390_I_TZ\(0),
dataf => N_40557,
datae => N_99871,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_548\,
datab => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_FP_PIPELINE_13_0_STDEP_545_0_IV_0_TZ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffffffcfffcff")
port map (
combout => \GRFPC0.FP_PIPELINE.13.0.STDEP_545_I_TZ\(0),
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_22536\,
datab => \GRFPC0.FIFO.INST_0\(19));
\GRFPC0_D_STLCK_RNO_2_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_140_I_M_2\(0),
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1015_REGDEPX_I_1\,
datab => \GRFPC0.FIFO.INST_0\(19));
\GRFPC0_FP_PIPELINE_4_STDEP_194_0_IV_0_A4_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_194_0_IV_0_A4_0_0\(0),
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1327_REGDEPX_0\,
datac => \GRFPC0.FIFO.INST_0\(29),
datab => \GRFPC0.FIFO.INST_0\(26));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_2_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_0_7__G2_0\,
dataf => \GRFPU0.GRFPU_X0.N_7241\,
datae => \GRFPU0.GRFPU_X0.N_18867\,
datad => \GRFPU0.GRFPU_X0.N_10059_I\,
datac => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_0_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0ffc0c000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_0_7__G2\,
dataf => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_0_7__G2_0\,
datae => \GRFPU0.GRFPU_X0.N_18948\,
datad => \GRFPU0.GRFPU_X0.N_18870\,
datac => \FPI.FLOP\(0),
datab => \FPI.NONSTD\);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00c00000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1\(7),
dataf => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_0_7__G2\,
datae => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_0_7__G0_0_0_TZ\,
datad => \GRFPU0.GRFPU_X0.N_18880\,
datac => \GRFPU0.GRFPU_X0.N_7241\,
datab => \GRFPU0.GRFPU_X0.N_10059_I\);
\GRFPC0_R_FSR_TEM_RNIFCB1A_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STATE6\,
dataf => \GRFPC0.FPEXC_0_SQMUXA_D\,
datae => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\);
GRFPC0_FP_PIPELINE_0_STDDEP_180_IV_0_A2_7_0_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff30000ff330000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_7_0_1\,
dataf => \GRFPC0.N_114\,
datae => \GRFPC0.FP_PIPELINE.7.STDEP_296_SEL0_1\,
datad => \GRFPC0.N_21817\,
datac => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.WR.CTRL.RDWR\);
\GRFPC0_D_STDLCK_RNO_0_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f030f0f0303")
port map (
combout => N_61057_TZ,
dataf => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_10_1\,
datae => \GRFPC0.N_22366\,
datad => \GRFPC0.N_22173_I\,
datac => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_6_1\,
datab => \GRFPC0.FP_PIPELINE.0.STDDEP_180_IV_0_A2_7_0_1\);
\GRFPU0_GRFPU_X0_COMB_EXPADDSUB_EXPT_0_O4_RNI0AQ01_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => \GRFPU0.GRFPU_X0.N_44\,
dataf => \GRFPU0.GRFPU_X0.N_24\,
datae => \GRFPU0.GRFPU_X0.N_18264\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\,
datac => \GRFPU0.GRFPU_X0.UN8_C\(9),
datab => \GRFPU0.GRFPU_X0.UN8_C\(8));
GRFPU0_GRFPU_X0_COMB_SHV2LTO10_0_A5_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000003")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_0_A5_3\,
dataf => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(10),
datae => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(9),
datad => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(8),
datac => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(7),
datab => \GRFPU0.GRFPU_X0.EXPDIFFN_1\(6));
GRFPU0_GRFPU_X0_COMB_SHV2LTO10_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003fff3fff3fff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHV2\,
dataf => \GRFPU0.GRFPU_X0.N_18258\,
datae => N_60912_TZ,
datad => \GRFPU0.GRFPU_X0.C\(11),
datac => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_0_A5_3\,
datab => \GRFPU0.GRFPU_X0.N_20729\);
\GRFPC0_FP_PIPELINE_0_STDEP_442_0_IV_I_A2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_23538\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(0),
datae => \GRFPC0.RFA.LD\,
datad => N_174,
datac => \GRFPC0.N_801\,
datab => N_173);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(2),
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(3),
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(7),
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(60),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(60),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(4),
dataf => \GRFPU0.GRFPU_X0.L1_4_2\(3),
datae => \GRFPU0.GRFPU_X0.UN233_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_4\,
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(9),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(6));
\GRFPU0_GRFPU_X0_ITER_RNDMODE_RNI6O9C1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03fc000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_3560_I\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datad => \GRFPU0.MULO.MRES\(67),
datac => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1));
GRFPU0_GRFPU_X0_C_CARRY_2_RNI2HKG1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_3\,
dataf => \GRFPU0.GRFPU_X0.C\(5),
datae => \GRFPU0.GRFPU_X0.C\(4),
datad => \GRFPU0.GRFPU_X0.C\(3),
datac => \GRFPU0.GRFPU_X0.C\(2));
GRFPU0_GRFPU_X0_C_CARRY_6_RNILF833: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_0\,
dataf => \GRFPU0.GRFPU_X0.C\(10),
datae => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_3\,
datad => \GRFPU0.GRFPU_X0.C\(7),
datac => \GRFPU0.GRFPU_X0.C\(1),
datab => \GRFPU0.GRFPU_X0.C\(6));
GRFPU0_GRFPU_X0_COMB_ANDV_TMP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_5850\,
dataf => \GRFPU0.GRFPU_X0.C\(11),
datae => \GRFPU0.GRFPU_X0.COMB.ANDV.TMP_5\,
datad => \GRFPU0.GRFPU_X0.COMB.ANDV.TMP_4\,
datac => \GRFPU0.GRFPU_X0.C\(10),
datab => \GRFPU0.GRFPU_X0.C\(9));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_0_A2_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f00000f0f0f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19811\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datae => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.N_4105\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(49));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_0_A2_0_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19812\,
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datac => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_0_A2_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19814\,
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datac => \GRFPU0.DIVROM0.RADDR\(3),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_0_A2_0_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f00000f0f0f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19815\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datae => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.N_4105\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(47));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f3300000f330f33")
port map (
combout => \GRFPU0.GRFPU_X0.N_279\,
dataf => \GRFPU0.GRFPU_X0.N_19546\,
datae => \GRFPU0.GRFPU_X0.N_18998\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(37));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_0_M2_RNICJB02_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff030f000f030f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19779\,
dataf => \GRFPU0.GRFPU_X0.N_19777\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_19546\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(5));
GRFPU0_GRFPU_X0_VST2_REG_1_SQMUXA_2_RNIJT2T2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f3f3f033333300")
port map (
combout => \GRFPU0.GRFPU_X0.N_18976\,
dataf => \GRFPU0.GRFPU_X0.N_19554\,
datae => \GRFPU0.GRFPU_X0.N_18998\,
datad => \GRFPU0.GRFPU_X0.N_19662\,
datac => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_2\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
GRFPU0_GRFPU_X0_COMB_DIFFIN116: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_3386\,
dataf => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_3_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00cc0c00000c0c")
port map (
combout => \GRFPU0.GRFPU_X0.N_19958\,
dataf => \GRFPU0.GRFPU_X0.N_19554\,
datae => \GRFPU0.GRFPU_X0.N_19549\,
datad => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_2\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(55));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00cc0c00000c0c")
port map (
combout => \GRFPU0.GRFPU_X0.N_262\,
dataf => \GRFPU0.GRFPU_X0.N_19554\,
datae => \GRFPU0.GRFPU_X0.N_19549\,
datad => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_2\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(52));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_O4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fff0ffccfffcff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19905\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datae => \GRFPU0.GRFPU_X0.N_19547\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_ITER_STATE_RNI120I_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19681\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(7),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(7),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0c0f0c0f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(7),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_33_M\(7),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(7),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(7),
datac => \GRFPU0.GRFPU_X0.N_5673_0\,
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(60),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(60),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(60));
GRFPU0_GRFPU_X0_VST2_RDY_2_SQMUXA_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"030f030f030f33ff")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.RDY_2_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.N_5250\,
datae => \GRFPU0.GRFPU_X0.N_3407\,
datad => \GRFPU0.GRFPU_X0.N_4175\,
datac => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__N_7_1\,
datab => \GRFPU0.GRFPU_X0.ST1.V\);
GRFPU0_GRFPU_X0_VST2_RDY_0_SQMUXA_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_3475\,
dataf => \GRFPU0.GRFPU_X0.N_3476\,
datae => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7));
GRFPU0_GRFPU_X0_ST2_RDY_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_10035\,
dataf => \GRFPU0.GRFPU_X0.N_3475\,
datae => \GRFPU0.GRFPU_X0.VST2.RDY_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.N_3516\,
datab => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__N_7_1\);
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_21__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_21__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_22__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_22__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_23__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_23__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_24__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_24__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_25__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_25__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_26__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_26__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_27__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_27__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_28__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_28__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_29__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_29__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_30__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_30__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_31__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_31__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_32__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_32__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_33__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_33__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_34__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_34__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_35__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_35__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_36__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_36__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_37__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_37__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_38__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_38__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_39__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_39__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_40__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_40__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_41__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_41__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_42__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_42__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_43__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_43__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_44__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_44__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_45__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_45__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_46__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_46__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_47__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_47__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_48__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_48__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccccccccccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_10__N_51\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
datae => N_32537,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(61),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(62));
GRFPU0_GRFPU_X0_VST3_REG_4_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_4_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.UN1_VST3.REG22\,
datae => \GRFPU0.GRFPU_X0.N_5987\,
datad => \GRFPU0.GRFPU_X0.N_5820\,
datac => \GRFPU0.GRFPU_X0.N_5791\,
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(7));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccccccc000c0000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_1_IV_0_63__N_4\,
dataf => \GRFPU0.GRFPU_X0.VST3.REG_4_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_5791\,
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(63));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000ffff0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(27),
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.N_14515\,
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(30));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M23_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"030f0303000c0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M23_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_2_01\,
datad => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.N_9666\,
datab => \GRFPU0.GRFPU_X0.L4_4\(4));
\GRFPU0_GRFPU_X0_ITER_STATE_RNI144J_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_7\,
dataf => \GRFPU0.GRFPU_X0.ITER.V\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(24));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_0__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16398\,
datab => \GRFPU0.GRFPU_X0.N_16463\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_2__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16400\,
datab => \GRFPU0.GRFPU_X0.N_16465\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_12__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16410\,
datab => \GRFPU0.GRFPU_X0.N_16475\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_13__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16411\,
datab => \GRFPU0.GRFPU_X0.N_16476\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_14__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16412\,
datab => \GRFPU0.GRFPU_X0.N_16477\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_17__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16415\,
datab => \GRFPU0.GRFPU_X0.N_16480\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_18__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16416\,
datab => \GRFPU0.GRFPU_X0.N_16481\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_23__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16421\,
datab => \GRFPU0.GRFPU_X0.N_16486\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_24__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16422\,
datab => \GRFPU0.GRFPU_X0.N_16487\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_26__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16424\,
datab => \GRFPU0.GRFPU_X0.N_16489\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_27__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16425\,
datab => \GRFPU0.GRFPU_X0.N_16490\);
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_1_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff000000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19067\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M29_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccfffcff00fff0")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_21__G1\,
dataf => \GRFPU0.GRFPU_X0.N_19016\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datad => \GRFPU0.GRFPU_X0.N_19067\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(50));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_19__G1\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_37\(48),
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_3\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(45));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_11__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_2_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_10__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_2_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_9__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_2_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_1_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19028\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M14_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fffcff00ffcc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_6__G1\,
dataf => \GRFPU0.GRFPU_X0.N_19016\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datad => \GRFPU0.GRFPU_X0.N_19028\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(35),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(32));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_5__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_1_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19025\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M13_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fffcff00ffcc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_5__G1\,
dataf => \GRFPU0.GRFPU_X0.N_19016\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datad => \GRFPU0.GRFPU_X0.N_19025\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(34),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(31));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_1_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19022\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M12_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fffcff00ffcc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_4__G1\,
dataf => \GRFPU0.GRFPU_X0.N_19016\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datad => \GRFPU0.GRFPU_X0.N_19022\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(33),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(30));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_0__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f00cc000000cc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_0__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.N_5774\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(29));
\GRFPU0_GRFPU_X0_ITER_BMLSB_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.BMLSB_0_0_1__N_5\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1));
\GRFPU0_GRFPU_X0_ITER_BMLSB_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.BMLSB_0_0_0__N_5\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68_0_1__G5\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(1),
datad => \FPI.OP1_RETO\(1));
\GRFPU0_GRFPU_X0_ST4_SGNF_RNO_0_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff000f0cccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.VST4.SGNF_1_1_29__G1\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN5_S3ADDO2\(29),
datad => N_28276,
datac => N_28228,
datab => \GRFPU0.GRFPU_X0.S3ADDI\(29));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_23__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000f0f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_20__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_20__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M90_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_20__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M90_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_19__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M89_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_19__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M89_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_18__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M88_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_18__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M88_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_17__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M87_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_17__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M87_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_16__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_16__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_15__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_15__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_14__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_14__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_13__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_13__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_12__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_12__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_11__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_11__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_10__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_10__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_9__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_9__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_8__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M94_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M78_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_8__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M94_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_7__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M93_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_7__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M93_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_6__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M92_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_6__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M92_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_5__G4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M91_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
\GRFPU0_GRFPU_X0_ST2_SGNF2_RNO_0_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_5__G3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M91_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_2_IV_1_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfff0fff0fff0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_2_IV_1\(60),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_19681\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(60));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_2_IV_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff00f3")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(60),
dataf => \GRFPU0.GRFPU_X0.N_6509_I_M\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_2_IV_1\(60),
datad => \GRFPU0.MULO.MRES\(120),
datac => N_99921,
datab => \GRFPU0.GRFPU_X0.N_18663\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33ff3fff00ff0fff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(7),
dataf => N_99921,
datae => \GRFPU0.GRFPU_X0.N_18663\,
datad => \GRFPU0.GRFPU_X0.N_19681\,
datac => \GRFPU0.MULO.MRES\(67),
datab => \GRFPU0.MULO.MRES\(68));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffffc0c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(7),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(7),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(7),
datac => \GRFPU0.GRFPU_X0.N_3560_I\,
datab => \GRFPU0.MULO.MRES\(67));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0fff000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(3),
dataf => N_99921,
datae => \GRFPU0.GRFPU_X0.N_18663\,
datad => \GRFPU0.MULO.MRES\(63),
datac => \GRFPU0.MULO.MRES\(64));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0fff00000f0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(2),
dataf => N_99921,
datae => \GRFPU0.GRFPU_X0.N_18663\,
datad => \GRFPU0.MULO.MRES\(63),
datac => \GRFPU0.MULO.MRES\(62));
\GRFPC0_OP1_3_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20094\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(37),
datad => \GRFPC0.WR.RREG.RES\(37));
\GRFPC0_OP1_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(37),
dataf => \GRFPC0.N_20225\,
datae => N_99877_1,
datad => \GRFPC0.N_20159\,
datac => \GRFPC0.RFA2.RS1SEL_0\(7),
datab => \GRFPC0.N_20094\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(34),
dataf => \GRFPU0.GRFPU_X0.N_21\,
datae => \GRFPU0.GRFPU_X0.N_18746\,
datad => \FPI.OP1\(37),
datac => \FPI.OP1\(34));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(37),
dataf => \GRFPU0.GRFPU_X0.N_21\,
datae => \GRFPU0.GRFPU_X0.N_18746\,
datad => \FPI.OP1\(37),
datac => \FPI.OP1\(40));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(8),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(8),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(13),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(13),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(13));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_0_0_TZ_0_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f000f000f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0_0_TZ_0\(22),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => N_99921,
datac => \GRFPU0.MULO.MRES\(83),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(22));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_0_0_TZ_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0_0_TZ\(22),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0_0_TZ_0\(22),
datae => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datad => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datac => \GRFPU0.MULO.MRES\(82),
datab => \GRFPU0.MULO.DRES_1\(82));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00f3ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(22),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(22),
datae => \GRFPU0.GRFPU_X0.N_18338\,
datad => \GRFPU0.GRFPU_X0.N_18527\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0_0_TZ\(22),
datab => \GRFPU0.GRFPU_X0.N_18664\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(22),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(22),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(22));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(33),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(33),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(35),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(35),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(35));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M46_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(47),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M14_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M46_2_03\,
datac => \GRFPU0.GRFPU_X0.N_9666\,
datab => \GRFPU0.GRFPU_X0.L4_4\(4));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M45_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(46),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M13_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M45_2_03\,
datac => \GRFPU0.GRFPU_X0.N_9666\,
datab => \GRFPU0.GRFPU_X0.L4_4\(4));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M44_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(45),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M12_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M44_2_03\,
datac => \GRFPU0.GRFPU_X0.N_9666\,
datab => \GRFPU0.GRFPU_X0.L4_4\(4));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M43_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(44),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M27_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M43_2_03\,
datac => \GRFPU0.GRFPU_X0.N_9666\,
datab => \GRFPU0.GRFPU_X0.L4_4\(4));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M42_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(43),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M26_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M42_2_03\,
datac => \GRFPU0.GRFPU_X0.N_9666\,
datab => \GRFPU0.GRFPU_X0.L4_4\(4));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M41_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(42),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M25_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M41_2_03\,
datac => \GRFPU0.GRFPU_X0.N_9666\,
datab => \GRFPU0.GRFPU_X0.L4_4\(4));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M40_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(41),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M24_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M40_2_03\,
datac => \GRFPU0.GRFPU_X0.N_9666\,
datab => \GRFPU0.GRFPU_X0.L4_4\(4));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M6_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03\,
datad => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M38_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c0f0c33300300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(39),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M22_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M38_2_03\,
datac => \GRFPU0.GRFPU_X0.N_9666\,
datab => \GRFPU0.GRFPU_X0.L4_4\(4));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M35_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(36),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M35_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_2_03\,
datac => \GRFPU0.GRFPU_X0.N_9666\,
datab => \GRFPU0.GRFPU_X0.L4_4\(4));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M34_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(35),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M18_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M34_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_2_03\,
datac => \GRFPU0.GRFPU_X0.N_9666\,
datab => \GRFPU0.GRFPU_X0.L4_4\(4));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M1_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\,
datae => \GRFPU0.GRFPU_X0.L4_4\(3),
datad => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M33_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(34),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M17_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M33_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_2_03\,
datac => \GRFPU0.GRFPU_X0.N_9666\,
datab => \GRFPU0.GRFPU_X0.L4_4\(4));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M32_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(33),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M16_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M32_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_2_03\,
datac => \GRFPU0.GRFPU_X0.N_9666\,
datab => \GRFPU0.GRFPU_X0.L4_4\(4));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M8_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c0f0c33300300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M8_0_03\,
datac => \GRFPU0.GRFPU_X0.L4_4\(3),
datab => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M9_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M9_0_03\,
datac => \GRFPU0.GRFPU_X0.L4_4\(3),
datab => \GRFPU0.GRFPU_X0.L4_4\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16771\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(111),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(43));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(51),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16771\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(51),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(51));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17035\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(51),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(110),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(50));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17036\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(52),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(111),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(51));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(25),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(25),
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(25),
datab => \FPI.OP1_RETO\(25));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(25),
dataf => \GRFPU0.GRFPU_X0.N_15237\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17018\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(34),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(93),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(33));
\GRFPU0_GRFPU_X0_L3_0_7_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0cfc0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_7\(0),
dataf => \GRFPU0.GRFPU_X0.L2_0_6\(4),
datae => \GRFPU0.GRFPU_X0.L2_0_6\(0),
datad => \GRFPU0.GRFPU_X0.L1_2_7\(0),
datac => \GRFPU0.GRFPU_X0.L1_2_5\(3),
datab => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L1_3\(0));
\GRFPU0_GRFPU_X0_L2_0_6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_6\(0),
dataf => \GRFPU0.GRFPU_X0.L1_0_6\(3),
datae => \GRFPU0.GRFPU_X0.L1_0_7\(0),
datad => \GRFPU0.GRFPU_X0.L1_1_7\(0));
\GRFPU0_GRFPU_X0_BCO_MSB_1_7_0_A4_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00300030ff300030")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_7_0_A4_0_0\(0),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(25),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(24),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(56),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(57));
\GRFPU0_GRFPU_X0_BCO_MSB_1_7_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03f303f303f30000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_7\(0),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_3\(26),
datae => \GRFPU0.GRFPU_X0.BCO_MSB_1_7_0_A4_0_0\(0),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(27),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(59));
\GRFPU0_GRFPU_X0_L1_0_7_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfcfffcf0fc")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_7\(0),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_3\(31),
datae => \GRFPU0.GRFPU_X0.BCO_MSB_1_7\(0),
datad => \GRFPU0.GRFPU_X0.N_13441\,
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3\(30),
datab => \GRFPU0.GRFPU_X0.N_13440\);
\GRFPU0_GRFPU_X0_BCO_MSB_4_5_0_TZ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0030f030")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_5_TZ\(0),
dataf => \GRFPU0.GRFPU_X0.N_19788\,
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(1),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(33));
\GRFPU0_GRFPU_X0_L1_3_1_5_A4_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00300030ff300030")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_1_5_A4_0_0\(0),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(5),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(4),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(37));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L1_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fff0f00300000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L1_3\(0),
dataf => \GRFPU0.GRFPU_X0.L1_3_1_5\(0),
datae => \GRFPU0.GRFPU_X0.BCO_MSB_4_5_TZ\(0),
datad => \GRFPU0.GRFPU_X0.N_13552_1\,
datac => \GRFPU0.GRFPU_X0.UN258_BCO_LSB_0_0\,
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3\(3));
\GRFPU0_GRFPU_X0_BCO_MSB_3_7_0_A4_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00300030ff300030")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_7_0_A4_0_0\(0),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(9),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(8),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(41));
\GRFPU0_GRFPU_X0_L1_2_1_6_A4_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000cff0c000c")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_6_A4_0_0\(0),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(13),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(12),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(45),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(44));
\GRFPU0_GRFPU_X0_L1_2_1_6_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03f303f303f30000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_6\(0),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_3\(14),
datae => \GRFPU0.GRFPU_X0.L1_2_1_6_A4_0_0\(0),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(15),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(47));
\GRFPU0_GRFPU_X0_L1_2_7_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fc00fcffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_7\(0),
dataf => \GRFPU0.GRFPU_X0.UN253_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.L1_2_1_6\(0),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3\(11),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_3_7_0_A4_0_0\(0),
datab => \GRFPU0.GRFPU_X0.INF_ABS0_3\(10));
\GRFPU0_GRFPU_X0_BCO_MSB_2_7_0_A4_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000cff0c000c")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_7_0_A4_0_0\(0),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(17),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(16),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(48));
\GRFPU0_GRFPU_X0_L1_1_7_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fc000000fcffff")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_7\(0),
dataf => \GRFPU0.GRFPU_X0.N_19772\,
datae => \GRFPU0.GRFPU_X0.UN248_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_3\(19),
datac => \GRFPU0.GRFPU_X0.INF_ABS0_3\(18),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_2_7_0_A4_0_0\(0));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(45),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(45),
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(45),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(45));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(45),
dataf => \GRFPU0.GRFPU_X0.N_15257\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f3333f0003333")
port map (
combout => \GRFPU0.GRFPU_X0.N_15551\,
dataf => \GRFPU0.GRFPU_X0.N_16074\,
datae => \GRFPU0.GRFPU_X0.N_14\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(61),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f00ff0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16074\,
dataf => \GRFPU0.GRFPU_X0.N_18195\,
datae => N_32537,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(61));
\GRFPU0_GRFPU_X0_EXP_11_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3cffccff3c00cc00")
port map (
combout => \GRFPU0.GRFPU_X0.EXP_11\(9),
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(10),
datae => N_32669,
datad => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(9));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_RNO_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(32),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(3),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16495\,
datab => \GRFPU0.GRFPU_X0.N_16430\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f033fffff033")
port map (
combout => \GRFPU0.GRFPU_X0.N_15645\,
dataf => \GRFPU0.GRFPU_X0.N_18444\,
datae => \GRFPU0.GRFPU_X0.N_15611\,
datad => \GRFPU0.GRFPU_X0.N_14\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(32),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_RNO_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(35),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(6),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16498\,
datab => \GRFPU0.GRFPU_X0.N_16433\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f033fffff033")
port map (
combout => \GRFPU0.GRFPU_X0.N_15648\,
dataf => \GRFPU0.GRFPU_X0.N_18444\,
datae => \GRFPU0.GRFPU_X0.N_15611\,
datad => \GRFPU0.GRFPU_X0.N_14\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(35),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f033fffff033")
port map (
combout => \GRFPU0.GRFPU_X0.N_15650\,
dataf => \GRFPU0.GRFPU_X0.N_18444\,
datae => \GRFPU0.GRFPU_X0.N_15611\,
datad => \GRFPU0.GRFPU_X0.N_14\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(37),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16437\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(39));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_RNO_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(39),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(10),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16502\,
datab => \GRFPU0.GRFPU_X0.N_16437\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f30003fff3ff03")
port map (
combout => \GRFPU0.GRFPU_X0.N_15652\,
dataf => \GRFPU0.GRFPU_X0.N_18444\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(39),
datad => \GRFPU0.GRFPU_X0.N_15611\,
datac => \GRFPU0.GRFPU_X0.N_14\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16438\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(40));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_RNO_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(40),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(11),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16503\,
datab => \GRFPU0.GRFPU_X0.N_16438\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f30003fff3ff03")
port map (
combout => \GRFPU0.GRFPU_X0.N_15653\,
dataf => \GRFPU0.GRFPU_X0.N_18444\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(40),
datad => \GRFPU0.GRFPU_X0.N_15611\,
datac => \GRFPU0.GRFPU_X0.N_14\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_RNO_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(41),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(12),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16504\,
datab => \GRFPU0.GRFPU_X0.N_16439\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f30003fff3ff03")
port map (
combout => \GRFPU0.GRFPU_X0.N_15654\,
dataf => \GRFPU0.GRFPU_X0.N_18444\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(41),
datad => \GRFPU0.GRFPU_X0.N_15611\,
datac => \GRFPU0.GRFPU_X0.N_14\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f30003fff3ff03")
port map (
combout => \GRFPU0.GRFPU_X0.N_15655\,
dataf => \GRFPU0.GRFPU_X0.N_18444\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(42),
datad => \GRFPU0.GRFPU_X0.N_15611\,
datac => \GRFPU0.GRFPU_X0.N_14\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f30003fff3ff03")
port map (
combout => \GRFPU0.GRFPU_X0.N_15656\,
dataf => \GRFPU0.GRFPU_X0.N_18444\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(43),
datad => \GRFPU0.GRFPU_X0.N_15611\,
datac => \GRFPU0.GRFPU_X0.N_14\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff033330f003333")
port map (
combout => \GRFPU0.GRFPU_X0.N_15536\,
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(17),
datae => \GRFPU0.GRFPU_X0.N_14\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(46),
datac => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc0fccffcc00ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(46),
dataf => \GRFPU0.GRFPU_X0.N_15536\,
datae => \GRFPU0.GRFPU_X0.N_18444\,
datad => N_99909_I_0,
datac => \GRFPU0.GRFPU_X0.N_15611\,
datab => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f3333f0003333")
port map (
combout => \GRFPU0.GRFPU_X0.N_15547\,
dataf => \GRFPU0.GRFPU_X0.N_16070\,
datae => \GRFPU0.GRFPU_X0.N_14\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(57),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f00ff0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16070\,
dataf => \GRFPU0.GRFPU_X0.N_18195\,
datae => N_32517,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(57));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16439\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(41));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003cff00003c00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16520\,
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(6),
datae => \GRFPU0.GRFPU_X0.N_5508\,
datad => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA\,
datac => N_32654,
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_42_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(13),
dataf => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datae => \GRFPU0.MULO.MRES\(73),
datad => \GRFPU0.MULO.DRES_1\(73));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(13),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(13),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(47),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(47));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(13),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.GRFPU_X0.N_4401\,
datad => \GRFPU0.MULO.DRES_S\(72),
datac => \GRFPU0.MULO.MRES\(73),
datab => \GRFPU0.MULO.DRES_1\(73),
dataa => \GRFPU0.MULO.DRES_1S\(72));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16997\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(13),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(72),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16993\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(9),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(68),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16994\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(10),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(69),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(9));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_RNO_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(43),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(14),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16506\,
datab => \GRFPU0.GRFPU_X0.N_16441\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16441\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(43));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16433\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(35));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16424\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(26));
\GRFPU0_GRFPU_X0_L4_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4\(0),
dataf => \GRFPU0.GRFPU_X0.N_9666\,
datae => \GRFPU0.GRFPU_X0.L3_0_2\(0),
datad => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(4),
datac => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(0),
datab => \GRFPU0.GRFPU_X0.L1_6\(0));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(3),
dataf => \GRFPU0.GRFPU_X0.L1_4_2\(3),
datae => \GRFPU0.GRFPU_X0.UN233_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_4\,
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(9),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(6));
\GRFPU0_GRFPU_X0_L4_4_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4\(3),
dataf => \GRFPU0.GRFPU_X0.N_9666\,
datae => \GRFPU0.GRFPU_X0.N_9672\,
datad => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(3),
datac => \GRFPU0.GRFPU_X0.N_9683\,
datab => \GRFPU0.GRFPU_X0.N_9671\);
\GRFPU0_GRFPU_X0_L3_0_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_2\(0),
dataf => \GRFPU0.GRFPU_X0.N_9672\,
datae => \GRFPU0.GRFPU_X0.L2_0_3\(0),
datad => \GRFPU0.GRFPU_X0.N_9671\,
datac => \GRFPU0.GRFPU_X0.L1_3_3\(0),
datab => \GRFPU0.GRFPU_X0.L1_2_3\(0));
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(0),
dataf => \GRFPU0.GRFPU_X0.L1_4_2\(3),
datae => \GRFPU0.GRFPU_X0.L1_4_3\(0),
datad => \GRFPU0.GRFPU_X0.L1_5_3\(0));
\GRFPU0_GRFPU_X0_L2_0_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_3\(0),
dataf => \GRFPU0.GRFPU_X0.N_9683\,
datae => \GRFPU0.GRFPU_X0.L1_0_4\(0),
datad => \GRFPU0.GRFPU_X0.L1_1_4\(0));
\GRFPU0_GRFPU_X0_BCO_MSB_6_2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff0fff00")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_6_2\(0),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(9),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(7));
\GRFPU0_GRFPU_X0_L1_5_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0f0000ff0c")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_3\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_6_2\(0),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(11),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(10));
\GRFPU0_GRFPU_X0_BCO_MSB_5_2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff0fff00")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_5_2\(0),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(15));
\GRFPU0_GRFPU_X0_L1_4_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0f0000ff0c")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_3\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_5_2\(0),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(18));
\GRFPU0_GRFPU_X0_BCO_MSB_4_2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_2\(0),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(24),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(23),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(22));
\GRFPU0_GRFPU_X0_L1_3_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0f0000ff0c")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_3\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_4_2\(0),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(27),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(26));
\GRFPU0_GRFPU_X0_BCO_MSB_3_2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_2\(0),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(32),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(31),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(30));
\GRFPU0_GRFPU_X0_L1_2_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0f0000ff0c")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_3\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_3_2\(0),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(37),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(35),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(34));
\GRFPU0_GRFPU_X0_BCO_MSB_2_3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_3\(0),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(40),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(38));
\GRFPU0_GRFPU_X0_L1_1_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0f0f0c0c0f0c")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_4\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_2_3\(0),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(42),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(45),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(44));
\GRFPU0_GRFPU_X0_BCO_MSB_1_3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_3\(0),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(46));
\GRFPU0_GRFPU_X0_L1_0_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3303330333033300")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_4\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_1_3\(0),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(50),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(52),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(51),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(53));
\GRFPU0_GRFPU_X0_L4_4_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4\(2),
dataf => \GRFPU0.GRFPU_X0.N_9666\,
datae => \GRFPU0.GRFPU_X0.L3_0_2\(2),
datad => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(4),
datac => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(2),
datab => \GRFPU0.GRFPU_X0.UN238_BCO_LSB\(15));
\GRFPU0_GRFPU_X0_L3_0_2_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_2\(2),
dataf => \GRFPU0.GRFPU_X0.N_9672\,
datae => \GRFPU0.GRFPU_X0.L2_0_3\(2),
datad => \GRFPU0.GRFPU_X0.N_9671\,
datac => \GRFPU0.GRFPU_X0.N_9673\,
datab => \GRFPU0.GRFPU_X0.N_9678\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16982\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(59));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16944\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(13),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(21));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16981\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(58));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16979\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(56));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16949\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(18),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16978\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(55));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16973\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(50));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16971\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16975\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(52));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16931\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16947\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16943\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(20));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16948\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(25));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16946\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(23));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17019\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(35),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(94),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(34));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16966\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(43));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16976\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(53));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16963\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(40));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16932\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(9));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16977\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(54));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16934\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(11));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16959\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(28),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17034\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(50),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(109),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(49));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(16),
dataf => \GRFPU0.GRFPU_X0.N_15228\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(16),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17016\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(32),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(91),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17010\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(26),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(85),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(25));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(5),
dataf => \GRFPU0.GRFPU_X0.N_15217\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5));
GRFPU0_GRFPU_X0_VITER_DBUF_1_SQMUXA_3_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33ff30fc33333030")
port map (
combout => \GRFPU0.GRFPU_X0.N_147_I\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17017\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(33),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(92),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(32));
GRFPU0_GRFPU_X0_COMB_SIGN1_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SIGN1_2\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datae => \GRFPU0.GRFPU_X0.ST1.SIGN1\,
datad => \GRFPU0.GRFPU_X0.ST1.OP1NX\);
\GRFPU0_GRFPU_X0_COMB_CCV_8_0_M5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f030f0300000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_13428\,
dataf => \GRFPU0.GRFPU_X0.COMB.LESS2\,
datae => \GRFPU0.GRFPU_X0.COMB.SIGN1_2\,
datad => \GRFPU0.GRFPU_X0.ST1.OP2NX\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_I_M2_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18563\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(8),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(67),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_RNO_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_M\(33),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_RNO_0_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(33),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(93),
datac => \GRFPU0.MULO.DRES_1\(93));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0f3f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(33),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_M\(33),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(33),
datad => \GRFPU0.GRFPU_X0.N_18663\,
datac => \GRFPU0.GRFPU_X0.N_19681\,
datab => \GRFPU0.MULO.MRES\(93));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(33),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(92),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(93),
datab => \GRFPU0.MULO.DRES_1\(93),
dataa => \GRFPU0.MULO.DRES_1S\(92));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc30fffffc300000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(33),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(33),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.UN177_RNDOP\(27),
datac => \GRFPU0.GRFPU_X0.UN166_RNDOP\(27),
datab => \GRFPU0.GRFPU_X0.N_11529\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_RNO_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(42),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(13),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16505\,
datab => \GRFPU0.GRFPU_X0.N_16440\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff033330f003333")
port map (
combout => \GRFPU0.GRFPU_X0.N_15539\,
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(20),
datae => \GRFPU0.GRFPU_X0.N_14\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(49),
datac => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccc0fffcccc00f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(49),
dataf => \GRFPU0.GRFPU_X0.N_15539\,
datae => N_99909_I_0,
datad => \GRFPU0.GRFPU_X0.N_18491\,
datac => \GRFPU0.GRFPU_X0.N_15611\,
datab => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff033330f003333")
port map (
combout => \GRFPU0.GRFPU_X0.N_15541\,
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(22),
datae => \GRFPU0.GRFPU_X0.N_14\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(51),
datac => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16440\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(42));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_RNO_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(37),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(8),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16500\,
datab => \GRFPU0.GRFPU_X0.N_16435\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16435\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(37));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff033330f003333")
port map (
combout => \GRFPU0.GRFPU_X0.N_15538\,
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(19),
datae => \GRFPU0.GRFPU_X0.N_14\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(48),
datac => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccc0fffcccc00f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(48),
dataf => \GRFPU0.GRFPU_X0.N_15538\,
datae => N_99909_I_0,
datad => \GRFPU0.GRFPU_X0.N_18491\,
datac => \GRFPU0.GRFPU_X0.N_15611\,
datab => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17030\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(46),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(105),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(45));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_RNO_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(23),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(83),
datac => \GRFPU0.MULO.DRES_1\(83));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(23),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(23),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(23),
datad => N_99921,
datac => \GRFPU0.MULO.MRES\(84));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf0fffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(23),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(23),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(23),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_18664\,
datab => \GRFPU0.MULO.MRES\(83));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(23),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(23),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(37),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(37));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0f000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(35),
dataf => \GRFPU0.GRFPU_X0.N_3560_I\,
datae => N_99921,
datad => \GRFPU0.MULO.MRES\(96),
datac => \GRFPU0.MULO.MRES\(95));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccf000f000f000f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(35),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => \GRFPU0.GRFPU_X0.N_18663\,
datac => \GRFPU0.MULO.MRES\(95),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(35));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_RNO_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(35),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.DRES_1\(95),
datac => \GRFPU0.MULO.MRES\(95));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffaa00aa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(35),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(94),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.DRES_1\(95),
datab => \GRFPU0.MULO.DRES_1S\(94),
dataa => \GRFPU0.MULO.MRES\(95));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3fffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(35),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(35),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(35),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(35),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(35),
datab => \GRFPU0.GRFPU_X0.N_18664\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc30fffffc300000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(35),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(35),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.UN177_RNDOP\(25),
datac => \GRFPU0.GRFPU_X0.UN166_RNDOP\(25),
datab => \GRFPU0.GRFPU_X0.N_11529\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17021\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(37),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0fccccf000cccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16986\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(1),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(1),
datac => \GRFPU0.GRFPU_X0.N_4\,
datab => \GRFPU0.MULO.MRES\(61));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17031\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(47),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(106),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17032\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(48),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(107),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(47));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17000\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(16),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(75),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff3fff00ff33ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(11),
dataf => N_99921,
datae => \GRFPU0.GRFPU_X0.N_18663\,
datad => \GRFPU0.GRFPU_X0.N_19681\,
datac => \GRFPU0.MULO.MRES\(72),
datab => \GRFPU0.MULO.MRES\(71));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_RNO_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(11),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(71),
datac => \GRFPU0.MULO.DRES_1\(71));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf0fffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(11),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(11),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(11),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_18664\,
datab => \GRFPU0.MULO.MRES\(71));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(11),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(11),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(49),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(49));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_M2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcfc3fff3cfc")
port map (
combout => \GRFPU0.GRFPU_X0.N_91\,
dataf => \GRFPU0.GRFPU_X0.N_18221\,
datae => \GRFPU0.GRFPU_X0.N_18213\,
datad => \GRFPU0.GRFPU_X0.C\(11),
datac => \GRFPU0.GRFPU_X0.C\(10),
datab => \GRFPU0.GRFPU_X0.C\(1));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(36),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(36),
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(36));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(36),
dataf => \GRFPU0.GRFPU_X0.N_15248\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(0),
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(0),
datad => \FPI.OP1_RETO\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15373\,
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(7),
dataf => \GRFPU0.GRFPU_X0.N_15219\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(10),
dataf => \GRFPU0.GRFPU_X0.N_15222\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(11),
dataf => \GRFPU0.GRFPU_X0.N_15223\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(9),
dataf => \GRFPU0.GRFPU_X0.N_15221\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(12),
dataf => \GRFPU0.GRFPU_X0.N_15224\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(12),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_I_M2_0_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18324\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(114),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_I_M2_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18336\,
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_18324\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(54));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ffffccf00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(37),
dataf => \GRFPU0.GRFPU_X0.N_17219\,
datae => \GRFPU0.GRFPU_X0.N_19547\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(37),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(37));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(29),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(29),
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(29),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(29));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(29),
dataf => \GRFPU0.GRFPU_X0.N_15241\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_M4_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19915\,
dataf => \GRFPU0.GRFPU_X0.N_15226\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_I_M4_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19923\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_0_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcc00fffff000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15227\,
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_0_1\(15),
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_1_0_A2_0\(15),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(15),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_M4_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19927\,
dataf => \GRFPU0.GRFPU_X0.N_19926\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_I_M4_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19933\,
dataf => \GRFPU0.GRFPU_X0.N_19932\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(32),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(32),
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(32));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(32),
dataf => \GRFPU0.GRFPU_X0.N_15244\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_0_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(38),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(38),
datae => \GRFPU0.GRFPU_X0.N_19546\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(38),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(38),
dataf => \GRFPU0.GRFPU_X0.N_15250\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_I_M3_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19574\,
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datae => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(2));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_27_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15374\,
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff3fff00ff33ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(10),
dataf => N_99921,
datae => \GRFPU0.GRFPU_X0.N_18663\,
datad => \GRFPU0.GRFPU_X0.N_19681\,
datac => \GRFPU0.MULO.MRES\(71),
datab => \GRFPU0.MULO.MRES\(70));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_RNO_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(10),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(70),
datac => \GRFPU0.MULO.DRES_1\(70));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf0fffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(10),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(10),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(10),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_18664\,
datab => \GRFPU0.MULO.MRES\(70));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(10),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(10),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(50),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(50));
\GRFPU0_GRFPU_X0_DIFFIN2_4_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14381\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_I_M4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19931\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17003\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(19),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(78),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(18));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17027\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(43),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(102),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(42));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17001\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(17),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(76),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17026\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(42),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(101),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(41));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0f3f0f3f0f3f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(25),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(25),
datad => \GRFPU0.GRFPU_X0.N_18663\,
datac => \GRFPU0.GRFPU_X0.N_19681\,
datab => \GRFPU0.MULO.MRES\(85));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_42_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(25),
dataf => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datae => \GRFPU0.MULO.MRES\(85),
datad => \GRFPU0.MULO.DRES_1\(85));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff303030")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(25),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(25),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(25),
datad => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datac => N_99921,
datab => \GRFPU0.MULO.MRES\(86));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf0fffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(25),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(25),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(25),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_18664\,
datab => \GRFPU0.MULO.MRES\(85));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(25),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(25),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(35),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(35));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17009\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(25),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(84),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(25),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(84),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(85),
datab => \GRFPU0.MULO.DRES_1\(85),
dataa => \GRFPU0.MULO.DRES_1S\(84));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17011\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(27),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(86),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17025\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(41),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(100),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(40));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17022\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(38),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(97),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(37));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16999\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(15),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(74),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0f3f0f3f0f3f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(15),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(15),
datad => \GRFPU0.GRFPU_X0.N_18663\,
datac => \GRFPU0.GRFPU_X0.N_19681\,
datab => \GRFPU0.MULO.MRES\(75));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_RNO_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(15),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(75),
datac => \GRFPU0.MULO.DRES_1\(75));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(15),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(15),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(15),
datad => N_99921,
datac => \GRFPU0.MULO.MRES\(76));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(15),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.GRFPU_X0.N_4401\,
datad => \GRFPU0.MULO.DRES_S\(74),
datac => \GRFPU0.MULO.MRES\(75),
datab => \GRFPU0.MULO.DRES_1\(75),
dataa => \GRFPU0.MULO.DRES_1S\(74));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(15),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(15),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(45),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(45));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_M\(8),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff33003f0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(8),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_M\(8),
datae => \GRFPU0.GRFPU_X0.N_18663\,
datad => N_99921,
datac => \GRFPU0.MULO.MRES\(68),
datab => \GRFPU0.MULO.MRES\(69));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(8),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.GRFPU_X0.N_4401\,
datad => \GRFPU0.MULO.DRES_S\(67),
datac => \GRFPU0.MULO.MRES\(68),
datab => \GRFPU0.MULO.DRES_1\(68),
dataa => \GRFPU0.MULO.DRES_1S\(67));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f033fffff0330000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(8),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(8),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(52),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17005\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(21),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(80),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(20));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_RNO_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(32),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(92),
datac => \GRFPU0.MULO.DRES_1\(92));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(32),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(32),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(32),
datad => N_99921,
datac => \GRFPU0.MULO.MRES\(93));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf0fffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(32),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(32),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(32),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_18664\,
datab => \GRFPU0.MULO.MRES\(92));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc30fffffc300000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(32),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(32),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.UN177_RNDOP\(28),
datac => \GRFPU0.GRFPU_X0.UN166_RNDOP\(28),
datab => \GRFPU0.GRFPU_X0.N_11529\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17002\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(18),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(77),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(17));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17033\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(49),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(108),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16775\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(115),
datac => \GRFPU0.DIVROM0.RADDR\(3),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(47));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(55),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16775\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(55),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(55));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16768\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(108),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(40));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(48),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16768\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(48),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16765\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(105),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(37));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(45),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16765\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(45));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17024\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(40),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(99),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(39));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17004\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(20),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(79),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17015\,
dataf => \GRFPU0.GRFPU_X0.N_18685\,
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(90),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(30));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17028\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(44),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(103),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(43));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17007\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(23),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(82),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(22));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16998\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(14),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(73),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(13));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0fff00000f0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(12),
dataf => N_99921,
datae => \GRFPU0.GRFPU_X0.N_18663\,
datad => \GRFPU0.MULO.MRES\(73),
datac => \GRFPU0.MULO.MRES\(72));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_RNO_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(12),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(72),
datac => \GRFPU0.MULO.DRES_1\(72));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf0fffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(12),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(12),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(12),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_18664\,
datab => \GRFPU0.MULO.MRES\(72));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(12),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(12),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(48),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(12),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.GRFPU_X0.N_4401\,
datad => \GRFPU0.MULO.DRES_S\(71),
datac => \GRFPU0.MULO.MRES\(72),
datab => \GRFPU0.MULO.DRES_1\(72),
dataa => \GRFPU0.MULO.DRES_1S\(71));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16996\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(12),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(71),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(11));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16995\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(11),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(70),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_RNO_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(14),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(74),
datac => \GRFPU0.MULO.DRES_1\(74));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0f3f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(14),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(14),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(14),
datad => \GRFPU0.GRFPU_X0.N_18663\,
datac => \GRFPU0.GRFPU_X0.N_19681\,
datab => \GRFPU0.MULO.MRES\(74));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf0fffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(14),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(14),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(14),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_18664\,
datab => \GRFPU0.MULO.MRES\(74));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(14),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(14),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(46),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(9),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.GRFPU_X0.N_4401\,
datad => \GRFPU0.MULO.DRES_S\(68),
datac => \GRFPU0.MULO.MRES\(69),
datab => \GRFPU0.MULO.DRES_1\(69),
dataa => \GRFPU0.MULO.DRES_1S\(68));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(9),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(9),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(51),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(51));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16760\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(100),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(40),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16760\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(40));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16762\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(102),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(34));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(42),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16762\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(42),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(42));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17006\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(22),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(81),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(21));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17014\,
dataf => \GRFPU0.GRFPU_X0.N_18686\,
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(89),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17013\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(29),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(88),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(28));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(14),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.GRFPU_X0.N_4401\,
datad => \GRFPU0.MULO.DRES_S\(73),
datac => \GRFPU0.MULO.MRES\(74),
datab => \GRFPU0.MULO.DRES_1\(74),
dataa => \GRFPU0.MULO.DRES_1S\(73));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16422\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(24));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16416\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(18));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16415\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(17));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(10),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.GRFPU_X0.N_4401\,
datad => \GRFPU0.MULO.DRES_S\(69),
datac => \GRFPU0.MULO.MRES\(70),
datab => \GRFPU0.MULO.DRES_1\(70),
dataa => \GRFPU0.MULO.DRES_1S\(69));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaccccff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(11),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.GRFPU_X0.N_4401\,
datad => \GRFPU0.MULO.DRES_S\(70),
datac => \GRFPU0.MULO.MRES\(71),
datab => \GRFPU0.MULO.DRES_1\(71),
dataa => \GRFPU0.MULO.DRES_1S\(70));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16400\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(2));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16398\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16425\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(27));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_RNO_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(24),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(84),
datac => \GRFPU0.MULO.DRES_1\(84));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(24),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(24),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(24),
datad => N_99921,
datac => \GRFPU0.MULO.MRES\(85));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf0fffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(24),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(24),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(24),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_18664\,
datab => \GRFPU0.MULO.MRES\(84));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(24),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(24),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(36),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17008\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(24),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(83),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(23));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(22),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(81),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(82),
datab => \GRFPU0.MULO.DRES_1\(82),
dataa => \GRFPU0.MULO.DRES_1S\(81));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(24),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(83),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(84),
datab => \GRFPU0.MULO.DRES_1\(84),
dataa => \GRFPU0.MULO.DRES_1S\(83));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(32),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(91),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(92),
datab => \GRFPU0.MULO.DRES_1\(92),
dataa => \GRFPU0.MULO.DRES_1S\(91));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0f3f0f3f0f3f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(30),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(30),
datad => \GRFPU0.GRFPU_X0.N_18663\,
datac => \GRFPU0.GRFPU_X0.N_19681\,
datab => \GRFPU0.MULO.MRES\(90));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_RNO_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(30),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(90),
datac => \GRFPU0.MULO.DRES_1\(90));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(30),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(30),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(30),
datad => N_99921,
datac => \GRFPU0.MULO.MRES\(91));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_I_M2_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18686\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(89),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(90),
datab => \GRFPU0.MULO.DRES_1\(90),
dataa => \GRFPU0.MULO.DRES_1S\(89));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf0fffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(30),
dataf => \GRFPU0.GRFPU_X0.N_18686\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(30),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_18664\,
datab => \GRFPU0.MULO.MRES\(90));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(30),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(30),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(30),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(30));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16412\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(14));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16410\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(12));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16411\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(13));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15868\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(91),
datad => \GRFPU0.MULO.MRES\(91));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15869\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(92),
datad => \GRFPU0.MULO.MRES\(92));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15870\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(93),
datad => \GRFPU0.MULO.MRES\(93));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15847\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(70),
datad => \GRFPU0.MULO.MRES\(70));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15850\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(73),
datad => \GRFPU0.MULO.MRES\(73));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15795\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(69),
datad => \GRFPU0.MULO.MRES\(69));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15796\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(70),
datad => \GRFPU0.MULO.MRES\(70));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15797\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(71),
datad => \GRFPU0.MULO.MRES\(71));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15798\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(72),
datad => \GRFPU0.MULO.MRES\(72));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15799\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(73),
datad => \GRFPU0.MULO.MRES\(73));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15800\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(74),
datad => \GRFPU0.MULO.MRES\(74));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15801\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(75),
datad => \GRFPU0.MULO.MRES\(75));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15802\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(76),
datad => \GRFPU0.MULO.MRES\(76));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15803\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(77),
datad => \GRFPU0.MULO.MRES\(77));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15804\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(78),
datad => \GRFPU0.MULO.MRES\(78));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15806\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(80),
datad => \GRFPU0.MULO.MRES\(80));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15807\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(81),
datad => \GRFPU0.MULO.MRES\(81));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15808\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(82),
datad => \GRFPU0.MULO.MRES\(82));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15809\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(83),
datad => \GRFPU0.MULO.MRES\(83));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15810\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(84),
datad => \GRFPU0.MULO.MRES\(84));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15811\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(85),
datad => \GRFPU0.MULO.MRES\(85));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15812\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(86),
datad => \GRFPU0.MULO.MRES\(86));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15813\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(87),
datad => \GRFPU0.MULO.MRES\(87));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15814\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(88),
datad => \GRFPU0.MULO.MRES\(88));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15815\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(89),
datad => \GRFPU0.MULO.MRES\(89));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15816\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(90),
datad => \GRFPU0.MULO.MRES\(90));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15817\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(91),
datad => \GRFPU0.MULO.MRES\(91));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15818\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(92),
datad => \GRFPU0.MULO.MRES\(92));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15819\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(93),
datad => \GRFPU0.MULO.MRES\(93));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15851\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(74),
datad => \GRFPU0.MULO.MRES\(74));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15852\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(75),
datad => \GRFPU0.MULO.MRES\(75));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15853\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(76),
datad => \GRFPU0.MULO.MRES\(76));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15854\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(77),
datad => \GRFPU0.MULO.MRES\(77));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15855\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(78),
datad => \GRFPU0.MULO.MRES\(78));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15857\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(80),
datad => \GRFPU0.MULO.MRES\(80));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15858\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(81),
datad => \GRFPU0.MULO.MRES\(81));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15859\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(82),
datad => \GRFPU0.MULO.MRES\(82));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15860\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(83),
datad => \GRFPU0.MULO.MRES\(83));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15861\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(84),
datad => \GRFPU0.MULO.MRES\(84));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15862\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(85),
datad => \GRFPU0.MULO.MRES\(85));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15863\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(86),
datad => \GRFPU0.MULO.MRES\(86));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15864\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(87),
datad => \GRFPU0.MULO.MRES\(87));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15865\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(88),
datad => \GRFPU0.MULO.MRES\(88));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15866\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(89),
datad => \GRFPU0.MULO.MRES\(89));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15867\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(90),
datad => \GRFPU0.MULO.MRES\(90));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18618\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(69),
datad => \GRFPU0.MULO.MRES\(69));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18619\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(71),
datad => \GRFPU0.MULO.MRES\(71));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_I_M2_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_74\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(72),
datad => \GRFPU0.MULO.MRES\(72));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f3333f0003333")
port map (
combout => \GRFPU0.GRFPU_X0.N_15550\,
dataf => \GRFPU0.GRFPU_X0.N_16073\,
datae => \GRFPU0.GRFPU_X0.N_14\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(60),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"003f00cf003000c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16523\,
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(9),
datae => N_32669,
datad => \GRFPU0.GRFPU_X0.N_5508\,
datac => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(8));
\GRFPU0_GRFPU_X0_S3ADDI_0_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_14515\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(29),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(28));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16753\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
datac => \GRFPU0.MULO.MRES\(93),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(25));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(33),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16753\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(33),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_I_M2_1_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18676\,
dataf => \GRFPU0.GRFPU_X0.N_18548\,
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(30));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_I_M2_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_18684\,
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.N_18681\,
datac => \GRFPU0.GRFPU_X0.N_18676\,
datab => \GRFPU0.MULO.MRES\(90));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_2_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16686\,
dataf => \GRFPU0.GRFPU_X0.N_18548\,
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(29),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.N_16624\,
datac => \GRFPU0.GRFPU_X0.N_16686\,
datab => \GRFPU0.MULO.MRES\(89));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_2_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16683\,
dataf => \GRFPU0.GRFPU_X0.N_18548\,
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(26),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(26),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.N_16621\,
datac => \GRFPU0.GRFPU_X0.N_16683\,
datab => \GRFPU0.MULO.MRES\(86));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16745\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(85),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(17));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(25),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16745\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(25),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(25));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16742\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
datac => \GRFPU0.MULO.MRES\(82),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(22),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16742\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(22),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(22));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16740\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
datac => \GRFPU0.MULO.MRES\(80),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(20),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16740\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(20),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(20));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16735\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
datac => \GRFPU0.MULO.MRES\(75),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(15),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16735\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(15),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(13),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16733\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(13),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(13));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(12),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16732\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(12),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16731\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
datac => \GRFPU0.MULO.MRES\(71),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(11),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16731\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(11),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(11));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16730\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
datac => \GRFPU0.MULO.MRES\(70),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16730\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(10),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(9),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16729\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(9),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(9));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18858_I\,
dataf => \GRFPU0.GRFPU_X0.N_18868\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(51),
datac => \FPI.OP2\(54));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(57),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.MULO.MRES\(117),
datac => \GRFPU0.MULO.MRES\(116),
datab => \GRFPU0.MULO.DRES_1\(117),
dataa => \GRFPU0.MULO.DRES_1S\(116));
\GRFPU0_DIVROM0_DATA_1_MUX_3_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.DIVAPPR\(5),
dataf => \GRFPU0.DIVROM0.DATA_1_1\(5),
datae => \GRFPU0.DIVROM0.DATA_1_2\(5),
datad => \GRFPU0.DIVROM0.DATA_1_0\(5),
datac => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0f0f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(57),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(117),
datac => \GRFPU0.MULO.DRES_1\(117));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0c000c000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(57),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(117),
datad => \GRFPU0.MULO.DRES_1\(117),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(57),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(116),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(117),
datab => \GRFPU0.MULO.DRES_1\(117),
dataa => \GRFPU0.MULO.DRES_1S\(116));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0fffffff3")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(57),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(57),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(57),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(57),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(57),
datab => \GRFPU0.GRFPU_X0.N_18664\);
\GRFPU0_SQRTROM0_DATA_1_0_6__ROM_4_0_G0\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff00ffffff")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_0\(5),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(4),
datad => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_M3_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fcfc3030")
port map (
combout => \GRFPU0.GRFPU_X0.N_18384\,
dataf => \GRFPU0.GRFPU_X0.N_128\,
datae => \GRFPU0.SQRTROM0.DATA_1_1\(5),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datac => \GRFPU0.SQRTROM0.DATA_1_0\(5),
datab => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.DIVROMI\(4),
dataf => \GRFPU0.GRFPU_X0.N_18868\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(51),
datac => \FPI.OP2\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(56),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.MULO.MRES\(116),
datac => \GRFPU0.MULO.MRES\(115),
datab => \GRFPU0.MULO.DRES_1\(116),
dataa => \GRFPU0.MULO.DRES_1S\(115));
\GRFPU0_DIVROM0_DATA_1_MUX_3_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_3\(4),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(4),
datad => \GRFPU0.DIVROM0.RADDR\(3));
\GRFPU0_DIVROM0_DATA_1_MUX_3_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7e6b3a2d5c49180")
port map (
combout => \GRFPU0.DIVAPPR\(4),
dataf => \GRFPU0.DIVROM0.DATA_1_2\(4),
datae => \GRFPU0.DIVROM0.DATA_1_1\(4),
datad => \GRFPU0.DIVROM0.DATA_1_0\(4),
datac => \GRFPU0.DIVROM0.DATA_1_3\(4),
datab => \GRFPU0.DIVROM0.RADDR\(6),
dataa => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(56),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(116),
datac => \GRFPU0.MULO.DRES_1\(116));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c00000c000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(56),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(116),
datad => \GRFPU0.MULO.DRES_1\(116),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(56),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(115),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(116),
datab => \GRFPU0.MULO.DRES_1\(116),
dataa => \GRFPU0.MULO.DRES_1S\(115));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3fffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(56),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(56),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(56),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(56),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(56),
datab => \GRFPU0.GRFPU_X0.N_18664\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_M3_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffcc3300")
port map (
combout => \GRFPU0.GRFPU_X0.N_18386\,
dataf => \GRFPU0.GRFPU_X0.N_128\,
datae => \GRFPU0.SQRTROM0.DATA_1_1\(4),
datad => \GRFPU0.SQRTROM0.DATA_1_0\(4),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datab => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18855_I\,
dataf => \GRFPU0.GRFPU_X0.N_18868\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(50),
datac => \FPI.OP2\(47));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(55),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(18),
datad => \GRFPU0.MULO.MRES\(120),
datac => \GRFPU0.MULO.MRES\(115),
datab => \GRFPU0.MULO.MRES\(114));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0f0f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(55),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(115),
datac => \GRFPU0.MULO.DRES_1\(115));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0c000c000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(55),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(115),
datad => \GRFPU0.MULO.DRES_1\(115),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15141\,
dataf => \GRFPU0.GRFPU_X0.N_4401\,
datae => \GRFPU0.MULO.DRES_1\(115),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datac => N_28152,
datab => N_28151);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fcfc0c0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(55),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(114),
datad => \GRFPU0.GRFPU_X0.N_15141\,
datac => \GRFPU0.GRFPU_X0.N_4401\,
datab => \GRFPU0.MULO.MRES\(115));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0fffffff3")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(55),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(55),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(55),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(55),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(55),
datab => \GRFPU0.GRFPU_X0.N_18664\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffcc3300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(55),
dataf => \GRFPU0.GRFPU_X0.N_128\,
datae => \GRFPU0.SQRTROM0.DATA_1_1\(3),
datad => \GRFPU0.SQRTROM0.DATA_1_0\(3),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datab => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(53),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.MULO.MRES\(113),
datac => \GRFPU0.MULO.MRES\(112),
datab => \GRFPU0.MULO.DRES_1\(113),
dataa => \GRFPU0.MULO.DRES_1S\(112));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0f0f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(53),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(113),
datac => \GRFPU0.MULO.DRES_1\(113));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0c000c000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(53),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(113),
datad => \GRFPU0.MULO.DRES_1\(113),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(53),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(112),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(113),
datab => \GRFPU0.MULO.DRES_1\(113),
dataa => \GRFPU0.MULO.DRES_1S\(112));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0fffffff3")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(53),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(53),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(53),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(53),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(53),
datab => \GRFPU0.GRFPU_X0.N_18664\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ffcc3300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(53),
dataf => \GRFPU0.GRFPU_X0.N_128\,
datae => \GRFPU0.SQRTROM0.DATA_1_1\(1),
datad => \GRFPU0.SQRTROM0.DATA_1_0\(1),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datab => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18853_I\,
dataf => \GRFPU0.GRFPU_X0.N_18868\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(47),
datac => \FPI.OP2\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_O2_0_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0f000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_O2_0\(52),
dataf => \GRFPU0.GRFPU_X0.N_18308\,
datae => N_99921,
datad => \GRFPU0.MULO.MRES\(113),
datac => \GRFPU0.MULO.DRES_1\(112));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_4_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"a0a0a0808080a080")
port map (
combout => \GRFPU0.GRFPU_X0.N_18364\,
dataf => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB\(2),
datae => N_93108,
datad => N_93109,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6_1\(41),
datab => \GRFPU0.GRFPU_X0.COMB.LOB2_I_M_1_I_0_0\,
dataa => \GRFPU0.MULO.MRES\(111));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15138\,
dataf => \GRFPU0.GRFPU_X0.N_4401\,
datae => \GRFPU0.MULO.DRES_1\(112),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datac => N_28146,
datab => N_28145);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fcfc0c0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(52),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(111),
datad => \GRFPU0.GRFPU_X0.N_15138\,
datac => \GRFPU0.GRFPU_X0.N_4401\,
datab => \GRFPU0.MULO.MRES\(112));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_0_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f3330000f000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(52),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(52),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(52),
datac => N_99920,
datab => \GRFPU0.GRFPU_X0.N_18664\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M2_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18330\,
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(8),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(8),
datad => \GRFPU0.GRFPU_X0.N_11529\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccfff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(52),
dataf => \GRFPU0.GRFPU_X0.N_128\,
datae => \GRFPU0.SQRTROM0.DATA_1_1\(0),
datad => \GRFPU0.SQRTROM0.DATA_1_0\(0),
datac => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(52));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M2_RNI1LH03_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c1d0c1d0c1d2e3f")
port map (
combout => D_N_6_1,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(52),
datae => \GRFPU0.GRFPU_X0.N_18330\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(52),
datac => \GRFPU0.DIVAPPR\(0),
datab => \GRFPU0.GRFPU_X0.N_5673_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(40),
dataf => \GRFPU0.GRFPU_X0.N_18868_0\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datad => \FPI.OP2\(43),
datac => \FPI.OP2\(40));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18848_I\,
dataf => \GRFPU0.GRFPU_X0.N_18868\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(38),
datac => \FPI.OP2\(41));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_4_RNO_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c00000c000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(46),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(106),
datad => \GRFPU0.MULO.DRES_1\(106),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15132\,
dataf => \GRFPU0.GRFPU_X0.N_4401\,
datae => \GRFPU0.MULO.DRES_1\(106),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datac => N_28134,
datab => N_28133);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fcfc0c0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(46),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(105),
datad => \GRFPU0.GRFPU_X0.N_15132\,
datac => \GRFPU0.GRFPU_X0.N_4401\,
datab => \GRFPU0.MULO.MRES\(106));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfc3030fc3030")
port map (
combout => N_93112,
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(14),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(14),
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(46),
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(37),
dataf => \GRFPU0.GRFPU_X0.N_18868_0\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datad => \FPI.OP2\(37),
datac => \FPI.OP2\(40));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3fffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(45),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(45),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(45),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(45),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(45),
datab => \GRFPU0.GRFPU_X0.N_18664\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfc3030fc3030")
port map (
combout => N_93120,
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(15),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(15),
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(45),
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18846_I\,
dataf => \GRFPU0.GRFPU_X0.N_18868\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(38),
datac => \FPI.OP2\(35));
GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_43_M2_E: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0a0a0a0808080a08")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_43_N_12\,
dataf => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB\(2),
datae => N_93108,
datad => N_93109,
datac => \GRFPU0.GRFPU_X0.RNDOP_14\(0),
datab => \GRFPU0.GRFPU_X0.COMB.LOB2_I_M_1_I_0_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_43_M2_E_0\);
GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_43_M4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000f000ff0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_43_N_5_I\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_43_N_12\,
datae => \GRFPU0.GRFPU_X0.N_3560_I\,
datad => \GRFPU0.GRFPU_X0.N_18663\,
datac => \GRFPU0.MULO.MRES\(103));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_6_0_0_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ccc00000fff0fff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6_0_0\(43),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => N_99921,
datac => \GRFPU0.MULO.MRES\(104),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(43));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_1_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0f0f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18365\,
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(103),
datac => \GRFPU0.MULO.DRES_1\(103));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_2_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0c000c000c")
port map (
combout => \GRFPU0.GRFPU_X0.N_18366\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(103),
datad => \GRFPU0.MULO.DRES_1\(103),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(43),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(102),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(103),
datab => \GRFPU0.MULO.DRES_1\(103),
dataa => \GRFPU0.MULO.DRES_1S\(102));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_5_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5050504040405040")
port map (
combout => \GRFPU0.GRFPU_X0.N_152\,
dataf => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB\(2),
datae => N_93108,
datad => N_93109,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6_1\(41),
datab => \GRFPU0.GRFPU_X0.COMB.LOB2_I_M_1_I_0_0\,
dataa => \GRFPU0.MULO.MRES\(102));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M2_RNI56E41_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf00c000c000c00")
port map (
combout => D_N_3_0_I,
dataf => \GRFPU0.GRFPU_X0.N_18329\,
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(43));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_6_0_5_RNIV5JI3_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"10dc101050505050")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(43),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_43_N_5_I\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6_0_5\(43),
datad => \GRFPU0.GRFPU_X0.N_152\,
datac => D_N_3_0_I,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_43_M7_0_0\,
dataa => \GRFPU0.GRFPU_X0.N_5673_0\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18845_I\,
dataf => \GRFPU0.GRFPU_X0.N_18868\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(33),
datac => \FPI.OP2\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_0_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff00f0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18350\,
dataf => \GRFPU0.GRFPU_X0.N_18527\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP\(19),
datad => \GRFPU0.GRFPU_X0.UN166_RNDOP\(19),
datac => \GRFPU0.GRFPU_X0.N_11529\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_5_0_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80888888d0dddddd")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5\(41),
dataf => \GRFPU0.GRFPU_X0.N_18311\,
datae => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP_D\,
datad => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP_0_0\,
datac => \GRFPU0.GRFPU_X0.N_18314\,
datab => \GRFPU0.GRFPU_X0.N_18663\,
dataa => \GRFPU0.MULO.MRES\(101));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_0_0_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ccc00000fff0fff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(41),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => N_99921,
datac => \GRFPU0.MULO.MRES\(102),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(41));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_2_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0f0f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18360\,
dataf => \GRFPU0.GRFPU_X0.N_18308\,
datae => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datad => N_28181,
datac => N_28180);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15127\,
dataf => \GRFPU0.GRFPU_X0.N_4401\,
datae => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datad => N_28181,
datac => N_28180,
datab => \GRFPU0.MULO.DRES_1S\(100));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fcfc0c0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(41),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(100),
datad => \GRFPU0.GRFPU_X0.N_15127\,
datac => \GRFPU0.GRFPU_X0.N_4401\,
datab => \GRFPU0.MULO.MRES\(101));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_3_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0a0a0a0808080a08")
port map (
combout => \GRFPU0.GRFPU_X0.N_143\,
dataf => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB\(2),
datae => N_93108,
datad => N_93109,
datac => \GRFPU0.GRFPU_X0.RNDOP_14\(0),
datab => \GRFPU0.GRFPU_X0.COMB.LOB2_I_M_1_I_0_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_3_0\(41));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000020000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18349\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_5\(41),
datae => \GRFPU0.GRFPU_X0.N_143\,
datad => \GRFPU0.GRFPU_X0.N_18310\,
datac => \GRFPU0.GRFPU_X0.N_18360\,
datab => \GRFPU0.GRFPU_X0.N_18527\,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_0\(41));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_0_RNISVF13_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ec00ec00ec0020")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(41),
dataf => \GRFPU0.GRFPU_X0.N_18349\,
datae => \GRFPU0.GRFPU_X0.N_18350\,
datad => \GRFPU0.GRFPU_X0.N_5673_0\,
datac => \GRFPU0.GRFPU_X0.N_128\,
datab => \GRFPU0.GRFPU_X0.ITER.V\,
dataa => \GRFPU0.GRFPU_X0.ITER.R_I\(41));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18844_I\,
dataf => \GRFPU0.GRFPU_X0.N_18868\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(35),
datac => \FPI.OP2\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_YY_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff000cc00")
port map (
combout => N_93232,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(40),
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datac => \GRFPU0.MULO.MRES\(100),
datab => \GRFPU0.MULO.MRES\(99));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(40),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(100),
datac => \GRFPU0.MULO.DRES_1\(100));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000c000c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(40),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(100),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datab => \GRFPU0.MULO.DRES_1\(100));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ccccff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15126\,
dataf => \GRFPU0.GRFPU_X0.N_4401\,
datae => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datad => \GRFPU0.MULO.DRES_1\(100),
datac => N_28122,
datab => N_28121);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fcfc0c0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(40),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(99),
datad => \GRFPU0.GRFPU_X0.N_15126\,
datac => \GRFPU0.GRFPU_X0.N_4401\,
datab => \GRFPU0.MULO.MRES\(100));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3fffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(40),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(40),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(40),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(40),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(40),
datab => \GRFPU0.GRFPU_X0.N_18664\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfc3030fc3030")
port map (
combout => N_93116,
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(20),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(20),
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(40),
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNO_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5404540454540404")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(40),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => N_93231,
datad => N_93232,
datac => N_93110,
datab => N_93116,
dataa => \GRFPU0.GRFPU_X0.N_5673_0\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(31),
dataf => \GRFPU0.GRFPU_X0.N_18868_0\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datad => \FPI.OP2\(31),
datac => \FPI.OP2\(34));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18843_I\,
dataf => \GRFPU0.GRFPU_X0.N_18868\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(30),
datac => \FPI.OP2\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_4_RNO_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0c000c000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(38),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(98),
datad => \GRFPU0.MULO.DRES_1\(98),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15124\,
dataf => \GRFPU0.GRFPU_X0.N_4401\,
datae => \GRFPU0.MULO.DRES_1\(98),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datac => N_28118,
datab => N_28117);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fcfc0c0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(38),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(97),
datad => \GRFPU0.GRFPU_X0.N_15124\,
datac => \GRFPU0.GRFPU_X0.N_4401\,
datab => \GRFPU0.MULO.MRES\(98));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfc3030fc3030")
port map (
combout => N_93114,
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(22),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(22),
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(38),
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18842_I\,
dataf => \GRFPU0.GRFPU_X0.N_18868\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(29),
datac => \FPI.OP2\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_3_RNO_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0f0f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(37),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(97),
datac => \GRFPU0.MULO.DRES_1\(97));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_3_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3f0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_3\(37),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(37),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(37),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_18663\,
datab => \GRFPU0.MULO.MRES\(97));
GRFPU0_GRFPU_X0_COMB_UN138_RNDOP_RNI6JHU1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0c000c000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(37),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(97),
datad => \GRFPU0.MULO.DRES_1\(97),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(37),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(96),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(97),
datab => \GRFPU0.MULO.DRES_1\(97),
dataa => \GRFPU0.MULO.DRES_1S\(96));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_3_RNI9KG38_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcfffffffa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV\(37),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_I_M\(37),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(37),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_3\(37),
datab => N_93160,
dataa => N_93159);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfc3030fc3030")
port map (
combout => N_93115,
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(23),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(23),
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(37),
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccc3ccc3")
port map (
combout => \GRFPU0.GRFPU_X0.N_18236\,
dataf => \GRFPU0.GRFPU_X0.N_18408\,
datae => \GRFPU0.GRFPU_X0.C\(6),
datad => N_32463,
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(6));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f00ff00f")
port map (
combout => \GRFPU0.GRFPU_X0.N_79\,
dataf => \GRFPU0.GRFPU_X0.N_18408\,
datae => \GRFPU0.GRFPU_X0.C\(1),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(1));
\GRFPU0_GRFPU_X0_S3ADDI_0_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14539\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(52),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(53));
\GRFPU0_GRFPU_X0_S3ADDI_0_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14538\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(51),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(52));
\GRFPU0_GRFPU_X0_S3ADDI_0_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14537\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(50),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(51));
\GRFPU0_GRFPU_X0_S3ADDI_0_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14536\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(49),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(50));
\GRFPU0_GRFPU_X0_S3ADDI_0_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14535\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(48),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(49));
\GRFPU0_GRFPU_X0_S3ADDI_0_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14534\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(47),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(48));
\GRFPU0_GRFPU_X0_S3ADDI_0_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14533\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(46),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(47));
\GRFPU0_GRFPU_X0_S3ADDI_0_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14532\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(45),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(46));
\GRFPU0_GRFPU_X0_S3ADDI_0_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14531\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(44),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(45));
\GRFPU0_GRFPU_X0_S3ADDI_0_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14530\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(43),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(44));
\GRFPU0_GRFPU_X0_S3ADDI_0_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14529\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(42),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(43));
\GRFPU0_GRFPU_X0_S3ADDI_0_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14528\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(41),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(42));
\GRFPU0_GRFPU_X0_S3ADDI_0_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14527\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(40),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(41));
\GRFPU0_GRFPU_X0_S3ADDI_0_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14526\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(39),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(40));
\GRFPU0_GRFPU_X0_S3ADDI_0_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14525\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(38),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(39));
\GRFPU0_GRFPU_X0_S3ADDI_0_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14524\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(37),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(38));
\GRFPU0_GRFPU_X0_S3ADDI_0_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14523\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(36),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(37));
\GRFPU0_GRFPU_X0_S3ADDI_0_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14522\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(35),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(36));
\GRFPU0_GRFPU_X0_S3ADDI_0_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14521\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(34),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(35));
\GRFPU0_GRFPU_X0_S3ADDI_0_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14520\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(33),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(34));
\GRFPU0_GRFPU_X0_S3ADDI_0_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14519\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(32),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(33));
\GRFPU0_GRFPU_X0_S3ADDI_0_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14518\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(31),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(32));
\GRFPU0_GRFPU_X0_S3ADDI_0_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14517\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(30),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(31));
GRFPU0_FPMUL0_R2_RET_83_RNI613V: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(120),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(120),
datad => N_28105);
GRFPU0_FPMUL0_R2_RET_158_RNIOAFI: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.DRES_1S\(94),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datae => \GRFPU0.FPMUL0.SX\(94),
datad => N_28112);
GRFPU0_FPMUL0_R2_RET_132_RNI33G8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.DRES_1\(95),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(95),
datad => N_28169);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fffcff00ffcc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_17__G1\,
dataf => \GRFPU0.GRFPU_X0.N_19016\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datad => \GRFPU0.GRFPU_X0.N_19061\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(43));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_17__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_2_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fffcff00ffcc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_16__G1\,
dataf => \GRFPU0.GRFPU_X0.N_19016\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datad => \GRFPU0.GRFPU_X0.N_19058\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(45),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(42));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_16__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_2_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fffcff00ffcc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_15__G1\,
dataf => \GRFPU0.GRFPU_X0.N_19016\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datad => \GRFPU0.GRFPU_X0.N_19055\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(44),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(41));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_15__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_2_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_8__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_2_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_2__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f00cc000000cc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_1__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.N_5774\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(30));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_1__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_COMB_VST4_MEXP_1_0_2__G0_0_M2\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(121),
datad => N_28107);
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccc3cccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(9),
datad => N_32537,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(61));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff00ff0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_10__N_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(10),
datad => N_32545,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(62));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc30fc300000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_31__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.UN6_SGNFX\(2),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(31),
datab => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_I_M2_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18329\,
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(17),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(17),
datad => \GRFPU0.GRFPU_X0.N_11529\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f00ff00f")
port map (
combout => \GRFPU0.GRFPU_X0.N_85\,
dataf => \GRFPU0.GRFPU_X0.N_18408\,
datae => \GRFPU0.GRFPU_X0.C\(7),
datad => N_32473,
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(7));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16426\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(28));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_28__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16426\,
datab => \GRFPU0.GRFPU_X0.N_16491\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16423\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(25));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_25__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16423\,
datab => \GRFPU0.GRFPU_X0.N_16488\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f3333f0003333")
port map (
combout => \GRFPU0.GRFPU_X0.N_15552\,
dataf => \GRFPU0.GRFPU_X0.N_16075\,
datae => \GRFPU0.GRFPU_X0.N_14\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(62),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"003f00cf003000c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16525\,
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(11),
datae => N_32677,
datad => \GRFPU0.GRFPU_X0.N_5508\,
datac => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(10));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(17),
dataf => \GRFPU0.GRFPU_X0.N_15229\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(17),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_I_M3_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19561\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datae => \FPI.OP1_RETO\(15),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(15));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f00ff00f")
port map (
combout => \GRFPU0.GRFPU_X0.N_82\,
dataf => \GRFPU0.GRFPU_X0.N_18408\,
datae => \GRFPU0.GRFPU_X0.C\(4),
datad => N_32458,
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(4));
GRFPU0_GRFPU_X0_COMB_EXP37: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXP37\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
datad => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0));
\GRFPU0_GRFPU_X0_ITER_EXPOP_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccc0cc00ccc0")
port map (
combout => N_53561,
dataf => \GRFPU0.GRFPU_X0.N_5678\,
datae => \GRFPU0.GRFPU_X0.N_19742\,
datad => \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1));
GRFPU0_GRFPU_X0_ST3_V_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00fffff0ff0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.V_0_0_G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN43_FLUSH\,
datae => \FPI.FLUSH\,
datad => \FPI.FLUSHID\(5),
datac => \GRFPU0.GRFPU_X0.ST2.ID\(5));
GRFPU0_GRFPU_X0_UN1_VCS_ITER15_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.V\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_RNDOP_32_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f3f00000fff0")
port map (
combout => \GRFPU0.GRFPU_X0.RNDOP_32\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_21\,
datae => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datac => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_16\(0));
GRFPU0_FPMUL0_R2_RET_109_RNIAUVE: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(121),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datae => N_28221,
datad => N_28220);
GRFPU0_GRFPU_X0_EXPOP_0_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.EXPOP_0_SQMUXA\,
dataf => \GRFPU0.GRFPU_X0.RNDOP_32\(0),
datae => \GRFPU0.MULO.DRES_1\(121),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
GRFPU0_GRFPU_X0_COMB_UN59_RNDOP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0c0c0c0f0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
dataf => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB\(2),
datae => N_93108,
datad => N_93109,
datac => \GRFPU0.GRFPU_X0.RNDOP_14\(0),
datab => \GRFPU0.GRFPU_X0.COMB.LOB2_I_M_1_I_0_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17020\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(36),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(95),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(35));
GRFPU0_GRFPU_X0_ITER_NX_RNO_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccccccfcfcfcccf")
port map (
combout => N_44700,
dataf => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB\(2),
datae => N_93108,
datad => N_93109,
datac => \GRFPU0.GRFPU_X0.COMB.LOB2_I_M_1_I_0_0\,
datab => \GRFPU0.GRFPU_X0.N_183\);
GRFPU0_GRFPU_X0_ITER_NX_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0f000cfcfff0f")
port map (
combout => N_44701,
dataf => N_44700,
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.MULO.DRES_S\(66),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.MULO.MRES\(67));
GRFPU0_GRFPU_X0_ITER_NX_RNO_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f3c000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_184\,
dataf => \GRFPU0.GRFPU_X0.ITER.V\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datac => \GRFPU0.GRFPU_X0.ITER.LOB\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(9));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16763\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(103),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(35));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(43),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16763\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(43),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(43));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16761\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(101),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(41),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16761\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(41));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16756\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(96),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(28));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(36),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16756\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(36));
\GRFPC0_WR_RREG_RES_RNO_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fffff0f0f0f0")
port map (
combout => N_47265,
dataf => N_99846,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_12_3588_I_A3_0_0_0\,
datad => N_99904_1,
datac => \GRFPC0.MEM.RREG.RES\(28),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(28));
\GRFPC0_MEM_RREG_RES_RNO_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fffff0f0f0f0")
port map (
combout => N_47223,
dataf => N_99847,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_12_3588_I_A3_0_0_0\,
datad => N_99904_1,
datac => \GRFPC0.EX.RREG.RES\(28),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(28));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_13_3562_I_A3_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000f003300ff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_13_3562_I_A3_0\,
dataf => N_99904_1,
datae => \GRFPU0.GRFPU_X0.N_400_1\,
datad => \GRFPC0.DIV.RESULT_0_0_27__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(27),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(27));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_14_3536_I_A3_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000f003300ff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_14_3536_I_A3_0\,
dataf => N_99904_2,
datae => \GRFPU0.GRFPU_X0.N_400_1\,
datad => \GRFPC0.DIV.RESULT_0_0_26__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(26),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(32),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16752\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(32),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16752\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(92),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0f3f0f3f0f3f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(27),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(27),
datad => \GRFPU0.GRFPU_X0.N_18663\,
datac => \GRFPU0.GRFPU_X0.N_19681\,
datab => \GRFPU0.MULO.MRES\(87));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_RNO_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(27),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(87),
datac => \GRFPU0.MULO.DRES_1\(87));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(27),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(27),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(27),
datad => N_99921,
datac => \GRFPU0.MULO.MRES\(88));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(27),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(86),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(87),
datab => \GRFPU0.MULO.DRES_1\(87),
dataa => \GRFPU0.MULO.DRES_1S\(86));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf0fffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(27),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(27),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(27),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_18664\,
datab => \GRFPU0.MULO.MRES\(87));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(27),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(27),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(33),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0f3f0f3f0f3f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(26),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(26),
datad => \GRFPU0.GRFPU_X0.N_18663\,
datac => \GRFPU0.GRFPU_X0.N_19681\,
datab => \GRFPU0.MULO.MRES\(86));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_RNO_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(26),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(86),
datac => \GRFPU0.MULO.DRES_1\(86));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(26),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(26),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(26),
datad => N_99921,
datac => \GRFPU0.MULO.MRES\(87));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(26),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(85),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(86),
datab => \GRFPU0.MULO.DRES_1\(86),
dataa => \GRFPU0.MULO.DRES_1S\(85));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf0fffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(26),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(26),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(26),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_18664\,
datab => \GRFPU0.MULO.MRES\(86));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(26),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(26),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(34),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(34));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16747\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19),
datac => \GRFPU0.MULO.MRES\(87),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(19));
\GRFPC0_MEM_RREG_RES_RNO_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fffff0f0f0f0")
port map (
combout => N_47213,
dataf => N_99847,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_22_3328_I_A3_0_0_0\,
datad => N_99904_1,
datac => \GRFPC0.EX.RREG.RES\(18),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(18));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16744\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(84),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(24),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16744\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(24),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(24));
\GRFPC0_WR_RREG_RES_RNO_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fffff0f0f0f0")
port map (
combout => N_47253,
dataf => N_99846,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_24_3276_I_A3_0_0_0\,
datad => N_99904_2,
datac => \GRFPC0.MEM.RREG.RES\(16),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(16));
\GRFPC0_MEM_RREG_RES_RNO_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fffff0f0f0f0")
port map (
combout => N_47211,
dataf => N_99847,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_24_3276_I_A3_0_0_0\,
datad => N_99904_1,
datac => \GRFPC0.EX.RREG.RES\(16),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(16));
\GRFPC0_WR_RREG_RES_RNO_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fffff0f0f0f0")
port map (
combout => N_47251,
dataf => N_99846,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_26_3224_I_A3_0_0_0\,
datad => N_99904_2,
datac => \GRFPC0.MEM.RREG.RES\(14),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(14));
\GRFPC0_MEM_RREG_RES_RNO_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fffff0f0f0f0")
port map (
combout => N_47207,
dataf => N_99847,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_28_3172_I_A3_0_0_0\,
datad => N_99904_1,
datac => \GRFPC0.EX.RREG.RES\(12),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(12));
\GRFPC0_FP_PIPELINE_WRDATA_3_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(10),
dataf => \GRFPC0.DIV.RESULT\(10),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(10),
datab => \FPO.RES\(10));
\GRFPC0_WRDATA_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(10),
dataf => N_441,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(42),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16734\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
datac => \GRFPU0.MULO.MRES\(74),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(6));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(14),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16734\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(14),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(14));
\GRFPC0_WR_RREG_RES_RNO_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fffff0f0f0f0")
port map (
combout => N_47243,
dataf => N_99846,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_34_3016_I_A3_0_0_0\,
datad => N_99904_2,
datac => \GRFPC0.MEM.RREG.RES\(6),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(6));
\GRFPC0_MEM_RREG_RES_RNO_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fffff0f0f0f0")
port map (
combout => N_47201,
dataf => N_99847,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_34_3016_I_A3_0_0_0\,
datad => N_99904_1,
datac => \GRFPC0.EX.RREG.RES\(6),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(6));
\GRFPC0_OP1_4_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20159\,
dataf => N_99879_0,
datae => N_632,
datad => N_696);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(8),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16728\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(8),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(8));
\GRFPC0_FP_PIPELINE_WRDATA_3_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(42),
dataf => \GRFPC0.DIV.RESULT\(42),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(42),
datab => \GRFPU0.GRFPU_X0.N_20271_I_0\);
\GRFPU0_GRFPU_X0_ST3_EXC_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc00f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.EXC_1\(5),
dataf => \GRFPU0.GRFPU_X0.N_5755_1\,
datae => \GRFPU0.GRFPU_X0.UN1_VST3.EXC_4_SQMUXA_TZ\,
datad => \GRFPU0.GRFPU_X0.N_5757\,
datac => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(3),
datab => \GRFPU0.GRFPU_X0.ST2.EXC\(5));
GRFPU0_GRFPU_X0_VST3_REG_1_SQMUXA_2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
dataf => \GRFPU0.GRFPU_X0.N_5820\,
datae => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8));
\GRFPC0_FP_PIPELINE_7_REGDEPX_138_0_A4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf00000cc000000")
port map (
combout => \GRFPC0.N_24962\,
dataf => \GRFPC0.N_21277_1\,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_22253\,
datac => \GRFPC0.N_25013\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2_0\(14));
GRFPU0_GRFPU_X0_ST1_DEFERNX_RET_1_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00003000")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.DEFERNX_0_0_G4\,
dataf => \GRFPU0.GRFPU_X0.ST1.OP2NX_0_0_N_6\,
datae => \GRFPU0.GRFPU_X0.N_18784\,
datad => \GRFPU0.GRFPU_X0.N_18837\,
datac => \FPI.FLOP\(6),
datab => \FPI.FLOP\(7));
\GRFPU0_GRFPU_X0_ITER_STATE_RNI7MER_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_191_5\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(15),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(18),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(21));
\GRFPU0_GRFPU_X0_ITER_STATE_RNIFTFJ_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000f0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_M3_0_A3_2\,
dataf => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(16),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(11),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(10));
\GRFPU0_GRFPU_X0_ITER_STATE_RNI1VS92_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_236\,
dataf => \GRFPU0.GRFPU_X0.N_3560_I\,
datae => \GRFPU0.GRFPU_X0.N_19681\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(19));
\GRFPU0_GRFPU_X0_ITER_STATE_RNIR85P3_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_188\,
dataf => \GRFPU0.GRFPU_X0.N_236\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_M3_0_A3_2\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(13));
GRFPU0_GRFPU_X0_ST2_ZERO_RNO_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf0c000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.INF_1_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.N_5250\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7));
GRFPU0_GRFPU_X0_COMB_VST3_EXC19LTO10_RNI7SL63: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_5937_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__I3_I_3\,
datad => \GRFPU0.GRFPU_X0.N_5774\,
datac => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8));
GRFPU0_GRFPU_X0_VST3_EXC_1_SQMUXA_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_5940\,
dataf => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.ITER.EXPT\(0),
datad => \GRFPU0.GRFPU_X0.ITER.EXPT\(1));
GRFPU0_GRFPU_X0_UN1_ST2_FLTYPE2_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcfffcfffc")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST2.FLTYPE2_8\,
dataf => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\,
datae => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(4),
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(6));
GRFPU0_GRFPU_X0_VST3_EXC_0_SQMUXA_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00030")
port map (
combout => \GRFPU0.GRFPU_X0.N_6206\,
dataf => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_5\,
datae => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datad => \GRFPU0.GRFPU_X0.ITER.EXPT\(1),
datac => \GRFPU0.GRFPU_X0.ITER.EXPT\(0),
datab => \GRFPU0.GRFPU_X0.ITER.EXPT\(2));
\GRFPU0_GRFPU_X0_UN1_ST2_FLTYPE2_6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0fff000f000f0")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST2.FLTYPE2_6\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__I3_I_3\,
datad => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(7));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M9_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_1_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff000000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19061\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M9_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M25_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56));
GRFPU0_GRFPU_X0_ITER_FLUSH0_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000cccc000000f0")
port map (
combout => N_53553,
dataf => \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_8\,
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datab => \GRFPU0.GRFPU_X0.ITER.FLUSH0\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_2_I_A3_4_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_2_I_A3_4\(32),
dataf => \GRFPU0.GRFPU_X0.ST3.INF\,
datae => \GRFPU0.GRFPU_X0.ST3.EXC\(5),
datad => \GRFPU0.GRFPU_X0.ST3.EXC\(4),
datac => \GRFPU0.GRFPU_X0.ST3.EXC\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_2_I_O2_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00030000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6806\,
dataf => N_40568,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_2_I_A3_4\(32),
datad => \GRFPU0.GRFPU_X0.ST3.EXC\(1),
datac => \GRFPU0.GRFPU_X0.ST3.EXC\(3),
datab => \GRFPU0.GRFPU_X0.ST3.EXC\(2));
GRFPU0_GRFPU_X0_UN1_INTO_CARRY_31_RNI8A101: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fff0fff00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
dataf => \GRFPU0.GRFPU_X0.UN1_INTO\(31),
datae => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(51),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(50));
GRFPU0_GRFPU_X0_UN1_VCS_ITER15_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00fff3ffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VCS_ITER15_8\,
dataf => \GRFPU0.GRFPU_X0.VITER.FLUSH0_0_SQMUXA_1\,
datae => \GRFPU0.GRFPU_X0.N_5633\,
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datab => \GRFPU0.GRFPU_X0.ITER.FLUSH0\);
\GRFPU0_GRFPU_X0_UN38_EXP_M_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(57),
dataf => \GRFPC0.N_19750\,
datae => \GRFPC0.N_19684\,
datad => N_99880,
datac => \GRFPC0.N_19619\,
datab => \GRFPC0.RFA2.RS2SEL\(7));
\GRFPC0_OP2_3_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19619\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(57),
datad => \GRFPC0.WR.RREG.RES\(57));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16957\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(26),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(34));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(34),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16754\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(34));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16754\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(94),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(26));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcc0fccf0cc00cc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16988\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(3),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(3),
datad => N_99908_I_0,
datac => \GRFPU0.GRFPU_X0.N_4\,
datab => \GRFPU0.MULO.MRES\(63));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_11_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0cfc0cfcfc0cfc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(3),
dataf => \GRFPU0.GRFPU_X0.VITER.DBUF_7_1_CO2\,
datae => \GRFPU0.GRFPU_X0.L2_0\(4),
datad => \GRFPU0.GRFPU_X0.L1_0_2\(3),
datac => \GRFPU0.GRFPU_X0.N_19742\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_I_M2_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18683\,
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_18677\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_I_M2_0_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18677\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(91),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(23));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16951\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(20),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(28));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16954\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(23),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16953\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(22),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(30));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16980\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(57));
\GRFPU0_GRFPU_X0_ITER_STATE_RNIFLRF_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_145\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(24));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_1_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf03cf03cf03")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(59),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(59),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_18663\,
datab => \GRFPU0.MULO.MRES\(119));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_4_RNO_0_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(59),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(119),
datac => \GRFPU0.MULO.DRES_1\(119));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_4_RNO_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c00000c000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(59),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(119),
datad => \GRFPU0.MULO.DRES_1\(119),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_4_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(59),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(59),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(59),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(59),
datac => \GRFPU0.MULO.MRES\(120),
datab => N_99921);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(59),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(118),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(119),
datab => \GRFPU0.MULO.DRES_1\(119),
dataa => \GRFPU0.MULO.DRES_1S\(118));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_0_RNI24VG4_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffa0ffffffcc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(59),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32_M\(59),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(59),
datac => \GRFPU0.GRFPU_X0.N_15765\,
datab => N_93163,
dataa => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfc3030fc3030")
port map (
combout => N_93111,
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(1),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(1),
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(59),
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16758\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(98),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(30));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(38),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16758\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(5),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(5),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.N_15134\,
dataf => \GRFPU0.GRFPU_X0.N_4401\,
datae => \GRFPU0.MULO.DRES_1S\(107),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datac => N_28195,
datab => N_28194);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fcfc0c0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(107),
datad => \GRFPU0.GRFPU_X0.N_15134\,
datac => \GRFPU0.GRFPU_X0.N_4401\,
datab => \GRFPU0.MULO.MRES\(108));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfc3030fc3030")
port map (
combout => N_93123,
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(12),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(12),
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(48),
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_42_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(48),
dataf => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datae => \GRFPU0.MULO.MRES\(108),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datac => N_28195,
datab => N_28194);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17029\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(45),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(104),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c00000c000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(45),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(105),
datad => \GRFPU0.MULO.DRES_1\(105),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(45),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(105),
datac => \GRFPU0.MULO.DRES_1\(105));
\GRFPU0_GRFPU_X0_ITER_TZR_RNO_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfc000cfcfc0c0")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_6__N_4_I\,
dataf => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_4__N_6\,
datae => \GRFPU0.GRFPU_X0.N_9542\,
datad => \GRFPU0.GRFPU_X0.L4_6\(4),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\);
\GRFPU0_GRFPU_X0_L4_6_RNI41L62_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00ff00ff03c3c0f")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_4__N_6\,
dataf => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__G4\,
datae => \GRFPU0.GRFPU_X0.L4_6\(2),
datad => \GRFPU0.GRFPU_X0.L4_6\(3),
datac => \GRFPU0.GRFPU_X0.L4_6\(4),
datab => \GRFPU0.GRFPU_X0.ITER.SQRT\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16421\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(23));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16419\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(21));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_21__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16419\,
datab => \GRFPU0.GRFPU_X0.N_16484\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff0f000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(36),
dataf => \GRFPU0.GRFPU_X0.N_3560_I\,
datae => N_99921,
datad => \GRFPU0.MULO.MRES\(97),
datac => \GRFPU0.MULO.MRES\(96));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccf000f000f000f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(36),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => \GRFPU0.GRFPU_X0.N_18663\,
datac => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3fffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(36),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(36),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(36),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(36),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(36),
datab => \GRFPU0.GRFPU_X0.N_18664\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc30fffffc300000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(36),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(36),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.UN177_RNDOP\(24),
datac => \GRFPU0.GRFPU_X0.UN166_RNDOP\(24),
datab => \GRFPU0.GRFPU_X0.N_11529\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(36),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(36),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(36));
GRFPU0_FPMUL0_R2_RET_159_RNIQEFI: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.DRES_1S\(95),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datae => \GRFPU0.FPMUL0.SX\(95),
datad => N_28114);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffaa00aa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(36),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(95),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.DRES_1\(96),
datab => \GRFPU0.MULO.DRES_1S\(95),
dataa => \GRFPU0.MULO.MRES\(96));
GRFPU0_FPMUL0_R2_RET_133_RNI57G8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.DRES_1\(96),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(96),
datad => N_28171);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_RNO_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(36),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.DRES_1\(96),
datac => \GRFPU0.MULO.MRES\(96));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(4),
dataf => \GRFPU0.GRFPU_X0.L1_4_1\(3),
datae => \GRFPU0.GRFPU_X0.UN113_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.N_14265_1\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(44));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M10_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M6_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M10_0_03\,
datac => \GRFPU0.GRFPU_X0.L4_4\(3),
datab => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M11_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M11_0_03\,
datac => \GRFPU0.GRFPU_X0.L4_4\(3),
datab => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M31_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M15_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_2_03\,
datad => \GRFPU0.GRFPU_X0.N_9666\,
datac => \GRFPU0.GRFPU_X0.N_9672\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M21_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M21_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_03\,
datad => \GRFPU0.GRFPU_X0.N_9666\,
datac => \GRFPU0.GRFPU_X0.N_9672\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M20_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M20_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_2_03\,
datad => \GRFPU0.GRFPU_X0.N_9666\,
datac => \GRFPU0.GRFPU_X0.N_9672\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M19_4_03_0_G1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_4_03_0_G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M19_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_2_03\,
datad => \GRFPU0.GRFPU_X0.N_9666\,
datac => \GRFPU0.GRFPU_X0.N_9672\);
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M2_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03\,
datae => \GRFPU0.GRFPU_X0.L4_4\(3),
datad => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M3_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\,
datae => \GRFPU0.GRFPU_X0.L4_4\(3),
datad => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M4_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M4_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_0_03\,
datad => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M5_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M5_0_03\,
datad => \GRFPU0.GRFPU_X0.L4_4\(3),
datac => \GRFPU0.GRFPU_X0.L4_4\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16778\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(118),
datac => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(50));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(58),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16778\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(58));
GRFPU0_FPMUL0_R2_RET_102_RNI9IIP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(101),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(101),
datad => N_28067);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0f0f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(42),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(102),
datac => \GRFPU0.MULO.DRES_1\(102));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000300030")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(42),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(102),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datab => \GRFPU0.MULO.DRES_1\(102));
GRFPU0_FPMUL0_R2_RET_101_RNI9IIP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(102),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(102),
datad => N_28069);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0fffffff3")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(42),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(42),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(42),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(42),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(42),
datab => \GRFPU0.GRFPU_X0.N_18664\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfc3030fc3030")
port map (
combout => N_93119,
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(18),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(18),
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(42),
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(34),
dataf => \GRFPU0.GRFPU_X0.N_18868_0\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datad => \FPI.OP2\(37),
datac => \FPI.OP2\(34));
\GRFPC0_OP1_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(38),
dataf => \GRFPC0.N_20226\,
datae => N_99877_1,
datad => \GRFPC0.N_20160\,
datac => \GRFPC0.RFA2.RS1SEL_0\(7),
datab => \GRFPC0.N_20095\);
\GRFPC0_OP1_3_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20095\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(38),
datad => \GRFPC0.WR.RREG.RES\(38));
GRFPU0_FPMUL0_R2_RET_100_RNI9IIP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(103),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(103),
datad => N_28071);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_4_RNO_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0c000c000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(44),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(104),
datad => \GRFPU0.MULO.DRES_1\(104),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15130\,
dataf => \GRFPU0.GRFPU_X0.N_4401\,
datae => \GRFPU0.MULO.DRES_1\(104),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datac => N_28130,
datab => N_28129);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fcfc0c0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(44),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(103),
datad => \GRFPU0.GRFPU_X0.N_15130\,
datac => \GRFPU0.GRFPU_X0.N_4401\,
datab => \GRFPU0.MULO.MRES\(104));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfc3030fc3030")
port map (
combout => N_93113,
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(16),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(16),
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(44),
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0f0f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(47),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(107),
datac => \GRFPU0.MULO.DRES_1\(107));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0c000c000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(47),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(107),
datad => \GRFPU0.MULO.DRES_1\(107),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0fffffff3")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(47),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(47),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(47),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(47),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(47),
datab => \GRFPU0.GRFPU_X0.N_18664\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfc3030fc3030")
port map (
combout => N_93118,
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(13),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(13),
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(47),
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_4_RNO_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c00000c000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(50),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(110),
datad => \GRFPU0.MULO.DRES_1\(110),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_4_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_4\(50),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(50),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_0\(50),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_1\(50),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(50),
datab => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15136\,
dataf => \GRFPU0.GRFPU_X0.N_4401\,
datae => \GRFPU0.MULO.DRES_1\(110),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datac => N_28142,
datab => N_28141);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fcfc0c0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(50),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(109),
datad => \GRFPU0.GRFPU_X0.N_15136\,
datac => \GRFPU0.GRFPU_X0.N_4401\,
datab => \GRFPU0.MULO.MRES\(110));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfc3030fc3030")
port map (
combout => N_93122,
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(10),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(10),
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(50),
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_ITER_R_I_RNO_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5454040454045404")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(50),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => N_93236,
datad => N_93235,
datac => N_93110,
datab => N_93122,
dataa => \GRFPU0.GRFPU_X0.N_5673_0\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18851_I\,
dataf => \GRFPU0.GRFPU_X0.N_18868\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(45),
datac => \FPI.OP2\(42));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18849_I\,
dataf => \GRFPU0.GRFPU_X0.N_18868\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(39),
datac => \FPI.OP2\(42));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18847_I\,
dataf => \GRFPU0.GRFPU_X0.N_18868\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(39),
datac => \FPI.OP2\(36));
GRFPU0_FPMUL0_R2_RET_95_RNIBP2V: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(108),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(108),
datad => N_28081);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_42_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42\(49),
dataf => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datae => \GRFPU0.MULO.MRES\(109),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datac => N_28197,
datab => N_28196);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.N_15135\,
dataf => \GRFPU0.GRFPU_X0.N_4401\,
datae => \GRFPU0.MULO.DRES_1S\(108),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datac => N_28197,
datab => N_28196);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fcfc0c0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(49),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(108),
datad => \GRFPU0.GRFPU_X0.N_15135\,
datac => \GRFPU0.GRFPU_X0.N_4401\,
datab => \GRFPU0.MULO.MRES\(109));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfc3030fc3030")
port map (
combout => N_93117,
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(11),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(11),
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(49),
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18850_I\,
dataf => \GRFPU0.GRFPU_X0.N_18868\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(41),
datac => \FPI.OP2\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_XX_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff000cc00")
port map (
combout => N_93135,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(51),
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datac => \GRFPU0.MULO.DRES_1\(111),
datab => \GRFPU0.MULO.DRES_1S\(110));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_D_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff30fffc003000")
port map (
combout => N_93190,
dataf => N_93135,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP\(9),
datad => \GRFPU0.GRFPU_X0.N_18527\,
datac => \GRFPU0.GRFPU_X0.UN166_RNDOP\(9),
datab => \GRFPU0.GRFPU_X0.N_11529\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(51),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(111),
datac => \GRFPU0.MULO.DRES_1\(111));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c00000c000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(51),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(111),
datad => \GRFPU0.MULO.DRES_1\(111),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(51),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(110),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(111),
datab => \GRFPU0.MULO.DRES_1\(111),
dataa => \GRFPU0.MULO.DRES_1S\(110));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3fffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(51),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(51),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(51),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(51),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(51),
datab => \GRFPU0.GRFPU_X0.N_18664\);
GRFPU0_FPMUL0_R2_RET_92_RNI4T2V: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(111),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(111),
datad => N_28087);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_YY_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff000cc00")
port map (
combout => N_93136,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(51),
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.GRFPU_X0.VITER.EXPOP_1_SQMUXA\,
datac => \GRFPU0.MULO.MRES\(111),
datab => \GRFPU0.MULO.MRES\(110));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_D_RNIQVMT2_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3210321032321010")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(51),
dataf => N_93189,
datae => N_93190,
datad => N_93136,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(51),
datab => \GRFPU0.GRFPU_X0.N_5673_0\,
dataa => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18852_I\,
dataf => \GRFPU0.GRFPU_X0.N_18868\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(43),
datac => \FPI.OP2\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_0_0_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0fff0fff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_0\(54),
dataf => \GRFPU0.GRFPU_X0.N_18326\,
datae => N_99920,
datad => N_99921,
datac => \GRFPU0.MULO.MRES\(115));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_O2_3_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00000cff0c0c")
port map (
combout => \GRFPU0.GRFPU_X0.N_18308\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datad => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_4_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18372\,
dataf => \GRFPU0.GRFPU_X0.N_18308\,
datae => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datad => N_28207,
datac => N_28206);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_I_M2_1_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.N_18316\,
dataf => \GRFPU0.GRFPU_X0.N_4401\,
datae => \GRFPU0.MULO.DRES_1S\(113),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datac => N_28207,
datab => N_28206);
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_0_I_M2_0_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fcfc0c0c")
port map (
combout => \GRFPU0.GRFPU_X0.N_89\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(113),
datad => \GRFPU0.GRFPU_X0.N_18316\,
datac => \GRFPU0.GRFPU_X0.N_4401\,
datab => \GRFPU0.MULO.MRES\(114));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_3_0_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c0000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_3\(54),
dataf => \GRFPU0.GRFPU_X0.N_89\,
datae => \GRFPU0.GRFPU_X0.N_18372\,
datad => \GRFPU0.GRFPU_X0.N_18527\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_I_A2_0\(54),
datab => \GRFPU0.GRFPU_X0.N_18664\);
GRFPU0_GRFPU_X0_COMB_UN59_RNDOP_D: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0fffffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP_D\,
dataf => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB\(2),
datae => N_93108,
datad => N_93109,
datac => \GRFPU0.GRFPU_X0.RNDOP_14\(0));
GRFPU0_FPMUL0_R2_RET_89_RNIDT2V: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(114),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(114),
datad => N_28093);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_1_A2_6_1_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcecececfcec")
port map (
combout => \GRFPU0.GRFPU_X0.N_18311\,
dataf => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB\(2),
datae => N_93108,
datad => N_93109,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6_S_0\(43),
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6_1_1\(43),
dataa => \GRFPU0.GRFPU_X0.COMB.LOB2_I_M_1_I_0_0\);
\GRFPU0_GRFPU_X0_COMB_LOB2_ALTB_S_0_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"4008100820081008")
port map (
combout => N_93108,
dataf => \GRFPU0.GRFPU_X0.L1_5_3\(3),
datae => \GRFPU0.GRFPU_X0.L1_4_3\(3),
datad => \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(3));
\GRFPU0_GRFPU_X0_BCO_MSB_3_3_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcaffcaffcaffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_13875\,
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(18),
datae => \GRFPU0.GRFPU_X0.N_18307\,
datad => \GRFPU0.GRFPU_X0.N_18315\,
datac => \GRFPU0.MULO.MRES\(120),
datab => \GRFPU0.MULO.DRES_1\(113),
dataa => \GRFPU0.MULO.DRES_1S\(112));
\GRFPU0_GRFPU_X0_COMB_LOB2_AXB_YY_YY_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00ff00ff0f00f0f")
port map (
combout => N_93296,
dataf => \GRFPU0.GRFPU_X0.UN128_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.N_13895\,
datad => \GRFPU0.GRFPU_X0.N_13875\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(1));
\GRFPU0_GRFPU_X0_COMB_LOB2_AXB_YY_XX_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccc3333ccc3ccc3")
port map (
combout => N_93295,
dataf => \GRFPU0.GRFPU_X0.UN123_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.N_13865\,
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(3),
datac => \GRFPU0.GRFPU_X0.N_18314\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(1));
\GRFPU0_GRFPU_X0_COMB_LOB2_AXB_XX_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccccc33c3c3c3c3")
port map (
combout => N_93106,
dataf => \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\,
datae => \GRFPU0.GRFPU_X0.UN133_BCO_LSB_2\(15),
datad => \GRFPU0.GRFPU_X0.N_13885_1\,
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(0),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(1));
\GRFPU0_GRFPU_X0_COMB_LOB2_AXB_XX_MM_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccee44e4e4ee44")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LOB2.AXB\(1),
dataf => \GRFPU0.GRFPU_X0.L1_5_3\(3),
datae => \GRFPU0.GRFPU_X0.L1_4_3\(3),
datad => N_93295,
datac => N_93296,
datab => N_93106,
dataa => \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\);
\GRFPU0_GRFPU_X0_BCO_MSB_3_3_0_TZ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_3_TZ\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(18),
datae => \GRFPU0.GRFPU_X0.N_18307\,
datad => \GRFPU0.MULO.MRES\(120),
datac => \GRFPU0.MULO.DRES_1\(113),
datab => \GRFPU0.MULO.DRES_1S\(112));
\GRFPU0_GRFPU_X0_L1_5_1_3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ca")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_1_3\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(12),
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(11),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(13),
datac => \GRFPU0.MULO.MRES\(120),
datab => \GRFPU0.MULO.DRES_1\(111),
dataa => \GRFPU0.MULO.DRES_1S\(110));
GRFPU0_FPMUL0_R2_RET_153_RNIAB2M: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S\(101),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datae => N_28126,
datad => N_28125);
GRFPU0_FPMUL0_R2_RET_126_RNI1G2C: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(103),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datae => N_28185,
datad => N_28184);
GRFPU0_FPMUL0_R2_RET_152_RNIH72M: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S\(102),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datae => N_28128,
datad => N_28127);
\GRFPU0_GRFPU_X0_L1_4_1_3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00ca")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_1_3\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(3),
datae => \GRFPU0.GRFPU_X0.N_18314\,
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(5),
datac => \GRFPU0.MULO.MRES\(120),
datab => \GRFPU0.MULO.DRES_1\(103),
dataa => \GRFPU0.MULO.DRES_1S\(102));
\GRFPU0_GRFPU_X0_L1_4_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33103310ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_4\(0),
dataf => \GRFPU0.GRFPU_X0.UN123_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.L1_4_1_3\(0),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(8),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(10),
datab => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(7),
dataa => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(9));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"44f044f0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_2\(0),
dataf => \GRFPU0.GRFPU_X0.L1_4_3\(3),
datae => \GRFPU0.GRFPU_X0.L1_4_4\(0),
datad => \GRFPU0.GRFPU_X0.UN128_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.L1_5_1_3\(0),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_3_3_TZ\(0),
dataa => \GRFPU0.GRFPU_X0.N_18315\);
\GRFPU0_GRFPU_X0_L1_6_1_3_A4_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000030303030")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6_1_3_A4_0_0\(0),
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.DRES_1\(119),
datad => \GRFPU0.MULO.DRES_1\(118),
datac => \GRFPU0.MULO.DRES_1S\(118),
datab => \GRFPU0.MULO.DRES_1S\(117));
\GRFPU0_GRFPU_X0_L1_6_1_3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff333300f02222")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6_1_3\(0),
dataf => \GRFPU0.GRFPU_X0.L1_6_1_3_A4_0_0\(0),
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.MULO.DRES_1\(116),
datac => \GRFPU0.MULO.DRES_1\(117),
datab => \GRFPU0.MULO.DRES_1S\(115),
dataa => \GRFPU0.MULO.DRES_1S\(116));
GRFPU0_FPMUL0_R2_RET_134_RNILEP9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ff0000ff")
port map (
combout => \GRFPU0.MULO.DRES_1\(97),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datae => \GRFPU0.FPMUL0.CS_DP_R\,
datad => \GRFPU0.FPMUL0.SX\(97),
datac => N_28173);
GRFPU0_FPMUL0_R2_RET_160_RNI1QOJ: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ff0000ff")
port map (
combout => \GRFPU0.MULO.DRES_1S\(96),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datae => \GRFPU0.FPMUL0.CS_DP_R\,
datad => \GRFPU0.FPMUL0.SX\(96),
datac => N_28116);
GRFPU0_FPMUL0_R2_RET_131_RNIPN2C: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(98),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datae => N_28175,
datad => N_28174);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(1),
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.DRES_1\(98),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datac => N_28118,
datab => N_28117);
\GRFPU0_GRFPU_X0_COMB_LOB2_ALTB_XX_MM_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"2202020222a2a2a2")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_2\(0),
datae => \GRFPU0.GRFPU_X0.L1_5_3\(3),
datad => \GRFPU0.GRFPU_X0.L1_4_3\(3),
datac => \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\,
datab => N_93124,
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(0));
GRFPU0_FPMUL0_R2_RET_110_RNI320F: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(119),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datae => N_28217,
datad => N_28216);
GRFPU0_FPMUL0_R2_RET_136_RNINDVO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S\(118),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datae => N_28160,
datad => N_28159);
\GRFPU0_GRFPU_X0_L1_6_1_3_I_A4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff03030303")
port map (
combout => \GRFPU0.GRFPU_X0.UN133_BCO_LSB_2\(15),
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.DRES_1\(119),
datad => \GRFPU0.MULO.DRES_1\(118),
datac => \GRFPU0.MULO.DRES_1S\(117),
datab => \GRFPU0.MULO.DRES_1S\(118));
GRFPU0_FPMUL0_R2_RET_112_RNI720F: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(117),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datae => N_28213,
datad => N_28212);
GRFPU0_FPMUL0_R2_RET_138_RNIGR1M: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S\(116),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datae => N_28156,
datad => N_28155);
GRFPU0_FPMUL0_R2_RET_113_RNI920F: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(116),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datae => N_28211,
datad => N_28210);
GRFPU0_FPMUL0_R2_RET_139_RNIIR1M: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S\(115),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datae => N_28154,
datad => N_28153);
\GRFPU0_GRFPU_X0_L1_6_1_3_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00fcfcfcfc")
port map (
combout => \GRFPU0.GRFPU_X0.N_13885_1\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.DRES_1\(116),
datad => \GRFPU0.MULO.DRES_1\(117),
datac => \GRFPU0.MULO.DRES_1S\(115),
datab => \GRFPU0.MULO.DRES_1S\(116));
\GRFPU0_GRFPU_X0_COMB_LOB2_AXB_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"95559595a565a5a5")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LOB2.AXB\(2),
dataf => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_2\(2),
datae => \GRFPU0.GRFPU_X0.UN133_BCO_LSB_2\(15),
datad => \GRFPU0.GRFPU_X0.N_13885_1\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(2));
\GRFPU0_GRFPU_X0_COMB_LOB2_ALTB_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccffccf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB\(2),
dataf => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB\(0),
datae => \GRFPU0.GRFPU_X0.COMB.LOB2.AXB\(1),
datad => \GRFPU0.GRFPU_X0.COMB.LOB2.AXB\(2),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(2));
GRFPU0_FPMUL0_R2_RET_116_RNIF20F: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(113),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datae => N_28205,
datad => N_28204);
GRFPU0_FPMUL0_R2_RET_142_RNIFV1M: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S\(112),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datae => N_28148,
datad => N_28147);
GRFPU0_FPMUL0_R2_RET_117_RNIH20F: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(112),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datae => N_28203,
datad => N_28202);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_I_M2_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.N_18315\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.DRES_1\(112),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datac => N_28146,
datab => N_28145);
GRFPU0_FPMUL0_R2_RET_114_RNIB20F: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(115),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datae => N_28209,
datad => N_28208);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(18),
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.DRES_1\(115),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datac => N_28152,
datab => N_28151);
GRFPU0_FPMUL0_R2_RET_141_RNIDV1M: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S\(113),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datae => N_28150,
datad => N_28149);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_I_I_M2_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18307\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.DRES_1S\(113),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datac => N_28207,
datab => N_28206);
\GRFPU0_GRFPU_X0_COMB_LOB2_ALTB_D_0_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"80f8e0f8e0f8e0f8")
port map (
combout => N_93109,
dataf => \GRFPU0.GRFPU_X0.L1_5_3\(3),
datae => \GRFPU0.GRFPU_X0.L1_4_3\(3),
datad => \GRFPU0.GRFPU_X0.UN1_QP1_SP_4\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(3));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNIH51I1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0fffff0fff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.LOB2_I_M_1_I_0_0\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.MRES\(96),
datad => \GRFPU0.MULO.MRES\(95),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(6));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_I_A2_3_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"a0a0a0808080a080")
port map (
combout => \GRFPU0.GRFPU_X0.N_18371\,
dataf => \GRFPU0.GRFPU_X0.COMB.LOB2.ALTB\(2),
datae => N_93108,
datad => N_93109,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_A2_6_1\(41),
datab => \GRFPU0.GRFPU_X0.COMB.LOB2_I_M_1_I_0_0\,
dataa => \GRFPU0.MULO.MRES\(113));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18854_I\,
dataf => \GRFPU0.GRFPU_X0.N_18868\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datad => \FPI.OP2\(49),
datac => \FPI.OP2\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_I_M2_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccfff00f00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18326\,
dataf => \GRFPU0.GRFPU_X0.N_128\,
datae => \GRFPU0.SQRTROM0.DATA_1_1\(2),
datad => \GRFPU0.SQRTROM0.DATA_1_0\(2),
datac => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(54));
GRFPU0_FPMUL0_R2_RET_88_RNIDT2V: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(115),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(115),
datad => N_28095);
\GRFPC0_OP2_3_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19613\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(51),
datad => \GRFPC0.WR.RREG.RES\(51));
\GRFPC0_OP2_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(51),
dataf => \GRFPC0.N_19744\,
datae => \GRFPC0.N_19678\,
datad => N_99880,
datac => \GRFPC0.N_19613\,
datab => \GRFPC0.RFA2.RS2SEL\(7));
\GRFPC0_WR_RREG_RES_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fffff0f0f0f0")
port map (
combout => N_47245,
dataf => N_99846,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_32_3068_I_A3_0_0_0\,
datad => N_99904_2,
datac => \GRFPC0.MEM.RREG.RES\(8),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(8));
\GRFPC0_MEM_RREG_RES_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fffff0f0f0f0")
port map (
combout => N_47203,
dataf => N_99847,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_32_3068_I_A3_0_0_0\,
datad => N_99904_1,
datac => \GRFPC0.EX.RREG.RES\(8),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0f3f0f3f0f3f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(21),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(21),
datad => \GRFPU0.GRFPU_X0.N_18663\,
datac => \GRFPU0.GRFPU_X0.N_19681\,
datab => \GRFPU0.MULO.MRES\(81));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_RNO_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(21),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(81),
datac => \GRFPU0.MULO.DRES_1\(81));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(21),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(21),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(21),
datad => N_99921,
datac => \GRFPU0.MULO.MRES\(82));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(21),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(80),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(81),
datab => \GRFPU0.MULO.DRES_1\(81),
dataa => \GRFPU0.MULO.DRES_1S\(80));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf0fffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(21),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(21),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(21),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_18664\,
datab => \GRFPU0.MULO.MRES\(81));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(21),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(21),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(39),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(39));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_S_0_TZ_1_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff3fff00ff33ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_S_0_TZ_1\(20),
dataf => N_99921,
datae => \GRFPU0.GRFPU_X0.N_18663\,
datad => \GRFPU0.GRFPU_X0.N_19681\,
datac => \GRFPU0.MULO.MRES\(81),
datab => \GRFPU0.MULO.MRES\(80));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(20),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(79),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(80),
datab => \GRFPU0.MULO.DRES_1\(80),
dataa => \GRFPU0.MULO.DRES_1S\(79));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_S_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00f3ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(20),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(20),
datae => \GRFPU0.GRFPU_X0.N_18674\,
datad => \GRFPU0.GRFPU_X0.N_18527\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_0_S_0_TZ\(20),
datab => \GRFPU0.GRFPU_X0.N_18664\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(20),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(20),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(20));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0f3f0f3f0f3f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(17),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(17),
datad => \GRFPU0.GRFPU_X0.N_18663\,
datac => \GRFPU0.GRFPU_X0.N_19681\,
datab => \GRFPU0.MULO.MRES\(77));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_RNO_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(17),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(77),
datac => \GRFPU0.MULO.DRES_1\(77));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(17),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(17),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(17),
datad => N_99921,
datac => \GRFPU0.MULO.MRES\(78));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(17),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(76),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(77),
datab => \GRFPU0.MULO.DRES_1\(77),
dataa => \GRFPU0.MULO.DRES_1S\(76));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf0fffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(17),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(17),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(17),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_18664\,
datab => \GRFPU0.MULO.MRES\(77));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(17),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(17),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(43),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(43));
GRFPU0_FPMUL0_R2_RET_96_RNIBP2V: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(107),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(107),
datad => N_28079);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16767\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(107),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(39));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(47),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16767\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(47));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_37_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccaaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(58),
dataf => \GRFPU0.GRFPU_X0.COMB.UN59_RNDOP\,
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.MULO.MRES\(117),
datac => \GRFPU0.MULO.MRES\(118),
datab => \GRFPU0.MULO.DRES_1\(118),
dataa => \GRFPU0.MULO.DRES_1S\(117));
\GRFPU0_DIVROM0_DATA_1_MUX_3_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff000000ff")
port map (
combout => \GRFPU0.DIVAPPR\(6),
dataf => \GRFPU0.DIVROM0.DATA_1_1\(6),
datae => \GRFPU0.DIVROM0.RADDR\(6),
datad => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_0_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0f0f00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(58),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(118),
datac => \GRFPU0.MULO.DRES_1\(118));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_RNO_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0c000c000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(58),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(118),
datad => \GRFPU0.MULO.DRES_1\(118),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
GRFPU0_FPMUL0_R2_RET_137_RNIER1M: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S\(117),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datae => N_28158,
datad => N_28157);
GRFPU0_FPMUL0_R2_RET_111_RNI520F: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(118),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datae => N_28215,
datad => N_28214);
GRFPU0_FPMUL0_R2_RET_85_RNIDT2V: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(118),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(118),
datad => N_28101);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(58),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(117),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(118),
datab => \GRFPU0.MULO.DRES_1\(118),
dataa => \GRFPU0.MULO.DRES_1S\(117));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff0fffffff3")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(58),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(58),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_I_M\(58),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_2\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_I_M\(58),
datab => \GRFPU0.GRFPU_X0.N_18664\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_7_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(58),
dataf => \GRFPU0.GRFPU_X0.N_128\,
datae => \GRFPU0.SQRTROM0.DATA_1_1\(6),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datac => \GRFPU0.DIVROM0.RADDR\(7));
\GRFPC0_OP2_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(52),
dataf => \GRFPC0.N_19745\,
datae => \GRFPC0.N_19679\,
datad => N_99880,
datac => \GRFPC0.N_19614\,
datab => \GRFPC0.RFA2.RS2SEL\(7));
\GRFPC0_OP2_3_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19614\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(52),
datad => \GRFPC0.WR.RREG.RES\(52));
\GRFPC0_OP1_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(33),
dataf => \GRFPC0.N_20221\,
datae => N_99877_1,
datad => \GRFPC0.N_20155\,
datac => \GRFPC0.RFA2.RS1SEL_0\(7),
datab => \GRFPC0.N_20090\);
\GRFPC0_OP1_3_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20090\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(33),
datad => \GRFPC0.WR.RREG.RES\(33));
GRFPU0_FPMUL0_R2_RET_99_RNIBP2V: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(104),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(104),
datad => N_28073);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16764\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(104),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(36));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(44),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16764\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(2),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(2),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNIP5TF2_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00030303")
port map (
combout => \GRFPU0.GRFPU_X0.N_6\,
dataf => \GRFPU0.GRFPU_X0.N_5673_0\,
datae => \GRFPU0.GRFPU_X0.ITER.V\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(14));
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000cc00ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_10067\,
dataf => \GRFPU0.GRFPU_X0.N_18448\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.N_18440_I_0\,
datac => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datab => \GRFPU0.GRFPU_X0.ST3.EXC\(3));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_I_M2_0_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_104\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(97),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_I_M2_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18337\,
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_104\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(37),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(37));
\GRFPU0_GRFPU_X0_ITER_TZR_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff00ff000ffff00")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_3__N_4_I\,
dataf => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__G4\,
datae => \GRFPU0.GRFPU_X0.L4_6\(2),
datad => \GRFPU0.GRFPU_X0.L4_6\(3),
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\);
GRFPU0_GRFPU_X0_ITER_ODDEXP_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_53557,
dataf => \GRFPU0.GRFPU_X0.N_128\,
datae => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datad => \GRFPU0.GRFPU_X0.ST1.EXP2\(0));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNI9DSV1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf0c000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.INF_3_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.N_3407\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNIT4BM1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf0c000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4245\,
dataf => \GRFPU0.GRFPU_X0.N_5250\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17012\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(28),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(87),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(27));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_20__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16418\,
datab => \GRFPU0.GRFPU_X0.N_16483\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16418\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(20));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000333c333c")
port map (
combout => \GRFPU0.GRFPU_X0.N_18237\,
dataf => \GRFPU0.GRFPU_X0.N_18408\,
datae => \GRFPU0.GRFPU_X0.C\(10),
datad => N_32483,
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(9),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(10));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M33_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(33),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M81_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M32_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(32),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M80_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_15\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(35),
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(34),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(38),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(27));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_19\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_15\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(37),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(36),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(31),
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(29));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_33\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_19\,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_20\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(47),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(43),
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(50),
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(48));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_34\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_33\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(41),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(39),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(42),
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(40));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_36: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff33fcfcfc30")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_TZ_3\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M64_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M46_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_35: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff33fcfcfc30")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_TZ_2\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M65_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_34: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcfcff33fc30")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_TZ_1\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_37: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_TZ_0\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M45_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M43_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_TZ_9\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_TZ_1\,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_TZ_2\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_TZ_3\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_TZ_0\);
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_19: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_TZ_5\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M42_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M39_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_TZ_4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M41_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M40_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0f0f000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_TZ_9\,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_TZ_5\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_TZ_4\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_23: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_16_TZ_1\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff33fcfcfc30")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_16_TZ_0\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M44_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_25: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_4_TZ\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_38: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccc0c0ccccc000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_1\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0f0f000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_3\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_1\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_13\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(25),
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(23),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(26),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(24));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffaaa8")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_18\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_13\,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_3\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_16_TZ_1\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_16_TZ_0\,
datab => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_4_TZ\,
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_0\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32\,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_18\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(49),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(45),
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(44),
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(51));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_26: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_23\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(47),
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(43),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(48),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(50));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_27\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_23\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(49),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(46),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(45),
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(44));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_29\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_27\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(41),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(39),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(42),
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(40));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_12_TZ_1\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M45_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M43_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0c0c0c000")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_12\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_12_TZ_1\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M30_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(30),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M78_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M46_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M28_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(28),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M76_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M44_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M35_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(35),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M83_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M34_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(34),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M82_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M32_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(32),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M80_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M45_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000f00f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M45_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M29_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(29),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M77_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M45_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M26_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(26),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M74_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M42_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M23_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(23),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M71_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M39_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M25_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(25),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M73_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M41_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M24_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(24),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M72_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M40_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_8\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(25),
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(24),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(26),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(23));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_13\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_8\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(35),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(34),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(32),
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(29));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_40: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ_6\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_39: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfcfcfcfcf0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ_2\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M50_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_29: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff3c0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ_10\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ_2\,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ_6\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M50_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M66_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M48_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M46_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M46_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M58_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_31: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff33fcfcfc30")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ_5\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M48_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M62_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M64_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M46_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_32: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff33fcfcfc30")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ_4\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_30: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ_8\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M39_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M44_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M44_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M56_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M41_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M41_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_33: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc3330")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ_7\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M60_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M44_2_03\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M41_2_03\,
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_13: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ_10\,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ_8\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ_5\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ_4\,
datab => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ_7\);
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M37_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(37),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M85_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M69_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M36_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(36),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M84_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M68_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M42_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M42_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M52_0_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M40_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M40_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M52_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M53_0_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M49_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M53_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M61_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M57_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M33_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(33),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M49_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M81_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M65_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M43_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M43_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M27_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(27),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M75_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M43_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M38_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(38),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M54_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M86_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M70_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M51_0_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M47_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M59_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M55_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M51_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M31_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(31),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M79_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M63_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M47_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(4));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_11\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(38),
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(33),
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(31),
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(27));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffefefffffefc")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_22\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_31_TZ\,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_11\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_2_TZ\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(36),
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(37),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(5));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_28\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_22\,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_13\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_12\,
datac => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(51),
datab => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(30),
dataa => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(28));
GRFPU0_GRFPU_X0_ST2_STICKY_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffefeffddfedc")
port map (
combout => \GRFPU0.GRFPU_X0.N_10039\,
dataf => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_34\,
datae => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_28\,
datad => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G3_32_0\,
datac => \GRFPU0.GRFPU_X0.ST2.STICKY_0_0_G2_29\,
datab => \GRFPU0.GRFPU_X0.COMB.SHV2_0\,
dataa => \GRFPU0.GRFPU_X0.C\(11));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_O3_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0fffffff3f")
port map (
combout => \GRFPU0.GRFPU_X0.N_18241\,
dataf => \GRFPU0.GRFPU_X0.N_4260\,
datae => \GRFPU0.GRFPU_X0.N_18216\,
datad => \GRFPU0.GRFPU_X0.N_18219\,
datac => \GRFPU0.GRFPU_X0.C\(11),
datab => \GRFPU0.GRFPU_X0.N_18220\);
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18252\,
dataf => \GRFPU0.GRFPU_X0.C\(10),
datae => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(10));
GRFPU0_GRFPU_X0_COMB_UN55_BLSBLTO4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0fff0fffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN55_BLSBLT5\,
dataf => \GRFPU0.GRFPU_X0.L4_3\(4),
datae => \GRFPU0.GRFPU_X0.L4_3\(2),
datad => \GRFPU0.GRFPU_X0.L4_3_I\(1),
datac => \GRFPU0.GRFPU_X0.L4_3\(3));
GRFPU0_GRFPU_X0_COMB_VITER_LOB2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.LOB2_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(6),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(7));
GRFPU0_GRFPU_X0_COMB_VITER_LOB2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f8fefcfff0fcf8fe")
port map (
combout => \GRFPU0.GRFPU_X0.N_6149\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_L4.ALTB\(3),
datae => \GRFPU0.GRFPU_X0.L4_3\(4),
datad => \GRFPU0.GRFPU_X0.L3_0\(5),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.LOB2_0\,
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(4));
GRFPU0_GRFPU_X0_VALLOW_1_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_5511\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(10));
\GRFPU0_GRFPU_X0_COMB_RMND_13_1_0__M3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff033cc0ff0c33c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.RMND_13\(0),
dataf => \GRFPU0.MULO.MRES\(68),
datae => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datad => \GRFPU0.MULO.MRES\(69),
datac => \GRFPU0.GRFPU_X0.ITER.BMLSB\(0),
datab => \GRFPU0.GRFPU_X0.ITER.BMLSB\(1));
\GRFPU0_GRFPU_X0_COMB_RNDM_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.RNDM_1\(0),
dataf => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(8));
GRFPU0_GRFPU_X0_COMB_VST3_EMAX_1_0_A2_7_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1_0_A2_7_3\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(52));
GRFPU0_GRFPU_X0_COMB_VST3_EMAX_1_0_A2_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1_0_A2_7_3\,
datae => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LTO9_3\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(62),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(58));
GRFPU0_GRFPU_X0_COMB_VST3_EMIN_1_0_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0000003c000c000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18419\,
dataf => \GRFPU0.GRFPU_X0.N_19694\,
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(59));
GRFPU0_GRFPU_X0_COMB_OP_GT_VST3_EXC40LT9_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40LTO9_1\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(58));
GRFPU0_GRFPU_X0_COMB_OP_GT_VST3_EXC40LTO10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333333333333330")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\,
dataf => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40LTO9_1\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(59),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(62));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0fccccf000cccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16990\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(5),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(5),
datac => \GRFPU0.GRFPU_X0.N_4\,
datab => \GRFPU0.MULO.MRES\(65));
GRFPU0_GRFPU_X0_VITER_FLUSH0_0_SQMUXA_1_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4438\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00000fff0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(0),
dataf => \GRFPU0.GRFPU_X0.N_18663\,
datae => N_99921,
datad => \GRFPU0.MULO.MRES\(61),
datac => \GRFPU0.MULO.MRES\(60));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_26_IV_0_A2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3f3f003f003f00")
port map (
combout => \GRFPC0.N_21393\,
dataf => \GRFPC0.N_21634\,
datae => \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_A2_3_1\,
datad => \GRFPC0.FP_PIPELINE.0.STDDEP_26_IV_0_O2_3\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP\,
datab => \GRFPC0.EX.CTRL.RDWR\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33cc33cc0f0ff0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_15120\,
dataf => \GRFPU0.GRFPU_X0.N_4401\,
datae => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datac => \GRFPU0.FPMUL0.SX\(94),
datab => \GRFPU0.FPMUL0.SX\(93));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fcfc0c0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(34),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(93),
datad => \GRFPU0.GRFPU_X0.N_15120\,
datac => \GRFPU0.GRFPU_X0.N_4401\,
datab => \GRFPU0.MULO.MRES\(94));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3fffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(34),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(34),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(34),
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(34),
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(34),
datab => \GRFPU0.GRFPU_X0.N_18664\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc30fffffc300000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(34),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(34),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.UN177_RNDOP\(26),
datac => \GRFPU0.GRFPU_X0.UN166_RNDOP\(26),
datab => \GRFPU0.GRFPU_X0.N_11529\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(34),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(34),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(34));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_RNO_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33cc3c3c00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(34),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datac => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datab => \GRFPU0.FPMUL0.SX\(94));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(60),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(60),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff3fff00ff33ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(4),
dataf => N_99921,
datae => \GRFPU0.GRFPU_X0.N_18663\,
datad => \GRFPU0.GRFPU_X0.N_19681\,
datac => \GRFPU0.MULO.MRES\(65),
datab => \GRFPU0.MULO.MRES\(64));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(4),
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(4));
GRFPU0_GRFPU_X0_UN1_VALLOW_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_18663\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(16),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(19));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_A2_0_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000003330000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_0_1\,
dataf => \GRFPU0.GRFPU_X0.UN1_INC_DP_S\(0),
datae => \GRFPU0.GRFPU_X0.N_9402\,
datad => \GRFPU0.GRFPU_X0.UN1_INC_DP\(0),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_11_0_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcffccffcc")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_2\,
dataf => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_A2_0_1\,
datae => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2S2_I_A2_1_1\,
datad => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_0\,
datac => \GRFPU0.GRFPU_X0.N_18662\,
datab => \GRFPU0.GRFPU_X0.N_18633\);
GRFPU0_GRFPU_X0_COMB_INCX_1_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1d0c3fff000022f3")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1_M0\,
datae => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_11_0_2\,
datad => \GRFPU0.GRFPU_X0.N_18629_2\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
dataa => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_9_0_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c030000000000000")
port map (
combout => N_60915,
dataf => \GRFPU0.GRFPU_X0.NXX_2\,
datae => \GRFPU0.GRFPU_X0.N_9402\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datac => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0));
GRFPU0_GRFPU_X0_UN1_INC_2_SQMUXA_9_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000300")
port map (
combout => \GRFPU0.GRFPU_X0.N_13465\,
dataf => N_60915,
datae => \GRFPU0.GRFPU_X0.N_18635\,
datad => \GRFPU0.MULO.MRES\(96),
datac => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0));
GRFPU0_GRFPU_X0_UN1_INC_0_SQMUXA_0_M4_0_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18611\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datae => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datad => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0));
GRFPU0_GRFPU_X0_UN1_INC_0_SQMUXA_0_M4_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000fffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18638\,
dataf => \GRFPU0.GRFPU_X0.N_18662\,
datae => \GRFPU0.MULO.MRES\(97),
datad => \GRFPU0.MULO.MRES\(98),
datac => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1));
GRFPU0_GRFPU_X0_COMB_INCX_1_M0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff0300000003")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.INCX_1_M0\,
dataf => \GRFPU0.GRFPU_X0.N_13465\,
datae => \GRFPU0.GRFPU_X0.N_18638\,
datad => \GRFPU0.GRFPU_X0.UN1_INC_2_SQMUXA_5\,
datac => \GRFPU0.GRFPU_X0.N_18611\,
datab => \GRFPU0.GRFPU_X0.N_18637\);
\GRFPU0_GRFPU_X0_UN1_INC_DP_S_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_DP_S\(0),
dataf => \GRFPU0.GRFPU_X0.NXX_1\,
datae => \GRFPU0.MULO.MRES\(68),
datad => \GRFPU0.MULO.MRES\(69));
\GRFPU0_GRFPU_X0_UN1_INC_DP_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff00fc00")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_DP\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_4\,
datae => \GRFPU0.GRFPU_X0.NXX_1_48\,
datad => \GRFPU0.MULO.MRES\(67),
datac => \GRFPU0.MULO.MRES\(68),
datab => \GRFPU0.MULO.MRES\(66));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff00ff0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15794\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES\(68),
datad => \GRFPU0.FPMUL0.CS_DP_R\,
datac => \GRFPU0.MULO.MRES_1S\(68));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0fccccf000cccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16987\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(2),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(2),
datac => \GRFPU0.GRFPU_X0.N_4\,
datab => \GRFPU0.MULO.MRES\(62));
GRFPU0_GRFPU_X0_COMB_INCX_1_M2S2_I_A2_1_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff3fcfffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.INCX_1_M2S2_I_A2_1_1\,
dataf => \GRFPU0.GRFPU_X0.N_9402\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(63),
datac => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0fff00000f0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(5),
dataf => N_99921,
datae => \GRFPU0.GRFPU_X0.N_18663\,
datad => \GRFPU0.MULO.MRES\(66),
datac => \GRFPU0.MULO.MRES\(65));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(5),
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(5));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0fff00000f0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(1),
dataf => N_99921,
datae => \GRFPU0.GRFPU_X0.N_18663\,
datad => \GRFPU0.MULO.MRES\(62),
datac => \GRFPU0.MULO.MRES\(61));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(1));
GRFPU0_GRFPU_X0_COMB_VST3_EMIN_1_0_O2_0_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19694\,
dataf => \GRFPU0.GRFPU_X0.N_19691\,
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(1));
\GRFPU0_GRFPU_X0_BIAS_4_0_1_A2_0_X2_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_162_I\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(7));
GRFPU0_GRFPU_X0_COMB_VCS_DP_1_I_0_I_O2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19705\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datae => \GRFPU0.GRFPU_X0.ST2.V\);
GRFPU0_GRFPU_X0_COMB_VST3_REG59_2_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6798\,
dataf => \GRFPU0.GRFPU_X0.N_335\,
datae => \GRFPU0.GRFPU_X0.N_5777_I_I_O2_I_O2_2_0_0\,
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(6));
GRFPU0_GRFPU_X0_COMB_VST3_RDY41: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_5791\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(4));
GRFPU0_GRFPU_X0_COMB_OP_LT_VST3_REG84LT9_3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fffffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LT9_3\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(57),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(59),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(58));
GRFPU0_GRFPU_X0_COMB_OP_LT_VST3_REG84LTO10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccccccccccccc0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
dataf => N_32260,
datae => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LTO9_3\,
datad => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LT9_3\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(62));
GRFPU0_GRFPU_X0_COMB_OP_LT_VST3_REG84LT9_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84LTO9_3\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(54),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_3__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M11_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_1_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19019\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M11_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fffcff00ffcc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_3__G1\,
dataf => \GRFPU0.GRFPU_X0.N_19016\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datad => \GRFPU0.GRFPU_X0.N_19019\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(32),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(29));
GRFPU0_GRFPU_X0_COMB_VST3_EXC51_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_1_2\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(4));
GRFPU0_GRFPU_X0_COMB_VST3_EXC51_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_3_2\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(4));
GRFPU0_GRFPU_X0_UN1_VST3_EXC52: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0fffffff0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_5757\,
dataf => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\,
datae => \GRFPU0.GRFPU_X0.N_5820\,
datad => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
datac => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(7));
GRFPU0_GRFPU_X0_COMB_VST3_RDY8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_5773\,
dataf => \GRFPU0.GRFPU_X0.ST2.EXPT\(0),
datae => \GRFPU0.GRFPU_X0.ST2.EXPT\(1));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_11\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(10),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(2));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_10\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(18));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_8\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(15),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(16));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_14: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_14\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_8\,
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(1),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(11));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_4\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(8));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_6_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_6_12\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(0));
GRFPU0_GRFPU_X0_COMB_VST3_REG59_0_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_16_0_A2_0_A2_1\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(0));
\GRFPU0_GRFPU_X0_ST2_FLOP_RNI1HR11_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPU0.GRFPU_X0.N_335\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(0));
GRFPU0_GRFPU_X0_COMB_VST3_REG59_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc000c00cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_5806\,
dataf => \GRFPU0.GRFPU_X0.N_335\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST2.FLOP_16_0_A2_0_A2_1\,
datad => \GRFPU0.GRFPU_X0.N_5777_I_I_O2_I_O2_2_0_0\,
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(6));
GRFPU0_GRFPU_X0_COMB_VST3_REG21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_5834\,
dataf => \GRFPU0.GRFPU_X0.N_5806\,
datae => \GRFPU0.GRFPU_X0.ST2.RDY\);
GRFPU0_GRFPU_X0_COMB_VST3_EXC19LTO10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccccccc0ccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19LT9\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(59),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(62));
GRFPU0_GRFPU_X0_COMB_VST3_EXC18LTO10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0f0f0f0f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.EXC18\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(61),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(60),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(59),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(62));
GRFPU0_GRFPU_X0_COMB_VST3_EXC18LTO10_RNIT09G3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00cc0cffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_5756_1\,
dataf => \GRFPU0.GRFPU_X0.N_5768\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.EXC19\,
datad => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__I3_I_3\,
datac => \GRFPU0.GRFPU_X0.COMB.VST3.EXC18\,
datab => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffcc00ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_22__G1\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_37\(51),
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_3\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(48),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(51));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_1_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f300f0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19055\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_2_01\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M23_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(55));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_3_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(4),
dataf => \GRFPU0.GRFPU_X0.L1_4_5\(3),
datae => \GRFPU0.GRFPU_X0.L1_5_2_0\(3),
datad => \GRFPU0.GRFPU_X0.UN63_BCO_LSB\(15));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f033fffff033")
port map (
combout => \GRFPU0.GRFPU_X0.N_15649\,
dataf => \GRFPU0.GRFPU_X0.N_18444\,
datae => \GRFPU0.GRFPU_X0.N_15611\,
datad => \GRFPU0.GRFPU_X0.N_14\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(36),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f033fffff033")
port map (
combout => \GRFPU0.GRFPU_X0.N_15646\,
dataf => \GRFPU0.GRFPU_X0.N_18444\,
datae => \GRFPU0.GRFPU_X0.N_15611\,
datad => \GRFPU0.GRFPU_X0.N_14\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(33),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_RNO_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc00000ffc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(33),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(4),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.N_18487\,
datac => \GRFPU0.GRFPU_X0.N_73\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(33));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_RNO_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc00000ffc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(36),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(7),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.N_18481_1\,
datac => \GRFPU0.GRFPU_X0.N_73\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(36));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f3333f0003333")
port map (
combout => \GRFPU0.GRFPU_X0.N_15548\,
dataf => \GRFPU0.GRFPU_X0.N_16071\,
datae => \GRFPU0.GRFPU_X0.N_14\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(58),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_EXP_11_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3cccffff3ccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.EXP_11\(6),
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(7),
datae => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA\,
datad => N_32654,
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(6));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_0_O2_2_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000000ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18195\,
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_22\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_3\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_1\,
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
GRFPU0_GRFPU_X0_COMB_VST4_REG17_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_1\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(5));
GRFPU0_GRFPU_X0_COMB_VST4_REG17_1_RNIDUIB1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccfcffffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
dataf => \GRFPU0.GRFPU_X0.N_6833\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_3\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_1\,
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST3.RDY\);
GRFPU0_GRFPU_X0_COMB_UN1_FLOP4_10_0_A3_0_RNI20T22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33f0000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18477\,
dataf => \GRFPU0.GRFPU_X0.N_18515\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_10_0_A3_0\,
datad => \GRFPU0.GRFPU_X0.N_18449\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(6));
\GRFPU0_GRFPU_X0_COMB_UN21_FLUSH_ALTB_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3f0f033f0f0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH.ALTB\(2),
datae => \FPI.FLUSHID\(4),
datad => \FPI.FLUSHID\(3),
datac => \GRFPU0.GRFPU_X0.ST1.ID\(4),
datab => \GRFPU0.GRFPU_X0.ST1.ID\(3));
\GRFPU0_GRFPU_X0_ST1_IDCST_RNIJDGS3_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00fffff0ff0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19671\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN21_FLUSH\,
datae => \FPI.FLUSH\,
datad => \FPI.FLUSHID\(5),
datac => \GRFPU0.GRFPU_X0.ST1.ID\(5));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M31_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(31),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M79_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M63_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M29_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(29),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M77_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M45_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M27_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(27),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M75_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M43_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M23_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(23),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M71_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M39_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M36_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(36),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M84_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M68_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M38_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(38),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M86_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M70_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M25_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(25),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M73_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M41_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M24_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(24),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M72_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M40_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M26_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(26),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M74_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M42_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M28_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(28),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M76_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M44_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M46_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M46_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M50_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M62_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M58_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M34_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(34),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M50_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M82_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M66_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M37_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(37),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M85_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M69_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M35_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(35),
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_2_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M83_2_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M67_2_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(5),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(4));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M47_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M47_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M59_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M45_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000f00f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M45_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M51_0_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M43_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M43_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M55_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M51_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M49_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M49_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M61_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M57_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M53_0_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccf0f0ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M41_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M41_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M53_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M48_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M48_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M60_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M40_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M40_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M42_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M42_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M54_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M52_0_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(0),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(1));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M44_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M44_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M56_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M52_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16430\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_16114\,
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(29),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(29),
datad => \GRFPU0.GRFPU_X0.N_11529\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_M\(91),
dataf => \GRFPU0.GRFPU_X0.N_3560_I\,
datae => \GRFPU0.MULO.MRES\(91));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_RNO_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7_M\(31),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_RNO_0_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(31),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(91),
datac => \GRFPU0.MULO.DRES_1\(91));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(31),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(31),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_0_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16099\,
dataf => \GRFPU0.GRFPU_X0.N_11529\,
datae => \GRFPU0.GRFPU_X0.UN177_RNDOP\(44),
datad => \GRFPU0.GRFPU_X0.UN166_RNDOP\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ff00ff00ff00ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(16),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => \GRFPU0.GRFPU_X0.N_19681\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0f3f0033")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(16),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(16),
datae => N_99921,
datad => \GRFPU0.GRFPU_X0.N_18663\,
datac => \GRFPU0.MULO.MRES\(77),
datab => \GRFPU0.MULO.MRES\(76));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(16),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(16),
datae => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datad => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datac => \GRFPU0.MULO.MRES\(76),
datab => \GRFPU0.MULO.DRES_1\(76));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(16),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(75),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(76),
datab => \GRFPU0.MULO.DRES_1\(76),
dataa => \GRFPU0.MULO.DRES_1S\(75));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(16),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(16),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_RNO_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.MULO_M\(76),
dataf => \GRFPU0.GRFPU_X0.N_3560_I\,
datae => \GRFPU0.MULO.MRES\(76));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_I_M2_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18685\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(90),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(91),
datab => \GRFPU0.MULO.DRES_1\(91),
dataa => \GRFPU0.MULO.DRES_1S\(90));
\GRFPC0_OP2_3_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19616\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(54),
datad => \GRFPC0.WR.RREG.RES\(54));
\GRFPC0_OP2_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(54),
dataf => \GRFPC0.N_19747\,
datae => \GRFPC0.N_19681\,
datad => N_99880,
datac => \GRFPC0.N_19616\,
datab => \GRFPC0.RFA2.RS2SEL\(7));
\GRFPC0_OP2_3_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19615\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(53),
datad => \GRFPC0.WR.RREG.RES\(53));
\GRFPC0_OP2_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(53),
dataf => \GRFPC0.N_19746\,
datae => \GRFPC0.N_19680\,
datad => N_99880,
datac => \GRFPC0.N_19615\,
datab => \GRFPC0.RFA2.RS2SEL\(7));
\GRFPU0_GRFPU_X0_S3ADDI_0_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_14516\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(30),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(29));
GRFPU0_GRFPU_X0_S_SP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.S_SP\,
dataf => \GRFPU0.GRFPU_X0.S_SP_19\,
datae => \GRFPU0.GRFPU_X0.S_SP_13\,
datad => \GRFPU0.GRFPU_X0.S_SP_20\,
datac => \GRFPU0.GRFPU_X0.S_SP_22\,
datab => \GRFPU0.GRFPU_X0.S_SP_21\);
GRFPU0_GRFPU_X0_COMB_S_SP_1_1_U: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcfccc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.S_SP_1_1\,
dataf => \GRFPU0.GRFPU_X0.S_SP\,
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(30),
datab => \GRFPU0.GRFPU_X0.ST3.FARRES\(29));
GRFPU0_GRFPU_X0_COMB_UN9_G_DP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6039\,
dataf => \GRFPU0.GRFPU_X0.COMB.G_DP_1\,
datae => \GRFPU0.GRFPU_X0.COMB.S_DP_1_1\);
GRFPU0_GRFPU_X0_NXX_1_RNI8LUG: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_2\,
dataf => \GRFPU0.GRFPU_X0.NXX_1\,
datae => \GRFPU0.MULO.MRES\(68));
GRFPU0_FPMUL0_R2_RET_106_RNI5KNH: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(97),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(97),
datad => N_28059);
GRFPU0_GRFPU_X0_NXX_1_48_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_48_12\,
dataf => \GRFPU0.GRFPU_X0.NXX_1_48_9\,
datae => \GRFPU0.MULO.MRES\(56),
datad => \GRFPU0.MULO.MRES\(55),
datac => \GRFPU0.MULO.MRES\(53),
datab => \GRFPU0.MULO.MRES\(46));
GRFPU0_GRFPU_X0_NXX_1_48: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_48\,
dataf => \GRFPU0.GRFPU_X0.NXX_1_48_12\,
datae => \GRFPU0.GRFPU_X0.NXX_1_48_11\,
datad => \GRFPU0.MULO.MRES\(50),
datac => \GRFPU0.MULO.MRES\(59),
datab => \GRFPU0.MULO.MRES\(57));
GRFPU0_GRFPU_X0_COMB_ORV_TMP_7_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_3_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_25\,
datae => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_21\,
datad => \GRFPU0.MULO.MRES\(26),
datac => \GRFPU0.MULO.MRES\(25),
datab => \GRFPU0.MULO.MRES\(28),
dataa => \GRFPU0.MULO.MRES\(27));
GRFPU0_GRFPU_X0_NXX_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1\,
dataf => \GRFPU0.GRFPU_X0.NXX_1_48\,
datae => \GRFPU0.GRFPU_X0.NXX_1_3_0\,
datad => \GRFPU0.GRFPU_X0.NXX_1_3\,
datac => \GRFPU0.MULO.MRES\(67),
datab => \GRFPU0.MULO.MRES\(66));
\GRFPU0_GRFPU_X0_UN1_INC_SP_I_A2_0_13_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_13\(0),
dataf => \GRFPU0.MULO.MRES\(92),
datae => \GRFPU0.MULO.MRES\(91),
datad => \GRFPU0.MULO.MRES\(90),
datac => \GRFPU0.MULO.MRES\(89));
\GRFPU0_GRFPU_X0_UN1_INC_SP_I_A2_0_5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_5\(0),
dataf => \GRFPU0.MULO.MRES\(84),
datae => \GRFPU0.MULO.MRES\(78),
datad => \GRFPU0.MULO.MRES\(77));
\GRFPU0_GRFPU_X0_UN1_INC_SP_I_A2_0_10_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_10\(0),
dataf => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_5\(0),
datae => \GRFPU0.MULO.MRES\(88),
datad => \GRFPU0.MULO.MRES\(85),
datac => \GRFPU0.MULO.MRES\(80),
datab => \GRFPU0.MULO.MRES\(79));
\GRFPU0_GRFPU_X0_UN1_INC_SP_I_A2_0_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_4\(0),
dataf => \GRFPU0.MULO.MRES\(83),
datae => \GRFPU0.MULO.MRES\(76),
datad => \GRFPU0.MULO.MRES\(75),
datac => \GRFPU0.MULO.MRES\(74));
\GRFPU0_GRFPU_X0_UN1_INC_SP_I_A2_0_12_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_12\(0),
dataf => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_10\(0),
datae => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_4\(0),
datad => \GRFPU0.MULO.MRES\(86),
datac => \GRFPU0.MULO.MRES\(81),
datab => \GRFPU0.MULO.MRES\(82));
GRFPU0_GRFPU_X0_COMB_NXX_1_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f322f3ffc022c0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.NXX_1\,
dataf => \GRFPU0.GRFPU_X0.NXX_2\,
datae => \GRFPU0.GRFPU_X0.N_18662\,
datad => \GRFPU0.GRFPU_X0.N_9402\,
datac => \GRFPU0.GRFPU_X0.NXX_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
dataa => \GRFPU0.MULO.MRES\(97));
GRFPU0_GRFPU_X0_COMB_NXX_1_3_RNIMB4Q6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0c0f0c0c0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_18440_I_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.NXX_1\,
datae => \GRFPU0.GRFPU_X0.VST4.EXC_1_SQMUXA_I_O3_0\,
datad => \GRFPU0.GRFPU_X0.N_6053\,
datac => \GRFPU0.GRFPU_X0.N_18449\,
datab => \GRFPU0.GRFPU_X0.ST3.RDY\);
\GRFPU0_GRFPU_X0_COMB_VST4_EXC_11_IV_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0037003fc0f7c0ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.EXC_11_IV_0\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.IEXC_6\(0),
datae => \GRFPU0.GRFPU_X0.COMB.IEXC25_I\,
datad => \GRFPU0.GRFPU_X0.N_73\,
datac => \GRFPU0.GRFPU_X0.N_5505\,
datab => \GRFPU0.GRFPU_X0.ITER.V\,
dataa => \GRFPU0.GRFPU_X0.ITER.STATE\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_EXC_11_IV_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.EXC_11_IV\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.EXC_11_IV_0\(0),
datae => \GRFPU0.GRFPU_X0.N_18440_I_0\,
datad => \GRFPU0.GRFPU_X0.ST3.EXC\(0));
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fe00fa00fefffaff")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__G3\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.EXC_11_IV\(0),
datae => \GRFPU0.GRFPU_X0.UN6_SGNFX_CARRY_22\,
datad => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1\,
datab => \GRFPU0.GRFPU_X0.ST3.EMAX\,
dataa => \GRFPU0.GRFPU_X0.ST3.REG\(28));
\GRFPU0_GRFPU_X0_ST4_EXC_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fffc000000fc")
port map (
combout => \GRFPU0.GRFPU_X0.N_10064\,
dataf => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__G3\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.REG_2\,
datad => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(19),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(18));
GRFPU0_GRFPU_X0_COMB_VST4_REG30_RNI2T0F: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.ST4.EXC_0_0_0__N_5\,
dataf => \GRFPU0.GRFPU_X0.N_5661\,
datae => \GRFPU0.GRFPU_X0.ST3.RDY\);
GRFPU0_GRFPU_X0_COMB_INCX16: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_9402\,
dataf => \GRFPU0.GRFPU_X0.N_7502\,
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(1));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_22: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_22\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_19\,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(24),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(21),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(7),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(6));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1_20: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_20\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_15\,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(9),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(8),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(11),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(10));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_22\,
datae => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_20\,
datad => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_21\,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(19),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(18));
GRFPU0_GRFPU_X0_COMB_IEXC25_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff00ff00f0ff0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.IEXC25_1\,
dataf => \GRFPU0.GRFPU_X0.L3_0_3\(5),
datae => \GRFPU0.GRFPU_X0.L3_0_5\(0),
datad => \GRFPU0.GRFPU_X0.L3_1_1\(0),
datac => \GRFPU0.GRFPU_X0.ITER.TZR\(1));
GRFPU0_GRFPU_X0_COMB_IEXC25_NE_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3fffcfffff3fffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.IEXC25_NE_1\,
dataf => \GRFPU0.GRFPU_X0.L4_7\(2),
datae => \GRFPU0.GRFPU_X0.L3_0_3\(5),
datad => \GRFPU0.GRFPU_X0.ITER.TZR\(3),
datac => \GRFPU0.GRFPU_X0.ITER.TZR\(0),
datab => \GRFPU0.GRFPU_X0.ITER.TZR\(6));
GRFPU0_GRFPU_X0_COMB_IEXC25_NE: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff3c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.IEXC25_I\,
dataf => \GRFPU0.GRFPU_X0.COMB.IEXC25_NE_2\,
datae => \GRFPU0.GRFPU_X0.COMB.IEXC25_NE_1\,
datad => \GRFPU0.GRFPU_X0.COMB.IEXC25_1\,
datac => \GRFPU0.GRFPU_X0.L4_7\(4),
datab => \GRFPU0.GRFPU_X0.ITER.TZR\(5));
\GRFPU0_GRFPU_X0_ITER_R_I_RNIEAJE2_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff00ff03ff")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_2_0\(3),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(54));
GRFPU0_GRFPU_X0_UN68_BCO_LSB_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"333333333333333f")
port map (
combout => \GRFPU0.GRFPU_X0.UN68_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.DP\);
\GRFPU0_GRFPU_X0_L2_1_4_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_1_4\(2),
dataf => \GRFPU0.GRFPU_X0.L1_2_3\(3),
datae => \GRFPU0.GRFPU_X0.UN48_BCO_LSB_0\,
datad => \GRFPU0.GRFPU_X0.N_13805_I_0\,
datac => \GRFPU0.GRFPU_X0.UN53_BCO_LSB\(15));
\GRFPU0_GRFPU_X0_L4_7_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.L4_7\(2),
dataf => \GRFPU0.GRFPU_X0.L3_0_3\(5),
datae => \GRFPU0.GRFPU_X0.L2_0_5\(4),
datad => \GRFPU0.GRFPU_X0.L2_1_4\(2),
datac => \GRFPU0.GRFPU_X0.L2_0_5\(2),
datab => \GRFPU0.GRFPU_X0.L3_1_1\(2));
\GRFPU0_GRFPU_X0_L1_6_1_4_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3f3fffff3ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_13735\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.DP\);
\GRFPU0_GRFPU_X0_BCO_MSB_6_4_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0fff3ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_13605\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(54));
\GRFPU0_GRFPU_X0_L1_5_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000003ffffff03ff")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_5\(1),
dataf => \GRFPU0.GRFPU_X0.N_13605\,
datae => \GRFPU0.GRFPU_X0.UN63_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(48));
\GRFPU0_GRFPU_X0_L3_1_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0fff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.L3_1_1\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(4),
datae => \GRFPU0.GRFPU_X0.L1_4_5\(3),
datad => \GRFPU0.GRFPU_X0.L1_5_5\(1),
datac => \GRFPU0.GRFPU_X0.N_13735\,
datab => \GRFPU0.GRFPU_X0.L1_4_6\(1));
\GRFPU0_GRFPU_X0_BCO_MSB_4_4_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fffffff3ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_13685\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(38));
\GRFPU0_GRFPU_X0_L1_0_5_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030000030300ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_13718\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(14));
\GRFPU0_GRFPU_X0_L2_0_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => N_82216,
dataf => \GRFPU0.GRFPU_X0.N_9486\,
datae => N_82203,
datad => \GRFPU0.GRFPU_X0.N_9487\,
datac => \GRFPU0.GRFPU_X0.N_13825_1\,
datab => \GRFPU0.GRFPU_X0.N_13695_1\);
\GRFPU0_GRFPU_X0_L3_0_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33f033f00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_5\(1),
dataf => \GRFPU0.GRFPU_X0.L2_0_5\(4),
datae => N_82216,
datad => \GRFPU0.GRFPU_X0.L1_2_3\(3),
datac => \GRFPU0.GRFPU_X0.L1_2_4\(1),
datab => N_82204);
\GRFPU0_GRFPU_X0_L1_6_1_4_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c000c0c0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6_1_4\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.DP\);
GRFPU0_GRFPU_X0_UN63_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN63_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(51));
\GRFPU0_GRFPU_X0_BCO_MSB_6_4_0_TZ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_6_4_TZ\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(54));
\GRFPU0_GRFPU_X0_L1_5_1_4_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000c00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_1_4\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(51));
\GRFPU0_GRFPU_X0_L1_5_5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3fff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_5\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_6_4_TZ\(0),
datae => \GRFPU0.GRFPU_X0.UN63_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.L1_5_1_4\(0),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(52));
\GRFPU0_GRFPU_X0_BCO_MSB_5_4_0_TZ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000fff00000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_5_4_TZ\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(47));
\GRFPU0_GRFPU_X0_L1_4_1_5_0_I_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00f0ffff00ff")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_1_5_0_I_0\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(42));
\GRFPU0_GRFPU_X0_L1_4_6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33ff0c0c00000c0c")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_6\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_5_4_TZ\(0),
datae => \GRFPU0.GRFPU_X0.UN58_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datac => \GRFPU0.GRFPU_X0.L1_4_1_5_0_I_0\(0),
datab => \GRFPU0.GRFPU_X0.ITER.DP\);
\GRFPU0_GRFPU_X0_L3_1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.L3_1_1\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_3\(4),
datae => \GRFPU0.GRFPU_X0.L1_4_5\(3),
datad => \GRFPU0.GRFPU_X0.L1_5_5\(0),
datac => \GRFPU0.GRFPU_X0.L1_4_6\(0),
datab => \GRFPU0.GRFPU_X0.L1_6_1_4\(0));
\GRFPU0_GRFPU_X0_BCO_MSB_4_4_0_TZ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f0000ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_4_TZ\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(38));
\GRFPU0_GRFPU_X0_L1_3_1_4_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000fc00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_1_4\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(35));
\GRFPU0_GRFPU_X0_L1_3_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3fff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_4\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_4_4_TZ\(0),
datae => \GRFPU0.GRFPU_X0.UN53_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.L1_3_1_4\(0),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(36));
GRFPU0_GRFPU_X0_UN48_BCO_LSB_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03000300030003ff")
port map (
combout => \GRFPU0.GRFPU_X0.UN48_BCO_LSB_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(27));
\GRFPU0_GRFPU_X0_BCO_MSB_3_4_0_TZ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fff000fcfffcff")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3_4_TZ\(0),
dataf => \GRFPU0.GRFPU_X0.N_18387\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(31));
\GRFPU0_GRFPU_X0_L1_2_4_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18381\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(28));
\GRFPU0_GRFPU_X0_L1_2_1_5_A4_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c000cff0c000c00")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_5_A4_0_0\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(56),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(27));
\GRFPU0_GRFPU_X0_L1_2_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fff0fff30000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_4\(0),
dataf => \GRFPU0.GRFPU_X0.L1_2_1_5\(0),
datae => \GRFPU0.GRFPU_X0.BCO_MSB_3_4_TZ\(0),
datad => \GRFPU0.GRFPU_X0.UN48_BCO_LSB_0\,
datac => \GRFPU0.GRFPU_X0.N_13805_I_0\,
datab => \GRFPU0.GRFPU_X0.N_18381\);
GRFPU0_GRFPU_X0_UN43_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000330f")
port map (
combout => \GRFPU0.GRFPU_X0.N_9487\,
dataf => \GRFPU0.GRFPU_X0.N_13825_1\,
datae => \GRFPU0.GRFPU_X0.TZI2\(11),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(18));
\GRFPU0_GRFPU_X0_BCO_MSB_2_5_0_A4_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0c0c00ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_5_0_A4_0_0\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(23));
\GRFPU0_GRFPU_X0_TZI2_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(9),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(17));
\GRFPU0_GRFPU_X0_TZI2_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(11),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(19));
GRFPU0_GRFPU_X0_UN38_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000030003f")
port map (
combout => \GRFPU0.GRFPU_X0.N_9500\,
dataf => \GRFPU0.GRFPU_X0.N_13855_1\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datad => \GRFPU0.GRFPU_X0.TZI2\(3),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(10));
\GRFPU0_GRFPU_X0_TZI2_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(5),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(13));
\GRFPU0_GRFPU_X0_BCO_MSB_1_4_0_A4_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"303000ff30300000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_4_0_A4_0_0\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(14));
\GRFPU0_GRFPU_X0_TZI2_I_M2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_40\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(12));
\GRFPU0_GRFPU_X0_TZI2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(1),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(9));
\GRFPU0_GRFPU_X0_L1_0_5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0cffff0f0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_5\(0),
dataf => \GRFPU0.GRFPU_X0.L1_0_1_4\(0),
datae => \GRFPU0.GRFPU_X0.N_9500\,
datad => \GRFPU0.GRFPU_X0.BCO_MSB_1_4_0_A4_0_0\(0),
datac => \GRFPU0.GRFPU_X0.N_40\,
datab => \GRFPU0.GRFPU_X0.TZI2\(5));
\GRFPU0_GRFPU_X0_L2_0_5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0cfc0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_5\(0),
dataf => \GRFPU0.GRFPU_X0.N_9486\,
datae => \GRFPU0.GRFPU_X0.L1_0_5\(0),
datad => \GRFPU0.GRFPU_X0.L1_1_1_5\(0),
datac => \GRFPU0.GRFPU_X0.N_9487\,
datab => \GRFPU0.GRFPU_X0.BCO_MSB_2_5\(0));
\GRFPU0_GRFPU_X0_L3_0_5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_5\(0),
dataf => \GRFPU0.GRFPU_X0.L2_0_5\(4),
datae => \GRFPU0.GRFPU_X0.L2_0_5\(0),
datad => \GRFPU0.GRFPU_X0.L1_2_3\(3),
datac => \GRFPU0.GRFPU_X0.L1_2_4\(0),
datab => \GRFPU0.GRFPU_X0.L1_3_4\(0));
\GRFPU0_GRFPU_X0_COMB_IEXC5_ALTB_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0f000c0fcfff0fc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.IEXC5.ALTB\(3),
dataf => \GRFPU0.GRFPU_X0.L4_7\(3),
datae => \GRFPU0.GRFPU_X0.COMB.IEXC5.ALTB\(1),
datad => \GRFPU0.GRFPU_X0.L4_7\(2),
datac => \GRFPU0.GRFPU_X0.ITER.TZR\(3),
datab => \GRFPU0.GRFPU_X0.ITER.TZR\(2));
\GRFPU0_GRFPU_X0_COMB_IEXC5_ALTB_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0f0fcff00c0f0fc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.IEXC5LT6\,
dataf => \GRFPU0.GRFPU_X0.COMB.IEXC5.ALTB\(3),
datae => \GRFPU0.GRFPU_X0.L3_0_3\(5),
datad => \GRFPU0.GRFPU_X0.L4_7\(4),
datac => \GRFPU0.GRFPU_X0.ITER.TZR\(5),
datab => \GRFPU0.GRFPU_X0.ITER.TZR\(4));
\GRFPU0_GRFPU_X0_COMB_IEXC_6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff0000fff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.IEXC_6\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.IEXC5LT6\,
datae => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datad => \GRFPU0.GRFPU_X0.ITER.TZR\(6),
datac => \GRFPU0.GRFPU_X0.ITER.NX\);
GRFPU0_GRFPU_X0_COMB_UN1_ITER_FLUSH0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_5508\,
dataf => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datae => \GRFPU0.GRFPU_X0.ITER.FLUSH0\);
GRFPU0_GRFPU_X0_VITER_EMAXP1_1_SQMUXA_1_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.EMAXP1_1_SQMUXA_1_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.V\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
datac => \GRFPU0.GRFPU_X0.ITER.EMAXP1\);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_RNI6K4D_94_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(94),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(94));
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_17: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_17\,
dataf => \GRFPU0.MULO.MRES\(92),
datae => \GRFPU0.MULO.MRES\(85),
datad => \GRFPU0.MULO.MRES\(81),
datac => \GRFPU0.MULO.MRES\(80),
datab => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_11\);
GRFPU0_GRFPU_X0_COMB_ORV_STICKY_I_A2_21: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_21\,
dataf => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_18\,
datae => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_17\,
datad => \GRFPU0.MULO.MRES\(95),
datac => \GRFPU0.MULO.MRES\(91),
datab => \GRFPU0.MULO.MRES\(90));
GRFPU0_GRFPU_X0_COMB_UN8_GUARD_I_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c000000cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_183\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_21\,
datad => \GRFPU0.MULO.MRES\(67),
datac => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_16\(0));
\GRFPU0_GRFPU_X0_RNDOP_14_IV_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000f00")
port map (
combout => N_40517,
dataf => \GRFPU0.GRFPU_X0.N_183\,
datae => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
datac => \GRFPU0.GRFPU_X0.ITER.SIGN\);
\GRFPU0_GRFPU_X0_RNDOP_14_IV_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff000cc00")
port map (
combout => \GRFPU0.GRFPU_X0.RNDOP_14\(0),
dataf => N_40517,
datae => \GRFPU0.MULO.MRES\(120),
datad => \GRFPU0.GRFPU_X0.N_9318\,
datac => \GRFPU0.MULO.MRES\(96),
datab => \GRFPU0.MULO.MRES\(95));
GRFPU0_GRFPU_X0_VITER_EMAXP1_1_SQMUXA_1_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_5754\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datad => N_28164,
datac => N_28163);
GRFPU0_GRFPU_X0_VITER_EMAXP1_1_SQMUXA_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000f000f000")
port map (
combout => \GRFPU0.GRFPU_X0.VITER.EMAXP1_1_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.RNDOP_14\(0),
datae => \GRFPU0.GRFPU_X0.N_5754\,
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.GRFPU_X0.VITER.EMAXP1_1_SQMUXA_1_1\,
datab => \GRFPU0.GRFPU_X0.ITER.DP\);
GRFPU0_GRFPU_X0_COMB_VITER_EMAXP112: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_3723\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXPT\(1),
datae => \GRFPU0.GRFPU_X0.ITER.EXPT\(0),
datad => \GRFPU0.GRFPU_X0.ITER.EXPT\(2));
\GRFPU0_GRFPU_X0_ITER_EXPT_RNII8B31_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffff00000fff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_5790\,
dataf => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
datae => \GRFPU0.GRFPU_X0.ITER.EXPT\(0),
datad => \GRFPU0.GRFPU_X0.ITER.EXPT\(1),
datac => \GRFPU0.GRFPU_X0.ITER.EXPT\(2));
GRFPU0_GRFPU_X0_ITER_EMAXP1_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f0ccccccf0")
port map (
combout => N_53555,
dataf => \GRFPU0.GRFPU_X0.VITER.EMAXP1_1_SQMUXA_1\,
datae => \GRFPU0.GRFPU_X0.ITER.EMIN_0_0_N_5\,
datad => \GRFPU0.GRFPU_X0.N_5790\,
datac => \GRFPU0.GRFPU_X0.N_3723\,
datab => \GRFPU0.GRFPU_X0.ITER.EMAXP1\);
GRFPU0_GRFPU_X0_VITER_ND_I_4_SQMUXA_I_0_O2_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19733\,
dataf => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(11));
GRFPU0_GRFPU_X0_VITER_ND_I_4_SQMUXA_I_0_O2_I_O2_RNI6R171: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0fff0ffc000f000")
port map (
combout => \GRFPU0.GRFPU_X0.N_172\,
dataf => \GRFPU0.GRFPU_X0.N_128\,
datae => \GRFPU0.GRFPU_X0.N_19733\,
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(17));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(21),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16741\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(21),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(21));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16741\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(81),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(13));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16773\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(113),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(45));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(53),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16773\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(53),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(53));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(6),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(6),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_2_I_A5_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_I_A5_0_0\,
dataf => \GRFPU0.GRFPU_X0.N_18221\,
datae => \GRFPU0.GRFPU_X0.N_18219\,
datad => \GRFPU0.GRFPU_X0.C\(7),
datac => \GRFPU0.GRFPU_X0.C\(1),
datab => \GRFPU0.GRFPU_X0.C\(0));
\GRFPU0_GRFPU_X0_ITER_EXPT_RNO_0_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000fff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__G4_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_I_A5_0_0\,
datae => \GRFPU0.GRFPU_X0.N_4275\,
datad => \GRFPU0.GRFPU_X0.C\(11),
datac => \GRFPU0.GRFPU_X0.C\(10));
GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_2_I_O3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffffffff0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_I_O3_0\,
dataf => \GRFPU0.GRFPU_X0.C\(11),
datae => \GRFPU0.GRFPU_X0.C\(10),
datad => \GRFPU0.GRFPU_X0.C\(1),
datac => \GRFPU0.GRFPU_X0.C\(0));
GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_2_I_A5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccccccccccccc0c")
port map (
combout => \GRFPU0.GRFPU_X0.N_18250\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1_2_I_O3_0\,
datae => \GRFPU0.GRFPU_X0.N_18216\,
datad => \GRFPU0.GRFPU_X0.N_18219\,
datac => \GRFPU0.GRFPU_X0.N_18220\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_OP_EQ_EXPT67_0_A5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000300")
port map (
combout => \GRFPU0.GRFPU_X0.N_4276\,
dataf => \GRFPU0.GRFPU_X0.N_18219\,
datae => \GRFPU0.GRFPU_X0.C\(11),
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_EQ.EXPT67_0_A5_0\,
datac => \GRFPU0.GRFPU_X0.C\(10),
datab => \GRFPU0.GRFPU_X0.C\(0));
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_UN38_C_0_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.N_18219\,
dataf => \GRFPU0.GRFPU_X0.C\(6),
datae => \GRFPU0.GRFPU_X0.C\(5),
datad => \GRFPU0.GRFPU_X0.C\(4),
datac => \GRFPU0.GRFPU_X0.C\(3),
datab => \GRFPU0.GRFPU_X0.C\(2));
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_UN38_C_0_A5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4264\,
dataf => \GRFPU0.GRFPU_X0.N_18221\,
datae => \GRFPU0.GRFPU_X0.N_18219\,
datad => \GRFPU0.GRFPU_X0.C\(11),
datac => \GRFPU0.GRFPU_X0.C\(10),
datab => \GRFPU0.GRFPU_X0.C\(7));
GRFPU0_GRFPU_X0_UN1_EXPT_5_SQMUXA_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0303030300000033")
port map (
combout => \GRFPU0.GRFPU_X0.N_4260\,
dataf => \GRFPU0.GRFPU_X0.N_4264\,
datae => \GRFPU0.GRFPU_X0.N_4275\,
datad => \GRFPU0.GRFPU_X0.N_4276\,
datac => \GRFPU0.GRFPU_X0.N_18220\,
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
\GRFPU0_GRFPU_X0_ITER_EXPT_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0c0c0cfc0c0c")
port map (
combout => N_53559,
dataf => \GRFPU0.GRFPU_X0.N_4260\,
datae => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__G4_0\,
datad => \GRFPU0.GRFPU_X0.N_18250\,
datac => \GRFPU0.GRFPU_X0.N_5673_0\,
datab => \GRFPU0.GRFPU_X0.ITER.EXPT\(2));
\GRFPU0_GRFPU_X0_REST_1_2_IV_0_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccfffc0000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.REST_1_2_IV_0\(2),
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(4));
GRFPU0_GRFPU_X0_UN1_VITER_EXP28: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000fffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_VITER.EXP28\,
dataf => \GRFPU0.GRFPU_X0.N_3407\,
datae => \GRFPU0.GRFPU_X0.REST_1_2\(2),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3));
GRFPU0_GRFPU_X0_UN1_EXPT_3_SQMUXA_3_I_O2_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0ffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18269\,
dataf => \GRFPU0.GRFPU_X0.N_16\,
datae => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\,
datad => \GRFPU0.GRFPU_X0.UN8_C\(10),
datac => \GRFPU0.GRFPU_X0.UN8_C\(1),
datab => \GRFPU0.GRFPU_X0.UN8_C\(0));
GRFPU0_GRFPU_X0_UN1_EXPT_3_SQMUXA_3_I_O2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19\,
dataf => \GRFPU0.GRFPU_X0.UN8_C\(9),
datae => \GRFPU0.GRFPU_X0.UN8_C\(8),
datad => \GRFPU0.GRFPU_X0.UN8_C\(7));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNIEJJG_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_5226\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(1));
GRFPU0_GRFPU_X0_UN1_EXPT_3_SQMUXA_3_I_A2_0_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3_I_A2_0_3\,
dataf => \GRFPU0.GRFPU_X0.UN8_C\(1),
datae => \GRFPU0.GRFPU_X0.UN8_C\(5),
datad => \GRFPU0.GRFPU_X0.UN8_C\(0),
datac => \GRFPU0.GRFPU_X0.UN8_C\(4));
GRFPU0_GRFPU_X0_UN1_EXPT_3_SQMUXA_3_I_A2_0_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3_I_A2_0_2\,
dataf => \GRFPU0.GRFPU_X0.UN8_C\(6),
datae => \GRFPU0.GRFPU_X0.UN8_C\(3),
datad => \GRFPU0.GRFPU_X0.UN8_C\(2));
GRFPU0_GRFPU_X0_UN1_EXPT_3_SQMUXA_3_I_A4_0_1_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3_I_A4_0_1_0\,
dataf => \GRFPU0.GRFPU_X0.UN8_C\(9),
datae => \GRFPU0.GRFPU_X0.UN8_C\(8),
datad => \GRFPU0.GRFPU_X0.UN8_C\(7));
GRFPU0_GRFPU_X0_UN1_EXPT_3_SQMUXA_3_I_O2_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_24\,
dataf => \GRFPU0.GRFPU_X0.N_16\,
datae => \GRFPU0.GRFPU_X0.UN8_C\(1),
datad => \GRFPU0.GRFPU_X0.UN8_C\(0));
GRFPU0_GRFPU_X0_UN1_EXPT_3_SQMUXA_3_I_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0033000000330030")
port map (
combout => N_60914,
dataf => \GRFPU0.GRFPU_X0.N_24\,
datae => \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3_I_A4_1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_LT.EXPT14LTO11\,
datac => \GRFPU0.GRFPU_X0.UN1_EXPT_3_SQMUXA_3_I_A4_0_1_0\,
datab => \GRFPU0.GRFPU_X0.UN8_C\(10));
GRFPU0_GRFPU_X0_COMB_EXPADDSUB_UN7_DP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN7_DP\,
dataf => \GRFPU0.GRFPU_X0.UN8_C\(10),
datae => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
datad => \GRFPU0.GRFPU_X0.ST1.EXP1\(10));
\GRFPU0_GRFPU_X0_COMB_EXPADDSUB_EXPT_0_A4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0c0c0ff00cc00")
port map (
combout => \GRFPU0.GRFPU_X0.N_42\,
dataf => \GRFPU0.GRFPU_X0.N_18262\,
datae => \GRFPU0.GRFPU_X0.N_18269\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.OP_GT.EXPT18\,
datac => \GRFPU0.GRFPU_X0.COMB.EXPADDSUB.UN7_DP\,
datab => \GRFPU0.GRFPU_X0.N_30\);
GRFPU0_GRFPU_X0_UN1_EXPT_3_SQMUXA_3_I_O2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17\,
dataf => \GRFPU0.GRFPU_X0.UN8_C\(9),
datae => \GRFPU0.GRFPU_X0.UN8_C\(8),
datad => \GRFPU0.GRFPU_X0.UN8_C\(7));
\GRFPU0_GRFPU_X0_REST_2_IV_0_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcc0000fffcf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.REST_2_IV_0\(2),
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(4));
GRFPU0_GRFPU_X0_UN1_REST_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_REST_3\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(2),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3));
GRFPU0_GRFPU_X0_COMB_CCV12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.CCV12\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3));
GRFPU0_GRFPU_X0_UN1_CCV12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_CCV12\,
dataf => \GRFPU0.GRFPU_X0.COMB.CCV12\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(2));
GRFPU0_GRFPU_X0_VST2_EXC_0_SQMUXA_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffc00000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.EXC_0_SQMUXA_1\,
dataf => \GRFPU0.GRFPU_X0.UN1_CCV12\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16960\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(37));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16961\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16945\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(14),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(22));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16939\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(8),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16968\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(45));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16974\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(51));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16941\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(10),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(18));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16942\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(11),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16970\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(47));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16940\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(9),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(17));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16969\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16955\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(24),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(39),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16759\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(39),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(39));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16759\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(99),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(31));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16935\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(4),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(12));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16952\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(21),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(29));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_I_M3_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18981\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(27),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(35));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16938\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(7),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(15));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16936\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(5),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(13));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16937\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(6),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(14));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16933\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16965\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(42));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16964\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(41));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16962\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(39));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16967\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16950\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(19),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(27));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16956\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(25),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(33));
GRFPU0_FPMUL0_R2_RET_93_RNI4T2V: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(110),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(110),
datad => N_28085);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16770\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(110),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(42));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(50),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16770\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(50));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff33f0f00033")
port map (
combout => \GRFPU0.GRFPU_X0.N_15666\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(53),
datae => \GRFPU0.GRFPU_X0.N_15611\,
datad => \GRFPU0.GRFPU_X0.N_14\,
datac => \GRFPU0.GRFPU_X0.N_15607\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f3333f0003333")
port map (
combout => \GRFPU0.GRFPU_X0.N_15546\,
dataf => \GRFPU0.GRFPU_X0.N_16069\,
datae => \GRFPU0.GRFPU_X0.N_14\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(56),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcc00ccff3c003c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(53),
dataf => \GRFPU0.GRFPU_X0.N_18195\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(53),
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(53));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003cff00003c00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16516\,
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(2),
datae => \GRFPU0.GRFPU_X0.N_5508\,
datad => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA\,
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(1));
\GRFPU0_GRFPU_X0_ITER_STATE_RNINUR11_0_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffff000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18449\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(8));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f3333f0003333")
port map (
combout => \GRFPU0.GRFPU_X0.N_15549\,
dataf => \GRFPU0.GRFPU_X0.N_16072\,
datae => \GRFPU0.GRFPU_X0.N_14\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(59),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_13_0_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f00ff0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16072\,
dataf => \GRFPU0.GRFPU_X0.N_18195\,
datae => N_32527,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(59));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_1_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"003f00cf003000c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16522\,
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(8),
datae => N_32664,
datad => \GRFPU0.GRFPU_X0.N_5508\,
datac => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(7));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccc0fffcccc00f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(50),
dataf => \GRFPU0.GRFPU_X0.N_15540\,
datae => N_99909_I_0,
datad => \GRFPU0.GRFPU_X0.N_18491\,
datac => \GRFPU0.GRFPU_X0.N_15611\,
datab => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc0fccffcc00ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(45),
dataf => \GRFPU0.GRFPU_X0.N_15535\,
datae => \GRFPU0.GRFPU_X0.N_18444\,
datad => N_99909_I_0,
datac => \GRFPU0.GRFPU_X0.N_15611\,
datab => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff033330f003333")
port map (
combout => \GRFPU0.GRFPU_X0.N_15540\,
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(21),
datae => \GRFPU0.GRFPU_X0.N_14\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(50),
datac => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff033330f003333")
port map (
combout => \GRFPU0.GRFPU_X0.N_15535\,
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(16),
datae => \GRFPU0.GRFPU_X0.N_14\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(45),
datac => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc0fccffcc00ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24\(47),
dataf => \GRFPU0.GRFPU_X0.N_15537\,
datae => \GRFPU0.GRFPU_X0.N_18444\,
datad => N_99909_I_0,
datac => \GRFPU0.GRFPU_X0.N_15611\,
datab => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff033330f003333")
port map (
combout => \GRFPU0.GRFPU_X0.N_15537\,
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(18),
datae => \GRFPU0.GRFPU_X0.N_14\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(47),
datac => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f30003fff3ff03")
port map (
combout => \GRFPU0.GRFPU_X0.N_15657\,
dataf => \GRFPU0.GRFPU_X0.N_18444\,
datae => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(44),
datad => \GRFPU0.GRFPU_X0.N_15611\,
datac => \GRFPU0.GRFPU_X0.N_14\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f033fffff033")
port map (
combout => \GRFPU0.GRFPU_X0.N_15651\,
dataf => \GRFPU0.GRFPU_X0.N_18444\,
datae => \GRFPU0.GRFPU_X0.N_15611\,
datad => \GRFPU0.GRFPU_X0.N_14\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(38),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f033fffff033")
port map (
combout => \GRFPU0.GRFPU_X0.N_15647\,
dataf => \GRFPU0.GRFPU_X0.N_18444\,
datae => \GRFPU0.GRFPU_X0.N_15611\,
datad => \GRFPU0.GRFPU_X0.N_14\,
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(34),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_RNO_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc00000ffc0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(34),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(5),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.N_18489\,
datac => \GRFPU0.GRFPU_X0.N_73\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(34));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16436\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(38));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_RNO_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(38),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(9),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16501\,
datab => \GRFPU0.GRFPU_X0.N_16436\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16442\,
dataf => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(44));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_3_RNO_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13\(44),
dataf => \GRFPU0.GRFPU_X0.UN6_SGNFX\(15),
datae => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16507\,
datab => \GRFPU0.GRFPU_X0.N_16442\);
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0c3f0c3")
port map (
combout => \GRFPU0.GRFPU_X0.N_86\,
dataf => \GRFPU0.GRFPU_X0.N_18408\,
datae => \GRFPU0.GRFPU_X0.C\(8),
datad => N_32473,
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(7));
\GRFPU0_GRFPU_X0_ITER_EXP_RNO_0_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f00ff00f")
port map (
combout => \GRFPU0.GRFPU_X0.N_87\,
dataf => \GRFPU0.GRFPU_X0.N_18408\,
datae => \GRFPU0.GRFPU_X0.C\(9),
datad => N_32483,
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(9));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33f0ccf0ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16454\,
dataf => N_32649,
datae => \GRFPU0.GRFPU_X0.COMB.EXP57\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(4));
GRFPU0_GRFPU_X0_C_CARRY_8_RNIR8AO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18213\,
dataf => \GRFPU0.GRFPU_X0.C\(9),
datae => \GRFPU0.GRFPU_X0.C\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_EXPT_1_1_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18221\,
dataf => \GRFPU0.GRFPU_X0.C\(9),
datae => \GRFPU0.GRFPU_X0.C\(8));
GRFPU0_GRFPU_X0_C_CARRY_0_RNIB8AO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18220\,
dataf => \GRFPU0.GRFPU_X0.C\(1),
datae => \GRFPU0.GRFPU_X0.C\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ff00ff00ff00ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(28),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => \GRFPU0.GRFPU_X0.N_19681\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(28));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_RNO_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(28),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(88),
datac => \GRFPU0.MULO.DRES_1\(88));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(28),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(87),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(88),
datab => \GRFPU0.MULO.DRES_1\(88),
dataa => \GRFPU0.MULO.DRES_1S\(87));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(28),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(28),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(32),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(32));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(28),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(28),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(28));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_1_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0f3f0f3f0f3f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(29),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(29),
datad => \GRFPU0.GRFPU_X0.N_18663\,
datac => \GRFPU0.GRFPU_X0.N_19681\,
datab => \GRFPU0.MULO.MRES\(89));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_RNO_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(29),
dataf => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datad => \GRFPU0.MULO.MRES\(89),
datac => \GRFPU0.MULO.DRES_1\(89));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0f00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(29),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(29),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_42_M\(29),
datad => N_99921,
datac => \GRFPU0.MULO.MRES\(90));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(29),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(88),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(89),
datab => \GRFPU0.MULO.DRES_1\(89),
dataa => \GRFPU0.MULO.DRES_1S\(88));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf0fffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(29),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(29),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(29),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_18664\,
datab => \GRFPU0.MULO.MRES\(89));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(29),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(29),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(31),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(31));
\GRFPC0_WR_RREG_RES_RNO_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000ffffcccccccc")
port map (
combout => N_47267,
dataf => N_99846,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_10_3640_I_A3_0_0_0\,
datad => N_99904_1,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(30),
datab => \GRFPC0.MEM.RREG.RES\(30));
GRFPC0_EX_CTRL_AFSR_RNIU9P7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => N_99884,
dataf => \GRFPC0.EX.CTRL.AFSR\,
datae => \GRFPC0.EX.CTRL.STDFQ\);
\GRFPC0_OP1_4_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20176\,
dataf => N_99879,
datae => N_649,
datad => N_713);
\GRFPC0_OP1_3_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20111\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(54),
datad => \GRFPC0.WR.RREG.RES\(54));
\GRFPC0_OP1_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(54),
dataf => \GRFPC0.N_20242\,
datae => N_99877,
datad => \GRFPC0.N_20176\,
datac => \GRFPC0.RFA2.RS1SEL_0\(7),
datab => \GRFPC0.N_20111\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(28),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16748\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(28),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(28));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_I_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fc300000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18747_I\,
dataf => \GRFPU0.GRFPU_X0.N_18837\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP1\(51),
datac => \FPI.OP1\(54),
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(59),
dataf => \GRFPU0.GRFPU_X0.N_18747_I\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(59),
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_18_3432_I_A3_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000f003300ff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_18_3432_I_A3_0\,
dataf => N_99904_2,
datae => \GRFPU0.GRFPU_X0.N_400_1\,
datad => \GRFPC0.DIV.RESULT_0_0_22__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(22),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(22));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16748\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(88),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(20));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(59),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16779\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(59),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(59));
GRFPU0_FPMUL0_R2_RET_84_RNIDT2V: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(119),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(119),
datad => N_28103);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16779\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(119),
datac => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(51));
\GRFPC0_STDATA_1_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff30ff000030ff")
port map (
combout => \GRFPC0.N_17570\,
dataf => \GRFPC0.R.STDATA\(13),
datae => \GRFPC0.EX.CTRL.STDFQ\,
datad => \GRFPC0.FP_PIPELINE.QNE2_I_A4_1\,
datac => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2\,
datab => \GRFPC0.N_23695\);
GRFPC0_FP_PIPELINE_UN1_CPI_2_0_A4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_CPI_2\,
dataf => N_249,
datae => N_248);
GRFPU0_FPMUL0_R2_RET_91_RNI4T2V: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(112),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(112),
datad => N_28089);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16772\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(112),
datac => \GRFPU0.DIVROM0.RADDR\(0),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(44));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(52),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16772\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(52),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(52));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_25_3250_I_A3_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000f003300ff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_25_3250_I_A3_0\,
dataf => N_99904_2,
datae => \GRFPU0.GRFPU_X0.N_400\,
datad => \GRFPC0.DIV.RESULT_0_0_15__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(15),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(15));
\GRFPU0_GRFPU_X0_TZI2_I_1_M3_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18387\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datae => \GRFPU0.GRFPU_X0.ITER.DP\,
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(30));
\GRFPU0_GRFPU_X0_TZI2_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.TZI2\(23),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(31));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_2_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15856\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1S\(79),
datad => \GRFPU0.MULO.MRES\(79));
\GRFPU0_GRFPU_X0_COMB_VST4_MSGNF_1_1_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_15805\,
dataf => \GRFPU0.GRFPU_X0.COMB.INCX_1\,
datae => \GRFPU0.MULO.MRES_1\(79),
datad => \GRFPU0.MULO.MRES\(79));
GRFPU0_GRFPU_X0_UN168_BCO_LSB_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN168_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(56));
\GRFPU0_GRFPU_X0_L4_2_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f0f0cccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.L4_2_1\(2),
dataf => \GRFPU0.GRFPU_X0.L1_4\(3),
datae => \GRFPU0.GRFPU_X0.L1_1_2\(3),
datad => \GRFPU0.GRFPU_X0.UN168_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.UN163_BCO_LSB\(15),
datab => \GRFPU0.GRFPU_X0.UN158_BCO_LSB\(15));
\GRFPU0_GRFPU_X0_L2_1_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.L2_1_1\(2),
dataf => \GRFPU0.GRFPU_X0.L1_2\(3),
datae => \GRFPU0.GRFPU_X0.UN153_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.UN148_BCO_LSB\(15));
\GRFPU0_GRFPU_X0_L2_0_2_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_2\(2),
dataf => \GRFPU0.GRFPU_X0.N_6540\,
datae => \GRFPU0.GRFPU_X0.N_6541\,
datad => \GRFPU0.GRFPU_X0.N_6546\);
\GRFPU0_GRFPU_X0_L4_3_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.L4_3\(2),
dataf => \GRFPU0.GRFPU_X0.L3_0\(5),
datae => \GRFPU0.GRFPU_X0.L4_2_1\(2),
datad => \GRFPU0.GRFPU_X0.N_6535\,
datac => \GRFPU0.GRFPU_X0.L2_0_2\(2),
datab => \GRFPU0.GRFPU_X0.L2_1_1\(2));
\GRFPU0_GRFPU_X0_L1_6_1_1_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f0fffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_14185\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(56));
\GRFPU0_GRFPU_X0_BCO_MSB_6_1_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffffff0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_14065\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(54));
\GRFPU0_GRFPU_X0_BCO_MSB_5_1_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00ff0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_14145\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(47));
\GRFPU0_GRFPU_X0_BCO_MSB_4_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f0fffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_14095\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(36));
\GRFPU0_GRFPU_X0_L1_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff3fff0fff0")
port map (
combout => N_82191,
dataf => \GRFPU0.GRFPU_X0.N_14095\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(35));
\GRFPU0_GRFPU_X0_BCO_MSB_3_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_14175\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(30));
\GRFPU0_GRFPU_X0_L1_2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff3fff0fff0")
port map (
combout => N_82190,
dataf => \GRFPU0.GRFPU_X0.N_14175\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(27));
\GRFPU0_GRFPU_X0_L1_1_1_1_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffffff0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_14305\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(19));
\GRFPU0_GRFPU_X0_L1_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcffff0000")
port map (
combout => N_82193,
dataf => \GRFPU0.GRFPU_X0.N_6541\,
datae => \GRFPU0.GRFPU_X0.N_14305\,
datad => \GRFPU0.GRFPU_X0.N_6535_2\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(20));
\GRFPU0_GRFPU_X0_BCO_MSB_1_1_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0fff0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_14075\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(12));
\GRFPU0_GRFPU_X0_L1_0_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff03ffffff00")
port map (
combout => N_82192,
dataf => \GRFPU0.GRFPU_X0.N_14075\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(11));
\GRFPU0_GRFPU_X0_L2_0_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => N_82208,
dataf => \GRFPU0.GRFPU_X0.N_6540\,
datae => N_82193,
datad => N_82192);
\GRFPU0_GRFPU_X0_L3_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfc0cffff0000")
port map (
combout => N_82219,
dataf => \GRFPU0.GRFPU_X0.N_6535\,
datae => N_82208,
datad => N_82191,
datac => \GRFPU0.GRFPU_X0.L1_2\(3),
datab => N_82190);
\GRFPU0_GRFPU_X0_L4_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"bf80bf80ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_3_I\(1),
dataf => \GRFPU0.GRFPU_X0.L3_0\(5),
datae => N_82219,
datad => N_82210,
datac => \GRFPU0.GRFPU_X0.L1_5\(3),
datab => \GRFPU0.GRFPU_X0.L1_4\(3),
dataa => \GRFPU0.GRFPU_X0.N_14185\);
\GRFPU0_GRFPU_X0_COMB_UN1_L4_ALTB_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cceecece00880808")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_L4.ALTB\(1),
dataf => \GRFPU0.GRFPU_X0.L4_3_I\(1),
datae => \GRFPU0.GRFPU_X0.L3_0\(5),
datad => \GRFPU0.GRFPU_X0.L4_2_1\(0),
datac => \GRFPU0.GRFPU_X0.L3_0\(0),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(0));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16420\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(22));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_22__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16420\,
datab => \GRFPU0.GRFPU_X0.N_16485\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ff00ff00ff00ff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(19),
dataf => N_99920,
datae => \GRFPU0.GRFPU_X0.N_128\,
datad => \GRFPU0.GRFPU_X0.N_19681\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0f3f0033")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(19),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(19),
datae => N_99921,
datad => \GRFPU0.GRFPU_X0.N_18663\,
datac => \GRFPU0.MULO.MRES\(80),
datab => \GRFPU0.MULO.MRES\(79));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_3_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(19),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(19),
datae => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datad => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datac => \GRFPU0.MULO.MRES\(79),
datab => \GRFPU0.MULO.DRES_1\(79));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(19),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(78),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(79),
datab => \GRFPU0.MULO.DRES_1\(79),
dataa => \GRFPU0.MULO.DRES_1S\(78));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf0fffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(19),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(19),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_3\(19),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_18664\,
datab => \GRFPU0.MULO.MRES\(79));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(19),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(19),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(41),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(41));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fcf000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(19),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(19),
datae => \GRFPU0.GRFPU_X0.N_5673_0\,
datad => \GRFPU0.GRFPU_X0.N_128\,
datac => \GRFPU0.GRFPU_X0.ITER.V\,
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_2_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_1\(18),
datae => \GRFPU0.GRFPU_X0.VITER.R_I_1_SQMUXA_3\,
datad => \GRFPU0.GRFPU_X0.RNDOP_29_IV\(0),
datac => \GRFPU0.MULO.MRES\(78),
datab => \GRFPU0.MULO.DRES_1\(78));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcf0fffffcc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(18),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_2\(18),
datad => \GRFPU0.GRFPU_X0.N_3560_I\,
datac => \GRFPU0.GRFPU_X0.N_18664\,
datab => \GRFPU0.MULO.MRES\(78));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_55_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(18),
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.UN177_RNDOP\(42),
datab => \GRFPU0.GRFPU_X0.UN166_RNDOP\(42));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(77),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(78),
datab => \GRFPU0.MULO.DRES_1\(78),
dataa => \GRFPU0.MULO.DRES_1S\(77));
\GRFPU0_GRFPU_X0_ITER_R_I_RNIT5572_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_2\(3),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(54));
\GRFPU0_GRFPU_X0_L1_6_1_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000f0f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6_1_1\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(59),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(57),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(58),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(56));
\GRFPU0_GRFPU_X0_L1_4_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000300")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4\(3),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datad => \GRFPU0.GRFPU_X0.UN158_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(47));
\GRFPU0_GRFPU_X0_BCO_MSB_6_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_6_1\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(53),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(55),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(54));
\GRFPU0_GRFPU_X0_L1_5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00ff000c")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_6_1\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(51));
\GRFPU0_GRFPU_X0_BCO_MSB_5_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00fff0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_5_1\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(44),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(46),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(47));
\GRFPU0_GRFPU_X0_L1_4_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f300f300f300f0")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_2\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_5_1\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(42));
\GRFPU0_GRFPU_X0_L4_2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffcc00f0fff000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_2_1\(0),
dataf => \GRFPU0.GRFPU_X0.L1_5\(3),
datae => \GRFPU0.GRFPU_X0.L1_4_2\(0),
datad => \GRFPU0.GRFPU_X0.L1_4\(3),
datac => \GRFPU0.GRFPU_X0.L1_5\(0),
datab => \GRFPU0.GRFPU_X0.L1_6_1_1\(0));
\GRFPU0_GRFPU_X0_L2_0_10_2_0_A2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_6535_2\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(23));
\GRFPU0_GRFPU_X0_L2_0_10_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6535\,
dataf => \GRFPU0.GRFPU_X0.N_6540\,
datae => \GRFPU0.GRFPU_X0.N_6541\,
datad => \GRFPU0.GRFPU_X0.N_6535_2\,
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(20));
GRFPU0_GRFPU_X0_UN148_BCO_LSB_RNIC8QE1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2\(3),
dataf => \GRFPU0.GRFPU_X0.UN148_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(31));
GRFPU0_GRFPU_X0_UN153_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN153_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(32));
\GRFPU0_GRFPU_X0_BCO_MSB_4_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(39),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(38));
\GRFPU0_GRFPU_X0_L1_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000ff00f000fc")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_4\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(35));
GRFPU0_GRFPU_X0_UN148_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN148_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(27));
\GRFPU0_GRFPU_X0_BCO_MSB_3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_3\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(31));
\GRFPU0_GRFPU_X0_L1_2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0f0000ff0c")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_2\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_3\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(27));
\GRFPU0_GRFPU_X0_L1_0_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6540\,
dataf => \GRFPU0.GRFPU_X0.N_6546\,
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(12));
GRFPU0_GRFPU_X0_UN143_BCO_LSB_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_6541\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(19));
\GRFPU0_GRFPU_X0_BCO_MSB_2_2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_2\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(23));
\GRFPU0_GRFPU_X0_L1_1_1_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1_1\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(19));
GRFPU0_GRFPU_X0_UN138_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_6546\,
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(11));
\GRFPU0_GRFPU_X0_BCO_MSB_1_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000f000ff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_1\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(13));
\GRFPU0_GRFPU_X0_L1_0_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0f0000ff0c")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_2\(0),
dataf => \GRFPU0.GRFPU_X0.BCO_MSB_1_1\(0),
datae => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
datac => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
datab => \GRFPU0.GRFPU_X0.ITER.R_I\(11));
\GRFPU0_GRFPU_X0_L2_0_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_2\(0),
dataf => \GRFPU0.GRFPU_X0.N_6540\,
datae => \GRFPU0.GRFPU_X0.L1_0_2\(0),
datad => \GRFPU0.GRFPU_X0.N_6541\,
datac => \GRFPU0.GRFPU_X0.BCO_MSB_2_2\(0),
datab => \GRFPU0.GRFPU_X0.L1_1_1_1\(0));
\GRFPU0_GRFPU_X0_L3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfc0cffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0\(0),
dataf => \GRFPU0.GRFPU_X0.N_6535\,
datae => \GRFPU0.GRFPU_X0.L2_0_2\(0),
datad => \GRFPU0.GRFPU_X0.L1_3\(0),
datac => \GRFPU0.GRFPU_X0.L1_2\(3),
datab => \GRFPU0.GRFPU_X0.L1_2_2\(0));
\GRFPU0_GRFPU_X0_L4_4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc0fcc0f0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.L4_4\(1),
dataf => \GRFPU0.GRFPU_X0.N_9666\,
datae => N_82215,
datad => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L2_2\(4),
datac => N_82202,
datab => \GRFPU0.GRFPU_X0.L1_6\(1));
\GRFPU0_GRFPU_X0_L3_0_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => N_82215,
dataf => \GRFPU0.GRFPU_X0.N_9672\,
datae => N_82200,
datad => \GRFPU0.GRFPU_X0.N_9671\,
datac => N_82179,
datab => N_82173);
\GRFPU0_GRFPU_X0_L2_0_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0fcf0ffff0000")
port map (
combout => N_82200,
dataf => \GRFPU0.GRFPU_X0.N_9683\,
datae => N_82177,
datad => \GRFPU0.GRFPU_X0.UN213_BCO_LSB_0\,
datac => \GRFPU0.GRFPU_X0.N_14025_1\,
datab => \GRFPU0.GRFPU_X0.N_13955\);
GRFPU0_GRFPU_X0_UN238_BCO_LSB_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN238_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(2));
\GRFPU0_GRFPU_X0_L1_6_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6\(1),
dataf => \GRFPU0.GRFPU_X0.UN238_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(0),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(1));
\GRFPU0_GRFPU_X0_BCO_MSB_6_2_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f0fffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_13945\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(9),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(8));
GRFPU0_GRFPU_X0_UN223_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_9673\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(27),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(26));
GRFPU0_GRFPU_X0_UN218_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_9678\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(37),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(35),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(34));
\GRFPU0_GRFPU_X0_L1_2_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcfcffffff00")
port map (
combout => N_82173,
dataf => \GRFPU0.GRFPU_X0.N_9678\,
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(37),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(32));
GRFPU0_GRFPU_X0_UN213_BCO_LSB_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN213_BCO_LSB_0\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(42),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(43));
\GRFPU0_GRFPU_X0_BCO_MSB_2_3_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0fff0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_13955\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(38),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(40));
\GRFPU0_GRFPU_X0_L1_1_1_3_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14025_1\,
dataf => \GRFPU0.GRFPU_X0.ST2.DIFF\(44),
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(45));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcc0fccf0cc00cc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16989\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(4),
datae => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(4),
datad => N_99908_I_0,
datac => \GRFPU0.GRFPU_X0.N_4\,
datab => \GRFPU0.MULO.MRES\(64));
\GRFPU0_GRFPU_X0_L4_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_1\(4),
dataf => \GRFPU0.GRFPU_X0.N_9787\,
datae => \GRFPU0.GRFPU_X0.N_9793\,
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(4));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(3),
dataf => \GRFPU0.GRFPU_X0.L1_4_1\(3),
datae => \GRFPU0.GRFPU_X0.UN113_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.N_14265_1\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(44));
\GRFPU0_GRFPU_X0_L4_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.L4_1\(3),
dataf => \GRFPU0.GRFPU_X0.N_9787\,
datae => \GRFPU0.GRFPU_X0.N_9793\,
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(3),
datac => \GRFPU0.GRFPU_X0.N_9804\,
datab => \GRFPU0.GRFPU_X0.N_9792\);
\GRFPU0_GRFPU_X0_BCO_MSB_6_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f0fffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_14115\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(46),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(45));
\GRFPU0_GRFPU_X0_ITER_DBUF_RNI775L_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_9793_2\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(14),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(15));
\GRFPU0_GRFPU_X0_L3_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => N_82217,
dataf => \GRFPU0.GRFPU_X0.N_9793\,
datae => N_82205,
datad => \GRFPU0.GRFPU_X0.N_9792\,
datac => N_82183,
datab => N_82186);
\GRFPU0_GRFPU_X0_L4_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"eef0eef0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_1_I\(1),
dataf => \GRFPU0.GRFPU_X0.N_9787\,
datae => N_82217,
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(4),
datac => N_82207,
datab => \GRFPU0.GRFPU_X0.N_14195_1\,
dataa => \GRFPU0.GRFPU_X0.UN118_BCO_LSB_2\(15));
\GRFPU0_GRFPU_X0_L1_6_1_I_A4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN118_BCO_LSB_2\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(50),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(51));
\GRFPU0_GRFPU_X0_L1_6_1_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14195_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(48),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(49));
\GRFPU0_GRFPU_X0_L2_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0c0c00ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_1\(2),
dataf => \GRFPU0.GRFPU_X0.N_9792\,
datae => \GRFPU0.GRFPU_X0.UN98_BCO_LSB_0\,
datad => \GRFPU0.GRFPU_X0.N_14275_1\,
datac => \GRFPU0.GRFPU_X0.N_14255_1\,
datab => \GRFPU0.GRFPU_X0.N_9794_2\);
\GRFPU0_GRFPU_X0_L4_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.L4_1\(2),
dataf => \GRFPU0.GRFPU_X0.N_9787\,
datae => \GRFPU0.GRFPU_X0.L4_2\(2),
datad => \GRFPU0.GRFPU_X0.N_9793\,
datac => \GRFPU0.GRFPU_X0.L2_0_1\(2),
datab => \GRFPU0.GRFPU_X0.L2_1\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0fccccf000cccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_16985\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_17\(0),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_11\(0),
datac => \GRFPU0.GRFPU_X0.N_4\,
datab => \GRFPU0.MULO.MRES\(60));
GRFPU0_GRFPU_X0_COMB_UN1_ITER_DP_I_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19742\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT\);
\GRFPU0_GRFPU_X0_L1_5_1_1_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14205_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(41));
\GRFPU0_GRFPU_X0_BCO_MSB_6_0_TZ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_6_TZ\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(46));
\GRFPU0_GRFPU_X0_L1_5_1_1_0_TZ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_1_1_TZ\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(42),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(43));
\GRFPU0_GRFPU_X0_L1_5_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"330033000f0f0000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_2\(0),
dataf => \GRFPU0.GRFPU_X0.UN113_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.L1_5_1_1_TZ\(0),
datad => \GRFPU0.GRFPU_X0.BCO_MSB_6_TZ\(0),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(44));
\GRFPU0_GRFPU_X0_BCO_MSB_5_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_5\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(37),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(39));
\GRFPU0_GRFPU_X0_L1_4_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0f00000f00")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_1\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(33),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(32));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(0),
dataf => \GRFPU0.GRFPU_X0.L1_4_1\(3),
datae => \GRFPU0.GRFPU_X0.L1_5_2\(0),
datad => \GRFPU0.GRFPU_X0.UN108_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_5\(0),
datab => \GRFPU0.GRFPU_X0.L1_4_1\(0));
\GRFPU0_GRFPU_X0_L1_3_1_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14255_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(24),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(25));
\GRFPU0_GRFPU_X0_L1_3_1_I_A4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_9794_2\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(26),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(27));
\GRFPU0_GRFPU_X0_BCO_MSB_4_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0f00000f00")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_1\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(28));
GRFPU0_GRFPU_X0_UN98_BCO_LSB_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN98_BCO_LSB_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(18),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(19));
\GRFPU0_GRFPU_X0_L1_2_1_1_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14275_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(16),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(17));
\GRFPU0_GRFPU_X0_L1_2_1_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_1\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(16),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(17),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(18),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(19));
\GRFPU0_GRFPU_X0_L1_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f03300f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2\(0),
dataf => \GRFPU0.GRFPU_X0.UN98_BCO_LSB_0\,
datae => \GRFPU0.GRFPU_X0.N_14275_1\,
datad => \GRFPU0.GRFPU_X0.BCO_MSB_3_1_TZ\(0),
datac => \GRFPU0.GRFPU_X0.L1_2_1_1\(0),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(20));
GRFPU0_GRFPU_X0_UN93_BCO_LSB_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN93_BCO_LSB_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(10),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(11));
\GRFPU0_GRFPU_X0_L1_1_1_2_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14295_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(8),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(9));
\GRFPU0_GRFPU_X0_BCO_MSB_2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(12),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(13),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(14),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(15));
\GRFPU0_GRFPU_X0_L1_0_1_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14345_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(0));
\GRFPU0_GRFPU_X0_BCO_MSB_1_0_I_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ff0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_18526\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(6),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(7));
\GRFPU0_GRFPU_X0_L1_0_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000f0")
port map (
combout => \GRFPU0.GRFPU_X0.L1_0_1\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(0),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(3));
\GRFPU0_GRFPU_X0_L2_0_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000033f033f0")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_1\(0),
dataf => \GRFPU0.GRFPU_X0.N_9804\,
datae => \GRFPU0.GRFPU_X0.L1_1_3\(0),
datad => \GRFPU0.GRFPU_X0.N_9856\,
datac => \GRFPU0.GRFPU_X0.L1_0_1\(0),
datab => \GRFPU0.GRFPU_X0.N_18526\);
\GRFPU0_GRFPU_X0_L3_0_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_1\(0),
dataf => \GRFPU0.GRFPU_X0.N_9793\,
datae => \GRFPU0.GRFPU_X0.L2_0_1\(0),
datad => \GRFPU0.GRFPU_X0.N_9792\,
datac => \GRFPU0.GRFPU_X0.L1_2\(0),
datab => \GRFPU0.GRFPU_X0.L1_3_2\(0));
\GRFPU0_GRFPU_X0_L4_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"44f044f0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_1\(0),
dataf => \GRFPU0.GRFPU_X0.N_9787\,
datae => \GRFPU0.GRFPU_X0.L3_0_1\(0),
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(4),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_1\(0),
datab => \GRFPU0.GRFPU_X0.N_13377\,
dataa => \GRFPU0.GRFPU_X0.ITER.DBUF\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaccaaccfff000f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(23),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(82),
datad => \GRFPU0.GRFPU_X0.N_4401\,
datac => \GRFPU0.MULO.MRES\(83),
datab => \GRFPU0.MULO.DRES_1\(83),
dataa => \GRFPU0.MULO.DRES_1S\(82));
GRFPU0_FPMUL0_R2_RET_87_RNIDT2V: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(116),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(116),
datad => N_28097);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16776\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(116),
datac => \GRFPU0.DIVROM0.RADDR\(4),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(48));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(56),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16776\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(56));
GRFPU0_GRFPU_X0_NXX_1_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.NXX_1_5\,
dataf => \GRFPU0.MULO.MRES\(64),
datae => \GRFPU0.MULO.MRES\(60));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(0),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(0),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(3),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(3),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL1_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL1_1\(4),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(4),
datae => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
GRFPU0_FPMUL0_R2_RET_90_RNI4T2V: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(113),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(113),
datad => N_28091);
\GRFPU0_GRFPU_X0_BCO_MSB_1_2_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff0fff0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_14045\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(33));
\GRFPU0_GRFPU_X0_BCO_MSB_3_6_I_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_13377\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(49),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(50),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(51));
\GRFPU0_GRFPU_X0_L1_2_1_2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000fff0")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_2\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(46),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(48));
\GRFPU0_GRFPU_X0_BCO_MSB_2_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0f00")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_1\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(42),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(43));
\GRFPU0_GRFPU_X0_L1_1_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.L1_1_1\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(37),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(39),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(40));
\GRFPU0_GRFPU_X0_BCO_MSB_1_2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff00f0")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_2\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(33),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
datad => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(36));
\GRFPU0_GRFPU_X0_L2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0\(0),
dataf => \GRFPU0.GRFPU_X0.L1_0_2\(3),
datae => \GRFPU0.GRFPU_X0.L1_0\(0),
datad => \GRFPU0.GRFPU_X0.UN78_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_2_1\(0),
datab => \GRFPU0.GRFPU_X0.L1_1_1\(0));
\GRFPU0_GRFPU_X0_L3_0_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fcc0fccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3\(0),
dataf => \GRFPU0.GRFPU_X0.L2_0\(4),
datae => \GRFPU0.GRFPU_X0.L2_0\(0),
datad => \GRFPU0.GRFPU_X0.UN83_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.N_13377\,
datab => \GRFPU0.GRFPU_X0.L1_2_1_2\(0));
\GRFPU0_GRFPU_X0_L1_2_1_2_I_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14265_1\,
dataf => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
datae => \GRFPU0.GRFPU_X0.ITER.DBUF\(46));
\GRFPU0_GRFPU_X0_L3_0_3_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0ff00cccc")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_3\(2),
dataf => \GRFPU0.GRFPU_X0.L2_0\(4),
datae => \GRFPU0.GRFPU_X0.L1_0_2\(3),
datad => \GRFPU0.GRFPU_X0.UN78_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.UN83_BCO_LSB\(15),
datab => \GRFPU0.GRFPU_X0.UN73_BCO_LSB\(15));
GRFPU0_FPMUL0_R2_RET_86_RNIDT2V: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(117),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(117),
datad => N_28099);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16777\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(117),
datac => \GRFPU0.DIVROM0.RADDR\(5),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(49));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(57),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16777\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(57),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(57));
\GRFPU0_GRFPU_X0_COMB_VST1_EXP2_1_1_I_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3cccccccffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18749\,
dataf => \GRFPU0.GRFPU_X0.N_10059_I\,
datae => \GRFPU0.GRFPU_X0.UN38_EXP_1_CO4\,
datad => \FPI.OP2\(60),
datac => \FPI.OP2\(61),
datab => \FPI.OP2\(62));
\GRFPU0_GRFPU_X0_UN38_EXP_M_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(61),
dataf => \GRFPC0.N_19754\,
datae => \GRFPC0.N_19688\,
datad => N_99880,
datac => \GRFPC0.N_19623\,
datab => \GRFPC0.RFA2.RS2SEL\(7));
\GRFPC0_OP2_3_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19623\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(61),
datad => \GRFPC0.WR.RREG.RES\(61));
\GRFPU0_GRFPU_X0_ST1_EXP2_RNO_0_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3cf0f0f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_14999\,
dataf => \GRFPU0.GRFPU_X0.N_10059_I\,
datae => \GRFPU0.GRFPU_X0.UN38_EXP_1_CO1\,
datad => \FPI.OP2\(58),
datac => \FPI.OP2\(59),
datab => \FPI.OP2\(57));
GRFPU0_GRFPU_X0_UN38_EXP_1_CO1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN38_EXP_1_CO1\,
dataf => \FPI.OP2\(55),
datae => \FPI.OP2\(56));
\GRFPU0_GRFPU_X0_COMB_VST1_EXP2_1_1_I_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f0f0fffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18748\,
dataf => \GRFPU0.GRFPU_X0.N_10059_I\,
datae => \GRFPU0.GRFPU_X0.UN38_EXP_1_CO4\,
datad => \FPI.OP2\(60),
datac => \FPI.OP2\(61));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f333f030c303c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_19__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M68_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M84_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_62_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcecfcecfcecacec")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_49\(18),
datae => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_48\(18),
datad => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_1\,
datac => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_2\,
datab => \GRFPU0.GRFPU_X0.VST3.REG_37\(18),
dataa => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\);
GRFPU0_GRFPU_X0_VST3_REG_2_SQMUXA_2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.VST3.REG_2_SQMUXA_2_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.OP_LT.VST3.REG84\,
datae => \GRFPU0.GRFPU_X0.COMB.OP_GT.VST3.EXC40\);
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fffcff00ffcc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_18__G1\,
dataf => \GRFPU0.GRFPU_X0.N_19016\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datad => \GRFPU0.GRFPU_X0.N_19064\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(47),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(44));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_18__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_2_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_1_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff00000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19052\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M22_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fffcff00ffcc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_14__G1\,
dataf => \GRFPU0.GRFPU_X0.N_19016\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datad => \GRFPU0.GRFPU_X0.N_19052\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(43),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(40));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_1_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff00000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19049\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M21_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fffcff00ffcc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_13__G1\,
dataf => \GRFPU0.GRFPU_X0.N_19016\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datad => \GRFPU0.GRFPU_X0.N_19049\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(42),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(39));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_13__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_2_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000f0f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_25__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M43_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c3f0c033033000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(43),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M37_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c3f0c033033000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(37),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M39_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c33303f0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(39),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M38_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c33303f0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(38),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M45_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f333c303f030c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(45),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M44_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c3f0c033033000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(44),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M47_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f333c303f030c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(47),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M46_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f333c303f030c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(46),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_18_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_18\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(44),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(47),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(46),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(45));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M50_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f333f030c303c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(50),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M66_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M49_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f333f030c303c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(49),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M65_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M20_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M20_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_0_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M4_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(4),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M52_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M20_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M0_4_03_0_G2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M0_4_03_0_G2\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M51_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f333f030c303c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(51),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M67_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M1_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M49_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M17_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M19_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M19_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_0_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M3_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(3),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M51_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M19_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M2_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(2),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M50_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M18_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_16_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_16\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(51),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(2),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(1));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_24_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff8")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_24\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_16\(18),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(50),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(49),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(4),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M0_4_03_0_G2\,
dataa => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_38_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_38\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_24\(18),
datae => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_18\(18),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(37),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(43),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(39),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(38));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M16_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfccc3c00f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(16),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M14_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(14),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M62_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M46_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M15_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(15),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M63_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M47_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M13_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(13),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M45_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M48_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f333f030c303c000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M48_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M64_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M80_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M28_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M28_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M12_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(12),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M44_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M28_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M23_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M23_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M7_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(7),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M23_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M21_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M21_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M5_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(5),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M53_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M21_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_22_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_22\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(48),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(7),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(5),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(12));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_27_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_27\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_22\(18),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(16),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(14),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(15),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(13));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M24_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M24_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M32_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M36_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M8_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(8),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M24_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M6_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(6),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M22_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M10_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(10),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M26_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M29_0_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(0));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M25_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M25_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M33_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M37_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M29_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M9_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(9),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M25_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M40_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c33303f0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(40),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M56_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M72_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M40_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M31_0_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(0),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(1),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(2));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M27_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M27_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M31_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M35_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M39_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M11_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcc0f0cc3c00300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(11),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M43_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M27_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M42_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c3f0c033033000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(42),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M58_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M42_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M41_4_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c3f0c033033000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(41),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M41_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_20_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_20\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(41),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(42),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(40),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(11));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_26_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_26\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_20\(18),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(8),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(6),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(10),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(9));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_45_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_45\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_26\(18),
datae => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_27\(18),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(28),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(29),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(31),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(30));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_49_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_49\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_45\(18),
datae => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_38\(18),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(35),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(34),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(36),
dataa => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(20));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_41_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_41\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(25),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(27),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(26),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(24));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_46_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_46\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_41\(18),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(21),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(32),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(23),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(22));
\GRFPU0_GRFPU_X0_COMB_VST3_REG_53_48_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_48\(18),
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.REG_53_46\(18),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(19),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(18),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(33),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2\(17));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000000cc00cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_25__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_2_03\,
datad => \GRFPU0.GRFPU_X0.N_5774\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(25));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffcc00ccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_20__G1\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datae => \GRFPU0.GRFPU_X0.VST3.REG_37\(49),
datad => \GRFPU0.GRFPU_X0.VST3.REG_47_SN_N_3\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(46),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(49));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_14__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_2_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fffcff00ffcc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_12__G1\,
dataf => \GRFPU0.GRFPU_X0.N_19016\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datad => \GRFPU0.GRFPU_X0.N_19046\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(41),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(38));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_12__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_2_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_28__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M61_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000000cc00cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_27__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_2_03\,
datad => \GRFPU0.GRFPU_X0.N_5774\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(27));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000f0f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_27__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M76_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M60_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000000cc00cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_26__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M5_2_03\,
datad => \GRFPU0.GRFPU_X0.N_5774\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(26));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000f0f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_26__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M59_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f000f0f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_24__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M57_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_22__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M55_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M71_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M8_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_1_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff000000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19058\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M8_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M24_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_1_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0ff00000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19046\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M20_2_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M4_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccc3cccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_5__N_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(5),
datad => N_32517,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(57));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff00ff0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_4__N_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(4),
datad => N_32517,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(56));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccc3cccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_3__N_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(3),
datad => N_32507,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(54),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(55));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff00ff0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_1__N_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(1),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(53));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff00ff0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_6__N_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(6),
datad => N_32527,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(58));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccc3cccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_7__N_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(7),
datad => N_32527,
datac => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(59));
\GRFPU0_GRFPU_X0_ST4_AEXP_RNO_0_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0ff0f0ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_8__N_7\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2_1_9__N_6\,
datae => N_32537,
datad => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(8),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(60));
GRFPU0_GRFPU_X0_UN1_ST3_FARRES_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000f0f")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_ST3.FARRES_2\,
dataf => \GRFPU0.GRFPU_X0.N_7278\,
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datac => \GRFPU0.GRFPU_X0.ST3.DIFFV\);
GRFPU0_GRFPU_X0_COMB_UN1_FLOP4_10_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc0f000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7296\,
dataf => \GRFPU0.GRFPU_X0.N_18515\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_FLOP4_10_0_A3_0\,
datad => \GRFPU0.GRFPU_X0.N_18449\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(6));
GRFPU0_GRFPU_X0_COMB_VST4_SEL5_0_A3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c000000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18515\,
dataf => \GRFPU0.GRFPU_X0.N_18449\,
datae => \GRFPU0.GRFPU_X0.N_18513\,
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(0));
GRFPU0_GRFPU_X0_COMB_ADDI3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcccfffff000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ADDI3\,
dataf => \GRFPU0.GRFPU_X0.N_18516\,
datae => \GRFPU0.GRFPU_X0.N_7296\,
datad => \GRFPU0.GRFPU_X0.N_18515\,
datac => \GRFPU0.GRFPU_X0.N_18509\,
datab => \GRFPU0.GRFPU_X0.N_18513\);
GRFPU0_GRFPU_X0_COMB_UN1_ADDI3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ADDI3\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
datae => \GRFPU0.GRFPU_X0.COMB.ADDI3\,
datad => \GRFPU0.GRFPU_X0.ST3.EMAX\,
datac => \GRFPU0.GRFPU_X0.ST3.EMINM1\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_DP_1_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc00f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7278\,
dataf => \GRFPU0.GRFPU_X0.UN3_S3ADDO1_CARRY_26\,
datae => \GRFPU0.GRFPU_X0.UN4_S3ADDO3_CARRY_23\,
datad => N_28276,
datac => \GRFPU0.GRFPU_X0.N_8976\,
datab => \GRFPU0.GRFPU_X0.N_8975\);
GRFPU0_GRFPU_X0_UN1_EXPDEC_DP_1_SQMUXA_RNIJL9E1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f000f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.ADDOF_1\,
dataf => \GRFPU0.GRFPU_X0.N_7278\,
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datac => \GRFPU0.GRFPU_X0.ST3.EMAX\);
\GRFPU0_GRFPU_X0_ST3_FARRES_RNIFH5V_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_3274\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(54));
GRFPU0_GRFPU_X0_COMB_UN1_EXPCC_2_0_A2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000003")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_EXPCC_2_0_A2_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(7),
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(6),
datad => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(8),
datac => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(0));
GRFPU0_GRFPU_X0_COMB_UN1_EXPCC_1_0_A2_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_EXPCC_1_0_A2_0_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(7),
datae => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(6),
datad => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(0));
GRFPU0_GRFPU_X0_COMB_CCUF_1_I_M3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fff33f03f0f3300")
port map (
combout => \GRFPU0.GRFPU_X0.N_13455\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_EXPCC_2_0_A2_3\,
datae => \GRFPU0.GRFPU_X0.N_18472\,
datad => \GRFPU0.GRFPU_X0.COMB.EXPCC_1\(10),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(62));
GRFPU0_GRFPU_X0_COMB_VST4_SEL5_0_A3_RNIJBQV1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c00ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18523\,
dataf => \GRFPU0.GRFPU_X0.N_18509\,
datae => \GRFPU0.GRFPU_X0.N_18449\,
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(0));
GRFPU0_GRFPU_X0_COMB_VST4_SEL5_0_A3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030000000ff00ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18509\,
dataf => \GRFPU0.GRFPU_X0.N_18449\,
datae => \GRFPU0.GRFPU_X0.N_18500\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(5));
GRFPU0_GRFPU_X0_COMB_UN1_FLOP4_0_0_A3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18516\,
dataf => \GRFPU0.GRFPU_X0.N_18509\,
datae => \GRFPU0.GRFPU_X0.N_18449\,
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(0));
GRFPU0_GRFPU_X0_COMB_ADDI2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.ADDI2\,
dataf => \GRFPU0.GRFPU_X0.N_18516\,
datae => \GRFPU0.GRFPU_X0.N_18523\,
datad => \GRFPU0.GRFPU_X0.N_18449\,
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(3));
GRFPU0_GRFPU_X0_COMB_VST1_V2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff3c000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.V2\,
dataf => \GRFPU0.GRFPU_X0.N_17542\,
datae => \GRFPU0.GRFPU_X0.COMB.VST1.V2_1_A3_0_1\,
datad => \GRFPU0.GRFPU_X0.N_17540\,
datac => \FPI.FLOP\(1),
datab => \FPI.FLOP\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff000300")
port map (
combout => \GRFPC0.N_756\,
dataf => \GRFPC0.N_583\,
datae => \GRFPC0.N_755\,
datad => \GRFPC0.N_490\,
datac => \GRFPC0.N_501\,
datab => \GRFPC0.N_579\);
GRFPC0_FP_PIPELINE_0_STDDEP_246_IV_0_0_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0cfc03f300f00")
port map (
combout => \GRFPC0.N_583\,
dataf => \GRFPC0.N_731\,
datae => \GRFPC0.N_462\,
datad => \GRFPC0.N_149\,
datac => \GRFPC0.N_501\,
datab => \GRFPC0.N_491\);
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_O3_2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000fffff00ff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_O3_2_1\,
dataf => \GRFPC0.N_114\,
datae => \GRFPC0.N_21269\,
datad => \GRFPC0.N_21241\,
datac => \GRFPC0.WR.CTRL.RDD\);
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_A3_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0000000f00000")
port map (
combout => \GRFPC0.N_21290\,
dataf => \GRFPC0.N_22173_I\,
datae => \GRFPC0.N_21327\,
datad => \GRFPC0.N_74_I_I\,
datac => \GRFPC0.N_21241\);
GRFPC0_FP_PIPELINE_0_STDDEP_312_IV_0_M3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000f000f0fff0")
port map (
combout => \GRFPC0.N_21266\,
dataf => \GRFPC0.N_21290\,
datae => \GRFPC0.FP_PIPELINE.0.STDDEP_312_IV_0_O3_2_1\,
datad => \GRFPC0.N_53\,
datac => \GRFPC0.N_579\);
\GRFPC0_D_STLCK_RNO_7_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00300000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O3_0_0\(1),
dataf => \GRFPC0.N_63\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_24935\,
datac => \GRFPC0.N_23961\,
datab => \GRFPC0.FIFO.INST_0\(19));
\GRFPC0_D_STLCK_RNO_6_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc0c0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_358_I_M_I_O2_1\(1),
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datad => \GRFPC0.N_21225\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datab => \GRFPC0.N_59\);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16738\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
datac => \GRFPU0.MULO.MRES\(78),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(10));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(18),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16738\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(18),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(18));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16739\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
datac => \GRFPU0.MULO.MRES\(79),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(11));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(19),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16739\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(19),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(19));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16736\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
datac => \GRFPU0.MULO.MRES\(76),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(16),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16736\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(16),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(16));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0ccccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16737\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
datac => \GRFPU0.MULO.MRES\(77),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(9));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(17),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16737\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(17),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(17));
\GRFPU0_GRFPU_X0_L4_6_RNI8P041_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0ff00ff00ff0fcf")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__G4\,
dataf => \GRFPU0.GRFPU_X0.L4_6\(0),
datae => \GRFPU0.GRFPU_X0.L4_6\(1),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datab => \GRFPU0.GRFPU_X0.ITER.ODDEXP\);
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_4_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(4),
dataf => \GRFPU0.GRFPU_X0.L1_4_4\(3),
datae => \GRFPU0.GRFPU_X0.L1_5_4\(3));
GRFPU0_GRFPU_X0_UN33_BCO_LSB_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN33_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(57),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(59));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_4_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(2),
dataf => \GRFPU0.GRFPU_X0.L1_4_4\(3),
datae => \GRFPU0.GRFPU_X0.UN23_BCO_LSB\(15),
datad => \GRFPU0.GRFPU_X0.UN28_BCO_LSB\(15));
\GRFPU0_GRFPU_X0_L4_6_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_6\(2),
dataf => \GRFPU0.GRFPU_X0.N_9542\,
datae => \GRFPU0.GRFPU_X0.L3_0_6\(2),
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(2),
datab => \GRFPU0.GRFPU_X0.UN33_BCO_LSB\(15));
\GRFPU0_GRFPU_X0_L4_6_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33f033f0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_6\(1),
dataf => \GRFPU0.GRFPU_X0.N_9542\,
datae => \GRFPU0.GRFPU_X0.L3_0_6\(1),
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(1),
datab => \GRFPU0.GRFPU_X0.N_13725\);
\GRFPU0_GRFPU_X0_L2_0_4_2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_9548_2\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(52),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(51),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(22),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(23));
\GRFPU0_GRFPU_X0_L1_1_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f0ff00ff00")
port map (
combout => N_82198,
dataf => \GRFPU0.GRFPU_X0.N_9595\,
datae => \GRFPU0.GRFPU_X0.N_9548_2\,
datad => \GRFPU0.GRFPU_X0.N_13835_1\,
datac => \GRFPU0.GRFPU_X0.N_13675_1\);
\GRFPU0_GRFPU_X0_BCO_MSB_1_5_I_A4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030303000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_13648\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(44),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(43),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(14),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(15));
\GRFPU0_GRFPU_X0_L3_0_6_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc0fcc0f0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_6\(1),
dataf => \GRFPU0.GRFPU_X0.N_9548\,
datae => N_82214,
datad => \GRFPU0.GRFPU_X0.N_9547\,
datac => N_82196,
datab => \GRFPU0.GRFPU_X0.L1_3_5\(1));
\GRFPU0_GRFPU_X0_L1_6_1_5_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fff3ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_13725\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(57),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(59));
\GRFPU0_GRFPU_X0_BCO_MSB_6_3_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_13625\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(55),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(53),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(52));
\GRFPU0_GRFPU_X0_L1_5_6_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff03ff03ff")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_6\(1),
dataf => \GRFPU0.GRFPU_X0.UN28_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.N_13625\,
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(49),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(48));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(1),
dataf => \GRFPU0.GRFPU_X0.L1_4_4\(3),
datae => \GRFPU0.GRFPU_X0.L1_4_5\(1),
datad => \GRFPU0.GRFPU_X0.L1_5_6\(1));
\GRFPU0_GRFPU_X0_BCO_MSB_4_3_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfcffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_13705\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(39),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(38),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(37),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(36));
\GRFPU0_GRFPU_X0_L1_3_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff03ff03ff")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_5\(1),
dataf => \GRFPU0.GRFPU_X0.N_9549\,
datae => \GRFPU0.GRFPU_X0.N_13705\,
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(33),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(32));
\GRFPU0_GRFPU_X0_L1_2_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffff0f0c")
port map (
combout => N_82196,
dataf => \GRFPU0.GRFPU_X0.TZI\(19),
datae => \GRFPU0.GRFPU_X0.N_13815_1\,
datad => \GRFPU0.GRFPU_X0.N_13638\,
datac => \GRFPU0.GRFPU_X0.TZI\(18),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_3_5_I_0\(1));
GRFPU0_FPMUL0_R2_RET_98_RNIBP2V: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(105),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(105),
datad => N_28075);
\GRFPU0_GRFPU_X0_BCO_MSB_5_3_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcccfffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_13655\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(44),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(47),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(46),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(45));
\GRFPU0_GRFPU_X0_L1_4_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff03ff03ff")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_5\(1),
dataf => \GRFPU0.GRFPU_X0.UN23_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.N_13655\,
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(41),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(40));
GRFPU0_FPMUL0_R2_RET_97_RNIBP2V: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(106),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(106),
datad => N_28077);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16766\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(106),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(46),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16766\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(46),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(46));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(49),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16769\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(49),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(49));
GRFPU0_FPMUL0_R2_RET_94_RNIBP2V: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(109),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(109),
datad => N_28083);
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16769\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(109),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(41));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_1_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16972\,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(49));
\GRFPU0_GRFPU_X0_L1_6_1_5_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f0c00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_6_1_5\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(57),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(56),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(59));
GRFPU0_GRFPU_X0_UN28_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN28_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(49),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(51),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(48));
\GRFPU0_GRFPU_X0_BCO_MSB_6_3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0c00000000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_6_3\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(52),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(53),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(55));
\GRFPU0_GRFPU_X0_L1_5_1_5_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000c00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_5_1_5\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(49),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(48),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(50),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(51));
GRFPU0_GRFPU_X0_UN23_BCO_LSB_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.UN23_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(41),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(43),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(42),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(40));
\GRFPU0_GRFPU_X0_BCO_MSB_5_3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0c00000000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_5_3\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(44),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(45),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(46),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(47));
\GRFPU0_GRFPU_X0_L1_4_1_4_0_TZ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0f0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_1_4_TZ\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(41),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(43),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(42));
\GRFPU0_GRFPU_X0_L1_4_5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00003f003f00")
port map (
combout => \GRFPU0.GRFPU_X0.L1_4_5\(0),
dataf => \GRFPU0.GRFPU_X0.UN23_BCO_LSB\(15),
datae => \GRFPU0.GRFPU_X0.BCO_MSB_5_3\(0),
datad => \GRFPU0.GRFPU_X0.L1_4_1_4_TZ\(0),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(40));
\GRFPU0_GRFPU_X0_COMB_TZ_L2_2_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(0),
dataf => \GRFPU0.GRFPU_X0.L1_4_4\(3),
datae => \GRFPU0.GRFPU_X0.L1_4_5\(0),
datad => \GRFPU0.GRFPU_X0.UN28_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_6_3\(0),
datab => \GRFPU0.GRFPU_X0.L1_5_1_5\(0));
GRFPU0_GRFPU_X0_UN18_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_9549\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(33),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(32),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(35),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(34));
\GRFPU0_GRFPU_X0_BCO_MSB_4_3_0_TZ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_4_3_TZ\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(37),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(38),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(39));
\GRFPU0_GRFPU_X0_L1_3_1_3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0c00000000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_1_3\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(32),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(33),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(34),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(35));
\GRFPU0_GRFPU_X0_L1_3_5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f003f00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_3_5\(0),
dataf => \GRFPU0.GRFPU_X0.N_9549\,
datae => \GRFPU0.GRFPU_X0.L1_3_1_3\(0),
datad => \GRFPU0.GRFPU_X0.BCO_MSB_4_3_TZ\(0),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(36));
\GRFPU0_GRFPU_X0_TZI_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(20),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(57),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(28));
\GRFPU0_GRFPU_X0_TZI_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(16),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(53),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(24));
\GRFPU0_GRFPU_X0_TZI_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(18),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(55),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(26));
\GRFPU0_GRFPU_X0_TZI_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(19),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(56),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(27));
\GRFPU0_GRFPU_X0_L1_2_1_4_0_TZ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ffffccf0ccf0")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_1_4_TZ\(0),
dataf => \GRFPU0.GRFPU_X0.TZI\(19),
datae => \GRFPU0.GRFPU_X0.TZI\(18),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(25));
\GRFPU0_GRFPU_X0_L1_2_5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f000f033330000")
port map (
combout => \GRFPU0.GRFPU_X0.L1_2_5\(0),
dataf => \GRFPU0.GRFPU_X0.N_9554\,
datae => \GRFPU0.GRFPU_X0.L1_2_1_4_TZ\(0),
datad => \GRFPU0.GRFPU_X0.TZI\(20),
datac => \GRFPU0.GRFPU_X0.BCO_MSB_3_5_TZ\(0),
datab => \GRFPU0.GRFPU_X0.TZI\(16));
GRFPU0_GRFPU_X0_UN8_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000330f")
port map (
combout => \GRFPU0.GRFPU_X0.N_9595\,
dataf => \GRFPU0.GRFPU_X0.N_13835_1\,
datae => \GRFPU0.GRFPU_X0.TZI\(11),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(47),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(18));
\GRFPU0_GRFPU_X0_BCO_MSB_2_6_0_A4_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030303000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_2_6_0_A4_0_0\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(52),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(51),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(23),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(22));
\GRFPU0_GRFPU_X0_TZI_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(9),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(46),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(17));
\GRFPU0_GRFPU_X0_TZI_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(11),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(48),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(19));
GRFPU0_GRFPU_X0_UN2_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000330f")
port map (
combout => \GRFPU0.GRFPU_X0.N_9608\,
dataf => \GRFPU0.GRFPU_X0.N_13845_1\,
datae => \GRFPU0.GRFPU_X0.TZI\(3),
datad => \GRFPU0.GRFPU_X0.ITER.DP\,
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(39),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(10));
\GRFPU0_GRFPU_X0_TZI_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(5),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(42),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(13));
\GRFPU0_GRFPU_X0_BCO_MSB_1_5_0_A4_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3030303000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.BCO_MSB_1_5_0_A4_0_0\(0),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(44),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(43),
datac => \GRFPU0.GRFPU_X0.ITER.ND_I\(15),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(14));
\GRFPU0_GRFPU_X0_TZI_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(1),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(38),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(9));
\GRFPU0_GRFPU_X0_TZI_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.TZI\(3),
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.ND_I\(40),
datad => \GRFPU0.GRFPU_X0.ITER.ND_I\(11));
\GRFPU0_GRFPU_X0_L2_0_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L2_0_4\(0),
dataf => \GRFPU0.GRFPU_X0.N_9559\,
datae => \GRFPU0.GRFPU_X0.L1_0_6\(0),
datad => \GRFPU0.GRFPU_X0.N_9595\,
datac => \GRFPU0.GRFPU_X0.L1_1_1_4\(0),
datab => \GRFPU0.GRFPU_X0.BCO_MSB_2_6\(0));
\GRFPU0_GRFPU_X0_L3_0_6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_6\(0),
dataf => \GRFPU0.GRFPU_X0.N_9548\,
datae => \GRFPU0.GRFPU_X0.L2_0_4\(0),
datad => \GRFPU0.GRFPU_X0.N_9547\,
datac => \GRFPU0.GRFPU_X0.L1_2_5\(0),
datab => \GRFPU0.GRFPU_X0.L1_3_5\(0));
\GRFPU0_GRFPU_X0_L4_6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L4_6\(0),
dataf => \GRFPU0.GRFPU_X0.N_9542\,
datae => \GRFPU0.GRFPU_X0.L3_0_6\(0),
datad => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(4),
datac => \GRFPU0.GRFPU_X0.COMB.TZ.L2_2_4\(0),
datab => \GRFPU0.GRFPU_X0.L1_6_1_5\(0));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(35),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16755\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(35));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16755\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(95),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(27));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00cc0c00000c0c")
port map (
combout => \GRFPU0.GRFPU_X0.N_19585\,
dataf => \GRFPU0.GRFPU_X0.N_19554\,
datae => \GRFPU0.GRFPU_X0.N_19549\,
datad => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_2\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(53));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00cc0c00000c0c")
port map (
combout => \GRFPU0.GRFPU_X0.N_19590\,
dataf => \GRFPU0.GRFPU_X0.N_19554\,
datae => \GRFPU0.GRFPU_X0.N_19549\,
datad => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_2\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(54));
\GRFPU0_GRFPU_X0_L3_0_7_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_7\(2),
dataf => \GRFPU0.GRFPU_X0.L2_0_6\(4),
datae => \GRFPU0.GRFPU_X0.L2_0_6\(2),
datad => \GRFPU0.GRFPU_X0.L1_2_5\(3),
datac => \GRFPU0.GRFPU_X0.UN253_BCO_LSB\(15),
datab => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L1_3\(2));
\GRFPU0_GRFPU_X0_L2_0_6_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => N_82213,
dataf => \GRFPU0.GRFPU_X0.L1_0_6\(3),
datae => N_82194,
datad => \GRFPU0.GRFPU_X0.UN248_BCO_LSB\(15),
datac => \GRFPU0.GRFPU_X0.N_13572_1\,
datab => \GRFPU0.GRFPU_X0.N_13532_1\);
\GRFPU0_GRFPU_X0_COMB_LZ_TZ_L2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fcf0fcf0")
port map (
combout => N_82225,
dataf => \GRFPU0.GRFPU_X0.L1_2_5\(3),
datae => N_82195,
datad => \GRFPU0.GRFPU_X0.UN253_BCO_LSB_1\(15),
datac => \GRFPU0.GRFPU_X0.N_13562_1\,
datab => \GRFPU0.GRFPU_X0.N_13512\);
GRFPU0_GRFPU_X0_UN248_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000003f3")
port map (
combout => \GRFPU0.GRFPU_X0.UN248_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.N_13572_1\,
datae => \GRFPU0.GRFPU_X0.N_19566\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(20),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(52));
\GRFPU0_GRFPU_X0_INF_ABS0_3_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(19),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(19),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(51));
\GRFPU0_GRFPU_X0_INF_ABS0_3_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(18),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(18),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(50));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0ffffcfc00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(2),
dataf => \GRFPU0.GRFPU_X0.N_15214\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(2),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2));
\GRFPU0_GRFPU_X0_INF_ABS0_3_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(11),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(11),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(43));
\GRFPU0_GRFPU_X0_INF_ABS0_3_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(10),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(10),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(42));
\GRFPU0_GRFPU_X0_L1_2_5_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000300030003ff03")
port map (
combout => \GRFPU0.GRFPU_X0.N_13515\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(9),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(8),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(40),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(41));
\GRFPU0_GRFPU_X0_INF_ABS0_3_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(26),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(26),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(58));
GRFPU0_GRFPU_X0_INF_ABS0_A_0_CARRY_24_RNIOEJB2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000300030003ff03")
port map (
combout => \GRFPU0.GRFPU_X0.N_13525\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(25),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(24),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(56),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(57));
\GRFPU0_GRFPU_X0_BCO_MSB_1_7_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffc0c")
port map (
combout => \GRFPU0.GRFPU_X0.N_13522\,
dataf => \GRFPU0.GRFPU_X0.N_13525\,
datae => \GRFPU0.GRFPU_X0.INF_ABS0_3\(26),
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(27),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(59));
\GRFPU0_GRFPU_X0_L3_0_7_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.L3_0_7\(3),
dataf => \GRFPU0.GRFPU_X0.L2_0_6\(4),
datae => \GRFPU0.GRFPU_X0.L1_0_6\(3),
datad => \GRFPU0.GRFPU_X0.L1_2_5\(3),
datac => \GRFPU0.GRFPU_X0.COMB.LZ.TZ.L1_3\(3));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_1_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1_0_51__G0_0_A3_0_1\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1_0_51__G0_0_A3_0_0\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.DIVROM0.RADDR\(7),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000c000ffffc000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(51),
dataf => \GRFPU0.GRFPU_X0.N_287\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1_0_51__G0_0_A3_0_1\,
datad => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(31),
datac => \GRFPU0.GRFPU_X0.N_3476\,
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(63));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f0f0f000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_19960\,
dataf => \GRFPU0.GRFPU_X0.N_19547\,
datae => \GRFPU0.GRFPU_X0.N_18969\,
datad => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(55));
GRFPU0_GRFPU_X0_VST2_REG_1_SQMUXA_2_RNINUKB2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19592_1\,
dataf => \GRFPU0.GRFPU_X0.N_19554\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datad => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_2\);
GRFPU0_GRFPU_X0_UN243_BCO_LSB_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000300030003ff03")
port map (
combout => \GRFPU0.GRFPU_X0.N_13441\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(29),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(28),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(61));
\GRFPU0_GRFPU_X0_INF_ABS0_3_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(30),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(30),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(62));
\GRFPU0_GRFPU_X0_L1_0_1_6_0_A3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00300030ff300030")
port map (
combout => \GRFPU0.GRFPU_X0.N_13440\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(29),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(28),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(61));
\GRFPU0_GRFPU_X0_INF_ABS0_3_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(31),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(31),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63));
GRFPU0_GRFPU_X0_UN258_BCO_LSB_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000300030003ff03")
port map (
combout => \GRFPU0.GRFPU_X0.UN258_BCO_LSB_0_0\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(5),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(4),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(37));
GRFPU0_GRFPU_X0_UN242_BCO_MSB_0_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00ff000f")
port map (
combout => \GRFPU0.GRFPU_X0.UN242_BCO_MSB_1\(15),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(1),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(33));
\GRFPU0_GRFPU_X0_INF_ABS0_3_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(3),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(3),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(35));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M2_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19788\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(2),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(34));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf0ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(23),
dataf => \GRFPU0.GRFPU_X0.N_18203\,
datae => \GRFPU0.GRFPU_X0.N_16743\,
datad => \GRFPU0.GRFPU_X0.N_18548\,
datac => \GRFPU0.GRFPU_X0.ITER.DBUF\(23),
datab => \GRFPU0.GRFPU_X0.ITER.ND_I\(23));
\GRFPU0_GRFPU_X0_INF_ABS0_3_I_M3_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19566\,
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(21),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(53));
\GRFPU0_GRFPU_X0_COMB_VITER_ND_I_1_3_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ccccff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_16743\,
dataf => \GRFPU0.GRFPU_X0.N_68\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1_SN_N_4\,
datad => \GRFPU0.MULO.MRES\(83),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(15));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc30fc300000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_30__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.UN6_SGNFX\(1),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(30),
datab => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\);
\GRFPU0_GRFPU_X0_ST4_REG_RNO_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc30fc300000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_29__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.UN6_SGNFX\(0),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(29),
datab => \GRFPU0.GRFPU_X0.VST4.REG_0_SQMUXA\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16399\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(1));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16399\,
datab => \GRFPU0.GRFPU_X0.N_16464\);
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff0f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_2__N_11\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
datae => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST3.REG\(53),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(54));
GRFPU0_GRFPU_X0_COMB_VST4_REG30_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_78_1\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(4));
GRFPU0_GRFPU_X0_COMB_VST4_REG30: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003030000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_5661\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_78_1\,
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(5));
\GRFPU0_GRFPU_X0_COMB_TMP3_1_1_0_IV_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0fcc0fff00cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.TMP316\,
datae => \GRFPU0.GRFPU_X0.N_6071\,
datad => \GRFPU0.GRFPU_X0.ST3.RDY\,
datac => \GRFPU0.GRFPU_X0.ST3.EMAX\,
datab => \GRFPU0.GRFPU_X0.ST3.ZERO\);
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff0f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_5__N_26\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
datae => N_32517,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(57));
GRFPU0_GRFPU_X0_UN23_EXP_ANC3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => N_32649,
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(1),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(3));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f3333f0003333")
port map (
combout => \GRFPU0.GRFPU_X0.N_15545\,
dataf => \GRFPU0.GRFPU_X0.N_16068\,
datae => \GRFPU0.GRFPU_X0.N_14\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(55),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
GRFPU0_GRFPU_X0_COMB_TMP3_1_1_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(0),
dataf => \GRFPU0.GRFPU_X0.ST3.RDY\,
datae => \GRFPU0.GRFPU_X0.ST3.QSNAN\);
\GRFPU0_GRFPU_X0_COMB_VST4_REG_24_1_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0f3333f0003333")
port map (
combout => \GRFPU0.GRFPU_X0.N_15544\,
dataf => \GRFPU0.GRFPU_X0.N_16067\,
datae => \GRFPU0.GRFPU_X0.N_14\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3\(54),
datac => \GRFPU0.GRFPU_X0.COMB.VST4.REG_13_SN_N_6\,
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
GRFPU0_GRFPU_X0_COMB_EXP57: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.EXP57\,
dataf => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0),
datae => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1));
\GRFPU0_GRFPU_X0_COMB_VST4_REG_3_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f00000f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_16401\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
datad => \GRFPU0.GRFPU_X0.ITER.R_I\(11),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(3));
\GRFPU0_GRFPU_X0_ST4_REG_RNO_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ccf00000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_3__N_6\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_5\,
datae => \GRFPU0.GRFPU_X0.N_6806\,
datad => \GRFPU0.GRFPU_X0.COMB.VST4.REG_3_SN_N_4\,
datac => \GRFPU0.GRFPU_X0.N_16401\,
datab => \GRFPU0.GRFPU_X0.N_16466\);
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff0f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_46\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
datae => N_32537,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(60),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(61));
\GRFPU0_GRFPU_X0_ST4_MEXP_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff0f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_7__N_36\,
dataf => \GRFPU0.GRFPU_X0.COMB.EXPINC_1\,
datae => N_32527,
datad => \GRFPU0.GRFPU_X0.ST3.REG\(58),
datac => \GRFPU0.GRFPU_X0.ST3.REG\(59));
GRFPU0_GRFPU_X0_UN1_ST3_REG_ANC1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => N_32507,
dataf => \GRFPU0.GRFPU_X0.ST3.REG\(52),
datae => \GRFPU0.GRFPU_X0.ST3.REG\(53));
GRFPU0_GRFPU_X0_UN23_EXP_SUM3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff0f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.UN23_EXP\(3),
dataf => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datae => \GRFPU0.GRFPU_X0.ITER.EXP\(1),
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(3));
GRFPU0_GRFPU_X0_COMB_TMP316_1_RNO_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_42_0\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(5));
GRFPU0_GRFPU_X0_COMB_TMP316_1_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_41_3\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(4));
GRFPU0_GRFPU_X0_COMB_TMP316_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00300000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6053\,
dataf => \GRFPU0.GRFPU_X0.N_6038\,
datae => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_41_3\,
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(8));
GRFPU0_GRFPU_X0_COMB_TMP316: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TMP316\,
dataf => \GRFPU0.GRFPU_X0.N_6053\,
datae => \GRFPU0.GRFPU_X0.N_8976\,
datad => \GRFPU0.GRFPU_X0.N_8975\);
\GRFPU0_GRFPU_X0_COMB_TMP3_1_1_0_IV_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ccf0ff00cc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(2),
dataf => \GRFPU0.GRFPU_X0.COMB.TMP316\,
datae => \GRFPU0.GRFPU_X0.N_10191\,
datad => \GRFPU0.GRFPU_X0.ST3.RDY\,
datac => \GRFPU0.GRFPU_X0.ST3.EMAX\,
datab => \GRFPU0.GRFPU_X0.ST3.INF\);
\GRFPU0_GRFPU_X0_ITER_STATE_RNIV5L51_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10191\,
dataf => \GRFPU0.GRFPU_X0.ITER.V\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(8));
GRFPU0_GRFPU_X0_COMB_VST4_REG17_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_3\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(2),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(4));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNIHT7H_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6408_2\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(5));
GRFPU0_GRFPU_X0_COMB_VST4_REG17_3_RNIEKCL1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cf00ff00ff00ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_16197_M_0\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST4.REG17_3\,
datae => \GRFPU0.GRFPU_X0.N_6408_2\,
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(8));
\GRFPU0_GRFPU_X0_ST3_FLOP_RNIALJD2_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7502\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN1_ST3.FLOP_3\,
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST3.FLOP\(8));
GRFPU0_GRFPU_X0_COMB_DPRES4_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_6038_3\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(4));
GRFPU0_GRFPU_X0_COMB_DPRES4_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6051_5\,
dataf => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
datae => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
datad => \GRFPU0.GRFPU_X0.ST3.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST3.FLOP\(2));
\GRFPU0_GRFPU_X0_EXP_11_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3cccffff3ccc0000")
port map (
combout => \GRFPU0.GRFPU_X0.EXP_11\(2),
dataf => \GRFPU0.GRFPU_X0.UN1_ITER.SGNFEQ_2\(3),
datae => \GRFPU0.GRFPU_X0.EXP_0_SQMUXA\,
datad => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
datac => \GRFPU0.GRFPU_X0.ITER.EXP\(1),
datab => \GRFPU0.GRFPU_X0.ITER.EXP\(2));
\GRFPU0_GRFPU_X0_REST_1_1_0_IV_RNICNO9_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_5250\);
\GRFPU0_GRFPU_X0_REST_1_1_0_IV_RNICNO9_0_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => N_40510,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.N_5250\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_0_M2_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0fcf0fc")
port map (
combout => \GRFPU0.GRFPU_X0.N_19777\,
dataf => \GRFPU0.GRFPU_X0.N_19547\,
datae => \GRFPU0.GRFPU_X0.N_18969\,
datad => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datac => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datab => \GRFPU0.GRFPU_X0.N_4105\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ffffccf00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(35),
dataf => \GRFPU0.GRFPU_X0.N_17217\,
datae => \GRFPU0.GRFPU_X0.N_19547\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(35),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(35));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf0ffffccf00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_50\(22),
dataf => \GRFPU0.GRFPU_X0.N_17204\,
datae => \GRFPU0.GRFPU_X0.N_19547\,
datad => \GRFPU0.GRFPU_X0.N_18969\,
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(22),
datab => \FPI.OP1_RETO\(22));
\GRFPU0_GRFPU_X0_ST2_REG_RNO_2_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f3300000f330f33")
port map (
combout => \GRFPU0.GRFPU_X0.N_19982\,
dataf => \GRFPU0.GRFPU_X0.N_19546\,
datae => \GRFPU0.GRFPU_X0.N_18998\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(22),
datab => \FPI.OP1_RETO\(22));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_I_M4_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19902\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(59));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_0_O4_0_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc00cc00cc00")
port map (
combout => \GRFPU0.GRFPU_X0.N_19897\,
dataf => \GRFPU0.GRFPU_X0.COMB.SWAP_1\,
datae => \GRFPU0.GRFPU_X0.N_394\,
datad => \GRFPU0.GRFPU_X0.N_18983_I\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_1_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff000000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19064\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M26_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M26_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M26_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M38_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f00cc000000cc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_2__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datad => \GRFPU0.GRFPU_X0.N_5774\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(31));
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_RNIUFIQ2_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
dataf => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__I3_I_3\,
datae => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5));
\GRFPU0_GRFPU_X0_VST3_REG_47_1_A6_1_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19031\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M15_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0fffcff00ffcc")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_7__G1\,
dataf => \GRFPU0.GRFPU_X0.N_19016\,
datae => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__N_4\,
datad => \GRFPU0.GRFPU_X0.N_19031\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(36),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(33));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_1_7__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M69_2_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(57));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_1_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000000cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_21__G1\,
dataf => \GRFPU0.GRFPU_X0.COMB.CNV_SHIFT214\,
datae => \GRFPU0.GRFPU_X0.N_5774\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_2_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(21));
\GRFPU0_GRFPU_X0_ST3_REG_RNO_0_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f00000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62_1_21__G5\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M54_2_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M70_2_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(56),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(57));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M10_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M6_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M10_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M22_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M22_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M34_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M18_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M18_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_0_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M30_0_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M30_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(0),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(1));
\GRFPU0_GRFPU_X0_UN38_EXP_M_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(55),
dataf => \GRFPC0.N_19748\,
datae => \GRFPC0.N_19682\,
datad => N_99880,
datac => \GRFPC0.N_19617\,
datab => \GRFPC0.RFA2.RS2SEL\(7));
\GRFPU0_GRFPU_X0_UN38_EXP_M_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(56),
dataf => \GRFPC0.N_19749\,
datae => \GRFPC0.N_19683\,
datad => N_99880,
datac => \GRFPC0.N_19618\,
datab => \GRFPC0.RFA2.RS2SEL\(7));
\GRFPU0_GRFPU_X0_UN38_EXP_M_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(62),
dataf => \GRFPC0.N_19755\,
datae => \GRFPC0.N_19689\,
datad => N_99880,
datac => \GRFPC0.N_19624\,
datab => \GRFPC0.RFA2.RS2SEL\(7));
\GRFPC0_OP2_3_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19618\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(56),
datad => \GRFPC0.WR.RREG.RES\(56));
\GRFPC0_OP2_3_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19624\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(62),
datad => \GRFPC0.WR.RREG.RES\(62));
\GRFPC0_OP2_3_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19617\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(55),
datad => \GRFPC0.WR.RREG.RES\(55));
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_O2_0_4_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_O2_0_4\(3),
dataf => \FPI.OP2\(60),
datae => \FPI.OP2\(59),
datad => \FPI.OP2\(62),
datac => \FPI.OP2\(57));
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_O2_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff3fffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18867\,
dataf => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_O2_0_4\(3),
datae => \FPI.OP2\(58),
datad => \FPI.OP2\(55),
datac => \FPI.OP2\(56),
datab => \FPI.OP2\(61));
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_O2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18883\,
dataf => \GRFPU0.GRFPU_X0.N_18867\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\);
\GRFPU0_GRFPU_X0_INF_ABS0_3_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(22),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(22),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(54));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65\(42),
dataf => \GRFPU0.GRFPU_X0.N_15254\,
datae => \GRFPU0.GRFPU_X0.N_18983_I\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_62_I_M4_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19937\,
dataf => \GRFPU0.GRFPU_X0.ST1.SGNF1\(3),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_2_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17119\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(3),
datac => \FPI.OP1_RETO\(3));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffccccf000cccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_15215\,
dataf => \GRFPU0.GRFPU_X0.N_17185\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_19547\,
datac => \GRFPU0.GRFPU_X0.N_17119\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(3));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(3),
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(3),
datad => \FPI.OP1_RETO\(3));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_2_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17158\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(42),
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(42));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffccccf000cccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_15254\,
dataf => \GRFPU0.GRFPU_X0.N_17224\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_65_SN_N_2_I\,
datad => \GRFPU0.GRFPU_X0.N_19547\,
datac => \GRFPU0.GRFPU_X0.N_17158\,
datab => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(42));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(42),
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(42),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(42));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_65_1_0_A4_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f00000f0f0f00")
port map (
combout => \GRFPU0.GRFPU_X0.N_272\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG36\,
datae => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datad => \GRFPU0.GRFPU_X0.N_4105\,
datac => \GRFPU0.GRFPU_X0.VST2.REG_1_SQMUXA_2\);
\GRFPU0_GRFPU_X0_REST_1_1_0_IV_RNO_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_13592_M\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(4));
\GRFPU0_GRFPU_X0_REST_1_1_0_IV_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffccccccc0")
port map (
combout => \GRFPU0.GRFPU_X0.REST_2\(5),
dataf => \GRFPU0.GRFPU_X0.N_13592_M\,
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(5));
\GRFPU0_GRFPU_X0_L1_2_1_6_I_A4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000300030003ff03")
port map (
combout => \GRFPU0.GRFPU_X0.UN253_BCO_LSB_1\(15),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(13),
datae => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(12),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW2\(45),
datab => \GRFPU0.GRFPU_X0.ST1.RAW2\(44));
\GRFPU0_GRFPU_X0_INF_ABS0_3_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.INF_ABS0_3\(14),
dataf => \GRFPU0.GRFPU_X0.INF_ABS0_A_0\(14),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(46));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNI07711_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG88\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(7),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(8));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_2_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17179\,
dataf => \GRFPU0.GRFPU_X0.REST_2\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datad => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datac => \GRFPU0.GRFPU_X0.ST1.RAW1\(63));
\GRFPU0_GRFPU_X0_REST_1_1_U_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f00000fff0")
port map (
combout => \GRFPU0.GRFPU_X0.REST_1_1\(2),
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(4));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNINRTP_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__N_7_1\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8));
GRFPU0_GRFPU_X0_COMB_VST2_EXC15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4175\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(6));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_19_1_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0f0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17322\,
dataf => \GRFPU0.GRFPU_X0.C\(11),
datae => \GRFPU0.GRFPU_X0.N_4201\,
datad => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datac => \GRFPU0.GRFPU_X0.ST1.SIGN1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_33_I_0_X2_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_73_I\,
dataf => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(2));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_47_U_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcff0c00fcf00c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_47\(63),
dataf => \GRFPU0.GRFPU_X0.COMB.VST2.REG_19\(63),
datae => \GRFPU0.GRFPU_X0.N_73_I\,
datad => \GRFPU0.GRFPU_X0.N_3504_1\,
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6),
datab => \GRFPU0.GRFPU_X0.ST1.RAW1\(63));
GRFPU0_GRFPU_X0_COMB_VST2_ADD3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4202\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(7));
GRFPU0_GRFPU_X0_ST1_SIGN1_RNINO3O: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_3440\,
dataf => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
datae => \GRFPU0.GRFPU_X0.ST1.SIGN1\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_50_3_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffcc0fccf0cc00")
port map (
combout => \GRFPU0.GRFPU_X0.N_17245\,
dataf => \GRFPU0.GRFPU_X0.N_17110\,
datae => \GRFPU0.GRFPU_X0.COMB.VST2.REG_19\(63),
datad => \GRFPU0.GRFPU_X0.VST2.REG_2_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.UN1_VST2.REG82_1\,
datab => \GRFPU0.GRFPU_X0.N_73_I\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_53_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0cfcfcfc0c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_53\(63),
dataf => \GRFPU0.GRFPU_X0.N_17245\,
datae => \GRFPU0.GRFPU_X0.N_19547\,
datad => \GRFPU0.GRFPU_X0.N_17179\,
datac => \GRFPU0.GRFPU_X0.COMB.VST2.REG88\,
datab => \GRFPU0.GRFPU_X0.ST1.SIGN2\);
\GRFPU0_GRFPU_X0_COMB_VST2_REG_48_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST2.REG_48\(63),
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
datae => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
datad => \GRFPU0.GRFPU_X0.ST1.RAW1\(63));
\GRFPU0_GRFPU_X0_REST_1_2_0_IV_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0f0f0ff00f000")
port map (
combout => \GRFPU0.GRFPU_X0.REST_1_2\(7),
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7));
\GRFPU0_GRFPU_X0_COMB_VST2_REG_68_IV_RNO_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf0c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_3413\,
dataf => \GRFPU0.GRFPU_X0.REST_1_2\(7),
datae => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
datab => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6));
GRFPU0_FPMUL0_R2_RET_124_RNITF2C: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(105),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datae => N_28189,
datad => N_28188);
GRFPU0_FPMUL0_R2_RET_150_RNID72M: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S\(104),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datae => N_28132,
datad => N_28131);
GRFPU0_FPMUL0_R2_RET_125_RNIVF2C: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(104),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datae => N_28187,
datad => N_28186);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(7),
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.DRES_1\(104),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datac => N_28130,
datab => N_28129);
GRFPU0_FPMUL0_R2_RET_122_RNIPF2C: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(107),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datae => N_28193,
datad => N_28192);
GRFPU0_FPMUL0_R2_RET_148_RNII32M: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S\(106),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datae => N_28136,
datad => N_28135);
GRFPU0_FPMUL0_R2_RET_123_RNIRF2C: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(106),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datae => N_28191,
datad => N_28190);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(9),
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.DRES_1\(106),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datac => N_28134,
datab => N_28133);
\GRFPU0_GRFPU_X0_BCO_MSB_2_4_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0f0fffff0ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_13865\,
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(10),
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(8),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(9),
datac => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(7));
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(3),
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datad => \GRFPU0.MULO.DRES_1\(100),
datac => N_28122,
datab => N_28121);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_I_M2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0f0cccccccc")
port map (
combout => \GRFPU0.GRFPU_X0.N_18314\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datad => N_28181,
datac => N_28180,
datab => \GRFPU0.MULO.DRES_1S\(100));
\GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_2_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccf0f000ccf0f0")
port map (
combout => \GRFPU0.GRFPU_X0.N_17023\,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(39),
datae => N_99908_I_0,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.DBUF_1_0\,
datac => \GRFPU0.MULO.MRES\(98),
datab => \GRFPU0.GRFPU_X0.ITER.DBUF\(38));
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_S_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => N_93110,
dataf => \GRFPU0.GRFPU_X0.N_18527\,
datae => \GRFPU0.GRFPU_X0.ITER.V\);
GRFPU0_FPMUL0_R2_RET_105_RNI5ONH: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(98),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(98),
datad => N_28061);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(2),
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.DRES_1\(99),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datac => N_28120,
datab => N_28119);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_1_0_D_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfcfc3030fc3030")
port map (
combout => N_93121,
dataf => \GRFPU0.GRFPU_X0.UN177_RNDOP\(21),
datae => \GRFPU0.GRFPU_X0.UN166_RNDOP\(21),
datad => \GRFPU0.GRFPU_X0.N_11529\,
datac => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_7\(39),
datab => \GRFPU0.GRFPU_X0.ITER.V\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_IV_5_4_RNO_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c00000c000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_47_M\(39),
dataf => \GRFPU0.GRFPU_X0.COMB.UN138_RNDOP\,
datae => \GRFPU0.MULO.MRES\(99),
datad => \GRFPU0.MULO.DRES_1\(99),
datac => \GRFPU0.GRFPU_X0.ITER.DP\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(4));
GRFPU0_FPMUL0_R2_RET_130_RNINN2C: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(99),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datae => N_28177,
datad => N_28176);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_2_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_15125\,
dataf => \GRFPU0.GRFPU_X0.N_4401\,
datae => \GRFPU0.MULO.DRES_1\(99),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datac => N_28120,
datab => N_28119);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_32_3_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00fcfc0c0c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_32\(39),
dataf => \GRFPU0.GRFPU_X0.COMB.UN23_RNDOP\,
datae => \GRFPU0.MULO.DRES_S\(98),
datad => \GRFPU0.GRFPU_X0.N_15125\,
datac => \GRFPU0.GRFPU_X0.N_4401\,
datab => \GRFPU0.MULO.MRES\(99));
GRFPU0_FPMUL0_R2_RET_103_RNI9IIP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(100),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(100),
datad => N_28065);
GRFPU0_FPMUL0_R2_RET_104_RNI5SNH: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.MULO.MRES\(99),
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(99),
datad => N_28063);
\GRFPU0_GRFPU_X0_L1_5_1_3_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0035")
port map (
combout => \GRFPU0.GRFPU_X0.N_13895\,
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(12),
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(11),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(13),
datac => \GRFPU0.MULO.MRES\(120),
datab => \GRFPU0.MULO.DRES_1\(111),
dataa => \GRFPU0.MULO.DRES_1S\(110));
GRFPU0_FPMUL0_R2_RET_118_RNIQB2C: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(111),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datae => N_28201,
datad => N_28200);
GRFPU0_FPMUL0_R2_RET_144_RNIA32M: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S\(110),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datae => N_28144,
datad => N_28143);
GRFPU0_FPMUL0_R2_RET_119_RNISB2C: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1\(110),
dataf => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datae => N_28199,
datad => N_28198);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0ccf0cc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(13),
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.DRES_1\(110),
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datac => N_28142,
datab => N_28141);
GRFPU0_FPMUL0_R2_RET_146_RNIE32M: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S\(108),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datae => N_28140,
datad => N_28139);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(12),
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.DRES_1S\(108),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datac => N_28197,
datab => N_28196);
GRFPU0_FPMUL0_R2_RET_147_RNIG32M: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPU0.MULO.DRES_1S\(107),
dataf => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
datae => N_28138,
datad => N_28137);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccf0ccffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(11),
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.DRES_1S\(107),
datad => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
datac => N_28195,
datab => N_28194);
GRFPU0_GRFPU_X0_UN128_BCO_LSB: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000035")
port map (
combout => \GRFPU0.GRFPU_X0.UN128_BCO_LSB\(15),
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(12),
datae => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(11),
datad => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(13),
datac => \GRFPU0.MULO.MRES\(120),
datab => \GRFPU0.MULO.DRES_1\(111),
dataa => \GRFPU0.MULO.DRES_1S\(110));
GRFPU0_GRFPU_X0_COMB_VST2_ADD2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPU0.GRFPU_X0.N_4201\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datae => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
datad => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(4));
\GRFPC0_FP_PIPELINE_REN2_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00fc00fc00fc0000")
port map (
combout => RFI2_REN2Z,
dataf => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datae => \GRFPC0.N_23598_I_0\,
datad => \GRFPC0.FP_PIPELINE.UN1_VRFA.ST\,
datac => \GRFPC0.FP_PIPELINE.VFIFO.FULL_6\,
datab => \GRFPC0.FP_PIPELINE.VFIFO.FULL10\);
\GRFPC0_D_STLCK_RNO_2_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000c0ffc0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_O2_6_0\(1),
dataf => \GRFPC0.N_810\,
datae => \GRFPC0.N_21866\,
datad => N_40557,
datac => \GRFPC0.N_690\,
datab => \GRFPC0.N_482\);
\GRFPC0_D_STLCK_RNO_0_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc00c000000000")
port map (
combout => \GRFPC0.N_22390\,
dataf => \GRFPC0.N_21878_1\,
datae => \GRFPC0.N_22173_I\,
datad => \GRFPC0.N_689\,
datac => \GRFPC0.N_481\,
datab => \GRFPC0.FP_PIPELINE.7.STDEP_318_I_M_I_A2_7_0\(1));
\GRFPC0_FP_PIPELINE_6_REGDEPX_120_0_A2_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_113_0_A4_0\(1),
dataf => \GRFPC0.FIFO.INST_0\(18),
datae => \GRFPC0.FIFO.INST_0\(17),
datad => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_A2_3_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000ff0f0000")
port map (
combout => \GRFPC0.N_22481\,
dataf => \GRFPC0.FP_PIPELINE.6.0.CHECK_DEP.DEP_2_I\(1),
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.6.0.REGDEPX_113_0_0\(1),
datac => \GRFPC0.FIFO.INST_0\(19));
\GRFPC0_FP_PIPELINE_12_REGDEPX_228_0_A3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fcf00000")
port map (
combout => \GRFPC0.N_23347\,
dataf => \GRFPC0.N_24834\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_24837_1\,
datac => \GRFPC0.N_24836\,
datab => \GRFPC0.FIFO.INST_0\(18));
\GRFPC0_FP_PIPELINE_V_FSR_CEXC_12_M_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.CEXC_12_M\(3),
dataf => \GRFPC0.V.FSR.CEXC_2_SQMUXA\,
datae => \GRFPC0.R.FSR.TEM\(3),
datad => \GRFPC0.WR2.RREG.EXCT\(3));
\GRFPC0_FP_PIPELINE_15_REGDEPX_282_0_A2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000ff00c000")
port map (
combout => \GRFPC0.N_23117\,
dataf => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datae => \GRFPC0.FP_PIPELINE.15.0.REGDEPX_275_0_0\(1),
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_24900\,
datab => \GRFPC0.N_23522_I_1\);
\GRFPC0_FP_PIPELINE_15_REGDEPX_282_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0c0000000000")
port map (
combout => \GRFPC0.N_23131\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_23125\,
datad => \GRFPC0.N_22253\,
datac => \GRFPC0.N_24911\,
datab => \GRFPC0.FP_PIPELINE.15.1.CHECK_DEP.UN4895_REGDEPX_2\);
\GRFPC0_FP_PIPELINE_REGDEPX_1_0_A4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0c0c000000000")
port map (
combout => \GRFPC0.N_25603\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datae => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4999_REGDEPX\,
datad => \GRFPC0.N_23978\,
datac => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_I_A3_0_0\(3),
datab => \GRFPC0.N_9468\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_4_1_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_23349_1\,
dataf => \GRFPC0.N_21626\,
datae => \GRFPC0.FIFO.INST_1\(17),
datad => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_1\(15),
datab => \GRFPC0.FIFO.INST_1\(16));
GRFPC0_RFA_RS1D_RNI8F091_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c00ff0c0c0000")
port map (
combout => N_99879,
dataf => \GRFPC0.N_235\,
datae => \GRFPC0.RFA.ST\,
datad => \GRFPC0.RFA.RS1D\,
datac => N_167,
datab => N_172);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_4_2_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_2\(14),
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.FIFO.INST_0\(29),
datad => \GRFPC0.FIFO.INST_0\(26),
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28));
GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_UN61_REGDEPX_2_I_O3_I_A2_0_A2_0_A2_RNIA8852: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => \GRFPC0.N_22762\,
dataf => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datae => \GRFPC0.N_543_1\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_2\,
datac => \GRFPC0.FIFO.INST_0\(26),
datab => \GRFPC0.FIFO.INST_0\(27));
\GRFPC0_FP_PIPELINE_DBGDATA_4_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => CPO_DBG_DATAZ(17),
dataf => N_425,
datae => N_426,
datad => N_708,
datac => N_644);
\GRFPC0_FP_PIPELINE_DBGDATA_4_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => CPO_DBG_DATAZ(12),
dataf => N_425,
datae => N_426,
datad => N_703,
datac => N_639);
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN928_REGDEPX_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN928_REGDEPX_1\,
dataf => N_94,
datae => N_93);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_5_0_A2_RNIN6VV3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.N_169\,
dataf => \GRFPC0.N_22579\,
datae => \GRFPC0.N_22546\,
datad => \GRFPC0.N_9478\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datab => \GRFPC0.N_59\);
\GRFPC0_D_STLCK_RNO_0_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cf00ff00ff00ff00")
port map (
combout => \GRFPC0.N_22582\,
dataf => \GRFPC0.N_742_1\,
datae => \GRFPC0.N_21701\,
datad => \GRFPC0.FP_PIPELINE.5.STDEP_238_I_M_I_A2_1_4\(1),
datac => \GRFPC0.N_21615\,
datab => \GRFPC0.N_663\);
GRFPC0_FP_PIPELINE_4_STDEP_172_SEL0_0_0_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_470\,
dataf => \GRFPC0.N_579\,
datae => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_R_FSR_AEXC_RNO_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffcf000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_2_M\(1),
dataf => \GRFPC0.V.FSR.CEXC_5_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.N_18290_I_0\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.R.FSR.AEXC\(1),
datab => \GRFPC0.WR2.RREG.EXCT\(1));
GRFPC0_FP_PIPELINE_0_UN1_EX_CTRL_DIV: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
dataf => \GRFPC0.EX.RREG.RESV\,
datae => \GRFPC0.EX.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O3_0_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00ffff00")
port map (
combout => \GRFPC0.N_21627\,
dataf => N_97,
datae => N_90,
datad => N_89);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(6),
dataf => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(6));
GRFPU0_GRFPU_X0_COMB_MULBP_1_RNO_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_4\,
dataf => \FPI.FLOP\(0),
datae => \FPI.FLOP\(5),
datad => \FPI.FLOP\(3),
datac => \FPI.FLOP\(4),
datab => \GRFPC0.DIVI_0_SQMUXA_1_2\);
GRFPU0_GRFPU_X0_COMB_MULBP_1_RNO_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_0_1\,
dataf => \FPI.FLOP\(1),
datae => \FPI.FLOP\(6),
datad => \FPI.FLOP\(0),
datac => \FPI.FLOP\(7),
datab => \FPI.FLOP\(2));
GRFPU0_GRFPU_X0_COMB_MULBP_1_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7363\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN2_FLOP_0_1\,
datae => \FPI.FLOP\(3),
datad => \FPI.FLOP\(4),
datac => \FPI.FLOP\(8));
GRFPU0_GRFPU_X0_COMB_VST1_V2_1_O3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000f0f0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_17540\,
dataf => \FPI.FLOP\(7),
datae => \FPI.FLOP\(2),
datad => \FPI.FLOP\(4),
datac => \FPI.FLOP\(8));
GRFPU0_GRFPU_X0_ST1_V_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c3f03c0f0fc3f03c")
port map (
combout => \GRFPU0.GRFPU_X0.N_181_I_I\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.ALTB\(3),
datae => \FPI.OPID\(5),
datad => \FPI.OPID\(4),
datac => \FPI.FLUSHID\(5),
datab => \FPI.FLUSHID\(4));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(32),
dataf => \GRFPU0.GRFPU_X0.N_21\,
datae => \GRFPU0.GRFPU_X0.N_18746\,
datad => \FPI.OP1\(35),
datac => \FPI.OP1\(32));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(40),
dataf => \GRFPU0.GRFPU_X0.N_21\,
datae => \GRFPU0.GRFPU_X0.N_18746\,
datad => \FPI.OP1\(40),
datac => \FPI.OP1\(43));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(41),
dataf => \GRFPU0.GRFPU_X0.N_21\,
datae => \GRFPU0.GRFPU_X0.N_18746\,
datad => \FPI.OP1\(41),
datac => \FPI.OP1\(44));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(43),
dataf => \GRFPU0.GRFPU_X0.N_21\,
datae => \GRFPU0.GRFPU_X0.N_18746\,
datad => \FPI.OP1\(43),
datac => \FPI.OP1\(46));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(47),
dataf => \GRFPU0.GRFPU_X0.N_21\,
datae => \GRFPU0.GRFPU_X0.N_18746\,
datad => \FPI.OP1\(47),
datac => \FPI.OP1\(50));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(46),
dataf => \GRFPU0.GRFPU_X0.N_21\,
datae => \GRFPU0.GRFPU_X0.N_18746\,
datad => \FPI.OP1\(49),
datac => \FPI.OP1\(46));
GRFPC0_FP_PIPELINE_V_STDATA_1_M0S2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff00ff")
port map (
combout => N_25,
dataf => \GRFPC0.EX.CTRL.PEND\,
datae => N_249,
datad => N_248);
\GRFPC0_FP_PIPELINE_12_0_REGDEPX_221_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000c0000")
port map (
combout => \GRFPC0.N_24834\,
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.N_23522_I_1\,
datad => \GRFPC0.FIFO.INST_0\(26),
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_1_2_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_22370_3\,
dataf => N_95,
datae => N_96);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_4_1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_22742_2\,
dataf => N_80,
datae => N_79);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_5_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_23421\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_24910\,
datad => \GRFPC0.N_22899_1\,
datac => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_1\(18));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN4063_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN4063_REGDEPX\,
dataf => N_80,
datae => N_79,
datad => N_82,
datac => N_81);
GRFPC0_RFA2_RS2DEP_RNO_9: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0c00f0c00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_0_1\,
dataf => \GRFPC0.FP_PIPELINE.1.REGDEP160\,
datae => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9\,
datac => \GRFPC0.EX.CTRL.RD\(0),
datab => \GRFPC0.EX.RREG.RESV\);
GRFPC0_RFA2_RS2DEP_RNO_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f00000ff00f0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_0_0\,
dataf => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datad => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.MEM.RREG.RESV\);
GRFPC0_FP_PIPELINE_1_REGDEP132: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0003000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP132\,
dataf => \GRFPC0.FP_PIPELINE.1.WRENX10_1\,
datae => RFI2_RD2ADDRZ(2),
datad => \GRFPC0.FP_PIPELINE.1.UN1_WR.CTRL.RD_2_1\,
datac => \GRFPC0.WR.CTRL.RDWR\,
datab => \GRFPC0.WR.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_1_REGDEP146: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0003000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP146\,
dataf => \GRFPC0.FPUSEL_1_0_3__G0_E_0_0\,
datae => RFI2_RD2ADDRZ(1),
datad => \GRFPC0.FP_PIPELINE.1.UN1_MEM.CTRL.RD_2_4\,
datac => \GRFPC0.MEM.CTRL.RDWR\,
datab => \GRFPC0.MEM.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_0_UN1_FPO_9_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9_2\,
dataf => \FPO.IDOUT\(1),
datae => \FPO.IDOUT\(3),
datad => \GRFPC0.EX.CTRL.ID\(1),
datac => \GRFPC0.EX.CTRL.ID\(3));
GRFPC0_RFA2_RS1DEP_RNO_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f00000ff00f0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP66_I_M_0_3\,
dataf => \GRFPC0.N_23599_I_0\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_9\,
datad => \GRFPC0.N_106_I\,
datac => \GRFPC0.EX.RREG.RESV\);
GRFPC0_RFA2_RS1DEP_RNO_7: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f00000ff00f0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP50_I_M_0_3\,
dataf => \GRFPC0.N_23599_I_0\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datad => \GRFPC0.N_579\,
datac => \GRFPC0.MEM.RREG.RESV\);
GRFPC0_RFA2_RS1DEP_RNO_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff00000000ff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP34_I_M_0_3\,
dataf => \GRFPC0.N_23599_I_0\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEP34\,
datad => \GRFPC0.WR.CTRL.RDD\);
GRFPC0_RFA2_RS1DEP_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f6ffffff00000000")
port map (
combout => \GRFPC0.RFA2.RS1DEP_0_0_G1_1\,
dataf => \GRFPC0.RFA2.RS1DEP_0_0_G1_0\,
datae => \GRFPC0.REGDEP_2_SQMUXA_2\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEP34_I_M_0_3\,
datac => \GRFPC0.N_21347\,
datab => \GRFPC0.N_22829\,
dataa => \GRFPC0.WR.CTRL.RD\(0));
GRFPC0_UN1_DIV_RDD: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP10\,
dataf => \GRFPC0.N_23599_I_0\,
datae => \GRFPC0.DIV.RDD\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_5_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_1\,
dataf => \FPO.IDOUT\(0),
datae => \FPO.IDOUT\(4),
datad => \GRFPC0.DIV.ID\(0),
datac => \GRFPC0.DIV.ID\(4));
GRFPC0_FP_PIPELINE_0_UN1_FPO_5_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c00c300300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_4\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5_1\,
datae => \FPO.IDOUT\(1),
datad => \FPO.IDOUT\(2),
datac => \GRFPC0.DIV.ID\(2),
datab => \GRFPC0.DIV.ID\(1));
GRFPC0_FP_PIPELINE_0_REGDEP2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP2\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_5\,
datae => \GRFPC0.DIV.VALID\);
GRFPC0_RFA2_RS1DEP_RNO_5: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0000080400000")
port map (
combout => N_61113_TZ,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEP10\,
datae => \GRFPC0.UN1_WRENX2_2_3_0\,
datad => \GRFPC0.N_22829\,
datac => \GRFPC0.UN1_WRENX2_2_4_0\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEP2\,
dataa => \GRFPC0.DIV.RD\(0));
GRFPC0_FP_PIPELINE_0_REGDEP46_I_S_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff0f")
port map (
combout => \GRFPC0.N_21347\,
dataf => \GRFPC0.FP_PIPELINE.0.WRENX2_I_S_0_4_1\,
datae => \GRFPC0.N_513_I\,
datad => \GRFPC0.N_512_I\,
datac => \GRFPC0.WR.CTRL.RDWR\);
GRFPC0_FP_PIPELINE_0_REGDEP62_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"e0100e0140b0040b")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP62_1\,
dataf => \GRFPC0.N_24063\,
datae => \GRFPC0.FP_PIPELINE.RS1_6\(1),
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.RFA.RS1\(4),
dataa => N_37);
GRFPC0_FP_PIPELINE_0_REGDEP62: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0300000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP62\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.RD_2_3\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEP62_1\,
datad => \GRFPC0.N_23714\,
datac => \GRFPC0.MEM.CTRL.RDWR\,
datab => \GRFPC0.MEM.CTRL.RD\(2));
GRFPC0_REGDEP_2_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000048ff12ff")
port map (
combout => \GRFPC0.REGDEP_2_SQMUXA\,
dataf => \GRFPC0.REGDEP_1_SQMUXA_1\,
datae => \GRFPC0.N_23599_I_0\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEP78\,
datac => \GRFPC0.N_22829\,
datab => \GRFPC0.N_106_I\,
dataa => \GRFPC0.EX.CTRL.RD\(0));
GRFPC0_REGDEP_2_SQMUXA_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"48ff12ff00000000")
port map (
combout => \GRFPC0.REGDEP_2_SQMUXA_2\,
dataf => \GRFPC0.REGDEP_2_SQMUXA\,
datae => \GRFPC0.N_23599_I_0\,
datad => \GRFPC0.FP_PIPELINE.0.REGDEP62\,
datac => \GRFPC0.N_22829\,
datab => \GRFPC0.N_579\,
dataa => \GRFPC0.MEM.CTRL.RD\(0));
GRFPC0_REGDEP_2_SQMUXA_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff48ff1200000000")
port map (
combout => \GRFPC0.REGDEP_2_SQMUXA_3\,
dataf => \GRFPC0.REGDEP_2_SQMUXA_2\,
datae => \GRFPC0.N_23599_I_0\,
datad => \GRFPC0.N_21347\,
datac => \GRFPC0.N_22829\,
datab => \GRFPC0.WR.CTRL.RDD\,
dataa => \GRFPC0.WR.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_0_UN1_FPO_6_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_2\,
dataf => \FPO.IDOUT\(1),
datae => \FPO.IDOUT\(3),
datad => \GRFPC0.WR2.CTRL.ID\(1),
datac => \GRFPC0.WR2.CTRL.ID\(3));
GRFPC0_FP_PIPELINE_0_UN1_FPO_6_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6_1\,
dataf => \FPO.IDOUT\(0),
datae => \FPO.IDOUT\(4),
datad => \GRFPC0.WR2.CTRL.ID\(0),
datac => \GRFPC0.WR2.CTRL.ID\(4));
GRFPC0_FP_PIPELINE_0_REGDEP18: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP18\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_6\,
datae => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.FPR.RDY\);
GRFPC0_WR_CTRL_PEND_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc00ffff0000")
port map (
combout => \GRFPC0.WR.CTRL.PEND_0_0_G1\,
dataf => N_46992,
datae => \GRFPC0.WR.CTRL.PEND_0_0_N_5\,
datad => \GRFPC0.WR.CTRL.PEND_0_0_G2_7\,
datac => \GRFPC0.WR.CTRL.RDWR\,
datab => \GRFPC0.WR.CTRL.CCWR\);
\GRFPC0_D_LDLCK_RNO_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff0cfc0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_22__G1\,
dataf => \GRFPC0.D.LDLCK_0_0_22__G3\,
datae => \GRFPC0.FP_PIPELINE.11.REGDEPX_214\(0),
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX_210\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datab => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_12\(0));
GRFPC0_VEX_CTRL_ID_2_1_CO1_RNIE9EK: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ccccccccccccccc")
port map (
combout => \FPI.OPID\(5),
dataf => \GRFPC0.VEX.CTRL.ID_2_1_CO1\,
datae => \GRFPC0.EX.CTRL.ID\(2),
datad => \GRFPC0.EX.CTRL.ID\(3),
datac => \GRFPC0.EX.CTRL.ID\(4),
datab => \GRFPC0.EX.CTRL.ID\(5));
\GRFPC0_MEM_RREG_RES_RNO_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000ffffcccccccc")
port map (
combout => N_47226,
dataf => N_99847,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_9_3666_I_A3_0_0_0\,
datad => N_99904_1,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(31),
datab => \GRFPC0.EX.RREG.RES\(31));
\GRFPC0_WR_RREG_RES_RNO_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff00cccccccc")
port map (
combout => N_47262,
dataf => N_99846,
datae => \GRFPU0.GRFPU_X0.N_401\,
datad => \FPO.RES_1\(25),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(25),
datab => \GRFPC0.MEM.RREG.RES\(25));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c3fc0f33f0cf3c0")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(4),
dataf => \GRFPU0.GRFPU_X0.UN13_EXP_1_CO3\,
datae => N_32594,
datad => \FPI.OP1\(59),
datac => \FPI.OP1\(56),
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03cf30fccf03fc30")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(6),
dataf => N_32604,
datae => \GRFPU0.GRFPU_X0.UN13_EXP_1_CO5\,
datad => \FPI.OP1\(58),
datac => \FPI.OP1\(61),
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0cc03ff3cc00ff33")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(7),
dataf => N_32604,
datae => N_32562,
datad => \FPI.OP1\(59),
datac => \FPI.OP1\(58),
datab => \FPI.FLOP\(1));
GRFPU0_GRFPU_X0_UN3_EXP_ANC8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => N_32619,
dataf => N_32604,
datae => \FPI.OP1\(59),
datad => \FPI.OP1\(60),
datac => \FPI.OP1\(58));
\GRFPC0_D_LDLCK_RNO_0_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00c0ffc000")
port map (
combout => \GRFPC0.D.LDLCK_0_0_8__G3\,
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX_88\(0),
datae => \GRFPC0.FP_PIPELINE.4.REGDEPX_84\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_OP\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1567_REGDEPX\,
datab => \GRFPC0.N_24820\);
\GRFPU0_GRFPU_X0_COMB_VITER_R_I_49_0_IV_0_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0fff00000f0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_0_IV_0\(6),
dataf => N_99921,
datae => \GRFPU0.GRFPU_X0.N_18663\,
datad => \GRFPU0.MULO.MRES\(67),
datac => \GRFPU0.MULO.MRES\(66));
\GRFPC0_FP_PIPELINE_RS2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.RS2_1\(0),
dataf => \GRFPC0.INST\(0),
datae => \GRFPC0.RFA.RS2\(0),
datad => N_37);
\GRFPC0_FP_PIPELINE_RS2_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => RFI2_RD2ADDRZ(1),
dataf => \GRFPC0.INST\(2),
datae => \GRFPC0.RFA.RS2\(2),
datad => N_37);
\GRFPC0_FP_PIPELINE_RS2_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => RFI2_RD2ADDRZ(2),
dataf => \GRFPC0.N_23921\,
datae => \GRFPC0.RFA.RS2\(3),
datad => N_37);
\GRFPC0_FP_PIPELINE_RS2_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => RFI2_RD2ADDRZ(3),
dataf => \GRFPC0.N_25334\,
datae => \GRFPC0.RFA.RS2\(4),
datad => N_37);
\GRFPC0_WRDATA_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(0),
dataf => N_431,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(32),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(0));
\GRFPC0_FP_PIPELINE_WRDATA_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(0),
dataf => \GRFPC0.DIV.RESULT\(0),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(0),
datab => \FPO.RES\(0));
\GRFPC0_FP_PIPELINE_WRDATA_3_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(32),
dataf => \GRFPC0.DIV.RESULT\(32),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(32),
datab => \GRFPU0.GRFPU_X0.N_20294_I_0\);
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffc0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_1\(1),
dataf => \GRFPC0.N_114\,
datae => \GRFPC0.N_21438\,
datad => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_0\(1),
datac => \GRFPC0.N_655\,
datab => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_0_A2_1_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_A2_1\(1),
dataf => \GRFPC0.N_805\,
datae => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_2_0\(1),
datad => \GRFPC0.N_21438\,
datac => \GRFPC0.N_655\,
datab => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_OP1_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \FPI.OP1\(63),
dataf => \GRFPC0.N_20317\,
datae => N_99877,
datad => N_99878_1,
datac => \GRFPC0.N_19988\,
datab => \GRFPC0.N_20054\);
\GRFPC0_FP_PIPELINE_14_STDEP_568_3_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0fffff0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_568\(1),
dataf => \GRFPC0.N_16_I\,
datae => \GRFPC0.N_23830\,
datad => \GRFPC0.N_23842\,
datac => \GRFPC0.FP_PIPELINE.14.STDEP_568_3_0_0\(1),
datab => \GRFPC0.FP_PIPELINE.14.STDEP_568_3_0_A2_0_0\(1));
\GRFPC0_OP1_4_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20162\,
dataf => N_99879_0,
datae => N_635,
datad => N_699);
\GRFPC0_OP1_3_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20097\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(40),
datad => \GRFPC0.WR.RREG.RES\(40));
\GRFPC0_OP1_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(40),
dataf => \GRFPC0.N_20228\,
datae => N_99877_1,
datad => \GRFPC0.N_20162\,
datac => \GRFPC0.RFA2.RS1SEL_0\(7),
datab => \GRFPC0.N_20097\);
\GRFPC0_WRDATA_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(2),
dataf => N_433,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(34),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(2));
\GRFPC0_FP_PIPELINE_WRDATA_3_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(34),
dataf => \GRFPC0.DIV.RESULT\(34),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(34),
datab => \GRFPU0.GRFPU_X0.N_20274_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(2),
dataf => \GRFPC0.DIV.RESULT\(2),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(2),
datab => \FPO.RES\(2));
\GRFPC0_FP_PIPELINE_9_REGDEPX_178_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX_178\(1),
dataf => \GRFPC0.FP_PIPELINE.9.REGDEPX_176\(1),
datae => \GRFPC0.N_21627\,
datad => \GRFPC0.N_23976\,
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3112_REGDEPX_0\,
datab => N_96);
\GRFPC0_FP_PIPELINE_3_REGDEPX_66_I_M2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc000f0f0")
port map (
combout => \GRFPC0.N_24725\,
dataf => \GRFPC0.FP_PIPELINE.3.0.REGDEPX_60\(0),
datae => \GRFPC0.FP_PIPELINE.3.1.REGDEPX_65_I_A2_0\(0),
datad => \GRFPC0.N_23345_1\,
datac => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datab => \GRFPC0.FP_PIPELINE.3.1.CHECK_DEP.UN1120_REGDEPX\);
\GRFPC0_FP_PIPELINE_11_REGDEPX_210_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffc0ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX_210\(0),
dataf => \GRFPC0.N_23403\,
datae => \GRFPC0.N_23480\,
datad => \GRFPC0.N_23479\,
datac => \GRFPC0.N_23348_1\,
datab => \GRFPC0.FP_PIPELINE.11.1.CHECK_DEP.UN3647_REGDEPX\);
\GRFPC0_FP_PIPELINE_4_0_REGDEPX_77_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => \GRFPC0.N_24829\,
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1327_REGDEPX_0\,
datad => \GRFPC0.FIFO.INST_0\(19),
datac => \GRFPC0.FIFO.INST_0\(29),
datab => \GRFPC0.FIFO.INST_0\(26));
\GRFPC0_FP_PIPELINE_4_REGDEPX_84_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcccfccff000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX_84_0_0\(0),
dataf => \GRFPC0.N_25051_1\,
datae => \GRFPC0.N_22639\,
datad => \GRFPC0.N_22689\,
datac => N_99871,
datab => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1448_REGDEPX\);
\GRFPC0_FP_PIPELINE_4_REGDEPX_84_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffccffc0")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX_84\(0),
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX_84_0_0\(0),
datae => \GRFPC0.N_24829\,
datad => \GRFPC0.N_25050\,
datac => \GRFPC0.FP_PIPELINE.4.0.REGDEPX_77_0_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\);
\GRFPC0_OP1_1_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19988\,
dataf => \GRFPC0.RFA2.RS1SEL\(4),
datae => \FPO.RES\(63),
datad => \GRFPC0.WR2.RREG.RES\(63));
\GRFPC0_OP1_2_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20054\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(63),
datad => \GRFPC0.MEM.RREG.RES\(63));
\GRFPC0_WRDATA_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(12),
dataf => N_443,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(44),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(12));
\GRFPC0_FP_PIPELINE_WRDATA_3_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(12),
dataf => \GRFPC0.DIV.RESULT\(12),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(12),
datab => \FPO.RES\(12));
\GRFPC0_FP_PIPELINE_WRDATA_3_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(44),
dataf => \GRFPC0.DIV.RESULT\(44),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(44),
datab => \GRFPU0.GRFPU_X0.N_20298_I_0\);
\GRFPC0_OP1_3_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20089\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(32),
datad => \GRFPC0.WR.RREG.RES\(32));
\GRFPC0_OP1_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(32),
dataf => \GRFPC0.N_20220\,
datae => N_99877_1,
datad => \GRFPC0.N_20154\,
datac => \GRFPC0.RFA2.RS1SEL_0\(7),
datab => \GRFPC0.N_20089\);
\GRFPC0_WRDATA_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(6),
dataf => N_437,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(38),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(6));
\GRFPC0_FP_PIPELINE_WRDATA_3_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(38),
dataf => \GRFPC0.DIV.RESULT\(38),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(38),
datab => \GRFPU0.GRFPU_X0.N_20296_I_0\);
\GRFPC0_OP1_3_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20103\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(46),
datad => \GRFPC0.WR.RREG.RES\(46));
\GRFPC0_OP1_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(46),
dataf => \GRFPC0.N_20234\,
datae => N_99877,
datad => \GRFPC0.N_20168\,
datac => \GRFPC0.RFA2.RS1SEL_0\(7),
datab => \GRFPC0.N_20103\);
\GRFPC0_OP1_4_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20166\,
dataf => N_99879_0,
datae => N_639,
datad => N_703);
\GRFPC0_OP1_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(44),
dataf => \GRFPC0.N_20232\,
datae => N_99877,
datad => \GRFPC0.N_20166\,
datac => \GRFPC0.RFA2.RS1SEL_0\(7),
datab => \GRFPC0.N_20101\);
\GRFPC0_OP2_3_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19625\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(63),
datad => \GRFPC0.WR.RREG.RES\(63));
\GRFPC0_OP2_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fcfcff003030")
port map (
combout => \FPI.OP2\(63),
dataf => \GRFPC0.N_19690\,
datae => N_99880,
datad => \GRFPC0.N_19756\,
datac => \GRFPC0.N_19625\,
datab => \GRFPC0.RFA2.RS2SEL\(7));
\GRFPC0_WRDATA_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(31),
dataf => N_462,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(63),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(31));
\GRFPC0_FP_PIPELINE_WRDATA_3_63_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(63),
dataf => \GRFPC0.DIV.RESULT\(63),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(63),
datab => \FPO.RES\(63));
\GRFPC0_FP_PIPELINE_WRDATA_3_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(31),
dataf => \GRFPC0.DIV.RESULT\(31),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(31),
datab => \FPO.RES\(31));
\GRFPC0_OP1_4_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20168\,
dataf => N_99879_0,
datae => N_641,
datad => N_705);
\GRFPC0_FP_PIPELINE_WRDATA_3_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(6),
dataf => \GRFPC0.DIV.RESULT\(6),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(6),
datab => \FPO.RES\(6));
GRFPC0_FP_PIPELINE_IS_RDD_UN1_INST_9_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000ff0f0f0f")
port map (
combout => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_0\,
dataf => \GRFPC0.N_23631\,
datae => \GRFPC0.INST\(9),
datad => \GRFPC0.N_23618\,
datac => \GRFPC0.INST\(11));
GRFPC0_FP_PIPELINE_IS_RDD_UN1_INST_9_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcf0cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_2\,
dataf => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_0\,
datae => \GRFPC0.INST\(5),
datad => \GRFPC0.INST\(12),
datac => \GRFPC0.INST\(9),
datab => \GRFPC0.INST\(7));
GRFPC0_FP_PIPELINE_IS_RDD_TMP_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000ff0000")
port map (
combout => N_61097,
dataf => \GRFPC0.INST\(5),
datae => \GRFPC0.INST\(7),
datad => \GRFPC0.INST\(11));
GRFPC0_FP_PIPELINE_IS_RDD_UN1_INST_9_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_3\,
dataf => \GRFPC0.N_23631\,
datae => \GRFPC0.INST\(5),
datad => \GRFPC0.INST\(11),
datac => \GRFPC0.INST\(10));
GRFPC0_FP_PIPELINE_IS_RDD_UN1_INST_9_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_4\,
dataf => \GRFPC0.N_23631\,
datae => \GRFPC0.INST\(5),
datad => \GRFPC0.INST\(12),
datac => \GRFPC0.INST\(11),
datab => \GRFPC0.INST\(10));
GRFPC0_FP_PIPELINE_IS_RDD_TMP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"333333333333333f")
port map (
combout => \GRFPC0.FP_PIPELINE.IS_RDD.TMP\,
dataf => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_2\,
datae => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_4\,
datad => \GRFPC0.FP_PIPELINE.IS_RDD.UN1_INST_9_3\,
datac => N_61097,
datab => \GRFPC0.INST\(31));
GRFPC0_FP_PIPELINE_DEPMUX_RES_U: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff7fdf5fa32c800")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.RES\,
dataf => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1\(0),
datae => \GRFPC0.N_17411\,
datad => \GRFPC0.N_17425\,
datac => \GRFPC0.FP_PIPELINE.IS_RDD.TMP\,
datab => \GRFPC0.INST\(29),
dataa => \GRFPC0.INST\(25));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_14_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5e6c4b391a280")
port map (
combout => \GRFPC0.N_17422\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420\(0),
datae => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_1\(24),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450\(0),
datac => \GRFPC0.FP_PIPELINE.REGDEPX2_1\(0),
datab => \GRFPC0.INST\(26),
dataa => \GRFPC0.INST\(27));
\GRFPC0_FP_PIPELINE_11_CHECK_DEP_DEP_6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00030")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_6\(0),
dataf => \GRFPC0.N_24201\,
datae => \GRFPC0.DIV.RDD\,
datad => \GRFPC0.DIV.INST\(17),
datac => \GRFPC0.DIV.INST\(18),
datab => \GRFPC0.DIV.INST\(14));
\GRFPC0_FP_PIPELINE_11_CHECK_DEP_DEP_7_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0003000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_7\(0),
dataf => \GRFPC0.N_24703_I\,
datae => \GRFPC0.DIV.RDD\,
datad => \GRFPC0.DIV.RD\(3),
datac => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.DIV.RD\(0));
\GRFPC0_FP_PIPELINE_11_CHECK_DEP_DEP_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_1\(0),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(2),
datac => \GRFPC0.DIV.INST\(4),
datab => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_11_CHECK_DEP_DEP_20_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_20\(0),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(0),
datae => \GRFPC0.WR2.CTRL.INST\(29),
datad => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_11_CHECK_DEP_DEP_8_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_8\(0),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(0),
datae => \GRFPC0.WR2.CTRL.INST\(1),
datad => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_355_A0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355_A0_0\(0),
dataf => \GRFPC0.WR2.CTRL.RS1V\,
datae => \GRFPC0.WR2.CTRL.INST\(15),
datad => \GRFPC0.WR2.CTRL.INST\(16),
datac => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.WR2.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_355_A0_RNICFK21_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff2fffffff20")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_2\(0),
dataf => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345\(0),
datae => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355_1\(0),
datad => N_1_3,
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datab => \GRFPC0.N_702\,
dataa => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5210_REGDEPX2\);
\GRFPC0_FP_PIPELINE_11_CHECK_DEP_DEP_17_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_17\(0),
dataf => \GRFPC0.MEM.CTRL.INST\(27),
datae => \GRFPC0.MEM.CTRL.INST\(26),
datad => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(28),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(0));
\GRFPC0_FP_PIPELINE_11_CHECK_DEP_DEP_18_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_18\(0),
dataf => \GRFPC0.EX.CTRL.INST\(3),
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(0));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_340_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0fcf000000000")
port map (
combout => \GRFPC0.N_24516\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.N_25122\,
datad => \GRFPC0.N_24160_1\,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_18\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(0));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_340_0_A2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_24526\,
dataf => \GRFPC0.N_177_2\,
datae => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_2__G3\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_340_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_340\(0),
dataf => \GRFPC0.N_24527\,
datae => \GRFPC0.N_24528\,
datad => \GRFPC0.N_24526\,
datac => \GRFPC0.N_24525\,
datab => \GRFPC0.N_24516\,
dataa => \GRFPC0.N_24518\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_345_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffc0ffff00c000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345\(0),
dataf => \GRFPC0.FP_PIPELINE.11.REGDEPX2_340\(0),
datae => \GRFPC0.FP_PIPELINE.11.REGDEPX2_343\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5165_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0));
\GRFPC0_FP_PIPELINE_11_CHECK_DEP_DEP_1_RNITQ5H1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffeeccf3f3e2c0")
port map (
combout => \GRFPC0.D.LDLCK_0_0_22__G3\,
dataf => \GRFPC0.FP_PIPELINE.11.REGDEPX2_358\(0),
datae => \GRFPC0.FP_PIPELINE.11.REGDEPX2_2\(0),
datad => \GRFPC0.FP_PIPELINE.11.REGDEPX2_348\(0),
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_1\(0),
datab => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffc000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_0\(0),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.N_24784\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(0),
datac => \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A2_0_2_0\(0),
datab => \GRFPC0.N_24180\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_3\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_0\(0),
datae => \GRFPC0.N_24677\,
datad => \GRFPC0.N_25560_2\,
datac => \GRFPC0.N_275\,
datab => \GRFPC0.DIV.RD\(3));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_325_0_O2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0c00ffff0000")
port map (
combout => \GRFPC0.N_24651\,
dataf => \GRFPC0.N_24160_1\,
datae => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_9\(0),
datad => \GRFPC0.EX.CTRL.INST\(27),
datac => \GRFPC0.EX.CTRL.INST\(26),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(0));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_325_0_A2_7_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_24671\,
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.N_23980\,
datad => \GRFPC0.N_24039\,
datac => \GRFPC0.N_227\,
datab => \GRFPC0.N_24642\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_12_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffefffc")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_12\(0),
dataf => \GRFPC0.N_24671\,
datae => \GRFPC0.N_23946_2\,
datad => \GRFPC0.N_24785\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_8\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_7\(0),
dataa => N_60930_TZ_TZ);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_11_I_M2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fedcba9876543210")
port map (
combout => \GRFPC0.N_24733\,
dataf => \GRFPC0.D.LDLCK_0_0_22__G3\,
datae => \GRFPC0.D.LDLCK_0_0_18__G3\,
datad => \GRFPC0.N_277\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270\(0),
datab => \GRFPC0.INST\(26),
dataa => \GRFPC0.INST\(27));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_200_0_A2_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_24173\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.N_25608_2\,
datad => \GRFPC0.MEM.CTRL.INST\(27),
datac => \GRFPC0.MEM.CTRL.INST\(26),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_O2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0c0c0ff000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_O2_0\(0),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.N_25560_2\,
datad => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_1_0\(1),
datac => \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_0_A2_1_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(0));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_200_0_A2_8_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_0_A2_8_0\(0),
dataf => \GRFPC0.EX.CTRL.INST\(16),
datae => \GRFPC0.EX.CTRL.INST\(18),
datad => \GRFPC0.EX.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_O2_8_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_O2_8\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_O2_3\(0),
datae => \GRFPC0.N_24145\,
datad => \GRFPC0.N_24175\,
datac => \GRFPC0.N_24174\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_O2_0\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_A2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.N_24775\,
dataf => \GRFPC0.N_263\,
datae => \GRFPC0.DIV.INST\(17),
datad => \GRFPC0.DIV.INST\(15),
datac => \GRFPC0.DIV.INST\(18));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_I_A2_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff000000ff")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_I_A2_0\(0),
dataf => \GRFPC0.WR2.CTRL.RDD\,
datae => \GRFPC0.WR2.CTRL.INST\(15),
datad => \GRFPC0.WR2.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_185_I_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f3ffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_185_I_A2_0\(0),
dataf => \FPI.FLOP\(1),
datae => \GRFPC0.N_225\,
datad => \GRFPC0.N_226\,
datac => \GRFPC0.N_223\,
datab => \GRFPC0.N_24627_1\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_185_I_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f000cc00ff00")
port map (
combout => \GRFPC0.N_24585\,
dataf => \GRFPC0.N_25204\,
datae => \GRFPC0.N_24623\,
datad => \GRFPC0.FP_PIPELINE.6.REGDEPX2_185_I_A2_0\(0),
datac => \GRFPC0.V.STDATA_14\(25),
datab => \GRFPC0.N_235\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccfeffffcccc")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210\(0),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_O2_7\(0),
datad => \GRFPC0.N_24585\,
datac => \GRFPC0.FP_PIPELINE.6.REGDEPX2_185_I_I2_0_O2_0\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_O2_8\(0),
dataa => \GRFPC0.N_24623\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_115_0_A4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_25569\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(0),
datad => \GRFPC0.N_25851\,
datac => \GRFPC0.WR2.CTRL.INST\(29),
datab => \GRFPC0.WR2.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_0_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00003000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_0\(6),
dataf => \GRFPC0.N_25569\,
datae => \GRFPC0.N_702\,
datad => \GRFPC0.N_25854\,
datac => \GRFPC0.N_25824_1\,
datab => \GRFPC0.WR.CTRL.INST\(4));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_115_0_A4_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_25571\,
dataf => \GRFPC0.N_25634\,
datae => \GRFPC0.WR2.CTRL.RS1V\,
datad => \GRFPC0.WR2.CTRL.INST\(16),
datac => \GRFPC0.WR2.CTRL.INST\(17),
datab => \GRFPC0.WR2.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_7_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_7\(6),
dataf => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_5\(6),
datae => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_0\(6),
datad => \GRFPC0.N_25570\,
datac => \GRFPC0.N_25571\,
datab => \GRFPC0.N_24779\);
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_15_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_15\(0),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
datae => \GRFPC0.DIV.INST\(2),
datad => \GRFPC0.DIV.INST\(3),
datac => \GRFPC0.DIV.INST\(1),
datab => \GRFPC0.DIV.INST\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f3000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_90_0\(0),
dataf => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_15\(0),
datae => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1300_REGDEPX2\,
datac => \GRFPC0.DIV.RDD\,
datab => \GRFPC0.DIV.RD\(0));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_16_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3ff333cc0cc000")
port map (
combout => \GRFPC0.FP_PIPELINE.DEPMUX.TMP_1\(0),
dataf => \GRFPC0.N_17410\,
datae => \GRFPC0.N_24733\,
datad => \GRFPC0.N_17422\,
datac => \GRFPC0.INST\(28),
datab => \GRFPC0.INST\(29));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_24084\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_A2_3_0\(0),
datad => \GRFPC0.DIV.RD\(4),
datac => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_24083\,
dataf => \GRFPC0.N_24796\,
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(2),
datac => \GRFPC0.DIV.INST\(4),
datab => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_180_0_A2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_24085\,
dataf => \GRFPC0.N_24222_1\,
datae => \GRFPC0.DIV.INST\(17),
datad => \GRFPC0.DIV.INST\(15),
datac => \GRFPC0.DIV.INST\(16),
datab => \GRFPC0.DIV.INST\(18));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_24080\,
dataf => \GRFPC0.N_24796\,
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(2),
datac => \GRFPC0.DIV.INST\(4),
datab => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_145_0_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf000cccc0000")
port map (
combout => \GRFPC0.N_24066\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(0),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(0),
datad => \GRFPC0.N_25859\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN369_REGDEPX2_1\,
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2168_REGDEPX2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_9_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff03000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_9_3\(0),
dataf => \GRFPC0.N_24087\,
datae => \GRFPC0.N_25676_1\,
datad => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3386_REGDEPX2_2\,
datac => \GRFPC0.MEM.CTRL.INST\(16),
datab => \GRFPC0.MEM.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_9_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_9\(0),
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_9_2\(0),
datad => \GRFPC0.N_24140\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_9_3\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_24081\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_A2_3_0\(0),
datad => \GRFPC0.DIV.RD\(4),
datac => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_465_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_25133\,
dataf => \GRFPC0.N_25388\,
datae => \GRFPC0.EX.CTRL.INST\(3),
datad => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.EX.CTRL.INST\(2),
datab => \GRFPC0.EX.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_9_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_9\(0),
dataf => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_3\(0),
datae => \GRFPC0.N_25562\,
datad => \GRFPC0.N_25133\,
datac => \GRFPC0.N_24765_1\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6869_REGDEPX2\);
\GRFPC0_FP_PIPELINE_15_REGDEPX2_475_0_A2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_25811\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(0),
datad => \GRFPC0.N_25785\,
datac => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_465_0_A2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_25134\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.N_25122\,
datad => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.EX.CTRL.INST\(28),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(0));
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00300000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_1\(0),
dataf => \GRFPC0.N_25134\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datad => \GRFPC0.N_25784\,
datac => \GRFPC0.N_25842_1\,
datab => \GRFPC0.N_25557\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_6\(0),
dataf => \GRFPC0.N_25807\,
datae => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_1\(0),
datad => \GRFPC0.N_25811\,
datac => \GRFPC0.N_25561\,
datab => \GRFPC0.N_25137\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_10_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff2000")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_10\(0),
dataf => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_6\(0),
datae => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_9\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(0),
datab => \GRFPC0.N_25783\,
dataa => \GRFPC0.N_25851\);
\GRFPC0_FP_PIPELINE_REGDEPX2_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff8f0")
port map (
combout => \GRFPC0.FP_PIPELINE.REGDEPX2_1\(0),
dataf => \GRFPC0.N_177\,
datae => \GRFPC0.N_25166\,
datad => \GRFPC0.DIVI_0_SQMUXA\,
datac => \GRFPC0.FP_PIPELINE.REGDEPX2_1_0_10\(0),
datab => \GRFPC0.FP_PIPELINE.15.REGDEPX2_454_0_A2_0\(1),
dataa => \GRFPC0.N_23980\);
\GRFPC0_FP_PIPELINE_14_CHECK_DEP_DEP_8_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00030")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_8\(0),
dataf => \GRFPC0.N_25784\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.CTRL.INST\(15),
datac => \GRFPC0.WR2.CTRL.INST\(16),
datab => \GRFPC0.WR2.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_A3_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_25401\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.N_25382\,
datad => \GRFPC0.MEM.CTRL.INST\(27),
datac => \GRFPC0.MEM.CTRL.INST\(26),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(0));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_435_0_A3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_25399\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(0),
datad => \GRFPC0.N_24137\,
datac => \GRFPC0.N_24180\,
datab => \GRFPC0.MEM.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_425_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_23933\,
dataf => \GRFPC0.N_177_2\,
datae => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_2__G3\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcccccc80")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440\(0),
dataf => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435\(0),
datae => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_1\(0),
datad => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_3\(0),
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_19\(0),
datab => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
dataa => \GRFPC0.WR.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_445_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0f0f080")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_445\(0),
dataf => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440\(0),
datae => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_11\(0),
datad => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP\(0),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_8\(0),
dataa => \GRFPC0.WR2.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_O2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_O2_0\(0),
dataf => \GRFPC0.N_24787\,
datae => \GRFPC0.N_24796\,
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3975_REGDEPX2_1\,
datac => \GRFPC0.DIV.INST\(3),
datab => \GRFPC0.DIV.INST\(2));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450\(0),
dataf => \GRFPC0.FP_PIPELINE.14.REGDEPX2_445\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_450_0_O2_0\(0),
datad => \GRFPC0.N_263\,
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3960_REGDEPX2_1\,
datab => \GRFPC0.DIV.INST\(17));
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_7_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000c0000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_7\(0),
dataf => \GRFPC0.N_704\,
datae => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.INST\(18),
datab => \GRFPC0.WR.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_170_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000cff0c00")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_170\(0),
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_168\(0),
datae => \GRFPC0.FP_PIPELINE.5.REGDEPX2_165\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datac => \GRFPC0.N_702\,
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_6_0\(0));
GRFPC0_VEX_RREG_RES_0_SQMUXA_0_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000ffff00ff")
port map (
combout => N_99868,
dataf => \GRFPC0.N_82\,
datae => \GRFPC0.RFA.ST\,
datad => N_37);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_413_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0300000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_413\(0),
dataf => \GRFPC0.FP_PIPELINE.13.REGDEPX2_411\(0),
datae => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6122_REGDEPX2\,
datad => \GRFPC0.WR2.CTRL.RDD\,
datac => \GRFPC0.WR2.CTRL.RS1V\,
datab => \GRFPC0.WR2.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_400_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000c000000")
port map (
combout => \GRFPC0.N_25147\,
dataf => \GRFPC0.N_25388\,
datae => \GRFPC0.EX.CTRL.INST\(3),
datad => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.EX.CTRL.INST\(2),
datab => \GRFPC0.EX.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_24162\,
dataf => \GRFPC0.N_24199\,
datae => \GRFPC0.MEM.CTRL.INST\(27),
datad => \GRFPC0.MEM.CTRL.INST\(29),
datac => \GRFPC0.MEM.CTRL.INST\(28),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(0));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405\(0),
dataf => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_5\(0),
datae => \GRFPC0.N_25170\,
datad => \GRFPC0.N_25169_2\,
datac => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN5885_REGDEPX2\,
datab => \FPI.FLOP\(6));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_410_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000cff0c00")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410\(0),
dataf => \GRFPC0.FP_PIPELINE.13.REGDEPX2_408\(0),
datae => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datac => \GRFPC0.N_702\,
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6092_REGDEPX2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_420_0_A2_3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000ff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420_0_A2_3_0\(0),
dataf => \GRFPC0.DIV.RDD\,
datae => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.DIV.RD\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_420_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_24074\,
dataf => \GRFPC0.N_24796\,
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(2),
datac => \GRFPC0.DIV.INST\(4),
datab => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_420_0_A2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_24076\,
dataf => \GRFPC0.N_24222_1\,
datae => \GRFPC0.DIV.INST\(17),
datad => \GRFPC0.DIV.INST\(16),
datac => \GRFPC0.DIV.INST\(15),
datab => \GRFPC0.DIV.INST\(18));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_380_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000300000")
port map (
combout => \GRFPC0.N_25672\,
dataf => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_14\(0),
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datad => \GRFPC0.N_706\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_1\,
datab => \GRFPC0.N_25496\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_25840\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(0),
datad => \GRFPC0.N_25785\,
datac => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_3_0_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ff00f3f30000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O2_3_0\(24),
dataf => \GRFPC0.N_25839_1\,
datae => \GRFPC0.N_24213_2\,
datad => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5724_REGDEPX2\,
datac => \GRFPC0.DIV.RDD\,
datab => \GRFPC0.DIV.RD\(0));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_475_0_A2_6_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000ff0000")
port map (
combout => \GRFPC0.N_25842_1\,
dataf => \GRFPC0.WR2.CTRL.RDD\,
datae => \GRFPC0.WR2.CTRL.RS1V\,
datad => \GRFPC0.WR2.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_380_0_O2_1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0f0f0fc")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_380_0_O2_1_1\(0),
dataf => \GRFPC0.N_25760_2\,
datae => \GRFPC0.N_25382\,
datad => \GRFPC0.N_25380\,
datac => \GRFPC0.N_25711\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(0));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_380_0_A2_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25680\,
dataf => \GRFPC0.N_25319\,
datae => \GRFPC0.N_25190\,
datad => \GRFPC0.EX.CTRL.INST\(18),
datac => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(0));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_380_0_A2_8_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_25705\,
dataf => \GRFPC0.N_177_2\,
datae => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datab => \GRFPC0.EX.CTRL.RD_0_0_2__G3\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_380_0_O2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc0ff00")
port map (
combout => \GRFPC0.N_25753\,
dataf => \GRFPC0.N_25704\,
datae => \GRFPC0.DIVI_0_SQMUXA\,
datad => \GRFPC0.N_25705\,
datac => \GRFPC0.N_258\,
datab => \GRFPC0.N_23980\);
GRFPC0_VEX_CTRL_ID_2_1_CO1_RNIE8PF: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff0f0f0f0f0f0f0")
port map (
combout => \FPI.OPID\(4),
dataf => \GRFPC0.VEX.CTRL.ID_2_1_CO1\,
datae => \GRFPC0.EX.CTRL.ID\(2),
datad => \GRFPC0.EX.CTRL.ID\(3),
datac => \GRFPC0.EX.CTRL.ID\(4));
\GRFPU0_GRFPU_X0_COMB_UN6_FLUSH_ALTB_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000f0c0fcf0fffc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.ALTB\(3),
dataf => \FPI.OPID\(3),
datae => \FPI.OPID\(2),
datad => \GRFPU0.GRFPU_X0.COMB.UN6_FLUSH.ALTB\(1),
datac => \FPI.FLUSHID\(3),
datab => \FPI.FLUSHID\(2));
GRFPC0_VEX_CTRL_ID_2_1_CO1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPC0.VEX.CTRL.ID_2_1_CO1\,
dataf => \GRFPC0.FP_PIPELINE.UN24_FPUSTART\,
datae => \GRFPC0.EX.CTRL.ID\(0),
datad => \GRFPC0.EX.CTRL.ID\(1));
GRFPC0_FP_PIPELINE_UN24_FPUSTART_RNIH2HA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffff00ff00ff00")
port map (
combout => \FPI.OPID\(1),
dataf => \GRFPC0.FP_PIPELINE.UN24_FPUSTART\,
datae => \GRFPC0.EX.CTRL.ID\(0),
datad => \GRFPC0.EX.CTRL.ID\(1));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfcfc0c0cfc0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(10),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(10),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(10),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datac => N_99870,
datab => \GRFPC0.DIV.PC\(10));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfcfc0c0cfc0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(31),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(31),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(31),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datac => N_99870,
datab => \GRFPC0.DIV.PC\(31));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0cfc0ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(10),
dataf => N_25,
datae => \FPI.FLOP\(5),
datad => \GRFPC0.N_243\,
datac => \GRFPC0.EX.CTRL.PEND\,
datab => \GRFPC0.EX.CTRL.INST\(10));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M7_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfc0cfc0ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M7\(31),
dataf => N_25,
datae => \GRFPC0.V.STDATA_14\(31),
datad => \GRFPC0.N_257\,
datac => \GRFPC0.EX.CTRL.PEND\,
datab => \GRFPC0.EX.CTRL.INST\(31));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff0000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(1),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(1),
datae => \GRFPC0.N_23669\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datac => \GRFPC0.MEM.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ffcc00f000cc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(8),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(8),
datae => \GRFPC0.N_23669\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datac => \GRFPC0.MEM.CTRL.INST\(8),
datab => \GRFPC0.MEM.CTRL.PC\(8));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ffcc00f000cc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(19),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(19),
datae => \GRFPC0.N_23669\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datac => \GRFPC0.MEM.CTRL.INST\(19),
datab => \GRFPC0.MEM.CTRL.PC\(19));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ffcc00f000cc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(21),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(21),
datae => \GRFPC0.N_23669\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datac => \GRFPC0.MEM.CTRL.INST\(21),
datab => \GRFPC0.MEM.CTRL.PC\(21));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(10),
dataf => \GRFPC0.N_23669\,
datae => \GRFPC0.MEM.CTRL.PC\(10),
datad => \GRFPC0.MEM.CTRL.INST\(10));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(31),
dataf => \GRFPC0.N_23669\,
datae => \GRFPC0.MEM.CTRL.PC\(31),
datad => \GRFPC0.MEM.CTRL.INST\(31));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(8),
dataf => \GRFPC0.N_23667\,
datae => \GRFPC0.WR.CTRL.PC\(8),
datad => \GRFPC0.WR.CTRL.INST\(8));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(19),
dataf => \GRFPC0.N_23667\,
datae => \GRFPC0.WR.CTRL.PC\(19),
datad => \GRFPC0.WR.CTRL.INST\(19));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(21),
dataf => \GRFPC0.N_23667\,
datae => \GRFPC0.WR.CTRL.INST\(21),
datad => \GRFPC0.WR.CTRL.PC\(21));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_237\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.PC_0\(2),
datad => \GRFPC0.FIFO.PC_1\(2));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_238\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.PC_0\(3),
datad => \GRFPC0.FIFO.PC_1\(3));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_242\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.PC_0\(7),
datad => \GRFPC0.FIFO.PC_1\(7));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_243\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.PC_0\(10),
datad => \GRFPC0.FIFO.PC_1\(10));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_25234\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.PC_0\(11),
datad => \GRFPC0.FIFO.PC_1\(11));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_25235\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.PC_0\(13),
datad => \GRFPC0.FIFO.PC_1\(13));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_246\,
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.PC_0\(15),
datad => \GRFPC0.FIFO.PC_1\(15));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_247\,
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.PC_0\(16),
datad => \GRFPC0.FIFO.PC_1\(16));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_248\,
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.PC_0\(17),
datad => \GRFPC0.FIFO.PC_1\(17));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_251\,
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.PC_0\(20),
datad => \GRFPC0.FIFO.PC_1\(20));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_252\,
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.PC_0\(21),
datad => \GRFPC0.FIFO.PC_1\(21));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_253\,
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.PC_0\(22),
datad => \GRFPC0.FIFO.PC_1\(22));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(26),
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.PC_0\(26),
datad => \GRFPC0.FIFO.PC_1\(26));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_25236\,
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.PC_0\(27),
datad => \GRFPC0.FIFO.PC_1\(27));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_254\,
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.PC_0\(28),
datad => \GRFPC0.FIFO.PC_1\(28));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_255\,
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.PC_0\(29),
datad => \GRFPC0.FIFO.PC_1\(29));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_257\,
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.PC_0\(31),
datad => \GRFPC0.FIFO.PC_1\(31));
\GRFPC0_FP_PIPELINE_FCC_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_CCZ(0),
dataf => \GRFPC0.FP_PIPELINE.FCC_1_M2\(0),
datae => N_38,
datad => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datac => \GRFPC0.WR2.RREG.RES\(10),
datab => \GRFPC0.R.FSR.FCC\(0));
\GRFPC0_FP_PIPELINE_FCC_1_M2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_1_M2\(0),
dataf => \GRFPC0.FP_PIPELINE.FCC_1_M0\(0),
datae => \GRFPC0.FP_PIPELINE.FCC_1_SM0\,
datad => \GRFPC0.N_9441\,
datac => \GRFPC0.EX.RREG.RES\(0),
datab => \GRFPC0.MEM.RREG.RES\(0));
\GRFPC0_FP_PIPELINE_FCC_1_M0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_1_M0\(0),
dataf => \GRFPC0.WR.RREG.RES\(0),
datae => \GRFPC0.WR2.RREG.RES\(0),
datad => \GRFPC0.WR.RREG.RESV\,
datac => \GRFPC0.WR.CTRL.CCWR\);
\GRFPC0_OP1_1_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19987\,
dataf => \FPO.RES\(62),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(62));
\GRFPC0_OP1_2_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20053\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(62),
datad => \GRFPC0.MEM.RREG.RES\(62));
\GRFPU0_GRFPU_X0_UN13_EXP_M_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \FPI.OP1\(62),
dataf => \GRFPC0.N_20316\,
datae => \GRFPC0.N_19987\,
datad => N_99877,
datac => N_99878,
datab => \GRFPC0.N_20053\);
\GRFPU0_GRFPU_X0_UN13_EXP_M_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \FPI.OP1\(61),
dataf => \GRFPC0.N_20315\,
datae => \GRFPC0.N_19986\,
datad => N_99877,
datac => N_99878,
datab => \GRFPC0.N_20052\);
\GRFPC0_OP1_4_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20179\,
dataf => N_99879,
datae => N_652,
datad => N_716);
\GRFPU0_GRFPU_X0_UN13_EXP_M_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(57),
dataf => \GRFPC0.N_20245\,
datae => N_99877,
datad => \GRFPC0.N_20179\,
datac => \GRFPC0.RFA2.RS1SEL\(7),
datab => \GRFPC0.N_20114\);
\GRFPC0_OP1_1_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19981\,
dataf => N_46771_3,
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(56));
\GRFPC0_OP1_2_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20047\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(56),
datad => \GRFPC0.MEM.RREG.RES\(56));
\GRFPU0_GRFPU_X0_UN13_EXP_M_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff0cfffc000c00")
port map (
combout => \FPI.OP1\(56),
dataf => \GRFPC0.N_20310\,
datae => \GRFPC0.N_19981\,
datad => N_99877,
datac => N_99878,
datab => \GRFPC0.N_20047\);
\GRFPC0_OP1_4_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20177\,
dataf => N_99879,
datae => N_650,
datad => N_714);
\GRFPC0_OP1_3_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20112\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(55),
datad => \GRFPC0.WR.RREG.RES\(55));
\GRFPU0_GRFPU_X0_UN13_EXP_M_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(55),
dataf => \GRFPC0.N_20243\,
datae => N_99877,
datad => \GRFPC0.N_20177\,
datac => \GRFPC0.RFA2.RS1SEL\(7),
datab => \GRFPC0.N_20112\);
\GRFPC0_OP2_2_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19555\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(59),
datad => \GRFPC0.MEM.RREG.RES\(59));
\GRFPU0_GRFPU_X0_UN38_EXP_M_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(59),
dataf => \GRFPC0.N_19489\,
datae => \GRFPC0.N_19818\,
datad => N_99880,
datac => \GRFPC0.N_19555\,
datab => N_99881);
GRFPU0_GRFPU_X0_COMB_UNPACK_FLTYPE45_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UNPACK.FLTYPE45_2\,
dataf => \FPI.OP2\(55),
datae => \FPI.OP2\(56),
datad => \FPI.OP2\(61),
datac => \FPI.OP2\(62));
GRFPU0_GRFPU_X0_SGNF_1_SQMUXA_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0ff0000c0c00000")
port map (
combout => \GRFPU0.GRFPU_X0.N_7321\,
dataf => \GRFPU0.GRFPU_X0.N_18948\,
datae => \GRFPU0.GRFPU_X0.N_7241\,
datad => \GRFPU0.GRFPU_X0.N_18870\,
datac => \GRFPU0.GRFPU_X0.N_18871\,
datab => \FPI.NONSTD\);
GRFPC0_FP_PIPELINE_RSDEC_RS1V_I_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000300300003c030")
port map (
combout => \GRFPC0.N_23771\,
dataf => \GRFPC0.N_23631\,
datae => \GRFPC0.INST\(5),
datad => \GRFPC0.INST\(9),
datac => \GRFPC0.N_23618\,
datab => \GRFPC0.INST\(19));
GRFPC0_DIV_EXC_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f000cccccccc")
port map (
combout => N_53562,
dataf => \GRFPC0.DIV.EXC_0_0_N_7\,
datae => \GRFPC0.PENDEXC_0_SQMUXA\,
datad => N_44718_1,
datac => \GRFPC0.DIV.EXC_0_0_G4_0_1042_A2_1\,
datab => \GRFPC0.DIV.EXC\);
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_239\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.PC_0\(4),
datad => \GRFPC0.FIFO.PC_1\(4));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_240\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.PC_0\(5),
datad => \GRFPC0.FIFO.PC_1\(5));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M4_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(24),
dataf => \GRFPC0.N_23669\,
datae => \GRFPC0.MEM.CTRL.PC\(24),
datad => \GRFPC0.MEM.CTRL.INST\(24));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M9_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfcfc0c0cfc0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M9\(24),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(24),
datae => \GRFPC0.FP_PIPELINE.V.STDATA_1_M4\(24),
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datac => N_99870,
datab => \GRFPC0.DIV.PC\(24));
\GRFPC0_FP_PIPELINE_DBGDATA_4_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(27),
dataf => \GRFPC0.R.FSR.TEM\(4),
datae => N_425,
datad => N_426,
datac => N_718,
datab => N_654);
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_241\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.PC_0\(6),
datad => \GRFPC0.FIFO.PC_1\(6));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(24),
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.PC_0\(24),
datad => \GRFPC0.FIFO.PC_1\(24));
\GRFPC0_V_STDATA_14_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \FPI.FLOP\(6),
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.INST_1\(11),
datad => \GRFPC0.FIFO.INST_0\(11));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(14),
dataf => \GRFPC0.N_23667\,
datae => \GRFPC0.WR.CTRL.INST\(14),
datad => \GRFPC0.WR.CTRL.PC\(14));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ffcc00f000cc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(14),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(14),
datae => \GRFPC0.N_23669\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datac => \GRFPC0.MEM.CTRL.INST\(14),
datab => \GRFPC0.MEM.CTRL.PC\(14));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_245\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.PC_0\(14),
datad => \GRFPC0.FIFO.PC_1\(14));
\GRFPC0_WR_RREG_RES_RNO_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000ffffcccccccc")
port map (
combout => N_47268,
dataf => N_99846,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_9_3666_I_A3_0_0_0\,
datad => N_99904_1,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(31),
datab => \GRFPC0.MEM.RREG.RES\(31));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(35),
dataf => \GRFPU0.GRFPU_X0.N_21\,
datae => \GRFPU0.GRFPU_X0.N_18746\,
datad => \FPI.OP1\(38),
datac => \FPI.OP1\(35));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(33),
dataf => \GRFPU0.GRFPU_X0.N_21\,
datae => \GRFPU0.GRFPU_X0.N_18746\,
datad => \FPI.OP1\(33),
datac => \FPI.OP1\(36));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(31),
dataf => \GRFPU0.GRFPU_X0.N_21\,
datae => \GRFPU0.GRFPU_X0.N_18746\,
datad => \FPI.OP1\(34),
datac => \FPI.OP1\(31));
\GRFPC0_WR_RREG_RES_RNO_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000ffffcccccccc")
port map (
combout => N_47266,
dataf => N_99846,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_11_3614_I_A3_0_0_0\,
datad => N_99904_1,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(29),
datab => \GRFPC0.MEM.RREG.RES\(29));
\GRFPC0_MEM_RREG_RES_RNO_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fffff0f0f0f0")
port map (
combout => N_47224,
dataf => N_99847,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_11_3614_I_A3_0_0_0\,
datad => N_99904_1,
datac => \GRFPC0.EX.RREG.RES\(29),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(29));
\GRFPC0_FP_PIPELINE_DBGDATA_4_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => CPO_DBG_DATAZ(29),
dataf => N_425,
datae => N_426,
datad => N_720,
datac => N_656);
\GRFPC0_FP_PIPELINE_WRDATA_3_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(27),
dataf => \GRFPC0.DIV.RESULT\(27),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(27),
datab => \FPO.RES\(27));
\GRFPC0_WRDATA_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(27),
dataf => N_458,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(59),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(27));
\GRFPC0_FP_PIPELINE_WRDATA_3_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(26),
dataf => \GRFPC0.DIV.RESULT\(26),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(26),
datab => \FPO.RES\(26));
\GRFPC0_WRDATA_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(26),
dataf => N_457,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(58),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(26));
\GRFPC0_FP_PIPELINE_DBGDATA_4_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(25),
dataf => \GRFPC0.R.FSR.TEM\(2),
datae => N_425,
datad => N_426,
datac => N_716,
datab => N_652);
\GRFPC0_FP_PIPELINE_WRDATA_3_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(25),
dataf => \GRFPC0.DIV.RESULT\(25),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(25),
datab => \FPO.RES\(25));
\GRFPC0_WRDATA_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(25),
dataf => N_456,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(57),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(25));
\GRFPC0_MEM_RREG_RES_RNO_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff00cccccccc")
port map (
combout => N_47220,
dataf => N_99847,
datae => \GRFPU0.GRFPU_X0.N_401\,
datad => \FPO.RES_1\(25),
datac => \GRFPU0.GRFPU_X0.ST4.SGNF\(25),
datab => \GRFPC0.EX.RREG.RES\(25));
\GRFPC0_FP_PIPELINE_DBGDATA_4_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(24),
dataf => \GRFPC0.R.FSR.TEM\(1),
datae => N_425,
datad => N_426,
datac => N_715,
datab => N_651);
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_17_3458_I_A3_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000f003300ff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_17_3458_I_A3_0\,
dataf => N_99904_2,
datae => \GRFPU0.GRFPU_X0.N_400_1\,
datad => \GRFPC0.DIV.RESULT_0_0_23__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(23),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(23));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_19_3406_I_A3_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000f003300ff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_19_3406_I_A3_0\,
dataf => N_99904_2,
datae => \GRFPU0.GRFPU_X0.N_400_1\,
datad => \GRFPC0.DIV.RESULT_0_0_21__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(21),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(21));
\GRFPC0_FP_PIPELINE_WRDATA_3_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(20),
dataf => \GRFPC0.DIV.RESULT\(20),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(20),
datab => \FPO.RES\(20));
\GRFPC0_WRDATA_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(20),
dataf => N_451,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(52),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(20));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_20_3380_I_A3_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000f003300ff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_20_3380_I_A3_0\,
dataf => N_99904_2,
datae => \GRFPU0.GRFPU_X0.N_400_1\,
datad => \GRFPC0.DIV.RESULT_0_0_20__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(20),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(20));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_21_3354_I_A3_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000f003300ff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_21_3354_I_A3_0\,
dataf => N_99904_2,
datae => \GRFPU0.GRFPU_X0.N_400\,
datad => \GRFPC0.DIV.RESULT_0_0_19__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(19),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(19));
\GRFPC0_WR_RREG_RES_RNO_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fffff0f0f0f0")
port map (
combout => N_47255,
dataf => N_99846,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_22_3328_I_A3_0_0_0\,
datad => N_99904_2,
datac => \GRFPC0.MEM.RREG.RES\(18),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(18));
\GRFPC0_WR_RREG_RES_RNO_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fffff0f0f0f0")
port map (
combout => N_47254,
dataf => N_99846,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_23_3302_I_A3_0_0_0\,
datad => N_99904_2,
datac => \GRFPC0.MEM.RREG.RES\(17),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(17));
\GRFPC0_MEM_RREG_RES_RNO_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fffff0f0f0f0")
port map (
combout => N_47212,
dataf => N_99847,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_23_3302_I_A3_0_0_0\,
datad => N_99904_1,
datac => \GRFPC0.EX.RREG.RES\(17),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(17));
\GRFPC0_FP_PIPELINE_DBGDATA_4_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(16),
dataf => \GRFPC0.R.FSR.FTT\(2),
datae => N_425,
datad => N_426,
datac => N_707,
datab => N_643);
\GRFPC0_FP_PIPELINE_WRDATA_3_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(48),
dataf => \GRFPC0.DIV.RESULT\(48),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(48),
datab => \GRFPU0.GRFPU_X0.N_20273_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(16),
dataf => \GRFPC0.DIV.RESULT\(16),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(16),
datab => \FPO.RES\(16));
\GRFPC0_WRDATA_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(16),
dataf => N_447,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(48),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(16));
\GRFPC0_MEM_RREG_RES_RNO_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fffff0f0f0f0")
port map (
combout => N_47209,
dataf => N_99847,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_26_3224_I_A3_0_0_0\,
datad => N_99904_1,
datac => \GRFPC0.EX.RREG.RES\(14),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(14));
\GRFPC0_OP1_3_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20101\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(44),
datad => \GRFPC0.WR.RREG.RES\(44));
\GRFPC0_WR_RREG_RES_RNO_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fffff0f0f0f0")
port map (
combout => N_47249,
dataf => N_99846,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_28_3172_I_A3_0_0_0\,
datad => N_99904_2,
datac => \GRFPC0.MEM.RREG.RES\(12),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(12));
\GRFPC0_FP_PIPELINE_DBGDATA_4_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(11),
dataf => \GRFPC0.R.FSR.FCC\(1),
datae => N_425,
datad => N_426,
datac => N_702,
datab => N_638);
\GRFPC0_FP_PIPELINE_DBGDATA_4_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(10),
dataf => \GRFPC0.R.FSR.FCC\(0),
datae => N_425,
datad => N_426,
datac => N_701,
datab => N_637);
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_30_3120_I_A3_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000f003300ff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_30_3120_I_A3_0\,
dataf => N_99904_2,
datae => \GRFPU0.GRFPU_X0.N_400\,
datad => \GRFPC0.DIV.RESULT_0_0_10__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(10),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(10));
\GRFPC0_FP_PIPELINE_WRDATA_3_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(41),
dataf => \GRFPC0.DIV.RESULT\(41),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(41),
datab => \GRFPU0.GRFPU_X0.N_20297_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(9),
dataf => \GRFPC0.DIV.RESULT\(9),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(9),
datab => \FPO.RES\(9));
\GRFPC0_WRDATA_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(9),
dataf => N_440,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(41),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(9));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_31_3094_I_A3_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000f003300ff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_31_3094_I_A3_0\,
dataf => N_99904_2,
datae => \GRFPU0.GRFPU_X0.N_400\,
datad => \GRFPC0.DIV.RESULT_0_0_9__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(9),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(9));
\GRFPC0_FP_PIPELINE_DBGDATA_4_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(6),
dataf => \GRFPC0.R.FSR.AEXC\(1),
datae => N_425,
datad => N_426,
datac => N_697,
datab => N_633);
\GRFPC0_OP1_4_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20160\,
dataf => N_99879_0,
datae => N_633,
datad => N_697);
\GRFPC0_FP_PIPELINE_DBGDATA_4_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(5),
dataf => \GRFPC0.R.FSR.AEXC\(0),
datae => N_425,
datad => N_426,
datac => N_696,
datab => N_632);
\GRFPC0_FP_PIPELINE_WRDATA_3_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(3),
dataf => \GRFPC0.DIV.RESULT\(3),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(3),
datab => \FPO.RES\(3));
\GRFPC0_WRDATA_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(3),
dataf => N_434,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(35),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(3));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_37_2938_I_A3_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000f003300ff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_37_2938_I_A3_0\,
dataf => N_99904_2,
datae => \GRFPU0.GRFPU_X0.N_400\,
datad => \GRFPC0.DIV.RESULT_0_0_3__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(3),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(3));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_38_2912_I_A3_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000f003300ff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_38_2912_I_A3_0\,
dataf => N_99904_2,
datae => \GRFPU0.GRFPU_X0.N_400\,
datad => \GRFPC0.DIV.RESULT_0_0_2__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(2),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(2));
GRFPC0_FP_PIPELINE_FCC_1_M2S4_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff000f000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_1_M2S4_0\,
dataf => \GRFPC0.WR.RREG.RESV\,
datae => \GRFPC0.WR.CTRL.CCWR\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.CTRL.CCWR\);
GRFPC0_EX_CTRL_CCWR_RNIK827: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.N_9441\,
dataf => \GRFPC0.EX.CTRL.CCWR\,
datae => \GRFPC0.EX.RREG.RESV\);
\GRFPC0_FP_PIPELINE_FCC_1_M0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0000fff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_1_M0\(1),
dataf => \GRFPC0.WR.RREG.RES\(1),
datae => \GRFPC0.WR2.RREG.RES\(1),
datad => \GRFPC0.WR.RREG.RESV\,
datac => \GRFPC0.WR.CTRL.CCWR\);
\GRFPC0_FP_PIPELINE_FCC_1_M2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ccfffff0cc0000")
port map (
combout => \GRFPC0.FP_PIPELINE.FCC_1_M2\(1),
dataf => \GRFPC0.FP_PIPELINE.FCC_1_M0\(1),
datae => \GRFPC0.FP_PIPELINE.FCC_1_SM0\,
datad => \GRFPC0.N_9441\,
datac => \GRFPC0.EX.RREG.RES\(1),
datab => \GRFPC0.MEM.RREG.RES\(1));
\GRFPC0_FP_PIPELINE_FCC_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_CCZ(1),
dataf => \GRFPC0.FP_PIPELINE.FCC_1_M2\(1),
datae => N_38,
datad => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datac => \GRFPC0.WR2.RREG.RES\(11),
datab => \GRFPC0.R.FSR.FCC\(1));
\GRFPC0_FP_PIPELINE_DBGDATA_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(0),
dataf => \GRFPC0.R.FSR.CEXC\(0),
datae => N_425,
datad => N_426,
datac => N_691,
datab => N_627);
\GRFPC0_OP1_4_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20154\,
dataf => N_99879_0,
datae => N_627,
datad => N_691);
\GRFPC0_FP_PIPELINE_V_FSR_FCC_1_M0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccf0cccccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M0\(0),
dataf => N_46992,
datae => \GRFPC0.FP_PIPELINE.UN25_HOLDN\,
datad => \GRFPC0.V.FSR.FCC_2_SQMUXA_0\,
datac => \GRFPC0.WR2.RREG.RES\(0),
datab => \GRFPC0.R.FSR.FCC\(0));
\GRFPC0_FP_PIPELINE_V_FSR_FCC_1_M0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccf0cccccc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.FCC_1_M0\(1),
dataf => N_46992,
datae => \GRFPC0.FP_PIPELINE.UN25_HOLDN\,
datad => \GRFPC0.V.FSR.FCC_2_SQMUXA_0\,
datac => \GRFPC0.WR2.RREG.RES\(1),
datab => \GRFPC0.R.FSR.FCC\(1));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_40_2860_I_A3_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000f003300ff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_40_2860_I_A3_0\,
dataf => N_99904_2,
datae => \GRFPU0.GRFPU_X0.N_400\,
datad => \GRFPC0.DIV.RESULT_0_0_0__G5\,
datac => \FPO.CC\(0),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(0));
\GRFPC0_EX_RREG_EXCT_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f000f000f0f0000")
port map (
combout => N_53552,
dataf => \GRFPC0.N_82\,
datae => \FPO.EXC\(0),
datad => \GRFPC0.EX.RREG.EXCT\(0),
datac => N_37);
GRFPC0_FP_PIPELINE_VWR_RREG_EXCT_1_0_1733_I_A3_0_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.EXCT_1_0_1733_I_A3_0_0_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.DEFERNX\,
datae => \GRFPU0.GRFPU_X0.ST4.EXC\(0));
GRFPC0_FP_PIPELINE_0_UN1_DEP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
dataf => N_113,
datae => \GRFPC0.FP_PIPELINE.UN24_OP\,
datad => \GRFPC0.N_313\,
datac => N_109,
datab => N_108);
\GRFPC0_FP_PIPELINE_5_STDEP_234_0_IV_I_A4_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000f0000000000")
port map (
combout => \GRFPC0.N_23281\,
dataf => \GRFPC0.RFA.LD\,
datae => \GRFPC0.RFA.RDD\,
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1889_DEP\,
datac => N_172);
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_I_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3300030000000000")
port map (
combout => \GRFPC0.N_21477\,
dataf => \GRFPC0.N_21948_1\,
datae => \GRFPC0.N_533\,
datad => \GRFPC0.N_655\,
datac => \GRFPC0.N_470\,
datab => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_I_0_A5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f03ff3300000000")
port map (
combout => \GRFPC0.N_22757\,
dataf => \GRFPC0.N_22718\,
datae => \GRFPC0.N_21462\,
datad => \GRFPC0.N_533\,
datac => \GRFPC0.N_655\,
datab => \GRFPC0.N_470\);
\GRFPC0_FP_PIPELINE_2_STDEP_110_0_IV_0_A3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => \GRFPC0.N_22764\,
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.N_543_1\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_2\,
datac => \GRFPC0.FIFO.INST_0\(26),
datab => \GRFPC0.FIFO.INST_0\(27));
GRFPC0_FP_PIPELINE_1_STDEP_56_SEL1_I_0_A2_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff3ffffffffff")
port map (
combout => \GRFPC0.N_26\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_2\,
datae => \GRFPC0.N_106_I\,
datad => \GRFPC0.EX.CTRL.RDWR\,
datac => \GRFPC0.EX.CTRL.RD\(2),
datab => \GRFPC0.EX.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_1_STDEP_48_3_I_X3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffffff00")
port map (
combout => \GRFPC0.N_68_I\,
dataf => \GRFPC0.N_22126\,
datae => \GRFPC0.WR.CTRL.RDD\,
datad => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_0_STDEP_82_0_IV_I_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPC0.N_22854\,
dataf => \GRFPC0.N_22837\,
datae => \GRFPC0.STDEP_0_SQMUXA_81_2_I\,
datad => \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN496_REGDEPX_0\,
datac => \GRFPC0.FIFO.INST_1\(29),
datab => \GRFPC0.FIFO.INST_1\(28));
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_O2_I_A3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000003000000000")
port map (
combout => \GRFPC0.N_675\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(2),
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN4672_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4672_REGDEPX\,
dataf => N_95,
datae => N_94,
datad => N_93,
datac => N_96);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_4_0_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_4_0\(29),
dataf => \GRFPC0.FIFO.INST_0\(18),
datae => \GRFPC0.FIFO.INST_0\(17),
datad => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_0_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf00000cc000000")
port map (
combout => \GRFPC0.N_24943\,
dataf => \GRFPC0.N_21277_1\,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_22253\,
datac => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4552_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4583_REGDEPX\);
\GRFPC0_FP_PIPELINE_13_0_REGDEPX_238_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00c00000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.0.REGDEPX_238\(1),
dataf => \GRFPC0.N_22571\,
datae => \GRFPC0.N_24921\,
datad => \GRFPC0.N_22535\,
datac => \GRFPC0.N_24924\,
datab => \GRFPC0.FIFO.INST_0\(18));
\GRFPC0_FP_PIPELINE_13_REGDEPX_246_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf00000cc000000")
port map (
combout => \GRFPC0.N_24006\,
dataf => \GRFPC0.N_21277_1\,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_22253\,
datac => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4240_REGDEPX\,
datab => \GRFPC0.FP_PIPELINE.13.1.CHECK_DEP.UN4271_REGDEPX\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O3_4_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff03000000")
port map (
combout => \GRFPC0.N_22809\,
dataf => \GRFPC0.N_22900\,
datae => \GRFPC0.N_22899_1\,
datad => \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN512_REGDEPX_0\,
datac => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_1\(18));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O3_4_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff03000000")
port map (
combout => \GRFPC0.N_22810\,
dataf => \GRFPC0.N_22903\,
datae => \GRFPC0.N_22902_1\,
datad => \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN512_REGDEPX_0\,
datac => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_1\(18));
\GRFPC0_FP_PIPELINE_7_REGDEPX_138_0_A4_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_8_0\(14),
dataf => \GRFPC0.FIFO.INST_1\(17),
datae => \GRFPC0.FIFO.INST_1\(18),
datad => \GRFPC0.FIFO.INST_1\(15),
datac => \GRFPC0.FIFO.INST_1\(16));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_4_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000ff303030")
port map (
combout => \GRFPC0.N_25028\,
dataf => N_99871,
datae => \GRFPC0.N_22902_1\,
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_8_0\(14),
datac => \GRFPC0.N_25013\,
datab => \GRFPC0.FIFO.INST_1\(19));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN300_REGDEPX_2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN928_REGDEPX_2\,
dataf => N_95,
datae => N_96);
\GRFPC0_FP_PIPELINE_7_REGDEPX_138_0_A2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf00000000000")
port map (
combout => \GRFPC0.N_24984\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_25016\,
datad => \GRFPC0.N_25011\,
datac => \GRFPC0.N_24977_1\,
datab => \GRFPC0.N_24978_1\);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN317_REGDEPX_2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN943_REGDEPX_2\,
dataf => N_81,
datae => N_82);
\GRFPC0_EX_CTRL_RD_RNIMOHA_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
dataf => \GRFPC0.N_106_I\,
datae => \GRFPC0.EX.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_13_STDEP_536_3_I_A3_I_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff0fff0c")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_536_3_I_A3_I_2\(0),
dataf => \GRFPC0.N_23288\,
datae => \GRFPC0.N_765\,
datad => \GRFPC0.FP_PIPELINE.13.STDEP_536_3_I_A3_I_0\(0),
datac => \GRFPC0.N_53\,
datab => \GRFPC0.N_579\);
\GRFPC0_FP_PIPELINE_13_STDEP_540_0_IV_I_A4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcfffcfffc0000")
port map (
combout => \GRFPC0.N_23284\,
dataf => \GRFPC0.N_21302\,
datae => \GRFPC0.FP_PIPELINE.13.STDEP_536_3_I_A3_I_2\(0),
datad => \GRFPC0.N_571\,
datac => N_99872,
datab => \GRFPC0.EX.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_7_STDEP_292_3_I_O2_1_I_A3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_690\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(2),
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_7_STDEP_292_3_0_A4_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00cc000000c00000")
port map (
combout => \GRFPC0.N_21855\,
dataf => \GRFPC0.N_22173_I\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datad => \GRFPC0.N_22325\,
datac => \GRFPC0.N_458\,
datab => \GRFPC0.FP_PIPELINE.7.STDEP_292_3_0_A4_1_0\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_O3_I_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.N_860\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(2),
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_0_REGDEP78: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP78\,
dataf => \GRFPC0.FPUSEL_6_2\(1),
datae => \GRFPC0.FPUSEL_6_0_1__G0_3_0\,
datad => \GRFPC0.FP_PIPELINE.RS1_6\(1),
datac => \GRFPC0.EX.CTRL.RD\(1));
GRFPC0_REGDEP_0_SQMUXA_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000ff000000")
port map (
combout => \GRFPC0.REGDEP_0_SQMUXA_1\,
dataf => \GRFPC0.N_23599_I_0\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEP90\,
datad => \GRFPC0.EX.CTRL.RDD_0_0_G1\);
GRFPC0_FP_PIPELINE_0_UN1_VEX_CTRL_RD_1_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"05fa3636af509c9c")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_3\,
dataf => \GRFPC0.N_24063\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datac => \GRFPC0.RFA.RS1\(4),
datab => \GRFPC0.RFA.RD\(4),
dataa => N_37);
GRFPC0_FP_PIPELINE_0_UN1_VEX_CTRL_RD_1_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"05fa3636af509c9c")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_2\,
dataf => \GRFPC0.N_24062\,
datae => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datad => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datac => \GRFPC0.RFA.RS1\(3),
datab => \GRFPC0.RFA.RD\(3),
dataa => N_37);
GRFPC0_FP_PIPELINE_0_REGDEP90: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000804")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP90\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_3\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_2\,
datad => \GRFPC0.N_23714\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_VEX.CTRL.RD_1_0\,
datab => \GRFPC0.EX.CTRL.RDWR_0_0_G2\,
dataa => \GRFPC0.N_24644\);
GRFPC0_REGDEP_1_SQMUXA_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0cc0f3300000000")
port map (
combout => \GRFPC0.REGDEP_1_SQMUXA_1\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEP90\,
datae => \GRFPC0.N_22829\,
datad => \GRFPC0.FP_PIPELINE.UN109_HOLDN\,
datac => \GRFPC0.V.STDATA_14\(25),
datab => \GRFPC0.RFA.RD\(0));
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_O2_1_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => \GRFPC0.N_533\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(2),
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(3));
GRFPC0_VWR2_RREG_RESV_0_SQMUXA_1_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffffff00")
port map (
combout => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datae => \GRFPC0.FPR.RDY\,
datad => N_37);
\GRFPC0_FP_PIPELINE_WRDATA_3_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(7),
dataf => \GRFPC0.DIV.RESULT\(7),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(7),
datab => \FPO.RES\(7));
\GRFPC0_WRDATA_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(7),
dataf => N_438,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(39),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(7));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_33_3042_I_A3_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000f003300ff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_33_3042_I_A3_0\,
dataf => N_99904_2,
datae => \GRFPU0.GRFPU_X0.N_400\,
datad => \GRFPC0.DIV.RESULT_0_0_7__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(7),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(7));
GRFPC0_VWR_RREG_RESV_0_SQMUXA_1_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
dataf => \GRFPC0.N_24361\,
datae => N_37);
GRFPC0_VFIFO_WR_1_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.VFIFO.WR_1_SQMUXA\,
dataf => \GRFPC0.FP_PIPELINE.CNTX14_0\,
datae => \GRFPC0.FP_PIPELINE.UN4_CNTX\(1),
datad => \GRFPC0.FP_PIPELINE.UN1_FIFO.VCNT_1_1\,
datac => \GRFPC0.FIFO.FULL\);
GRFPC0_VFIFO_WR_0_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.VFIFO.WR_0_SQMUXA\,
dataf => \GRFPC0.FP_PIPELINE.0.UN78_PENDEXC\,
datae => \GRFPC0.FIFO.WR\(0),
datad => \GRFPC0.FIFO.RD\(0),
datac => \GRFPC0.FIFO.FULL\);
\GRFPC0_UN1_PENDEXC_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccc0fffffff3")
port map (
combout => N_82238,
dataf => CPO_EXCZ,
datae => \GRFPC0.VFIFO.WR_1_SQMUXA\,
datad => \GRFPC0.VFIFO.WR_0_SQMUXA_1\,
datac => \GRFPC0.VFIFO.WR_0_SQMUXA\,
datab => \GRFPC0.FP_PIPELINE.VFIFO.RD10\);
GRFPC0_VFIFO_WR_0_SQMUXA_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.VFIFO.WR_0_SQMUXA_1\,
dataf => \GRFPC0.FP_PIPELINE.1.UN87_PENDEXC\,
datae => \GRFPC0.FIFO.WR\(0),
datad => \GRFPC0.FIFO.RD\(0),
datac => \GRFPC0.FIFO.FULL\);
GRFPC0_FP_PIPELINE_RSDEC_RS1V_I_I_A2_1_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPC0.N_23789\,
dataf => \GRFPC0.N_23625\,
datae => \GRFPC0.INST\(19),
datad => \GRFPC0.INST\(31));
GRFPC0_FP_PIPELINE_RSDEC_RS1V_I_I_A2_0_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_23778_2\,
dataf => \GRFPC0.N_23625\,
datae => \GRFPC0.INST\(31));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_25233\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.PC_0\(9),
datad => \GRFPC0.FIFO.PC_1\(9));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_244\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.PC_0\(12),
datad => \GRFPC0.FIFO.PC_1\(12));
GRFPC0_FP_PIPELINE_UN29_WREN_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00cc00cc00c000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN29_WREN_1\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.UN28_WREN_2\,
datad => \GRFPC0.DIV.VALID\,
datac => \GRFPC0.WR2.CTRL.SEQERR\,
datab => N_37);
\GRFPC0_RFA2_RS2SEL_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f0fcc00")
port map (
combout => \GRFPC0.FPUSEL_1\(4),
dataf => \GRFPC0.UN1_WRENX10_1\,
datae => \GRFPC0.FP_PIPELINE.1.WRENX10\,
datad => \GRFPC0.FP_PIPELINE.1.WR2EN10\,
datac => \GRFPC0.N_24359\,
datab => \GRFPC0.WR2SEL_1\(4));
\GRFPC0_RFA2_RS2SEL_RNO_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cccc0fff")
port map (
combout => \GRFPC0.N_10561\,
dataf => \GRFPC0.UN1_WRENX10\,
datae => \GRFPC0.FP_PIPELINE.1.WR2EN10\,
datad => \GRFPC0.FP_PIPELINE.1.DIVEN10_4\,
datac => \GRFPC0.FP_PIPELINE.1.DIVEN10_3\,
datab => \GRFPC0.WR2SEL_1\(7));
GRFPC0_FP_PIPELINE_1_WRENX10_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00000f00f00000f")
port map (
combout => \GRFPC0.FP_PIPELINE.1.WRENX10_1\,
dataf => RFI2_RD2ADDRZ(3),
datae => RFI2_RD2ADDRZ(1),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_1_WRENX10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c030000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.WRENX10\,
dataf => \GRFPC0.FP_PIPELINE.1.WRENX10_1\,
datae => \GRFPC0.FP_PIPELINE.1.WRENX10_1_0\,
datad => RFI2_RD2ADDRZ(2),
datac => \GRFPC0.WR.CTRL.RDWR\,
datab => \GRFPC0.WR.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_RS2_1_RNI2JM61_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00000f00f00000f")
port map (
combout => \GRFPC0.FPUSEL_1_0_1__G0_3_1\,
dataf => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datae => RFI2_RD2ADDRZ(0),
datad => \GRFPC0.EX.CTRL.RD\(1),
datac => \GRFPC0.EX.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_0_UN1_MEM_CTRL_RD_1_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffff0f0ff0f00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.RD_2_3\,
dataf => \GRFPC0.N_24062\,
datae => \GRFPC0.MEM.CTRL.RD\(3),
datad => \GRFPC0.RFA.RS1\(3),
datac => N_37);
\GRFPC0_RFA_RS1_RNI60I01_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc03000030cf0000")
port map (
combout => \GRFPC0.FPUSEL_6_0_3__G0_E_0\,
dataf => \GRFPC0.N_24063\,
datae => \GRFPC0.MEM.CTRL.RDWR\,
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.RFA.RS1\(4),
datab => N_37);
\GRFPC0_FP_PIPELINE_RS1_6_I_M3_RNIE4OJL_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FPUSEL_6_0_3__G0_E_2\,
dataf => \GRFPC0.N_22829\,
datae => \GRFPC0.N_23714\,
datad => \GRFPC0.MEM.CTRL.RD\(0),
datac => \GRFPC0.MEM.CTRL.RD\(2));
\GRFPC0_FP_PIPELINE_RS2_1_RNI0DK31_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FPUSEL_1_0_3__G0_E_0_0\,
dataf => RFI2_RD2ADDRZ(0),
datae => RFI2_RD2ADDRZ(2),
datad => \GRFPC0.MEM.CTRL.RD\(1),
datac => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_RS2_1_RNIHU273_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c030000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.MEMEN10\,
dataf => \GRFPC0.FPUSEL_1_0_3__G0_E_0_0\,
datae => \GRFPC0.FPUSEL_1_0_3__G0_E_1\,
datad => RFI2_RD2ADDRZ(1),
datac => \GRFPC0.MEM.CTRL.RDWR\,
datab => \GRFPC0.MEM.CTRL.RD\(2));
GRFPC0_EX_RREG_RESV_RNIUA5L2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_155_1\,
dataf => \GRFPC0.N_82\,
datae => \GRFPC0.EX.RREG.RESV\);
GRFPC0_FP_PIPELINE_0_MEMSEL4_I_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_24389\,
dataf => \GRFPC0.N_24428\,
datae => \GRFPC0.MEM.RREG.RESV\);
\GRFPC0_OP1_3_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20114\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(57),
datad => \GRFPC0.WR.RREG.RES\(57));
\GRFPC0_FP_PIPELINE_WRDATA_3_57_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(57),
dataf => \GRFPC0.DIV.RESULT\(57),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(57),
datab => \GRFPU0.GRFPU_X0.N_20287_I_0\);
\GRFPU0_GRFPU_X0_UN13_EXP_M_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc000cff0c00")
port map (
combout => \FPI.OP1\(58),
dataf => \GRFPC0.N_19983\,
datae => \GRFPC0.N_20312\,
datad => N_99877,
datac => N_99878,
datab => \GRFPC0.N_20049\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(26),
dataf => \GRFPC0.R.FSR.TEM\(3),
datae => N_425,
datad => N_426,
datac => N_717,
datab => N_653);
\GRFPC0_OP1_2_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20049\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(58),
datad => \GRFPC0.MEM.RREG.RES\(58));
\GRFPC0_OP1_1_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19983\,
dataf => \FPO.RES\(58),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(58));
\GRFPC0_FP_PIPELINE_WRDATA_3_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(58),
dataf => \GRFPC0.DIV.RESULT\(58),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(58),
datab => \FPO.RES\(58));
\GRFPC0_OP1_4_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20181\,
dataf => N_99879,
datae => N_654,
datad => N_718);
\GRFPC0_OP1_3_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20116\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(1),
datae => \GRFPC0.EX.RREG.RES\(59),
datad => \GRFPC0.WR.RREG.RES\(59));
\GRFPU0_GRFPU_X0_UN13_EXP_M_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(59),
dataf => \GRFPC0.N_20247\,
datae => N_99877,
datad => \GRFPC0.N_20181\,
datac => \GRFPC0.RFA2.RS1SEL\(7),
datab => \GRFPC0.N_20116\);
\GRFPC0_OP2_1_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19489\,
dataf => \FPO.RES\(59),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(59));
\GRFPC0_FP_PIPELINE_WRDATA_3_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(59),
dataf => \GRFPC0.DIV.RESULT\(59),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(59),
datab => \FPO.RES\(59));
\GRFPC0_FP_PIPELINE_WRDATA_3_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(29),
dataf => \GRFPC0.DIV.RESULT\(29),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(29),
datab => \FPO.RES\(29));
\GRFPC0_WRDATA_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(29),
dataf => N_460,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(61),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(29));
\GRFPC0_FP_PIPELINE_WRDATA_3_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(55),
dataf => \GRFPC0.DIV.RESULT\(55),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(55),
datab => \FPO.RES\(55));
\GRFPC0_FP_PIPELINE_WRDATA_3_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(23),
dataf => \GRFPC0.DIV.RESULT\(23),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(23),
datab => \FPO.RES\(23));
\GRFPC0_WRDATA_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(23),
dataf => N_454,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(55),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(23));
\GRFPU0_GRFPU_X0_UN13_EXP_M_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(60),
dataf => \GRFPC0.N_20248\,
datae => N_99877,
datad => \GRFPC0.N_20182\,
datac => \GRFPC0.RFA2.RS1SEL\(7),
datab => \GRFPC0.N_20117\);
\GRFPC0_OP1_4_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20182\,
dataf => N_99879,
datae => N_655,
datad => N_719);
\GRFPC0_OP1_3_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20117\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(1),
datae => \GRFPC0.EX.RREG.RES\(60),
datad => \GRFPC0.WR.RREG.RES\(60));
\GRFPC0_FP_PIPELINE_WRDATA_3_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(28),
dataf => \GRFPC0.DIV.RESULT\(28),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(28),
datab => \FPO.RES\(28));
\GRFPC0_WRDATA_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(28),
dataf => N_459,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(60),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(28));
\GRFPC0_FP_PIPELINE_WRDATA_3_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(60),
dataf => \GRFPC0.DIV.RESULT\(60),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(60),
datab => \GRFPU0.GRFPU_X0.N_20288_I_0\);
\GRFPC0_R_STATE_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f030f0f0f030000")
port map (
combout => \GRFPC0.R.STATE_0_0_0__G2\,
dataf => N_46992,
datae => \GRFPC0.R.STATE\(0),
datad => \GRFPC0.R.STATE\(1),
datac => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA\,
datab => N_40);
\GRFPC0_FP_PIPELINE_DBGDATA_4_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => CPO_DBG_DATAZ(28),
dataf => N_425,
datae => N_426,
datad => N_719,
datac => N_655);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(30),
dataf => \GRFPU0.GRFPU_X0.N_21\,
datae => \GRFPU0.GRFPU_X0.N_18746\,
datad => \FPI.OP1\(33),
datac => \FPI.OP1\(30));
\GRFPU0_GRFPU_X0_COMB_VITER_ALLOW_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ff0ffff0ff00000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.ALLOW_1\(1),
dataf => \GRFPU0.GRFPU_X0.N_15366\,
datae => \GRFPU0.GRFPU_X0.N_138\,
datad => \GRFPU0.GRFPU_X0.VALLOW_3_SQMUXA_5_2\,
datac => \GRFPU0.GRFPU_X0.ITER.SQRT\);
\GRFPU0_GRFPU_X0_ALLOW_I_O3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccccfcc00000f00")
port map (
combout => \GRFPU0.GRFPU_X0.N_138\,
dataf => \GRFPU0.GRFPU_X0.VALLOW_5_SQMUXA_7_1\,
datae => \GRFPU0.GRFPU_X0.N_5539\,
datad => \GRFPU0.GRFPU_X0.VALLOW_3_SQMUXA_5_2\,
datac => \GRFPU0.GRFPU_X0.N_5987\,
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_14\);
GRFPU0_GRFPU_X0_VALLOW_3_SQMUXA_5_0_A3_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fffffffc")
port map (
combout => \GRFPU0.GRFPU_X0.VALLOW_3_SQMUXA_5_2\,
dataf => \GRFPU0.GRFPU_X0.N_18408_1\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(18),
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(17),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(11));
GRFPC0_FP_PIPELINE_UN6_SHARE: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff00ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.UN6_SHARE\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => \GRFPC0.EX.CTRL.CCWR\);
GRFPC0_FID_2_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_9160\,
dataf => \GRFPC0.N_9163\,
datae => \GRFPC0.FP_PIPELINE.UN17_SHARE\,
datad => \GRFPC0.FP_PIPELINE.ORV.TMP\,
datac => \GRFPC0.FP_PIPELINE.UN11_SHARE\,
datab => \GRFPC0.FP_PIPELINE.UN6_SHARE\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_130_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00c0ffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_130\(0),
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX2_128\(0),
datae => \GRFPC0.FP_PIPELINE.4.REGDEPX2_125\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2033_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(0));
GRFPC0_FP_PIPELINE_RSDEC_RDWR_I_0_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcf0000cfcf00ff")
port map (
combout => \GRFPC0.N_95\,
dataf => \GRFPC0.INST\(5),
datae => \GRFPC0.INST\(12),
datad => \GRFPC0.N_23618\,
datac => \GRFPC0.INST\(11),
datab => \GRFPC0.INST\(10));
GRFPC0_FP_PIPELINE_IS_RDD_UN1_INST_7_I_O2_I_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_23783\,
dataf => \GRFPC0.INST\(12),
datae => \GRFPC0.INST\(11));
GRFPC0_FP_PIPELINE_RSDEC_RS2D_IV_I_O2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffff0000")
port map (
combout => \GRFPC0.N_23629\,
dataf => \GRFPC0.N_23631\,
datae => \GRFPC0.INST\(5),
datad => \GRFPC0.INST\(12));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_83_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc400")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_83\(0),
dataf => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80\(0),
datae => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_4\(0),
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1271_REGDEPX2\,
datac => \GRFPC0.WR2.CTRL.RDD\,
datab => \GRFPC0.WR2.CTRL.RS1V\,
dataa => \GRFPC0.WR2.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_249\,
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.PC_0\(18),
datad => \GRFPC0.FIFO.PC_1\(18));
GRFPC0_FP_PIPELINE_0_REGDEP78_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc03000030cf0000")
port map (
combout => \GRFPC0.FPUSEL_6_0_1__G0_3_0\,
dataf => \GRFPC0.N_24063\,
datae => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.EX.CTRL.RD\(4),
datac => \GRFPC0.RFA.RS1\(4),
datab => N_37);
GRFPC0_FP_PIPELINE_0_REGDEP78_0_RNI6AJAS: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c00c000030030000")
port map (
combout => \GRFPC0.FPUSEL_6_3\(1),
dataf => \GRFPC0.N_22829\,
datae => \GRFPC0.FPUSEL_6_0_1__G0_3_0\,
datad => \GRFPC0.FP_PIPELINE.RS1_6\(1),
datac => \GRFPC0.EX.CTRL.RD\(1),
datab => \GRFPC0.EX.CTRL.RD\(0));
\GRFPC0_RFA_RS1_RNI30VSL_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"e0100e0140b0040b")
port map (
combout => \GRFPC0.FPUSEL_6_2\(1),
dataf => \GRFPC0.N_24062\,
datae => \GRFPC0.N_23714\,
datad => \GRFPC0.EX.CTRL.RD\(3),
datac => \GRFPC0.EX.CTRL.RD\(2),
datab => \GRFPC0.RFA.RS1\(3),
dataa => N_37);
GRFPC0_FP_PIPELINE_0_EXEN2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.EXEN2\,
dataf => \GRFPC0.FPUSEL_6_3\(1),
datae => \GRFPC0.FPUSEL_6_2\(1));
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC_1_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f00ff0f0fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1_2\,
dataf => \GRFPC0.R.FSR.TEM\(2),
datae => \GRFPC0.R.FSR.TEM\(1),
datad => \GRFPC0.DIV.EXCT\(2),
datac => \GRFPC0.DIV.EXCT\(1));
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC_1_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f00ff0f0fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1_1\,
dataf => \GRFPC0.R.FSR.TEM\(0),
datae => \GRFPC0.R.FSR.TEM\(4),
datad => \GRFPC0.DIV.EXCT\(0),
datac => \GRFPC0.DIV.EXCT\(4));
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC_1_1_RNI08MC1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ec00ff00ff00ff00")
port map (
combout => N_44718_1,
dataf => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1_2\,
datae => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_1_1\,
datad => \GRFPC0.DIV.VALID\,
datac => \GRFPC0.R.FSR.TEM\(3),
datab => \GRFPC0.DIV.EXCT\(5),
dataa => \GRFPC0.DIV.EXCT\(3));
\GRFPC0_OP1_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(52),
dataf => \GRFPC0.N_20240\,
datae => N_99877,
datad => \GRFPC0.N_20174\,
datac => \GRFPC0.RFA2.RS1SEL_0\(7),
datab => \GRFPC0.N_20109\);
\GRFPC0_OP1_4_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20174\,
dataf => N_99879,
datae => N_647,
datad => N_711);
\GRFPC0_OP1_3_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20109\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(52),
datad => \GRFPC0.WR.RREG.RES\(52));
GRFPC0_WR2_CTRL_PEND_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030303000")
port map (
combout => \GRFPC0.WR2.CTRL.PEND_0_0_G2\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.N_23696\,
datad => \GRFPC0.DIV.PEND\,
datac => \GRFPC0.WR2.CTRL.PEND\,
datab => \GRFPC0.DIV.EXC_MB_2_I_0\);
GRFPC0_FP_PIPELINE_VWR2_CTRL_PEND_1_IV_0_A4_0_4_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.CTRL.PEND_1_IV_0_A4_0_4_4\,
dataf => \GRFPC0.WR2.CTRL.INST\(22),
datae => \GRFPC0.WR2.CTRL.INST\(21),
datad => \GRFPC0.WR2.CTRL.INST\(31),
datac => \GRFPC0.WR2.CTRL.INST\(23));
GRFPC0_FP_PIPELINE_VWR2_CTRL_PEND_1_IV_0_A4_0_4_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR2.CTRL.PEND_1_IV_0_A4_0_4_3\,
dataf => \GRFPC0.WR2.CTRL.INST\(24),
datae => \GRFPC0.WR2.CTRL.INST\(30),
datad => \GRFPC0.WR2.CTRL.INST\(20));
GRFPC0_WR2_CTRL_PEND_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff33300000")
port map (
combout => \GRFPC0.WR2.CTRL.PEND_0_0_G1\,
dataf => \GRFPC0.WR2.CTRL.PEND_0_0_G2\,
datae => \GRFPC0.N_23731_4\,
datad => \GRFPC0.WR2.CTRL.CCWR\,
datac => \GRFPC0.WR2.CTRL.RDWR\,
datab => \GRFPC0.DIV.EXC_MB_2_I_0\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(50),
dataf => \GRFPU0.GRFPU_X0.N_21\,
datae => \GRFPU0.GRFPU_X0.N_18746\,
datad => \FPI.OP1\(53),
datac => \FPI.OP1\(50));
\GRFPC0_FP_PIPELINE_DBGDATA_4_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => CPO_DBG_DATAZ(20),
dataf => N_425,
datae => N_426,
datad => N_711,
datac => N_647);
\GRFPC0_OP1_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc000cff0c00")
port map (
combout => \FPI.OP1\(50),
dataf => \GRFPC0.N_19975\,
datae => \GRFPC0.N_20304\,
datad => N_99877,
datac => N_99878_1,
datab => \GRFPC0.N_20041\);
\GRFPC0_OP1_2_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20041\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(50),
datad => \GRFPC0.MEM.RREG.RES\(50));
\GRFPC0_OP1_1_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19975\,
dataf => \FPO.RES\(50),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(50));
\GRFPC0_FP_PIPELINE_DBGDATA_4_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00f0f0")
port map (
combout => CPO_DBG_DATAZ(18),
dataf => N_425,
datae => N_426,
datad => N_709,
datac => N_645);
\GRFPC0_FP_PIPELINE_DBGDATA_4_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(2),
dataf => \GRFPC0.R.FSR.CEXC\(2),
datae => N_425,
datad => N_426,
datac => N_693,
datab => N_629);
\GRFPC0_OP1_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(34),
dataf => \GRFPC0.N_20222\,
datae => N_99877_1,
datad => \GRFPC0.N_20156\,
datac => \GRFPC0.RFA2.RS1SEL_0\(7),
datab => \GRFPC0.N_20091\);
\GRFPC0_OP1_4_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20156\,
dataf => N_99879_0,
datae => N_629,
datad => N_693);
\GRFPC0_OP1_3_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20091\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(34),
datad => \GRFPC0.WR.RREG.RES\(34));
\GRFPC0_FP_PIPELINE_WRDATA_3_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(39),
dataf => \GRFPC0.DIV.RESULT\(39),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(39),
datab => \GRFPU0.GRFPU_X0.N_19153_I_0\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(7),
dataf => \GRFPC0.R.FSR.AEXC\(2),
datae => N_425,
datad => N_426,
datac => N_698,
datab => N_634);
\GRFPC0_OP1_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(39),
dataf => \GRFPC0.N_20227\,
datae => N_99877_1,
datad => \GRFPC0.N_20161\,
datac => \GRFPC0.RFA2.RS1SEL_0\(7),
datab => \GRFPC0.N_20096\);
\GRFPC0_OP1_4_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20161\,
dataf => N_99879_0,
datae => N_634,
datad => N_698);
\GRFPC0_OP1_3_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20096\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(39),
datad => \GRFPC0.WR.RREG.RES\(39));
\GRFPC0_FP_PIPELINE_WRDATA_3_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(40),
dataf => \GRFPC0.DIV.RESULT\(40),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(40),
datab => \GRFPU0.GRFPU_X0.N_20289_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(8),
dataf => \GRFPC0.DIV.RESULT\(8),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(8),
datab => \FPO.RES\(8));
\GRFPC0_WRDATA_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(8),
dataf => N_439,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(40),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(8));
\GRFPC0_OP1_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(41),
dataf => \GRFPC0.N_20229\,
datae => N_99877_1,
datad => \GRFPC0.N_20163\,
datac => \GRFPC0.RFA2.RS1SEL_0\(7),
datab => \GRFPC0.N_20098\);
\GRFPC0_OP1_4_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20163\,
dataf => N_99879_0,
datae => N_636,
datad => N_700);
\GRFPC0_OP1_3_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20098\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(41),
datad => \GRFPC0.WR.RREG.RES\(41));
\GRFPC0_OP1_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(42),
dataf => \GRFPC0.N_20230\,
datae => N_99877_1,
datad => \GRFPC0.N_20164\,
datac => \GRFPC0.RFA2.RS1SEL_0\(7),
datab => \GRFPC0.N_20099\);
\GRFPC0_OP1_4_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20164\,
dataf => N_99879_0,
datae => N_637,
datad => N_701);
\GRFPC0_OP1_3_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20099\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(42),
datad => \GRFPC0.WR.RREG.RES\(42));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_A2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18808\,
dataf => \FPI.OP1\(51),
datae => \FPI.OP1\(52),
datad => \FPI.OP1\(53));
\GRFPC0_FP_PIPELINE_WRDATA_3_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(46),
dataf => \GRFPC0.DIV.RESULT\(46),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(46),
datab => \GRFPU0.GRFPU_X0.N_20291_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(14),
dataf => \GRFPC0.DIV.RESULT\(14),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(14),
datab => \FPO.RES\(14));
\GRFPC0_WRDATA_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(14),
dataf => N_445,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(46),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(14));
\GRFPC0_OP1_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(48),
dataf => \GRFPC0.N_20236\,
datae => N_99877,
datad => \GRFPC0.N_20170\,
datac => \GRFPC0.RFA2.RS1SEL_0\(7),
datab => \GRFPC0.N_20105\);
\GRFPC0_OP1_4_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20170\,
dataf => N_99879_0,
datae => N_643,
datad => N_707);
\GRFPC0_OP1_3_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20105\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(48),
datad => \GRFPC0.WR.RREG.RES\(48));
\GRFPC0_R_FSR_FTT_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0ff00cfc00f00")
port map (
combout => N_27777,
dataf => \GRFPC0.V.FSR.FTT_1_SQMUXA_2\,
datae => \GRFPC0.WR2.CTRL.SEQERR\,
datad => \GRFPC0.R.FSR.FTT\(2),
datac => N_37,
datab => N_35);
\GRFPC0_OP1_4_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20171\,
dataf => N_99879_0,
datae => N_644,
datad => N_708);
\GRFPC0_OP1_3_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20106\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(49),
datad => \GRFPC0.WR.RREG.RES\(49));
\GRFPC0_OP1_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(49),
dataf => \GRFPC0.N_20237\,
datae => N_99877,
datad => \GRFPC0.N_20171\,
datac => \GRFPC0.RFA2.RS1SEL_0\(7),
datab => \GRFPC0.N_20106\);
\GRFPC0_FP_PIPELINE_WRDATA_3_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(49),
dataf => \GRFPC0.DIV.RESULT\(49),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(49),
datab => \GRFPU0.GRFPU_X0.N_20292_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(17),
dataf => \GRFPC0.DIV.RESULT\(17),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(17),
datab => \FPO.RES\(17));
\GRFPC0_WRDATA_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(17),
dataf => N_448,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(49),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(17));
\GRFPC0_FP_PIPELINE_WRDATA_3_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(51),
dataf => \GRFPC0.DIV.RESULT\(51),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(51),
datab => \GRFPU0.GRFPU_X0.N_20285_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(19),
dataf => \GRFPC0.DIV.RESULT\(19),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(19),
datab => \FPO.RES\(19));
\GRFPC0_WRDATA_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(19),
dataf => N_450,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(51),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(19));
\GRFPC0_OP1_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(51),
dataf => \GRFPC0.N_20239\,
datae => N_99877,
datad => \GRFPC0.N_20173\,
datac => \GRFPC0.RFA2.RS1SEL_0\(7),
datab => \GRFPC0.N_20108\);
\GRFPC0_OP1_4_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20173\,
dataf => N_99879,
datae => N_646,
datad => N_710);
\GRFPC0_OP1_3_51_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20108\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(51),
datad => \GRFPC0.WR.RREG.RES\(51));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_O2_1_4_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_O2_1_4\(4),
dataf => \FPI.OP1\(59),
datae => \FPI.OP1\(60),
datad => \FPI.OP1\(58),
datac => \FPI.OP1\(57));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_O2_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff3fffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18781\,
dataf => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_O2_1_4\(4),
datae => \FPI.OP1\(55),
datad => \FPI.OP1\(56),
datac => \FPI.OP1\(61),
datab => \FPI.OP1\(62));
\GRFPC0_FP_PIPELINE_DBGDATA_4_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => CPO_DBG_DATAZ(19),
dataf => N_425,
datae => N_426,
datad => N_710,
datac => N_646);
\GRFPC0_FP_PIPELINE_WRDATA_3_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(52),
dataf => \GRFPC0.DIV.RESULT\(52),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(52),
datab => \GRFPU0.GRFPU_X0.N_20293_I_0\);
\GRFPC0_FP_PIPELINE_DBGDATA_4_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(4),
dataf => \GRFPC0.R.FSR.CEXC\(4),
datae => N_425,
datad => N_426,
datac => N_695,
datab => N_631);
\GRFPC0_WR_RREG_RES_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fffff0f0f0f0")
port map (
combout => N_47241,
dataf => N_99846,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_36_2964_I_A3_0_0_0\,
datad => N_99904_2,
datac => \GRFPC0.MEM.RREG.RES\(4),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(4));
\GRFPC0_R_FSR_AEXC_RNO_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffcf000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.FSR.AEXC_2_M\(3),
dataf => \GRFPC0.V.FSR.CEXC_5_SQMUXA\,
datae => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.R.FSR.AEXC\(3),
datab => \GRFPC0.WR2.RREG.EXCT\(3));
\GRFPC0_OP1_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(43),
dataf => \GRFPC0.N_20231\,
datae => N_99877_1,
datad => \GRFPC0.N_20165\,
datac => \GRFPC0.RFA2.RS1SEL_0\(7),
datab => \GRFPC0.N_20100\);
\GRFPC0_OP1_4_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20165\,
dataf => N_99879_0,
datae => N_638,
datad => N_702);
\GRFPC0_OP1_3_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20100\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(43),
datad => \GRFPC0.WR.RREG.RES\(43));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(39),
dataf => \GRFPU0.GRFPU_X0.N_21\,
datae => \GRFPU0.GRFPU_X0.N_18746\,
datad => \FPI.OP1\(42),
datac => \FPI.OP1\(39));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0330cffccffc0330")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(1),
dataf => \FPI.OP1\(52),
datae => \FPI.OP1\(53),
datad => \FPI.OP1\(55),
datac => \FPI.OP1\(56),
datab => \FPI.FLOP\(1));
\GRFPC0_FP_PIPELINE_WRDATA_3_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(33),
dataf => \GRFPC0.DIV.RESULT\(33),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(33),
datab => \FPO.RES\(33));
\GRFPC0_FP_PIPELINE_WRDATA_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(1),
dataf => \GRFPC0.DIV.RESULT\(1),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(1),
datab => \FPO.RES\(1));
\GRFPC0_WRDATA_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(1),
dataf => N_432,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(33),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(1));
\GRFPC0_FP_PIPELINE_DBGDATA_4_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(3),
dataf => \GRFPC0.R.FSR.CEXC\(3),
datae => N_425,
datad => N_426,
datac => N_694,
datab => N_630);
\GRFPC0_OP1_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(35),
dataf => \GRFPC0.N_20223\,
datae => N_99877_1,
datad => \GRFPC0.N_20157\,
datac => \GRFPC0.RFA2.RS1SEL_0\(7),
datab => \GRFPC0.N_20092\);
\GRFPC0_OP1_4_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20157\,
dataf => N_99879_0,
datae => N_630,
datad => N_694);
\GRFPC0_OP1_3_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20092\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(35),
datad => \GRFPC0.WR.RREG.RES\(35));
\GRFPC0_FP_PIPELINE_WRDATA_3_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(30),
dataf => \GRFPC0.DIV.RESULT\(30),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(30),
datab => \FPO.RES\(30));
\GRFPC0_WRDATA_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(30),
dataf => N_461,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(62),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(30));
\GRFPC0_FP_PIPELINE_WRDATA_3_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(35),
dataf => \GRFPC0.DIV.RESULT\(35),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(35),
datab => \GRFPU0.GRFPU_X0.N_20295_I_0\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_A2_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A2_0_0\(1),
dataf => \GRFPC0.DIV.RD\(4),
datae => \GRFPC0.DIV.RD\(2),
datad => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_0\(1),
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datad => \GRFPC0.N_24115\,
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3975_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A2_0_0\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_1\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_0\(1),
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13\(1),
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3917_REGDEPX2\,
datab => \GRFPC0.WR2.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff03000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_2\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_1\(1),
datae => \GRFPC0.N_24215_1\,
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3960_REGDEPX2_1\,
datac => \GRFPC0.DIV.INST\(17),
datab => \GRFPC0.DIV.INST\(16));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff000c0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_3\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_2\(1),
datae => \GRFPC0.N_25244_1\,
datad => \GRFPC0.N_25226\,
datac => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00300000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_4\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_3\(1),
datae => \GRFPC0.N_25592_1\,
datad => \GRFPC0.N_25227\,
datac => \GRFPC0.WR2.CTRL.INST\(29),
datab => \GRFPC0.WR2.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_15_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fb73d951ea62c840")
port map (
combout => \GRFPC0.N_17425\,
dataf => \GRFPC0.N_24729\,
datae => \GRFPC0.N_24730\,
datad => \GRFPC0.N_24732\,
datac => \GRFPC0.N_17419\,
datab => \GRFPC0.INST\(28),
dataa => \GRFPC0.INST\(27));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_465_0_A2_3_2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_465_0_A2_3_2_0\(0),
dataf => \GRFPC0.MEM.CTRL.RS1V\,
datae => \GRFPC0.MEM.CTRL.INST\(16),
datad => \GRFPC0.MEM.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O4_0_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0c000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O4_0\(31),
dataf => \GRFPC0.N_25510\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(1),
datac => \GRFPC0.N_24137\,
datab => \GRFPC0.FP_PIPELINE.15.REGDEPX2_465_0_A2_3_2_0\(0));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O4_3_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff000c00")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O4_3\(31),
dataf => \GRFPC0.N_25511\,
datae => \GRFPC0.FP_PIPELINE.15.REGDEPX2_475_0_A2_0_1\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datac => \GRFPC0.N_25783\,
datab => \GRFPC0.N_25871\);
\GRFPC0_FP_PIPELINE_15_REGDEPX2_460_I_O2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fffffffffffffff")
port map (
combout => \GRFPC0.N_24279\,
dataf => \GRFPC0.EX.CTRL.INST\(3),
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O4_7_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffec")
port map (
combout => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O4_7\(31),
dataf => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O4_5\(31),
datae => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O4_3\(31),
datad => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_O4_0\(31),
datac => \GRFPC0.N_25781\,
datab => \GRFPC0.N_25817\,
dataa => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_446_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff40000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_446\(1),
dataf => \GRFPC0.FP_PIPELINE.14.REGDEPX2_445\(1),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datad => \GRFPC0.DIV.RD\(3),
datac => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.DIV.RD\(2),
dataa => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_448_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_448\(1),
dataf => \GRFPC0.FP_PIPELINE.14.REGDEPX2_446\(1),
datae => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3960_REGDEPX2_1\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(1),
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_13_0\(1),
datab => \GRFPC0.DIV.RS1V\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_449_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_449\(1),
dataf => \GRFPC0.FP_PIPELINE.14.REGDEPX2_448\(1),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3975_REGDEPX2_1\,
datac => \GRFPC0.DIV.INST\(3),
datab => \GRFPC0.DIV.INST\(2));
GRFPC0_FP_PIPELINE_14_REGDEPX2_435TT_1_M3_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff3fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435TT_1_M3_0_A2_0\,
dataf => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_15\(1),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(1),
datad => \GRFPC0.N_24137\,
datac => \GRFPC0.N_24180\,
datab => \GRFPC0.MEM.CTRL.RS1V\);
GRFPC0_FP_PIPELINE_14_REGDEPX2_435_1_M9_I_A4_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_435_1_N_12\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.N_24189\,
datad => \GRFPC0.EX.CTRL.INST\(3),
datac => \GRFPC0.EX.CTRL.INST\(4),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_440_A1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => N_2_6,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.N_707\,
datad => \GRFPC0.N_25496\,
datac => \GRFPC0.WR.CTRL.INST\(26),
datab => \GRFPC0.WR.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_14_CHECK_DEP_DEP_23_IV_I_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_23939\,
dataf => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datab => \GRFPC0.N_24484\);
\GRFPC0_FP_PIPELINE_14_REGDEPX2_423_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_423\(1),
dataf => \GRFPC0.N_23939\,
datae => \GRFPC0.N_25221\,
datad => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6767_REGDEPX2_2\,
datac => \FPI.FLOP\(6),
datab => \GRFPC0.N_23941_1\);
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6414_REGDEPX2_0_A4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN6414_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(27),
datae => \GRFPC0.EX.CTRL.INST\(26),
datad => \GRFPC0.EX.CTRL.INST\(29),
datac => \GRFPC0.EX.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_14_REGDEPX2_445_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0f0f080")
port map (
combout => \GRFPC0.FP_PIPELINE.14.REGDEPX2_445\(1),
dataf => \GRFPC0.FP_PIPELINE.14.REGDEPX2_440\(1),
datae => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP\(1),
datad => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_11\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_8\(1),
dataa => \GRFPC0.WR2.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_13_I_M2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffc0f0cf3f00300")
port map (
combout => \GRFPC0.N_24732\,
dataf => \GRFPC0.FP_PIPELINE.14.REGDEPX2_449\(1),
datae => \GRFPC0.FP_PIPELINE.REGDEPX2_1\(1),
datad => \GRFPC0.FP_PIPELINE.14.REGDEPX2_445\(1),
datac => \GRFPC0.INST\(26),
datab => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\);
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_1\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(1),
datae => \GRFPC0.DIV.INST\(17),
datad => \GRFPC0.DIV.INST\(16),
datac => \GRFPC0.DIV.INST\(15),
datab => \GRFPC0.DIV.INST\(18));
\GRFPC0_FP_PIPELINE_13_CHECK_DEP_DEP_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(2),
datac => \GRFPC0.DIV.INST\(4),
datab => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_415_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0f0f080")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415\(1),
dataf => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410\(1),
datae => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_3\(1),
datad => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_15\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_18\(1),
dataa => \GRFPC0.WR2.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_420_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0f0f080")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420\(1),
dataf => \GRFPC0.FP_PIPELINE.13.REGDEPX2_415\(1),
datae => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_2\(1),
datad => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP\(1),
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datab => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_1\(1),
dataa => \GRFPC0.DIV.RS1V\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_385_0_A3_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_25503\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.N_703\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN351_REGDEPX2_1\,
datac => \GRFPC0.WR.CTRL.INST\(4),
datab => \GRFPC0.WR.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_375_0_A3_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.N_25405\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.N_25383\,
datad => \GRFPC0.MEM.CTRL.INST\(1),
datac => \GRFPC0.MEM.CTRL.INST\(2),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5681_REGDEPX2_2_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_25784\,
dataf => \GRFPC0.WR2.CTRL.INST\(17),
datae => \GRFPC0.WR2.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_385_0_A3_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_25501\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13\(1),
datad => \GRFPC0.N_25784\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN383_REGDEPX2_1\,
datab => \GRFPC0.WR2.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0c00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_4\(1),
dataf => \GRFPC0.N_25501\,
datae => \GRFPC0.N_25405\,
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX2_385_0_A3_3_0\(1),
datac => \GRFPC0.N_705\,
datab => \GRFPC0.WR.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_390_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff4fffff0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390\(1),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390_0_10\(1),
datad => \GRFPC0.FP_PIPELINE.12.REGDEPX2_363\(1),
datac => \GRFPC0.N_25403\,
datab => \GRFPC0.N_25370\,
dataa => \GRFPC0.V.STDATA_14_I_M_10\(0));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_12_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPC0.N_17419\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_420\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_390\(1),
datad => \GRFPC0.INST\(26));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_8_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7d5e6c4b391a280")
port map (
combout => \GRFPC0.N_17411\,
dataf => \GRFPC0.N_17405\,
datae => \GRFPC0.N_17399\,
datad => \GRFPC0.N_17401\,
datac => \GRFPC0.N_17407\,
datab => \GRFPC0.INST\(28),
dataa => \GRFPC0.INST\(27));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_0\(1),
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3505_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3534_REGDEPX2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_A0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000300000000000")
port map (
combout => N_1_1,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.N_24201\,
datad => \GRFPC0.N_25624_1\,
datac => \GRFPC0.DIV.INST\(17),
datab => \GRFPC0.DIV.INST\(18));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_A0_RNIBHLH1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_1\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240_0\(1),
datae => N_1_1,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datac => \GRFPC0.N_25859\,
datab => \GRFPC0.N_25871\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_A5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => N_6_0,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.N_703\,
datad => \GRFPC0.N_25854\,
datac => \GRFPC0.WR.CTRL.INST\(4),
datab => \GRFPC0.WR.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_A4_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPC0.N_25595\,
dataf => \GRFPC0.N_25632\,
datae => \GRFPC0.WR2.CTRL.INST\(2),
datad => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_A4_0_RNISAB72_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_4\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_1\(1),
datae => \GRFPC0.N_25595\,
datad => N_6_0,
datac => \GRFPC0.N_25635\,
datab => \GRFPC0.N_25633\);
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_8_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_8\(1),
dataf => \GRFPC0.MEM.CTRL.INST\(1),
datae => \GRFPC0.MEM.CTRL.INST\(4),
datad => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST\(3),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1));
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_1\(1),
dataf => \GRFPC0.EX.CTRL.INST\(16),
datae => \GRFPC0.EX.CTRL.INST\(15),
datad => \GRFPC0.EX.CTRL.INST\(18),
datac => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_215_I_A2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f00ff00030033")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_215_I_A2_1\(1),
dataf => \GRFPC0.N_24568\,
datae => \GRFPC0.N_24622\,
datad => \FPI.FLOP\(1),
datac => \GRFPC0.N_223\,
datab => \GRFPC0.V.STDATA_14\(25));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_220_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f800ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220\(1),
dataf => \GRFPC0.N_24555\,
datae => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_2\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP\(1),
datab => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_1\(1),
dataa => \GRFPC0.EX.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_225_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0f0e0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_225\(1),
dataf => \GRFPC0.FP_PIPELINE.7.REGDEPX2_220\(1),
datae => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_20\(1),
datad => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_9\(1),
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datab => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_8\(1),
dataa => \GRFPC0.MEM.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_7_REGDEPX2_226_RNI1GT74_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffff0800")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_240\(1),
dataf => \GRFPC0.FP_PIPELINE.7.REGDEPX2_226\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datac => \GRFPC0.N_705\,
datab => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_18_0\(1),
dataa => \GRFPC0.WR.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_O2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.N_25543\,
dataf => \FPI.FLOP\(1),
datae => \GRFPC0.N_225\,
datad => \GRFPC0.N_226\,
datac => \GRFPC0.N_223\,
datab => \GRFPC0.N_24627_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_13_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0fc0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_13\(1),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.6.REGDEPX2_185_I_I2_0_O2_0\(0),
datad => \GRFPC0.N_24623\,
datac => \GRFPC0.N_25543\,
datab => \GRFPC0.N_235\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_4\(1),
dataf => \GRFPC0.N_25610\,
datae => \GRFPC0.N_25715_1\,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2004_REGDEPX2_1\,
datac => \GRFPC0.EX.CTRL.INST\(27),
datab => \GRFPC0.EX.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0ccfc00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_3\(1),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.N_707\,
datad => \GRFPC0.N_703\,
datac => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A4_1_0\(1),
datab => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2976_REGDEPX2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_A3_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_13_0\(1),
dataf => \GRFPC0.DIV.INST\(17),
datae => \GRFPC0.DIV.INST\(16));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_A3_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_25433\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.N_25624_1\,
datad => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.DEP_13_0\(1),
datac => \GRFPC0.DIV.INST\(15),
datab => \GRFPC0.DIV.INST\(18));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f330f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_1\(1),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_1_1\(1),
datad => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_0_A2_0_1\(1),
datac => \GRFPC0.MEM.CTRL.INST\(1),
datab => \GRFPC0.MEM.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_11_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffff8")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_11\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_7\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_9\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_4\(1),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_210_0_3\(1),
datab => \GRFPC0.N_280\,
dataa => \GRFPC0.FP_PIPELINE.6.REGDEPX2_195_0_0_A2_0\(1));
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_21_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_21\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(1),
datae => \GRFPC0.DIV.INST\(17),
datad => \GRFPC0.DIV.INST\(16),
datac => \GRFPC0.DIV.INST\(15),
datab => \GRFPC0.DIV.INST\(18));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_176_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_24071\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datae => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.DIV.RD\(4),
datac => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_1\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(2),
datac => \GRFPC0.DIV.INST\(4),
datab => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_175_0_A4_2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_I_A2_0_0\(0),
dataf => \GRFPC0.WR2.CTRL.INST\(2),
datae => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_6_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_6_0\(0),
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(3),
datad => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_175_0_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0ccfc00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_0_2\(1),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.N_707\,
datad => \GRFPC0.N_703\,
datac => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_6_0\(0),
datab => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2535_REGDEPX2\);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_175_0_A4_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_175_0_A4_0_0\(1),
dataf => \GRFPC0.WR.CTRL.RS1V\,
datae => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.INST\(18),
datab => \GRFPC0.WR.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00fffff000f0")
port map (
combout => \GRFPC0.N_17405\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_4\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_180\(1),
datad => \GRFPC0.INST\(26),
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_3\(1));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_116_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff03000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_116\(1),
dataf => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115\(1),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datad => \GRFPC0.N_24703_I\,
datac => \GRFPC0.DIV.RD\(3),
datab => \GRFPC0.DIV.RD\(4));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1770_REGDEPX2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1770_REGDEPX2\,
dataf => \GRFPC0.DIV.INST\(2),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(1),
datac => \GRFPC0.DIV.INST\(4));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_119_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_119\(1),
dataf => \GRFPC0.FP_PIPELINE.3.REGDEPX2_116\(1),
datae => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_11\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datac => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1770_REGDEPX2\,
datab => \GRFPC0.DIV.RS1V\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_113_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_113\(1),
dataf => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110\(1),
datae => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_9\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13\(1),
datac => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_8_0\(1),
datab => \GRFPC0.WR2.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_3_CHECK_DEP_DEP_13_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_13_0\(1),
dataf => \GRFPC0.WR2.CTRL.INST\(1),
datae => \GRFPC0.WR2.CTRL.INST\(2),
datad => \GRFPC0.WR2.CTRL.INST\(4),
datac => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_105_0_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000ffc0c0c0")
port map (
combout => \GRFPC0.N_25652\,
dataf => \GRFPC0.N_25122\,
datae => \GRFPC0.N_25197\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1),
datab => \GRFPC0.N_24322\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc00000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_1\(1),
dataf => \GRFPC0.N_25823\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datad => \GRFPC0.N_25717\,
datac => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1637_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffc")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110\(1),
dataf => \GRFPC0.N_25156\,
datae => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_2\(1),
datad => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110_0_1\(1),
datac => \GRFPC0.N_25693\,
datab => \GRFPC0.N_25692\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_115_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00c0ffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_115\(1),
dataf => \GRFPC0.FP_PIPELINE.3.REGDEPX2_113\(1),
datae => \GRFPC0.FP_PIPELINE.3.REGDEPX2_110\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(1),
datab => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_13_0\(1));
GRFPC0_FP_PIPELINE_14_STDEP_572_SEL0_0_1_0_O3_I_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_858\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(2),
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_14_STDEP_568_3_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"030f030ff3ff030f")
port map (
combout => \GRFPC0.FP_PIPELINE.14.STDEP_568_3_0_0\(0),
dataf => \GRFPC0.N_362\,
datae => \GRFPC0.N_23842\,
datad => \GRFPC0.N_114\,
datac => \GRFPC0.N_23807\,
datab => \GRFPC0.N_19008\);
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN4612_DEP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4612_DEP\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2));
\GRFPC0_FP_PIPELINE_14_STDEP_568_3_0_A2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_23829\,
dataf => \GRFPC0.N_16_I\,
datae => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4612_DEP\,
datad => \GRFPC0.N_481\,
datac => \GRFPC0.N_458\,
datab => \GRFPC0.N_23807\);
\GRFPC0_FP_PIPELINE_14_STDEP_580_0_IV_I_M3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fff3fff3fff00c0")
port map (
combout => \GRFPC0.N_23173\,
dataf => \GRFPC0.N_23829\,
datae => \GRFPC0.FP_PIPELINE.14.STDEP_568_3_0_0\(0),
datad => \GRFPC0.N_21951_1\,
datac => \GRFPC0.N_858\,
datab => \GRFPC0.N_470\);
GRFPC0_FP_PIPELINE_14_1_CHECK_DEP_UN4552_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4552_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(28),
datae => \GRFPC0.FIFO.INST_1\(29),
datad => \GRFPC0.FIFO.INST_1\(26),
datac => \GRFPC0.FIFO.INST_1\(27));
GRFPC0_FP_PIPELINE_0_STDDEP_334_IV_0_O2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000fffff000f000")
port map (
combout => \GRFPC0.N_21539\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.FP_PIPELINE.14.STDEP_576_SEL0\,
datad => \GRFPC0.EX.CTRL.LD\,
datac => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4855_DEP\);
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_I_O2_6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffff00ff")
port map (
combout => \GRFPC0.N_21462\,
dataf => \GRFPC0.N_114\,
datae => \GRFPC0.WR.CTRL.RDD\,
datad => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_3_1_REGDEPX_63_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00000300")
port map (
combout => \GRFPC0.FP_PIPELINE.3.1.REGDEPX_63\(1),
dataf => \GRFPC0.FP_PIPELINE.3.1.REGDEPX_62\(1),
datae => \GRFPC0.N_24910\,
datad => \GRFPC0.N_22243\,
datac => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_1\(18));
\GRFPC0_FP_PIPELINE_12_STDEP_496_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0cfff30c000c")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_496\(1),
dataf => \GRFPC0.FP_PIPELINE.12.STDEP_492\(1),
datae => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datad => \GRFPC0.N_18319\,
datac => \GRFPC0.FP_PIPELINE.12.STDEP_496_SEL0_1\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_12_RNIQH1B1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_13_4\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_12_I_1\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datad => \GRFPC0.N_9465\);
GRFPC0_FP_PIPELINE_12_0_CHECK_DEP_UN3823_REGDEPX_I_0_O3_I_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.N_24875\,
dataf => \GRFPC0.FIFO.INST_0\(29),
datae => \GRFPC0.FIFO.INST_0\(26),
datad => \GRFPC0.FIFO.INST_0\(27),
datac => \GRFPC0.FIFO.INST_0\(28));
GRFPC0_EX_CTRL_LD_RNIA6811_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffffffffff")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_12_I_1\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_245,
datad => N_244,
datac => N_243,
datab => N_242);
GRFPC0_FP_PIPELINE_9_CHECK_DEP_UN3127_REGDEPX_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3127_REGDEPX\,
dataf => N_80,
datae => N_79,
datad => N_81,
datac => N_82);
\GRFPC0_FP_PIPELINE_9_REGDEPX_174_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0ff00c0c00000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_0\(0),
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.9.0.REGDEPX_168_0_A4_0_1\(0),
datac => \GRFPC0.N_22252\,
datab => \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.DEP_1_2\(1));
\GRFPC0_FP_PIPELINE_9_REGDEPX_174_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX_174\(0),
dataf => \GRFPC0.N_24959\,
datae => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_0\(0),
datad => \GRFPC0.N_24957\,
datac => \GRFPC0.N_25004\,
datab => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_A4_2_1\(0));
GRFPC0_FP_PIPELINE_9_CHECK_DEP_UN3112_REGDEPX_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3112_REGDEPX_0\,
dataf => N_93,
datae => N_95,
datad => N_94);
\GRFPC0_FP_PIPELINE_9_1_CHECK_DEP_DEP_1_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.DEP_1_2\(1),
dataf => \GRFPC0.FIFO.INST_1\(3),
datae => \GRFPC0.FIFO.INST_1\(2),
datad => \GRFPC0.FIFO.INST_1\(4),
datac => \GRFPC0.FIFO.INST_1\(1));
\GRFPC0_FP_PIPELINE_9_REGDEPX_174_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00c0ffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX_174\(1),
dataf => \GRFPC0.FP_PIPELINE.9.1.REGDEPX_172\(1),
datae => \GRFPC0.FP_PIPELINE.9.0.REGDEPX_168\(1),
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_22253\,
datab => \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.DEP_1_2\(1));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_160_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00c0ffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_160\(1),
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_158\(1),
datae => \GRFPC0.FP_PIPELINE.5.REGDEPX2_155\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2474_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_110_0_A2_0_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_25823_2\,
dataf => \GRFPC0.WR.CTRL.RS1V\,
datae => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(18),
datac => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_100_0_A2_6_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c000")
port map (
combout => \GRFPC0.N_25179\,
dataf => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datab => \GRFPC0.N_24484\);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_158_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_158\(1),
dataf => \GRFPC0.FP_PIPELINE.5.REGDEPX2_155\(1),
datae => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2459_REGDEPX2\,
datad => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_11\(1),
datac => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1));
\GRFPC0_FP_PIPELINE_RS2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => RFI2_RD2ADDRZ(0),
dataf => \GRFPC0.INST\(1),
datae => \GRFPC0.RFA.RS2\(1),
datad => N_37);
\GRFPC0_OP1_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(36),
dataf => \GRFPC0.N_20290\,
datae => N_99877_1,
datad => \GRFPC0.N_19961\,
datac => N_99878_1,
datab => \GRFPC0.N_20027\);
\GRFPC0_OP1_2_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20027\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(36),
datad => \GRFPC0.MEM.RREG.RES\(36));
\GRFPC0_OP1_1_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19961\,
dataf => \FPO.RES\(36),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(36));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(36),
dataf => \GRFPU0.GRFPU_X0.N_21\,
datae => \GRFPU0.GRFPU_X0.N_18746\,
datad => \FPI.OP1\(36),
datac => \FPI.OP1\(39));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(29),
dataf => \GRFPU0.GRFPU_X0.N_21_0\,
datae => \GRFPU0.GRFPU_X0.N_18746_0\,
datad => \FPI.OP1\(32),
datac => \FPI.OP1\(29));
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_8_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_8\(0),
dataf => \GRFPC0.MEM.CTRL.INST\(1),
datae => \GRFPC0.MEM.CTRL.INST\(4),
datad => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST\(3),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_I_TZ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff3fff00ff")
port map (
combout => \GRFPC0.N_14_TZ\,
dataf => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_11\(0),
datae => \GRFPC0.N_24575\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN681_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(0));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_40_I_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000003f00ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_40_I_1\(0),
dataf => \GRFPC0.N_24608\,
datae => \GRFPC0.N_25169_2\,
datad => \GRFPC0.N_14_TZ\,
datac => \GRFPC0.N_23994_2\,
datab => \GRFPC0.N_260_2\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_0_A4_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_25564\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(0),
datad => \GRFPC0.N_25226\,
datac => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(4));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_0_A4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_25563\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(0),
datad => \GRFPC0.N_25227\,
datac => \GRFPC0.WR2.CTRL.INST\(29),
datab => \GRFPC0.WR2.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_3\(0),
dataf => \GRFPC0.N_25564\,
datae => \GRFPC0.N_25563\,
datad => \GRFPC0.N_25634\,
datac => \GRFPC0.N_25568_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000003000000000")
port map (
combout => \GRFPC0.N_24221\,
dataf => \GRFPC0.N_24796\,
datae => \GRFPC0.DIV.INST\(2),
datad => \GRFPC0.DIV.INST\(3),
datac => \GRFPC0.DIV.INST\(1),
datab => \GRFPC0.DIV.INST\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_60_0_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffff000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60_0_2\(0),
dataf => \GRFPC0.N_24221\,
datae => \GRFPC0.N_24219\,
datad => \GRFPC0.N_24222_1\,
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN873_REGDEPX2\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_16_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_16\(0),
dataf => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN873_REGDEPX2_2\,
datae => \GRFPC0.DIV.RDD\,
datad => \GRFPC0.DIV.INST\(16),
datac => \GRFPC0.DIV.INST\(15),
datab => \GRFPC0.DIV.INST\(14));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_26_0_A2_1_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000000f")
port map (
combout => \GRFPC0.N_24242\,
dataf => \GRFPC0.DIV.RDD\,
datae => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.DIV.RD\(4),
datac => \GRFPC0.DIV.RD\(0));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_9_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_9\(0),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN383_REGDEPX2_1\,
datae => \GRFPC0.WR2.CTRL.RDD\,
datad => \GRFPC0.WR2.CTRL.INST\(18),
datac => \GRFPC0.WR2.CTRL.INST\(17),
datab => \GRFPC0.WR2.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_8_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_8\(0),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(0),
datae => \GRFPC0.WR2.CTRL.INST\(1),
datad => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_25_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00f800")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_25\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20\(0),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_8\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_1\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_9\(0),
dataa => \GRFPC0.WR2.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_15_REGDEPX2_454_0_A2_1_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.REGDEPX2_465_0_A2_4_0\(0),
dataf => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\);
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN6869_REGDEPX2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6869_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(16),
datae => \GRFPC0.EX.CTRL.INST\(15),
datad => \GRFPC0.EX.CTRL.INST\(18),
datac => \GRFPC0.EX.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_15_REGDEPX2_465_0_O2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffc000")
port map (
combout => \GRFPC0.N_25124\,
dataf => \GRFPC0.N_25382\,
datae => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_1\(0),
datad => \GRFPC0.MEM.CTRL.INST\(27),
datac => \GRFPC0.MEM.CTRL.INST\(26),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(0));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2459_REGDEPX2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2459_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(15),
datae => \GRFPC0.EX.CTRL.INST\(16),
datad => \GRFPC0.EX.CTRL.INST\(17),
datac => \GRFPC0.EX.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_22_IV_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff3ffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_22_IV\(0),
dataf => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datab => \GRFPC0.N_25649\);
\GRFPC0_FP_PIPELINE_5_REGDEPX2_153_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30000000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_153\(0),
dataf => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_22_IV\(0),
datae => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2357_REGDEPX2_1\,
datad => \FPI.FLOP\(6),
datac => \GRFPC0.N_23975\,
datab => \GRFPC0.V.STDATA_14\(18));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ff00c000")
port map (
combout => \GRFPC0.N_25630\,
dataf => \GRFPC0.N_24067\,
datae => \GRFPC0.N_25624\,
datad => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN7062_REGDEPX2\);
\GRFPC0_FP_PIPELINE_11_REGDEPX_210_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_23479\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22902_1\,
datad => \GRFPC0.N_24910\,
datac => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_1\(18));
\GRFPC0_FP_PIPELINE_11_REGDEPX_210_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffc00000")
port map (
combout => \GRFPC0.N_23480\,
dataf => \GRFPC0.N_23985\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.11.0.CHECK_DEP.DEP\(0),
datac => \GRFPC0.N_23986_1\,
datab => \GRFPC0.FP_PIPELINE.11.0.REGDEPX_203_0_A4_0\(1));
\GRFPC0_FP_PIPELINE_11_0_REGDEPX_200_IV_0_O2_I_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030000000")
port map (
combout => \GRFPC0.N_23895\,
dataf => \GRFPC0.FIFO.INST_0\(19),
datae => \GRFPC0.FIFO.INST_0\(29),
datad => \GRFPC0.FIFO.INST_0\(26),
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28));
\GRFPC0_FP_PIPELINE_WRADDR_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRADDRZ(3),
dataf => N_430,
datae => \GRFPC0.WREN_0_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datac => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.WR2.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_WRADDR_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRADDRZ(2),
dataf => N_429,
datae => \GRFPC0.WREN_0_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datac => \GRFPC0.DIV.RD\(3),
datab => \GRFPC0.WR2.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_WRADDR_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRADDRZ(1),
dataf => N_428,
datae => \GRFPC0.WREN_0_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datac => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.WR2.CTRL.RD\(2));
\GRFPC0_FP_PIPELINE_WRADDR_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRADDRZ(0),
dataf => N_427,
datae => \GRFPC0.WREN_0_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datac => \GRFPC0.DIV.RD\(1),
datab => \GRFPC0.WR2.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_UN1_VRFA_ST_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_VRFA.ST\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.ST_1\,
datae => N_37,
datad => \GRFPC0.RFA.ST\);
GRFPC0_FP_PIPELINE_UN45_WREN: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN45_WREN\,
dataf => \GRFPC0.FP_PIPELINE.WREN_17_I\(0),
datae => \GRFPC0.FP_PIPELINE.WREN_17_IV\(1));
GRFPC0_FP_PIPELINE_0_REGDEP30_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fc0330cf")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP30_1\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_2\,
datae => \GRFPC0.N_24063\,
datad => \GRFPC0.WR2.CTRL.RD\(4),
datac => \GRFPC0.RFA.RS1\(4),
datab => N_37);
GRFPC0_FP_PIPELINE_RSDEC_RS2D_IV_I_X3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPC0.N_72_I\,
dataf => \GRFPC0.INST\(10),
datae => \GRFPC0.INST\(11));
GRFPC0_FP_PIPELINE_RSDEC_RS1V5_I_0_O2_0_I_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPC0.N_23781\,
dataf => \GRFPC0.RFA.WRITE_RD_0_0_I1_I_1\,
datae => \GRFPC0.INST\(5),
datad => \GRFPC0.N_23618\);
GRFPC0_FP_PIPELINE_RSDEC_RS1V17_I_0_O2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000330f000f33")
port map (
combout => \GRFPC0.FP_PIPELINE.RSDEC.RS1V17_I_0_O2_0\,
dataf => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datae => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_1\(23),
datab => \GRFPC0.FIFO.INST_0\(23));
GRFPC0_FP_PIPELINE_RSDEC_RS1V17_I_0_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30ffffff")
port map (
combout => \GRFPC0.N_23625\,
dataf => \GRFPC0.FP_PIPELINE.RSDEC.RS1V17_I_0_O2_0\,
datae => \GRFPC0.INST\(21),
datad => \GRFPC0.INST\(24),
datac => \GRFPC0.N_24061\,
datab => N_101);
GRFPC0_UN1_WR2_CTRL_RDD: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP26\,
dataf => \GRFPC0.N_23599_I_0\,
datae => \GRFPC0.WR2.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_WRDATA_3_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(56),
dataf => \GRFPC0.DIV.RESULT\(56),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(56),
datab => N_46771_3);
\GRFPC0_FP_PIPELINE_WRDATA_3_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(24),
dataf => \GRFPC0.DIV.RESULT\(24),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(24),
datab => \FPO.RES\(24));
\GRFPC0_WRDATA_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(24),
dataf => N_455,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(56),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(24));
\GRFPC0_EX_CTRL_ID_RNIAORI2_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => N_99847,
dataf => \GRFPC0.N_82\,
datae => N_37);
\GRFPC0_OP1_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(53),
dataf => \GRFPC0.N_20241\,
datae => N_99877,
datad => \GRFPC0.N_20175\,
datac => \GRFPC0.RFA2.RS1SEL_0\(7),
datab => \GRFPC0.N_20110\);
\GRFPC0_OP1_4_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20175\,
dataf => N_99879,
datae => N_648,
datad => N_712);
\GRFPC0_OP1_3_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20110\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(53),
datad => \GRFPC0.WR.RREG.RES\(53));
\GRFPC0_WRDATA_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(21),
dataf => N_452,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(53),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(21));
\GRFPC0_V_STDATA_14_I_M2_RNINH5H1_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0303030f030f33ff")
port map (
combout => N_44738_1,
dataf => \FPI.FLOP\(1),
datae => \FPI.FLOP\(6),
datad => \FPI.FLOP\(7),
datac => \FPI.FLOP\(5),
datab => \FPI.FLOP\(3));
GRFPC0_FP_PIPELINE_1_IS_RDD_UN1_V_STDATA_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f30000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.1.IS_RDD.UN1_V.STDATA_15\,
dataf => N_44738_1,
datae => \FPI.FLOP\(1),
datad => \FPI.FLOP\(7),
datac => \FPI.FLOP\(2),
datab => \FPI.FLOP\(3));
GRFPC0_RFA_RDD_RNIQMTTH: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30f03030")
port map (
combout => \GRFPC0.EX.CTRL.RDD_0_0_G1\,
dataf => \GRFPC0.TMP_0_SQMUXA_2\,
datae => N_47178_2,
datad => \FPI.START\,
datac => \GRFPC0.RFA.RDD\,
datab => N_37);
\GRFPC0_FP_PIPELINE_RS2_1_RNIA3N61_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f00000f00f00000f")
port map (
combout => \GRFPC0.FPUSEL_1_2\(1),
dataf => RFI2_RD2ADDRZ(1),
datae => RFI2_RD2ADDRZ(2),
datad => \GRFPC0.EX.CTRL.RD\(3),
datac => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_1_REGDEP160: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEP160\,
dataf => \GRFPC0.FPUSEL_1_2\(1),
datae => RFI2_RD2ADDRZ(0),
datad => \GRFPC0.FPUSEL_1_0_1__G0_3_0\,
datac => \GRFPC0.EX.CTRL.RD\(1));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_80_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcccccc80")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80\(0),
dataf => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75\(0),
datae => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_5\(0),
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_21\(0),
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_20\(0),
datab => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
dataa => \GRFPC0.WR.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_5\(0),
dataf => \GRFPC0.N_702\,
datae => \GRFPC0.WR.CTRL.INST\(4),
datad => \GRFPC0.WR.CTRL.INST\(3),
datac => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_20_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000030")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_20\(0),
dataf => \GRFPC0.N_704\,
datae => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(18),
datac => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_21_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_21\(0),
dataf => \GRFPC0.N_706\,
datae => \GRFPC0.WR.CTRL.INST\(26),
datad => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.WR.CTRL.INST\(28),
datab => \GRFPC0.WR.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_A2_7_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_I_A2_0_0\(0),
dataf => \GRFPC0.WR2.CTRL.INST\(1),
datae => \GRFPC0.WR2.CTRL.INST\(2),
datad => \GRFPC0.WR2.CTRL.INST\(4),
datac => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_205_0_O2_1_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3f03300f0f00000")
port map (
combout => \GRFPC0.N_25637_1\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13\(1),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(1),
datad => \GRFPC0.N_25633\,
datac => \GRFPC0.FP_PIPELINE.6.REGDEPX2_205_I_A2_0_0\(0),
datab => \GRFPC0.WR2.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_A2_0_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.N_24777_1_0\,
dataf => \GRFPC0.DIV.INST\(3),
datae => \GRFPC0.DIV.INST\(2),
datad => \GRFPC0.DIV.INST\(4),
datac => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_A2_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_1_0\(1),
dataf => \GRFPC0.DIV.RD\(3),
datae => \GRFPC0.DIV.RD\(4),
datad => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_210_0_A3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0cc0000000000")
port map (
combout => \GRFPC0.N_25432\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datac => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.DEP_1_0\(1),
datab => \GRFPC0.N_24777_1_0\);
GRFPC0_STDEP_0_SQMUXA_98_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0333000000000000")
port map (
combout => \GRFPC0.STDEP_0_SQMUXA_98_0\,
dataf => \GRFPC0.FP_PIPELINE.3.1.CHECK_DEP.UN1120_REGDEPX\,
datae => \GRFPC0.N_22237\,
datad => \GRFPC0.FIFO.INST_1\(12),
datac => \GRFPC0.FIFO.INST_1\(8),
datab => \GRFPC0.FIFO.INST_1\(25));
\GRFPC0_FP_PIPELINE_3_0_STDEP_145_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffcfffffffcff")
port map (
combout => \GRFPC0.N_18198\,
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1015_REGDEPX_I_1\,
datab => \GRFPC0.FIFO.INST_0\(19));
GRFPC0_EX_CTRL_LD_RNIGOI52: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000ff00ff00")
port map (
combout => N_47188_2,
dataf => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => N_35);
GRFPC0_VMEM_RREG_RESV_0_SQMUXA_1_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
dataf => \GRFPC0.N_24428\,
datae => N_37);
GRFPC0_V_FSR_CEXC_3_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.V.FSR.CEXC_3_SQMUXA\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.V.FSR.CEXC_3_SQMUXA_3\,
datad => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datac => \GRFPC0.WR2.CTRL.SEQERR\,
datab => \GRFPC0.V.FSR.AEXC_1_SQMUXA\);
GRFPC0_V_FSR_CEXC_2_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.V.FSR.CEXC_2_SQMUXA\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.V.FSR.CEXC_3_SQMUXA_3\,
datad => \GRFPC0.FP_PIPELINE.FPRDY_1_1\,
datac => \GRFPC0.WR2.CTRL.SEQERR\,
datab => \GRFPC0.V.FSR.AEXC_1_SQMUXA\);
GRFPC0_UN1_V_FSR_CEXC_3_SQMUXA_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcf0fcf0fcf0")
port map (
combout => \GRFPC0.UN1_V.FSR.CEXC_3_SQMUXA_0\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.V.FSR.CEXC_0_SQMUXA_0\,
datad => N_44718_1,
datac => \GRFPC0.WR2.CTRL.SEQERR\,
datab => \GRFPC0.DIV.EXCT\(5));
GRFPC0_V_FSR_CEXC_0_SQMUXA_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccccccc00000c00")
port map (
combout => \GRFPC0.V.FSR.CEXC_0_SQMUXA_2\,
dataf => \GRFPC0.UN1_V.FSR.CEXC_3_SQMUXA_0\,
datae => N_46992,
datad => \GRFPC0.V.FSR.FTT_1_SQMUXA_2_1_0\,
datac => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
datab => \GRFPC0.V.FSR.AEXC_1_SQMUXA\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_I_O2_4_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00fc00")
port map (
combout => \GRFPC0.N_22959\,
dataf => \GRFPC0.N_694\,
datae => \GRFPC0.N_23010\,
datad => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_23012\,
datab => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.DEP_1\(1));
\GRFPC0_FP_PIPELINE_0_STDEP_16_3_I_O2_I_A2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f00ff00000000")
port map (
combout => \GRFPC0.N_861\,
dataf => \GRFPC0.N_22173_I\,
datae => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
datad => \GRFPC0.DIV.RD\(0),
datac => \GRFPC0.WR2.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_0_STDEP_16_3_I_O2_I_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfc0000fc000000")
port map (
combout => \GRFPC0.N_738\,
dataf => \GRFPC0.N_861\,
datae => \GRFPC0.N_21419\,
datad => \GRFPC0.N_74_I_I\,
datac => \GRFPC0.N_21353\,
datab => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_0_STDEP_16_3_I_O2_I_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03030000ff03ff00")
port map (
combout => \GRFPC0.N_367\,
dataf => \GRFPC0.N_738\,
datae => \GRFPC0.N_104\,
datad => \GRFPC0.FP_PIPELINE.0.STDEP_16_3_I_O2_I_A3_1\(0),
datac => \GRFPC0.N_477\,
datab => \GRFPC0.N_482\);
GRFPC0_FP_PIPELINE_15_STDEP_616_SEL1_I_0_A2_1_0_A3_RNIQO5U8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00c0ffff0000")
port map (
combout => \GRFPC0.N_23059\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.N_23108\,
datad => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.DEP_20\(0),
datac => \GRFPC0.N_18394_1\,
datab => \GRFPC0.EX.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_15_STDEP_612_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fffffff0080f080")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_612\(0),
dataf => \GRFPC0.FP_PIPELINE.15.STDEP_608\(0),
datae => \GRFPC0.N_104\,
datad => \GRFPC0.N_18829\,
datac => \GRFPC0.N_470\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4976_DEP\,
dataa => \GRFPC0.MEM.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_15_STDEP_612_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffffff00800f80")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_612\(1),
dataf => \GRFPC0.FP_PIPELINE.15.STDEP_608\(1),
datae => \GRFPC0.N_104\,
datad => \GRFPC0.N_18829\,
datac => \GRFPC0.N_470\,
datab => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4976_DEP\,
dataa => \GRFPC0.MEM.CTRL.RDWR\);
GRFPC0_FP_PIPELINE_12_1_CHECK_DEP_UN3959_REGDEPX_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.1.CHECK_DEP.UN4895_REGDEPX_2\,
dataf => \GRFPC0.FIFO.INST_1\(3),
datae => \GRFPC0.FIFO.INST_1\(4));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3751_REGDEPX_1_0_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_25037\,
dataf => N_79,
datae => N_80);
GRFPC0_UN1_FIFO_INST_0_1_I_A2_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPC0.N_24900\,
dataf => \GRFPC0.FIFO.INST_0\(26),
datae => \GRFPC0.FIFO.INST_0\(27),
datad => \GRFPC0.FIFO.INST_0\(28));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_3_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000000ff0c0c0c")
port map (
combout => \GRFPC0.N_24813\,
dataf => \GRFPC0.N_25021\,
datae => \GRFPC0.N_24902\,
datad => \GRFPC0.N_23854_I_0\,
datac => \GRFPC0.N_23923\,
datab => \GRFPC0.FIFO.INST_0\(16));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN4855_DEP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.CHECK_DEP.UN4855_DEP\,
dataf => N_242,
datae => N_245,
datad => N_244,
datac => N_243);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_15_I_O2_0_0_I_O2_RNIG4Q01_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_23371\,
dataf => \GRFPC0.N_21454\,
datae => N_245,
datad => N_244,
datac => N_243,
datab => N_242);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_15: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.N_9468\,
dataf => N_105,
datae => N_104,
datad => N_107,
datac => N_106);
GRFPC0_STDDEP_0_SQMUXA_I_I_A2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_I_I_A2_1\,
dataf => N_244,
datae => N_245,
datad => N_243,
datac => N_242);
GRFPC0_UN1_STDEP514: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300030003")
port map (
combout => \GRFPC0.UN1_STDEP514\,
dataf => \GRFPC0.N_481\,
datae => \GRFPC0.N_458\,
datad => \GRFPC0.N_525\,
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4));
\GRFPC0_FP_PIPELINE_10_STDEP_412_3_0_I_O2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffffffffff")
port map (
combout => \GRFPC0.N_501\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(2),
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_10_STDEP_412_3_0_I_A3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f030ff33")
port map (
combout => \GRFPC0.N_708\,
dataf => \GRFPC0.N_742\,
datae => \GRFPC0.N_484\,
datad => \GRFPC0.N_501\,
datac => \GRFPC0.N_491\,
datab => \GRFPC0.N_482\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_185_I_O3_1_I_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPC0.N_25204\,
dataf => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\);
GRFPC0_FP_PIPELINE_UN1_DIV_EXEC: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
dataf => \GRFPC0.DIV.EXEC\,
datae => \GRFPC0.DIV.VALID\);
GRFPC0_FP_PIPELINE_0_UN1_WR2_CTRL_DIV: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
dataf => \GRFPC0.WR2.RREG.RESV\,
datae => \GRFPC0.WR2.CTRL.DIV\);
GRFPC0_FP_PIPELINE_1_REGDEP118_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.1.WR2EN10_0_0\,
dataf => RFI2_RD2ADDRZ(0),
datae => RFI2_RD2ADDRZ(2),
datad => \GRFPC0.WR2.CTRL.RD\(1),
datac => \GRFPC0.WR2.CTRL.RD\(3));
\GRFPC0_R_STATE_0_0_0__G0_0\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.R.STATE_0_0_1__G0\,
dataf => N_37,
datae => N_35);
\GRFPC0_FP_PIPELINE_WRDATA_3_53_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(53),
dataf => \GRFPC0.DIV.RESULT\(53),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(53),
datab => \FPO.RES\(53));
\GRFPC0_FP_PIPELINE_WRDATA_3_62_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(62),
dataf => \GRFPC0.DIV.RESULT\(62),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(62),
datab => \FPO.RES\(62));
GRFPU0_GRFPU_X0_UN1_RNDOP_2_I_A2_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.VALLOW_0_SQMUXA_2\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(9));
GRFPU0_GRFPU_X0_IEXC_0_SQMUXA_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_5633\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(8));
\GRFPU0_GRFPU_X0_ITER_RNDMODE_RNI6O9C1_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"03fcffff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_7\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
datad => \GRFPU0.MULO.MRES\(67),
datac => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1));
\GRFPU0_GRFPU_X0_ITER_STATE_RNIEJ125_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19703\,
dataf => \GRFPU0.GRFPU_X0.N_134\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datad => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_VITER_ALLOW_CNST_I_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0030ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_13485\,
dataf => \GRFPU0.GRFPU_X0.N_19703\,
datae => \GRFPU0.GRFPU_X0.N_140\,
datad => \GRFPU0.GRFPU_X0.N_5987\,
datac => \GRFPU0.GRFPU_X0.N_7\,
datab => \GRFPU0.GRFPU_X0.UN1_ITER.STATE_76_2\);
GRFPU0_GRFPU_X0_VITER_V_1_SQMUXA_I_O2_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19707\,
dataf => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datae => \GRFPU0.GRFPU_X0.ITER.STATE\(8));
\GRFPU0_GRFPU_X0_ITER_ALLOW_RNIDS0C2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000003000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4415_M_0_A3_3\,
dataf => \FPI.FLOP\(1),
datae => \GRFPU0.GRFPU_X0.N_4415_M_0_A3_1\,
datad => \FPI.FLOP\(0),
datac => \FPI.FLOP\(4),
datab => \FPI.FLOP\(8));
\GRFPU0_GRFPU_X0_ITER_ALLOW_RNIEHBA3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c30000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_5539\,
dataf => \GRFPU0.GRFPU_X0.N_4415_M_0_A3_3\,
datae => \FPI.START\,
datad => \FPI.FLOP\(6),
datac => \FPI.FLOP\(5),
datab => \FPI.FLOP\(2));
\GRFPU0_GRFPU_X0_COMB_VITER_ALLOW_1_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f3f300fff3f3")
port map (
combout => \GRFPU0.GRFPU_X0.N_15366\,
dataf => \GRFPU0.GRFPU_X0.VALLOW_1_SQMUXA_3\,
datae => \GRFPU0.GRFPU_X0.COMB.VITER.ALLOW_1_SN_N_3\,
datad => \GRFPU0.GRFPU_X0.N_140\,
datac => \GRFPU0.GRFPU_X0.N_4364_1\,
datab => \GRFPU0.GRFPU_X0.ITER.ODDEXP\);
GRFPU0_GRFPU_X0_VITER_NX_0_SQMUXA_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4623_2\,
dataf => \GRFPU0.GRFPU_X0.ITER.DP\,
datae => \GRFPU0.GRFPU_X0.ITER.SQRT\);
GRFPU0_GRFPU_X0_RNDOP_1_SQMUXA_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000c000c0c00000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4664\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.DRES_S\(66),
datad => \GRFPU0.MULO.MRES\(67),
datac => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1));
\GRFPU0_GRFPU_X0_ITER_RNDMODE_RNI8LU42_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c000c000c0c0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_4481\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.DRES_S\(66),
datad => \GRFPU0.MULO.MRES\(67),
datac => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datab => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1));
GRFPU0_GRFPU_X0_COMB_RNDOP19_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_9318\,
dataf => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
datae => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1));
GRFPU0_GRFPU_X0_UN1_RNDOP_0_SQMUXA_10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3c0f3c0f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_4482\,
dataf => \GRFPU0.MULO.MRES\(120),
datae => \GRFPU0.MULO.DRES_S\(66),
datad => \GRFPU0.GRFPU_X0.N_9318\,
datac => \GRFPU0.GRFPU_X0.N_9344\,
datab => \GRFPU0.MULO.MRES\(67));
GRFPU0_GRFPU_X0_UN1_RNDOP_0_SQMUXA_10_RNIFP1S2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_6509\,
dataf => \GRFPU0.GRFPU_X0.N_4482\,
datae => \GRFPU0.GRFPU_X0.N_4664\,
datad => \GRFPU0.GRFPU_X0.N_4481\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(45),
dataf => \GRFPU0.GRFPU_X0.N_21\,
datae => \GRFPU0.GRFPU_X0.N_18746\,
datad => \FPI.OP1\(45),
datac => \FPI.OP1\(48));
GRFPC0_FP_PIPELINE_12_0_CHECK_DEP_UN3855_REGDEPX_1_0_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_23915\,
dataf => \GRFPC0.FIFO.INST_0\(3),
datae => \GRFPC0.FIFO.INST_0\(4));
GRFPC0_FP_PIPELINE_2_0_CHECK_DEP_UN720_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.UN720_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(18),
datae => \GRFPC0.FIFO.INST_0\(17),
datad => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_FP_PIPELINE_10_STDEP_416_3_0_0_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_571\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.N_106_I\);
GRFPC0_FP_PIPELINE_UN1_HOLDN_I_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => N_99866_I,
dataf => \GRFPC0.WR.CTRL.LD\,
datae => N_37);
GRFPC0_EX_CTRL_LD_RNIA6811_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_680\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_243,
datad => N_242,
datac => N_244,
datab => N_245);
GRFPC0_FP_PIPELINE_0_STDDEP_224_IV_0_0_M2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f3fff3fff3ff030f")
port map (
combout => N_82245,
dataf => \GRFPC0.N_584_I\,
datae => \GRFPC0.N_528\,
datad => \GRFPC0.N_615\,
datac => \GRFPC0.N_502\,
datab => \GRFPC0.N_579\);
GRFPC0_FP_PIPELINE_UN17_SHARE: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000f0f0f000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN17_SHARE\,
dataf => \GRFPC0.WR.CTRL.LD\,
datae => \GRFPC0.WR.CTRL.RDWR\,
datad => \GRFPC0.WR.CTRL.CCWR\,
datac => \GRFPC0.WR.CTRL.VCNT\(0));
GRFPC0_STDDEP_0_SQMUXA_182: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000f0003333ffff")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_182\,
dataf => \GRFPC0.N_22621\,
datae => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1386_DEP\,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\,
datac => \GRFPC0.STDDEP_0_SQMUXA_54_0\,
datab => \GRFPC0.EX.CTRL.RDWR\);
GRFPC0_STDDEP_0_SQMUXA_169_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f000f000ffff")
port map (
combout => \GRFPC0.N_22621\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_145\,
datae => \GRFPC0.N_18769\,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\,
datac => \GRFPC0.MEM.CTRL.RDWR\);
\GRFPC0_D_STLCK_RNO_2_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcffffffffffffff")
port map (
combout => \GRFPC0.N_22644\,
dataf => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1327_REGDEPX_0\,
datac => \GRFPC0.FIFO.INST_0\(29),
datab => \GRFPC0.FIFO.INST_0\(26));
GRFPC0_FP_PIPELINE_4_STDEP_176_SEL1_I_0_A2_I_O4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffffffffff")
port map (
combout => \GRFPC0.N_22636\,
dataf => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1386_DEP\,
datae => \GRFPC0.N_106_I\,
datad => \GRFPC0.EX.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_4_STDEP_172_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fffffff003fc03f")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_172\(1),
dataf => \GRFPC0.FP_PIPELINE.4.STDEP_168\(1),
datae => \GRFPC0.N_104\,
datad => \GRFPC0.FP_PIPELINE.4.STDEP_172_SEL0\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\,
datab => \GRFPC0.STDDEP_0_SQMUXA_54_0\);
\GRFPC0_FP_PIPELINE_15_STDEP_608_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f7ffffff02000a00")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_608\(0),
dataf => \GRFPC0.FP_PIPELINE.15.STDEP_604\(0),
datae => \GRFPC0.N_114\,
datad => \GRFPC0.N_494\,
datac => \GRFPC0.N_25889\,
datab => \GRFPC0.STDDEP_0_SQMUXA_58_0_A2_0\,
dataa => \GRFPC0.WR.CTRL.RDWR\);
\GRFPC0_FP_PIPELINE_4_STDEP_168_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30ffffff0030cf30")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_168\(1),
dataf => \GRFPC0.FP_PIPELINE.4.STDEP_164\(1),
datae => \GRFPC0.N_114\,
datad => \GRFPC0.N_18769\,
datac => \GRFPC0.N_494\,
datab => \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL0_1\);
\GRFPC0_FP_PIPELINE_15_STDEP_608_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbf3ffff0200060c")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_608\(1),
dataf => \GRFPC0.FP_PIPELINE.15.STDEP_604\(1),
datae => \GRFPC0.N_114\,
datad => \GRFPC0.N_494\,
datac => \GRFPC0.N_25889\,
datab => \GRFPC0.STDDEP_0_SQMUXA_58_0_A2_0\,
dataa => \GRFPC0.WR.CTRL.RDWR\);
GRFPC0_EX_CTRL_LD_RNIA6811_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPC0.N_22707\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_245,
datad => N_244,
datac => N_243,
datab => N_242);
\GRFPC0_D_STLCK_RNO_0_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdfdfdfdfdfdfdf0")
port map (
combout => \GRFPC0.N_21262\,
dataf => \GRFPC0.N_21295\,
datae => \GRFPC0.N_21297\,
datad => \GRFPC0.N_21298\,
datac => \GRFPC0.N_21325\,
datab => N_99872,
dataa => \GRFPC0.EX.CTRL.RD\(0));
\GRFPC0_D_STLCK_RNO_8_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff33f030ff33ff33")
port map (
combout => \GRFPC0.FP_PIPELINE.13.STDEP_558_I_M_I_A3_14_0\(1),
dataf => \GRFPC0.N_21951_1\,
datae => \GRFPC0.N_53\,
datad => N_99872,
datac => \GRFPC0.N_470\,
datab => \GRFPC0.EX.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_13_STDEP_536_3_I_A3_6_RNIPSJHK_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fdff0c0e0c0e0c0e")
port map (
combout => \GRFPC0.N_21253\,
dataf => \GRFPC0.N_742_1\,
datae => \GRFPC0.N_21327\,
datad => \GRFPC0.N_114\,
datac => \GRFPC0.N_21241\,
datab => \GRFPC0.WR.CTRL.RDD\,
dataa => \GRFPC0.WR.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_14_1_CHECK_DEP_UN4568_REGDEPX_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.14.1.CHECK_DEP.UN4568_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(17),
datae => \GRFPC0.FIFO.INST_1\(18),
datad => \GRFPC0.FIFO.INST_1\(15),
datac => \GRFPC0.FIFO.INST_1\(16));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_25063\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22429\,
datad => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN97_REGDEPX_2\,
datac => \GRFPC0.FIFO.INST_0\(2),
datab => \GRFPC0.FIFO.INST_0\(1));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_11: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.N_9484\,
dataf => N_107,
datae => N_106,
datad => N_105,
datac => N_104);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_124_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030000000")
port map (
combout => \GRFPC0.N_25663\,
dataf => \GRFPC0.N_25658\,
datae => \FPI.FLOP\(6),
datad => \GRFPC0.N_23975\,
datac => \GRFPC0.N_24489\,
datab => \GRFPC0.V.STDATA_14\(18));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_128_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffcccf000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_128\(0),
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX2_125\(0),
datae => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2004_REGDEPX2\,
datad => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_11\(0),
datac => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(0));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffe00fc00")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75\(0),
dataf => \GRFPC0.FP_PIPELINE.2.REGDEPX2_70\(0),
datae => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_19\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_18\(0),
datab => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_11\(0),
dataa => \GRFPC0.MEM.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ff0000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(0),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(0),
datae => \GRFPC0.N_23669\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datac => \GRFPC0.MEM.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_18_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_18\(0),
dataf => \GRFPC0.MEM.CTRL.INST\(1),
datae => \GRFPC0.MEM.CTRL.INST\(4),
datad => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST\(3),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_70_0_A3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_25423\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.EX.CTRL.INST\(27),
datad => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(0),
datab => \GRFPC0.N_24322\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_70_0_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_1\(0),
dataf => \GRFPC0.N_25423\,
datae => \GRFPC0.N_25426\,
datad => \GRFPC0.N_25460\,
datac => \GRFPC0.N_24189\,
datab => \GRFPC0.N_25388\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_70_0_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffb1a0ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_2\(0),
dataf => \GRFPC0.N_23946_2\,
datae => \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_1\(0),
datad => \GRFPC0.N_24539\,
datac => \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN824_REGDEPX\,
datab => \GRFPC0.FIFO.INST_0\(18),
dataa => \GRFPC0.FIFO.RD_0\(0));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_70_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffeac0ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_70\(0),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.2.REGDEPX2_70_0_2\(0),
datad => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_8_0\(1),
datac => \GRFPC0.FP_PIPELINE.2.REGDEPX2_65_0_A2_0\(0),
datab => \GRFPC0.N_23980\,
dataa => \GRFPC0.N_25649\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_240_I_M2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00c0ffc000")
port map (
combout => \GRFPC0.N_24709\,
dataf => \GRFPC0.FP_PIPELINE.7.REGDEPX2_238\(0),
datae => \GRFPC0.FP_PIPELINE.7.REGDEPX2_235\(0),
datad => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
datab => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3534_REGDEPX2\);
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_7_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000300")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_7\(0),
dataf => \GRFPC0.N_24201\,
datae => \GRFPC0.DIV.RDD\,
datad => \GRFPC0.DIV.INST\(17),
datac => \GRFPC0.DIV.INST\(18),
datab => \GRFPC0.DIV.INST\(14));
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_18_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_18_0\(1),
dataf => \GRFPC0.WR.CTRL.INST\(15),
datae => \GRFPC0.WR.CTRL.INST\(18),
datad => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.INST\(17));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1712_REGDEPX2_2_I_O4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_25557\,
dataf => \GRFPC0.WR2.CTRL.INST\(15),
datae => \GRFPC0.WR2.CTRL.INST\(16));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_145_0_A2_0_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPC0.N_24761_2\,
dataf => \GRFPC0.WR2.CTRL.RS1V\,
datae => \GRFPC0.WR2.CTRL.INST\(17),
datad => \GRFPC0.WR2.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1682_REGDEPX2_0_A2_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.N_25854\,
dataf => \GRFPC0.WR.CTRL.INST\(1),
datae => \GRFPC0.WR.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_230_0_A3_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_25509\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.N_702\,
datad => \GRFPC0.N_25854\,
datac => \GRFPC0.WR.CTRL.INST\(4),
datab => \GRFPC0.WR.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_13_0_A4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_13\(0),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(0),
datae => \GRFPC0.WR2.CTRL.INST\(1),
datad => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.WR2.CTRL.INST\(3));
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN3462_REGDEPX2_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.N_25851\,
dataf => \GRFPC0.WR2.CTRL.INST\(26),
datae => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_235_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000c0000000")
port map (
combout => \GRFPC0.N_24760\,
dataf => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_13\(0),
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(0),
datac => \GRFPC0.N_25859\,
datab => \GRFPC0.N_25851\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_200_0_A2_4_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_25608_2\,
dataf => \GRFPC0.MEM.CTRL.INST\(29),
datae => \GRFPC0.MEM.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_230_0_A2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_25519\,
dataf => \GRFPC0.MEM.CTRL.INST\(1),
datae => \GRFPC0.MEM.CTRL.INST\(4),
datad => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST\(3),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_230_0_O2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.REGDEPX2_230_0_O2_0\(0),
dataf => \GRFPC0.N_25519\,
datae => \GRFPC0.N_25608_2\,
datad => \GRFPC0.MEM.CTRL.INST\(27),
datac => \GRFPC0.MEM.CTRL.INST\(26),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(0));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_230_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25518\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(0),
datae => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3386_REGDEPX2_2\,
datad => \GRFPC0.MEM.CTRL.RS1V\,
datac => \GRFPC0.MEM.CTRL.INST\(16),
datab => \GRFPC0.MEM.CTRL.INST\(15));
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN3356_REGDEPX2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3356_REGDEPX2\,
dataf => \GRFPC0.EX.CTRL.INST\(3),
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.DEP_1\(0),
dataf => \GRFPC0.EX.CTRL.INST\(16),
datae => \GRFPC0.EX.CTRL.INST\(15),
datad => \GRFPC0.EX.CTRL.INST\(18),
datac => \GRFPC0.EX.CTRL.INST\(17),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(0));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5724_REGDEPX2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN5724_REGDEPX2\,
dataf => \GRFPC0.DIV.INST\(17),
datae => \GRFPC0.DIV.INST\(16),
datad => \GRFPC0.DIV.INST\(15),
datac => \GRFPC0.DIV.INST\(18));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5577_REGDEPX2_1_I_O3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_25382\,
dataf => \GRFPC0.MEM.CTRL.INST\(29),
datae => \GRFPC0.MEM.CTRL.INST\(28));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5667_REGDEPX2_2_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_25783\,
dataf => \GRFPC0.WR2.CTRL.INST\(29),
datae => \GRFPC0.WR2.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_12_REGDEPX2_385_0_A3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000030000000")
port map (
combout => \GRFPC0.N_25500\,
dataf => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_11\(1),
datae => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN369_REGDEPX2_1\,
datab => \GRFPC0.N_25783\);
\GRFPC0_FP_PIPELINE_12_CHECK_DEP_DEP_24_IV_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_24_IV\(1),
dataf => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datab => \GRFPC0.N_24484\);
\GRFPC0_FP_PIPELINE_12_REGDEPX2_363_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.12.REGDEPX2_363\(1),
dataf => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.DEP_24_IV\(1),
datae => \GRFPC0.N_25658\,
datad => \GRFPC0.N_25221\,
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN6767_REGDEPX2_2\,
datab => \FPI.FLOP\(6));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5696_REGDEPX2_2_0_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_25785\,
dataf => \GRFPC0.WR2.CTRL.INST\(4),
datae => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_12_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPC0.N_24194\,
dataf => \GRFPC0.MEM.CTRL.INST\(27),
datae => \GRFPC0.MEM.CTRL.INST\(29),
datad => \GRFPC0.MEM.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_135_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00000c000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_1\(1),
dataf => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.DEP_18\(1),
datae => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datad => \GRFPC0.N_24193\,
datac => \GRFPC0.MEM.CTRL.INST\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_A2_2_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3386_REGDEPX2_2\,
dataf => \GRFPC0.MEM.CTRL.INST\(17),
datae => \GRFPC0.MEM.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_135_A0_0_RNI4NMH1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0c0c0ff000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_0\(1),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_A0_0\(1),
datad => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135_A0_1\(1),
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2033_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_124_0_A2_1_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_125_0_A2_1_0\(1),
dataf => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\);
\GRFPC0_FP_PIPELINE_4_REGDEPX2_140_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000cff0c00")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX2_140\(1),
dataf => \GRFPC0.FP_PIPELINE.4.REGDEPX2_138\(1),
datae => \GRFPC0.FP_PIPELINE.4.REGDEPX2_135\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datac => \GRFPC0.N_703\,
datab => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2123_REGDEPX2\);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN2196_REGDEPX2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2196_REGDEPX2\,
dataf => \GRFPC0.DIV.INST\(17),
datae => \GRFPC0.DIV.INST\(16),
datad => \GRFPC0.DIV.INST\(15),
datac => \GRFPC0.DIV.INST\(18));
\GRFPC0_FP_PIPELINE_4_REGDEPX2_146_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_24072\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datae => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.DIV.RD\(4),
datac => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.DIV.RD\(1));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN2168_REGDEPX2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2168_REGDEPX2\,
dataf => \GRFPC0.WR2.CTRL.INST\(1),
datae => \GRFPC0.WR2.CTRL.INST\(2),
datad => \GRFPC0.WR2.CTRL.INST\(4),
datac => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0c00")
port map (
combout => \GRFPC0.N_25791\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_O2_1\(1),
datae => \GRFPC0.N_25802\,
datad => \GRFPC0.N_25805_1\,
datac => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.WR2.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_A2_0_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000030000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_0_1\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datae => \GRFPC0.DIV.INST\(2),
datad => \GRFPC0.DIV.INST\(3),
datac => \GRFPC0.DIV.INST\(1),
datab => \GRFPC0.DIV.INST\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_150_0_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff0c0c0cff000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_3\(1),
dataf => \GRFPC0.N_25805_1\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_150_0_A2_0_1\(1),
datad => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datac => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.WR2.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_56_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff000c0000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_56\(1),
dataf => \GRFPC0.FP_PIPELINE.1.REGDEPX2_55\(1),
datae => \GRFPC0.N_24115\,
datad => \GRFPC0.DIV.RD\(4),
datac => \GRFPC0.DIV.RD\(2),
datab => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_1_CHECK_DEP_DEP_4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000003000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_4\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datae => \GRFPC0.DIV.INST\(2),
datad => \GRFPC0.DIV.INST\(3),
datac => \GRFPC0.DIV.INST\(1),
datab => \GRFPC0.DIV.INST\(4));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_59_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_59\(1),
dataf => \GRFPC0.FP_PIPELINE.1.REGDEPX2_56\(1),
datae => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_4\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(1),
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN873_REGDEPX2\,
datab => \GRFPC0.DIV.RS1V\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_55_0_A4_1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.N_25568_1\,
dataf => \GRFPC0.WR2.CTRL.RS1V\,
datae => \GRFPC0.WR2.CTRL.INST\(16),
datad => \GRFPC0.WR2.CTRL.INST\(18),
datac => \GRFPC0.WR2.CTRL.INST\(17));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN785_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN785_REGDEPX2\,
dataf => \GRFPC0.WR.CTRL.INST\(15),
datae => \GRFPC0.WR.CTRL.INST\(16),
datad => \GRFPC0.WR.CTRL.INST\(18),
datac => \GRFPC0.WR.CTRL.INST\(17));
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN2535_REGDEPX2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN771_REGDEPX2_2\,
dataf => \GRFPC0.WR.CTRL.INST\(26),
datae => \GRFPC0.WR.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_45_0_A3_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_25417\,
dataf => \GRFPC0.N_24403_1\,
datae => \GRFPC0.MEM.CTRL.INST\(1),
datad => \GRFPC0.MEM.CTRL.INST\(4),
datac => \GRFPC0.MEM.CTRL.INST\(2),
datab => \GRFPC0.MEM.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_1_REGDEPX2_45_0_1_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffffc0")
port map (
combout => \GRFPC0.FP_PIPELINE.1.REGDEPX2_45_0_1\(1),
dataf => \GRFPC0.N_25420\,
datae => \GRFPC0.N_25417\,
datad => \GRFPC0.N_25419\,
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.DEP_10_1\(0),
datab => \GRFPC0.N_25406_1\);
\GRFPC0_FP_PIPELINE_1_REGDEPX2_45_0_A3_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f0f0f0c0")
port map (
combout => \GRFPC0.N_25415\,
dataf => \GRFPC0.N_25420\,
datae => \GRFPC0.N_25421\,
datad => \GRFPC0.N_25441\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datab => \GRFPC0.N_25419\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_26_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.N_24233\,
dataf => \GRFPC0.DIV.RD\(2),
datae => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_26_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff03000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_26\(1),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_25\(1),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datad => \GRFPC0.N_24233\,
datac => \GRFPC0.DIV.RD\(3),
datab => \GRFPC0.DIV.RD\(4));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN447_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN447_REGDEPX2\,
dataf => \GRFPC0.DIV.INST\(2),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(1),
datac => \GRFPC0.DIV.INST\(4));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_A2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003000000")
port map (
combout => \GRFPC0.N_25253\,
dataf => \GRFPC0.N_705\,
datae => \GRFPC0.N_25250_3\,
datad => \GRFPC0.WR.CTRL.RS1V\,
datac => \GRFPC0.WR.CTRL.INST\(15),
datab => \GRFPC0.WR.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_25_0_A2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPC0.N_25806\,
dataf => \GRFPC0.N_25244_1\,
datae => \GRFPC0.WR2.CTRL.INST\(1),
datad => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.WR2.CTRL.INST\(3));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN383_REGDEPX2_1_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN383_REGDEPX2_1\,
dataf => \GRFPC0.WR2.CTRL.INST\(15),
datae => \GRFPC0.WR2.CTRL.INST\(16));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_25_0_A2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPC0.N_25805\,
dataf => \GRFPC0.N_25805_1\,
datae => \GRFPC0.WR2.CTRL.INST\(18),
datad => \GRFPC0.WR2.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_14_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0c0c0ffc0c0c0c0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_14_0_0\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datae => \GRFPC0.N_25380\,
datad => \GRFPC0.N_25376\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN302_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_10_I_A2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.N_25287\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.EX.CTRL.INST\(27),
datad => \GRFPC0.EX.CTRL.INST\(26),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1),
datab => \GRFPC0.N_24322\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_10_I_O2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_10_I_O2_1\(1),
dataf => \GRFPC0.N_25287\,
datae => \GRFPC0.N_25291\,
datad => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN695_REGDEPX2_2\,
datac => \GRFPC0.N_25190\,
datab => \GRFPC0.N_280\);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_1_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcf3f00f0c0300")
port map (
combout => \GRFPC0.N_17399\,
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_60\(1),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_29\(1),
datad => \GRFPC0.FP_PIPELINE.0.REGDEPX2_25\(1),
datac => \GRFPC0.INST\(26),
datab => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\);
GRFPC0_EX_CTRL_LD_RNIA6811_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_23515_I\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_242,
datad => N_243,
datac => N_244,
datab => N_245);
\GRFPC0_D_STLCK_RNO_6_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_23550\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datae => \GRFPC0.RFA.LD\,
datad => N_174,
datac => \GRFPC0.N_801\,
datab => N_173);
GRFPC0_FP_PIPELINE_11_1_CHECK_DEP_UN3632_REGDEPX_1_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_24910\,
dataf => \GRFPC0.FIFO.INST_1\(15),
datae => \GRFPC0.FIFO.INST_1\(16));
\GRFPC0_FP_PIPELINE_4_REGDEPX_84_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffccfffcff00fff0")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX_84_0_1\(1),
dataf => \GRFPC0.N_21638_1\,
datae => \GRFPC0.N_22639\,
datad => \GRFPC0.N_22656\,
datac => \GRFPC0.N_21277_1\,
datab => \GRFPC0.FP_PIPELINE.4.1.CHECK_DEP.UN1448_REGDEPX\);
\GRFPC0_FP_PIPELINE_4_0_REGDEPX_77_0_A2_2_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.N_24892\,
dataf => \GRFPC0.FIFO.INST_0\(16),
datae => \GRFPC0.FIFO.INST_0\(15));
GRFPC0_FP_PIPELINE_4_0_CHECK_DEP_UN1327_REGDEPX_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.UN1327_REGDEPX_0\,
dataf => \GRFPC0.FIFO.INST_0\(27),
datae => \GRFPC0.FIFO.INST_0\(28));
\GRFPC0_FP_PIPELINE_4_REGDEPX_84_0_A4_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000fff00000")
port map (
combout => \GRFPC0.N_22657\,
dataf => \GRFPC0.N_23178\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_23180\,
datac => \GRFPC0.FP_PIPELINE.4.0.CHECK_DEP.DEP\(1));
\GRFPC0_FP_PIPELINE_4_REGDEPX_86_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff00c0")
port map (
combout => \GRFPC0.FP_PIPELINE.4.REGDEPX_86\(1),
dataf => \GRFPC0.N_22657\,
datae => \GRFPC0.FP_PIPELINE.4.REGDEPX_84_0_1\(1),
datad => N_97,
datac => \GRFPC0.N_9477\,
datab => \GRFPC0.N_59\);
GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_UN190_REGDEPX_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPC0.N_25083\,
dataf => \GRFPC0.FIFO.INST_1\(18),
datae => \GRFPC0.FIFO.INST_1\(15),
datad => \GRFPC0.FIFO.INST_1\(16));
\GRFPC0_FIFO_INST_1_RNIEEFJ1_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ffffffffffff")
port map (
combout => \GRFPC0.N_23324\,
dataf => \GRFPC0.FIFO.INST_1\(29),
datae => \GRFPC0.FIFO.INST_1\(28),
datad => \GRFPC0.FIFO.INST_1\(26),
datac => \GRFPC0.FIFO.INST_1\(27));
\GRFPC0_D_STLCK_RNO_6_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000003000300")
port map (
combout => \GRFPC0.D.STLCK_0_0_19__G3\,
dataf => N_40557,
datae => N_99871,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_548\,
datab => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A4_2_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.N_23265\,
dataf => \GRFPC0.N_25051_1\,
datae => \GRFPC0.FIFO.INST_1\(17),
datad => \GRFPC0.FIFO.INST_1\(18),
datac => \GRFPC0.FIFO.INST_1\(15),
datab => \GRFPC0.FIFO.INST_1\(16));
GRFPC0_FP_PIPELINE_13_0_CHECK_DEP_UN4167_REGDEPX_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.0.CHECK_DEP.UN4167_REGDEPX_0_A2_0\,
dataf => \GRFPC0.FIFO.INST_0\(3),
datae => \GRFPC0.FIFO.INST_0\(4));
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_O2_4_I_O2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_462\,
dataf => \GRFPC0.N_114\,
datae => \GRFPC0.WR.CTRL.RDD\);
GRFPC0_FP_PIPELINE_0_STDDEP_158_IV_0_0_O2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcc3f0c33003300")
port map (
combout => \GRFPC0.N_492\,
dataf => \GRFPC0.N_842\,
datae => \GRFPC0.N_22173_I\,
datad => \GRFPC0.N_462\,
datac => \GRFPC0.N_74_I_I\,
datab => \GRFPC0.N_474\);
GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_UN172_REGDEPX_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.1.CHECK_DEP.UN172_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(29),
datae => \GRFPC0.FIFO.INST_1\(28),
datad => \GRFPC0.FIFO.INST_1\(26),
datac => \GRFPC0.FIFO.INST_1\(27));
GRFPC0_FP_PIPELINE_11_IS_RDD_TMP_I_1_A2_0_RNIEHRK_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPC0.N_61_I\,
dataf => N_103,
datae => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_1\,
datad => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_0\);
GRFPC0_FP_PIPELINE_11_IS_RDD_TMP_I_1_A2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003f3f303c3f3f")
port map (
combout => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_1\,
dataf => N_88,
datae => N_84,
datad => N_85,
datac => N_90,
datab => N_86);
GRFPC0_FP_PIPELINE_11_IS_RDD_TMP_I_1_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000003fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_0\,
dataf => N_108,
datae => N_89,
datad => N_88,
datac => N_86,
datab => N_84);
GRFPC0_FP_PIPELINE_11_IS_RDD_TMP_I_1_A2_0_RNIEHRK: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00ffffff")
port map (
combout => \GRFPC0.N_59\,
dataf => N_103,
datae => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_1\,
datad => \GRFPC0.FP_PIPELINE.11.IS_RDD.TMP_I_1_A2_0\);
GRFPC0_FP_PIPELINE_5_1_CHECK_DEP_UN1760_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1760_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(17),
datae => \GRFPC0.FIFO.INST_1\(18),
datad => \GRFPC0.FIFO.INST_1\(15),
datac => \GRFPC0.FIFO.INST_1\(16));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_21641\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.N_22253\,
datad => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1775_REGDEPX_1\,
datac => \GRFPC0.FIFO.INST_1\(2),
datab => \GRFPC0.FIFO.INST_1\(4));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1567_REGDEPX_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1879_REGDEPX_2\,
dataf => N_80,
datae => N_82);
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN4375_REGDEPX_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1879_REGDEPX_1\,
dataf => N_79,
datae => N_81);
\GRFPC0_FP_PIPELINE_11_0_REGDEPX_203_0_O2_0_I_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_24924\,
dataf => \GRFPC0.FIFO.INST_0\(6),
datae => \GRFPC0.FIFO.INST_0\(14));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(42),
dataf => \GRFPU0.GRFPU_X0.N_21\,
datae => \GRFPU0.GRFPU_X0.N_18746\,
datad => \FPI.OP1\(45),
datac => \FPI.OP1\(42));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.N_9476\,
dataf => N_107,
datae => N_106,
datad => N_105,
datac => N_104);
GRFPC0_FP_PIPELINE_0_STDDEP_70_IV_0_A2_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.STDDEP_70_IV_0_A2_0\,
dataf => \GRFPC0.N_106_I\,
datae => \GRFPC0.EX.CTRL.RDWR\);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN44_DEP_2_0_A3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN44_DEP_2\,
dataf => \GRFPC0.MEM.CTRL.RD\(4),
datae => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_3_STDEP_128_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5fff5fff5fff02a2")
port map (
combout => \GRFPC0.FP_PIPELINE.3.STDEP_128\(0),
dataf => \GRFPC0.FP_PIPELINE.0.RESV2_I_M_31\,
datae => \GRFPC0.STDEP_2_SQMUXA_129\,
datad => \GRFPC0.N_114\,
datac => \GRFPC0.N_18933\,
datab => \GRFPC0.FP_PIPELINE.3.STDEP_128_SEL0_1\,
dataa => \GRFPC0.N_494\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A3_0_1_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003000000")
port map (
combout => \GRFPC0.N_21186_1\,
dataf => N_93,
datae => N_96,
datad => \GRFPC0.N_21627\,
datac => N_95,
datab => N_94);
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN2815_REGDEPX_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2815_REGDEPX\,
dataf => N_81,
datae => N_80,
datad => N_79,
datac => N_82);
GRFPC0_FP_PIPELINE_8_1_CHECK_DEP_UN2696_REGDEPX_2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.9.1.CHECK_DEP.UN3008_REGDEPX_2\,
dataf => \GRFPC0.FIFO.INST_1\(17),
datae => \GRFPC0.FIFO.INST_1\(16));
\GRFPC0_FP_PIPELINE_8_REGDEPX_156_0_O2_1_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f00000f0f30033")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX_156_0_O2_1_0\(1),
dataf => N_40557,
datae => \GRFPC0.N_22253\,
datad => \GRFPC0.N_22244\,
datac => \GRFPC0.FP_PIPELINE.8.1.CHECK_DEP.UN2711_REGDEPX\,
datab => \GRFPC0.FIFO.INST_1\(19));
\GRFPC0_FP_PIPELINE_8_0_REGDEPX_149_0_A2_1_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.0.REGDEPX_149_0_A2_1_0_0\(0),
dataf => \GRFPC0.FIFO.INST_0\(18),
datae => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_FP_PIPELINE_8_REGDEPX_156_0_O4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX_156\(1),
dataf => \GRFPC0.FP_PIPELINE.8.REGDEPX_156_0_O2_1_0\(1),
datae => \GRFPC0.N_22305\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_22273_1\,
datab => \GRFPC0.N_22243\);
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3736_REGDEPX_1_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_25036\,
dataf => N_93,
datae => N_94);
GRFPC0_FP_PIPELINE_FCC_VALID_1_U_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.N_24385\,
dataf => \GRFPC0.EX.RREG.RESV\,
datae => \GRFPC0.EX.CTRL.CCWR\,
datad => \GRFPC0.MEM.CTRL.CCWR\,
datac => \GRFPC0.MEM.RREG.RESV\,
datab => \GRFPC0.N_24383\);
GRFPC0_FP_PIPELINE_FCC_VALID_1_U_I_M2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.N_24383\,
dataf => \GRFPC0.WR.RREG.RESV\,
datae => \GRFPC0.WR.CTRL.CCWR\,
datad => \GRFPC0.WR2.CTRL.CCWR\,
datac => \GRFPC0.WR2.RREG.RESV\,
datab => \GRFPC0.N_6\);
\GRFPC0_FP_PIPELINE_7_REGDEPX_138_0_A2_3_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.N_23854_I_0\,
dataf => \GRFPC0.FIFO.INST_0\(1),
datae => \GRFPC0.FIFO.INST_0\(2));
GRFPC0_FP_PIPELINE_3_0_CHECK_DEP_UN1032_REGDEPX_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.0.CHECK_DEP.UN1032_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_0\(18),
datae => \GRFPC0.FIFO.INST_0\(17),
datad => \GRFPC0.FIFO.INST_0\(16),
datac => \GRFPC0.FIFO.INST_0\(15));
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN3534_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.7.CHECK_DEP.UN3534_REGDEPX2\,
dataf => \GRFPC0.DIV.INST\(2),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(1),
datac => \GRFPC0.DIV.INST\(4));
GRFPC0_WR2_RREG_RESV_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3f0f0f3f3f3fff")
port map (
combout => \GRFPC0.N_315\,
dataf => CPO_EXCZ,
datae => \GRFPC0.WR.CTRL.LD\,
datad => \GRFPC0.WR.CTRL.VCNT\(0),
datac => N_37,
datab => N_39);
GRFPC0_WR2_CTRL_RDD_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33000000333f0000")
port map (
combout => \GRFPC0.WR2.CTRL.RDD_0_0_G1\,
dataf => CPO_EXCZ,
datae => \GRFPC0.WR.CTRL.RDD\,
datad => \GRFPC0.WR.CTRL.LD\,
datac => \GRFPC0.WR.CTRL.VCNT\(0),
datab => N_39);
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_O3_4_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00c00000")
port map (
combout => \GRFPC0.N_25899\,
dataf => \GRFPC0.N_666\,
datae => \GRFPC0.N_104\,
datad => \GRFPC0.N_467\,
datac => \GRFPC0.N_579\,
datab => \GRFPC0.MEM.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_0_UN1_WR_CTRL_DIV_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
dataf => \GRFPC0.WR.RREG.RESV\,
datae => \GRFPC0.WR.CTRL.DIV\);
GRFPC0_FP_PIPELINE_0_REGDEP34: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0c0f0f0f0f0f0f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEP34\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_3\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_4\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_2_5\,
datac => \GRFPC0.WR.RREG.RESV\,
datab => \GRFPC0.WR.CTRL.ID\(7));
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN4513_DEP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN4513_DEP\,
dataf => N_175,
datae => N_173,
datad => N_174,
datac => N_176);
GRFPC0_FP_PIPELINE_5_CHECK_DEP_UN1889_DEP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN1889_DEP\,
dataf => N_175,
datae => N_173,
datad => N_176,
datac => N_174);
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN4185_DEP_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN5169_DEP_2\,
dataf => N_175,
datae => N_176);
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3857_DEP_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1233_DEP_1\,
dataf => N_173,
datae => N_174);
\GRFPC0_FP_PIPELINE_10_CHECK_DEP_DEP_11_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_11\(1),
dataf => \GRFPC0.N_707\,
datae => \GRFPC0.WR.CTRL.INST\(26),
datad => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.WR.CTRL.INST\(28),
datab => \GRFPC0.WR.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_318_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff00c0")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_318\(1),
dataf => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315\(1),
datae => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_11\(1),
datad => \GRFPC0.N_705\,
datac => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4754_REGDEPX2\,
datab => \GRFPC0.WR.CTRL.RS1V\);
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN4769_REGDEPX2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4769_REGDEPX2\,
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(3),
datad => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_0\(1),
dataf => \GRFPC0.N_24159\,
datae => \GRFPC0.N_24160_1\,
datad => \GRFPC0.N_25715_1\,
datac => \GRFPC0.EX.CTRL.INST\(27),
datab => \GRFPC0.EX.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff30000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_1\(1),
dataf => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_0\(1),
datae => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_A2_0_0\(1),
datac => \GRFPC0.MEM.CTRL.INST\(27),
datab => \GRFPC0.MEM.CTRL.INST\(26));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_305_0_A2_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_325_0_A2_9_0\(0),
dataf => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_305_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000003000000000")
port map (
combout => \GRFPC0.N_24503\,
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.V.STDATA_14_I_M_10\(0),
datad => \GRFPC0.N_24039\,
datac => \GRFPC0.N_227\,
datab => \GRFPC0.N_24642\);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_315_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315\(1),
dataf => \GRFPC0.N_24503\,
datae => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315_0_5\(1),
datad => \GRFPC0.N_23994_1\,
datac => N_60930_TZ_TZ,
datab => \GRFPC0.N_25221\);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_320_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000cff0c00")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX2_320\(1),
dataf => \GRFPC0.FP_PIPELINE.10.REGDEPX2_318\(1),
datae => \GRFPC0.FP_PIPELINE.10.REGDEPX2_315\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datac => \GRFPC0.N_703\,
datab => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4769_REGDEPX2\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A4_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_24974\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3960_REGDEPX2_1\,
datad => \GRFPC0.N_25624_1\,
datac => \GRFPC0.DIV.INST\(17),
datab => \GRFPC0.DIV.INST\(16));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_296_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0f030000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_296\(0),
dataf => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295\(0),
datae => \GRFPC0.N_24118\,
datad => \GRFPC0.DIV.RDD\,
datac => \GRFPC0.DIV.RD\(3),
datab => \GRFPC0.DIV.RD\(0));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_298_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0300000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_298\(0),
dataf => \GRFPC0.FP_PIPELINE.9.REGDEPX2_296\(0),
datae => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4401_REGDEPX2\,
datad => \GRFPC0.DIV.RDD\,
datac => \GRFPC0.DIV.RS1V\,
datab => \GRFPC0.DIV.INST\(14));
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_7_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_7\(0),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(2),
datac => \GRFPC0.DIV.INST\(4),
datab => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_0\(0),
dataf => \GRFPC0.N_24750\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(0),
datac => \GRFPC0.FP_PIPELINE.9.REGDEPX2_285_0_A2_0_2_0\(0),
datab => \GRFPC0.N_24181\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_2\(0),
dataf => \GRFPC0.N_24749\,
datae => \GRFPC0.N_25516_2\,
datad => \GRFPC0.N_25250_3\,
datac => \GRFPC0.WR.CTRL.INST\(15),
datab => \GRFPC0.WR.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_5\(0),
dataf => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_2\(0),
datae => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_0\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(0),
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4344_REGDEPX2\);
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_11_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c00000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_11\(0),
dataf => \GRFPC0.EX.CTRL.INST\(3),
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(0));
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_19_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_19\(0),
dataf => \GRFPC0.MEM.CTRL.INST\(1),
datae => \GRFPC0.MEM.CTRL.INST\(4),
datad => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST\(3),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_285_0_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.N_24735\,
dataf => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_19\(0),
datae => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4254_REGDEPX2_2\,
datad => \GRFPC0.MEM.CTRL.INST\(26),
datac => \GRFPC0.MEM.CTRL.INST\(29),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(0));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_A4_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_25598\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(0),
datad => \GRFPC0.N_25226\,
datac => \GRFPC0.WR2.CTRL.INST\(1),
datab => \GRFPC0.WR2.CTRL.INST\(4));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_6_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0c000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_6\(0),
dataf => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_4\(0),
datae => \GRFPC0.N_24765_1\,
datad => \GRFPC0.N_25316\,
datac => \GRFPC0.EX.CTRL.INST\(16),
datab => \GRFPC0.EX.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff8fffffff0")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295\(0),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.N_23994\,
datad => \GRFPC0.N_23995\,
datac => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_8\(0),
datab => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4193_REGDEPX2\,
dataa => \GRFPC0.N_23980\);
\GRFPC0_FP_PIPELINE_8_REGDEPX2_248_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_248\(0),
dataf => \GRFPC0.FP_PIPELINE.8.REGDEPX2_246\(0),
datae => \GRFPC0.N_25190\,
datad => \GRFPC0.N_25316\,
datac => \GRFPC0.EX.CTRL.RS1V\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(0));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_250_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00c0ffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_250\(0),
dataf => \GRFPC0.FP_PIPELINE.8.REGDEPX2_248\(0),
datae => \GRFPC0.FP_PIPELINE.8.REGDEPX2_245\(0),
datad => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3797_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_90_A0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000ff0000")
port map (
combout => \GRFPC0.N_25839_1\,
dataf => \GRFPC0.DIV.RDD\,
datae => \GRFPC0.DIV.RS1V\,
datad => \GRFPC0.DIV.INST\(14));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_A2_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_24421\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3960_REGDEPX2_1\,
datad => \GRFPC0.N_25839_1\,
datac => \GRFPC0.DIV.INST\(17),
datab => \GRFPC0.DIV.INST\(16));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_1\(0),
dataf => \GRFPC0.N_24421\,
datae => \GRFPC0.N_24401\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(0),
datab => \GRFPC0.N_24404_1\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_4\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_2\(0),
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_1\(0),
datad => \GRFPC0.N_24087_1\,
datac => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3917_REGDEPX2\,
datab => \GRFPC0.WR2.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_2_1\(0),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3813_REGDEPX2\,
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3842_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_270_0_A2_6_2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_270_0_A2_6_2_1\(0),
dataf => \GRFPC0.DIV.RD\(3),
datae => \GRFPC0.DIV.RD\(4),
datad => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_10_REGDEPX2_325_0_A2_4_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_24976_2\,
dataf => \GRFPC0.WR2.CTRL.RS1V\,
datae => \GRFPC0.WR2.CTRL.INST\(15),
datad => \GRFPC0.WR2.CTRL.INST\(16),
datac => \GRFPC0.WR2.CTRL.INST\(17),
datab => \GRFPC0.WR2.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_64_0_A2_3_RNINPEE1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff3000003030")
port map (
combout => N_60930_TZ_TZ,
dataf => \GRFPC0.N_24539\,
datae => \GRFPC0.N_24643\,
datad => \GRFPC0.N_24531\,
datac => \GRFPC0.N_23530_2\,
datab => \GRFPC0.FIFO.INST_1\(15));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_175_0_O2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.N_25550\,
dataf => \GRFPC0.WR2.CTRL.INST\(26),
datae => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_7_CHECK_DEP_DEP_3_0_A2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_25859\,
dataf => \GRFPC0.WR2.CTRL.INST\(29),
datae => \GRFPC0.WR2.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0c000000")
port map (
combout => \GRFPC0.N_24937\,
dataf => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.DEP_16\(1),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datad => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3975_REGDEPX2_1\,
datac => \GRFPC0.DIV.INST\(3),
datab => \GRFPC0.DIV.INST\(2));
\GRFPC0_FP_PIPELINE_10_REGDEPX_192_0_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.REGDEPX_192_0_2\(1),
dataf => \GRFPC0.FP_PIPELINE.10.REGDEPX_192_0_0\(1),
datae => \GRFPC0.N_24986\,
datad => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datac => \GRFPC0.N_22253\,
datab => \GRFPC0.FP_PIPELINE.VD.LDLCK_1_0_A2_2_0\(20));
\GRFPC0_D_STLCK_RNO_3_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_176\,
dataf => \GRFPC0.N_23560\,
datae => \GRFPC0.FIFO.INST_1\(19));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN351_REGDEPX2_1_0_A2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN351_REGDEPX2_1\,
dataf => \GRFPC0.WR.CTRL.INST\(1),
datae => \GRFPC0.WR.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3842_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3842_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(1),
datae => \GRFPC0.MEM.CTRL.INST\(4),
datad => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST\(3));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN320_REGDEPX2_1_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_1\,
dataf => \GRFPC0.WR.CTRL.INST\(26),
datae => \GRFPC0.WR.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_256_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00003000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_256\(1),
dataf => \GRFPC0.FP_PIPELINE.8.REGDEPX2_255\(1),
datae => \GRFPC0.N_707\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN320_REGDEPX2_1\,
datac => \GRFPC0.WR.CTRL.INST\(29),
datab => \GRFPC0.WR.CTRL.INST\(28));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN334_REGDEPX2_1_0_A2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN334_REGDEPX2_1\,
dataf => \GRFPC0.WR.CTRL.INST\(15),
datae => \GRFPC0.WR.CTRL.INST\(16));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_358_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffeaaac000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_358\(1),
dataf => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355\(1),
datae => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_6\(1),
datad => \GRFPC0.N_24115\,
datac => \GRFPC0.N_24703_I\,
datab => \GRFPC0.DIV.RD\(4),
dataa => \GRFPC0.DIV.RS1V\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_359_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00800000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_359\(1),
dataf => \GRFPC0.FP_PIPELINE.11.REGDEPX2_358\(1),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datad => \GRFPC0.DIV.INST\(3),
datac => \GRFPC0.DIV.INST\(2),
datab => \GRFPC0.DIV.INST\(4),
dataa => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_11_CHECK_DEP_DEP_19_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_19\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13\(1),
datae => \GRFPC0.WR2.CTRL.INST\(15),
datad => \GRFPC0.WR2.CTRL.INST\(16),
datac => \GRFPC0.WR2.CTRL.INST\(18),
datab => \GRFPC0.WR2.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_11_CHECK_DEP_DEP_20_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_20\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(1),
datae => \GRFPC0.WR2.CTRL.INST\(29),
datad => \GRFPC0.WR2.CTRL.INST\(28),
datac => \GRFPC0.WR2.CTRL.INST\(26),
datab => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_11_CHECK_DEP_DEP_8_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_8\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(1),
datae => \GRFPC0.WR2.CTRL.INST\(1),
datad => \GRFPC0.WR2.CTRL.INST\(2),
datac => \GRFPC0.WR2.CTRL.INST\(4),
datab => \GRFPC0.WR2.CTRL.INST\(3));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5195_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5195_REGDEPX2\,
dataf => \GRFPC0.WR.CTRL.INST\(15),
datae => \GRFPC0.WR.CTRL.INST\(18),
datad => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.INST\(17));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5210_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000f00000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5210_REGDEPX2\,
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(3),
datad => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5181_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5181_REGDEPX2\,
dataf => \GRFPC0.WR.CTRL.INST\(29),
datae => \GRFPC0.WR.CTRL.INST\(26),
datad => \GRFPC0.WR.CTRL.INST\(27),
datac => \GRFPC0.WR.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_350_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff000800")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_350\(1),
dataf => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345\(1),
datae => \GRFPC0.N_24280\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datac => \GRFPC0.N_705\,
datab => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.UN5195_REGDEPX2\,
dataa => \GRFPC0.WR.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_11_REGDEPX2_355_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffccc8ccc0")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_355\(1),
dataf => \GRFPC0.FP_PIPELINE.11.REGDEPX2_350\(1),
datae => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_19\(1),
datad => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_20\(1),
datac => \GRFPC0.FP_PIPELINE.11.CHECK_DEP.DEP_8\(1),
datab => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
dataa => \GRFPC0.WR2.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_A2_2_1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.N_24703_I\,
dataf => \GRFPC0.DIV.RD\(2),
datae => \GRFPC0.DIV.RD\(1));
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN5283_REGDEPX2_1_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_24201\,
dataf => \GRFPC0.DIV.INST\(15),
datae => \GRFPC0.DIV.INST\(16));
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN4754_REGDEPX2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4754_REGDEPX2\,
dataf => \GRFPC0.WR.CTRL.INST\(15),
datae => \GRFPC0.WR.CTRL.INST\(18),
datad => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_450_0_A2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPC0.N_275\,
dataf => \GRFPC0.DIV.RD\(4),
datae => \GRFPC0.DIV.RD\(2),
datad => \GRFPC0.DIV.RD\(1));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6621_REGDEPX2_2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3975_REGDEPX2_1\,
dataf => \GRFPC0.DIV.INST\(4),
datae => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_21_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(0),
dataf => \GRFPC0.DIV.RDD\,
datae => \GRFPC0.DIV.INST\(0));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_O2_4_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff3f0f0f0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_O2_4_1\(0),
dataf => \GRFPC0.N_24772\,
datae => \GRFPC0.N_25560_2\,
datad => \GRFPC0.N_275\,
datac => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4754_REGDEPX2\,
datab => \GRFPC0.DIV.RD\(3));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6606_REGDEPX2_2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3960_REGDEPX2_1\,
dataf => \GRFPC0.DIV.INST\(15),
datae => \GRFPC0.DIV.INST\(18));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A2_5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000c00")
port map (
combout => \GRFPC0.N_24782\,
dataf => \GRFPC0.N_706\,
datae => \GRFPC0.WR.CTRL.INST\(26),
datad => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.WR.CTRL.INST\(28),
datab => \GRFPC0.WR.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A2_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0c0f0c0f0c0f000")
port map (
combout => \GRFPC0.N_24785\,
dataf => \GRFPC0.N_24770\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_330_0_O2_4_1\(0),
datad => \GRFPC0.N_24782\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datab => \GRFPC0.N_25516_2\);
\GRFPC0_FP_PIPELINE_10_REGDEPX2_325_0_A2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcccf00000000000")
port map (
combout => \GRFPC0.N_24677\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(0),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(0),
datac => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4814_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4785_REGDEPX2\);
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN4814_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4814_REGDEPX2\,
dataf => \GRFPC0.WR2.CTRL.INST\(1),
datae => \GRFPC0.WR2.CTRL.INST\(2),
datad => \GRFPC0.WR2.CTRL.INST\(4),
datac => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_10_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(0),
dataf => \GRFPC0.WR2.CTRL.RDD\,
datae => \GRFPC0.WR2.CTRL.INST\(0));
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN4785_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN4785_REGDEPX2\,
dataf => \GRFPC0.WR2.CTRL.INST\(29),
datae => \GRFPC0.WR2.CTRL.INST\(28),
datad => \GRFPC0.WR2.CTRL.INST\(26),
datac => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_16_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(0),
dataf => \GRFPC0.WR2.CTRL.RDD\,
datae => \GRFPC0.WR2.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_WRDATA_3_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(21),
dataf => \GRFPC0.DIV.RESULT\(21),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(21),
datab => \FPO.RES\(21));
\GRFPU0_GRFPU_X0_RES_1_6_0_0_O7_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000000000ff")
port map (
combout => N_99904,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(0));
\GRFPC0_FP_PIPELINE_DBGDATA_4_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => CPO_DBG_DATAZ(30),
dataf => \FPI.RNDMODE\(0),
datae => N_425,
datad => N_426,
datac => N_721,
datab => N_657);
\GRFPC0_MEM_RREG_RES_RNO_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000ffffcccccccc")
port map (
combout => N_47225,
dataf => N_99847,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_10_3640_I_A3_0_0_0\,
datad => N_99904_1,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(30),
datab => \GRFPC0.EX.RREG.RES\(30));
\GRFPU0_GRFPU_X0_RES_1_6_I_A3_1_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_404\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1));
\GRFPU0_GRFPU_X0_RES_1_6_I_A3_0_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_403\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1));
\GRFPU0_GRFPU_X0_RES_1_6_0_A3_1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_401\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(0));
\GRFPU0_GRFPU_X0_RES_1_6_0_A3_0_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_400\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(0));
GRFPC0_WREN_2_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.WREN_2_SQMUXA\,
dataf => \GRFPC0.WR2.CTRL.RDD\,
datae => \GRFPC0.UN28_WREN_2\,
datad => \GRFPC0.WR2.CTRL.SEQERR\,
datac => \GRFPC0.PENDEXC_0_SQMUXA\);
\GRFPC0_OP1_4_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20155\,
dataf => N_99879_0,
datae => N_628,
datad => N_692);
GRFPC0_FP_PIPELINE_UN1_WR_CTRL_AFSR_I_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_6\,
dataf => \GRFPC0.WR.CTRL.LD\,
datae => \GRFPC0.WR.CTRL.AFSR\);
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_39_2886_I_A3_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000f003300ff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_39_2886_I_A3_0\,
dataf => N_99904_2,
datae => \GRFPU0.GRFPU_X0.N_400\,
datad => \GRFPC0.DIV.RESULT_0_0_1__G5\,
datac => \FPO.CC\(1),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(1));
GRFPC0_FP_PIPELINE_UN25_HOLDN: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN25_HOLDN\,
dataf => \GRFPC0.FP_PIPELINE.UN25_HOLDN_1\,
datae => N_37);
\GRFPC0_OP2_3_60_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19622\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(60),
datad => \GRFPC0.WR.RREG.RES\(60));
\GRFPU0_GRFPU_X0_UN38_EXP_M_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(60),
dataf => \GRFPC0.N_19753\,
datae => \GRFPC0.N_19687\,
datad => N_99880,
datac => \GRFPC0.N_19622\,
datab => \GRFPC0.RFA2.RS2SEL\(7));
\GRFPC0_FP_PIPELINE_WRDATA_3_54_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(54),
dataf => \GRFPC0.DIV.RESULT\(54),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(54),
datab => \GRFPU0.GRFPU_X0.N_20286_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(22),
dataf => \GRFPC0.DIV.RESULT\(22),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(22),
datab => \FPO.RES\(22));
\GRFPC0_WRDATA_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(22),
dataf => N_453,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(54),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(22));
GRFPU0_GRFPU_X0_UN13_EXP_1_CO1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.UN13_EXP_1_CO1\,
dataf => \FPI.OP1\(55),
datae => \FPI.OP1\(56));
\GRFPU0_GRFPU_X0_ST1_EXP1_RNO_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cf03fc3003cf30fc")
port map (
combout => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(2),
dataf => \GRFPU0.GRFPU_X0.N_18772\,
datae => \GRFPU0.GRFPU_X0.UN13_EXP_1_CO1\,
datad => \FPI.OP1\(54),
datac => \FPI.OP1\(57),
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_O2_2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18772\,
dataf => \FPI.OP1\(52),
datae => \FPI.OP1\(53));
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_RNO_0_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000f0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_0_7__N_4\,
dataf => \GRFPU0.GRFPU_X0.N_18833\,
datae => \GRFPU0.GRFPU_X0.N_18831\,
datad => \GRFPU0.GRFPU_X0.N_10059_I\,
datac => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_I_O2_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f0f0f0f0f0fff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18754\,
dataf => \FPI.OP1\(52),
datae => \FPI.OP1\(53),
datad => \FPI.OP1\(54),
datac => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_I_O2_RNISOG91_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18837\,
dataf => \GRFPU0.GRFPU_X0.N_18768\,
datae => \GRFPU0.GRFPU_X0.N_18754\,
datad => \FPI.NONSTD\);
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_A2_0_14_2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_0_14_2\(4),
dataf => \FPI.OP1\(49),
datae => \FPI.OP1\(32));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_A2_0_14_4_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_0_14_4\(4),
dataf => \FPI.OP1\(41),
datae => \FPI.OP1\(40),
datad => \FPI.OP1\(35),
datac => \FPI.OP1\(34));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_A2_0_13_7_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_0_13_7\(4),
dataf => \FPI.OP1\(50),
datae => \FPI.OP1\(37),
datad => \FPI.OP1\(48),
datac => \FPI.OP1\(46));
\GRFPU0_GRFPU_X0_VST1_FLTYPE1_1_1_I_A2_0_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18829\,
dataf => \GRFPU0.GRFPU_X0.N_18829_13\,
datae => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_0_14_4\(4),
datad => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_1_I_A2_0_14_2\(4),
datac => \FPI.OP1\(33),
datab => \FPI.OP1\(47));
\GRFPC0_OP1_1_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19948\,
dataf => \FPO.RES\(23),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(23));
\GRFPC0_OP1_2_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20014\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(23),
datad => \GRFPC0.MEM.RREG.RES\(23));
\GRFPC0_OP1_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(23),
dataf => \GRFPC0.N_20277\,
datae => N_99877_1,
datad => \GRFPC0.N_19948\,
datac => N_99878_1,
datab => \GRFPC0.N_20014\);
\GRFPC0_OP1_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(22),
dataf => \GRFPC0.N_20276\,
datae => N_99877_1,
datad => \GRFPC0.N_19947\,
datac => N_99878_1,
datab => \GRFPC0.N_20013\);
\GRFPC0_OP1_1_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19946\,
dataf => \FPO.RES\(21),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(21));
\GRFPC0_OP1_2_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20012\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(21),
datad => \GRFPC0.MEM.RREG.RES\(21));
\GRFPC0_OP1_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(21),
dataf => \GRFPC0.N_20275\,
datae => N_99877_0,
datad => \GRFPC0.N_19946\,
datac => N_99878_0,
datab => \GRFPC0.N_20012\);
\GRFPC0_OP1_1_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19945\,
dataf => \FPO.RES\(20),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(20));
\GRFPC0_OP1_2_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20011\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(20),
datad => \GRFPC0.MEM.RREG.RES\(20));
\GRFPC0_OP1_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(20),
dataf => \GRFPC0.N_20274\,
datae => N_99877_0,
datad => \GRFPC0.N_19945\,
datac => N_99878_0,
datab => \GRFPC0.N_20011\);
\GRFPC0_OP1_1_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19944\,
dataf => \FPO.RES\(19),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(19));
\GRFPC0_OP1_2_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20010\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(19),
datad => \GRFPC0.MEM.RREG.RES\(19));
\GRFPC0_OP1_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(19),
dataf => \GRFPC0.N_20273\,
datae => N_99877_0,
datad => \GRFPC0.N_19944\,
datac => N_99878_0,
datab => \GRFPC0.N_20010\);
\GRFPC0_OP1_1_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19943\,
dataf => \FPO.RES\(18),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(18));
\GRFPC0_OP1_2_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20009\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(18),
datad => \GRFPC0.MEM.RREG.RES\(18));
\GRFPC0_OP1_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(18),
dataf => \GRFPC0.N_20272\,
datae => N_99877_0,
datad => \GRFPC0.N_19943\,
datac => N_99878_0,
datab => \GRFPC0.N_20009\);
\GRFPC0_OP1_1_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19942\,
dataf => \FPO.RES\(17),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(17));
\GRFPC0_OP1_2_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20008\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(17),
datad => \GRFPC0.MEM.RREG.RES\(17));
\GRFPC0_OP1_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(17),
dataf => \GRFPC0.N_20271\,
datae => N_99877_0,
datad => \GRFPC0.N_19942\,
datac => N_99878_0,
datab => \GRFPC0.N_20008\);
\GRFPC0_OP1_1_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19941\,
dataf => \FPO.RES\(16),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(16));
\GRFPC0_OP1_2_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20007\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(16),
datad => \GRFPC0.MEM.RREG.RES\(16));
\GRFPC0_OP1_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(16),
dataf => \GRFPC0.N_20270\,
datae => N_99877_0,
datad => \GRFPC0.N_19941\,
datac => N_99878_0,
datab => \GRFPC0.N_20007\);
\GRFPC0_OP1_1_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19940\,
dataf => \FPO.RES\(15),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(15));
\GRFPC0_OP1_2_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20006\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(15),
datad => \GRFPC0.MEM.RREG.RES\(15));
\GRFPC0_OP1_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(15),
dataf => \GRFPC0.N_20269\,
datae => N_99877_0,
datad => \GRFPC0.N_19940\,
datac => N_99878_0,
datab => \GRFPC0.N_20006\);
\GRFPC0_OP1_1_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19939\,
dataf => \FPO.RES\(14),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(14));
\GRFPC0_OP1_2_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20005\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(14),
datad => \GRFPC0.MEM.RREG.RES\(14));
\GRFPC0_OP1_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(14),
dataf => \GRFPC0.N_20268\,
datae => N_99877_0,
datad => \GRFPC0.N_19939\,
datac => N_99878_0,
datab => \GRFPC0.N_20005\);
\GRFPC0_OP1_1_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19937\,
dataf => \FPO.RES\(12),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(12));
\GRFPC0_OP1_2_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20003\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(12),
datad => \GRFPC0.MEM.RREG.RES\(12));
\GRFPC0_OP1_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(12),
dataf => \GRFPC0.N_20266\,
datae => N_99877_0,
datad => \GRFPC0.N_19937\,
datac => N_99878_0,
datab => \GRFPC0.N_20003\);
\GRFPC0_OP1_1_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19932\,
dataf => \FPO.RES\(7),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(7));
\GRFPC0_OP1_2_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19998\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(7),
datad => \GRFPC0.MEM.RREG.RES\(7));
\GRFPC0_OP1_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(7),
dataf => \GRFPC0.N_20261\,
datae => N_99877_0,
datad => \GRFPC0.N_19932\,
datac => N_99878_0,
datab => \GRFPC0.N_19998\);
\GRFPC0_OP1_1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19931\,
dataf => \FPO.RES\(6),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(6));
\GRFPC0_OP1_2_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19997\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(6),
datad => \GRFPC0.MEM.RREG.RES\(6));
\GRFPC0_OP1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(6),
dataf => \GRFPC0.N_20260\,
datae => N_99877_0,
datad => \GRFPC0.N_19931\,
datac => N_99878_0,
datab => \GRFPC0.N_19997\);
\GRFPC0_OP1_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19929\,
dataf => \FPO.RES\(4),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(4));
\GRFPC0_OP1_2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19995\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(4),
datad => \GRFPC0.MEM.RREG.RES\(4));
\GRFPC0_OP1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(4),
dataf => \GRFPC0.N_20258\,
datae => N_99877_0,
datad => \GRFPC0.N_19929\,
datac => N_99878_0,
datab => \GRFPC0.N_19995\);
\GRFPC0_OP1_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19928\,
dataf => \FPO.RES\(3),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(3));
\GRFPC0_OP1_2_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19994\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(3),
datad => \GRFPC0.MEM.RREG.RES\(3));
\GRFPC0_OP1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(3),
dataf => \GRFPC0.N_20257\,
datae => N_99877_0,
datad => \GRFPC0.N_19928\,
datac => N_99878_0,
datab => \GRFPC0.N_19994\);
\GRFPC0_OP1_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19927\,
dataf => \FPO.RES\(2),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(2));
\GRFPC0_OP1_2_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19993\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(2),
datad => \GRFPC0.MEM.RREG.RES\(2));
\GRFPC0_OP1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(2),
dataf => \GRFPC0.N_20256\,
datae => N_99877_0,
datad => \GRFPC0.N_19927\,
datac => N_99878_0,
datab => \GRFPC0.N_19993\);
\GRFPC0_OP1_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19926\,
dataf => \FPO.RES\(1),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(1));
\GRFPC0_OP1_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19992\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.MEM.RREG.RES\(1),
datad => \GRFPC0.DIV.RESULT\(1));
\GRFPC0_OP1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(1),
dataf => \GRFPC0.N_20255\,
datae => N_99877_0,
datad => \GRFPC0.N_19926\,
datac => N_99878_0,
datab => \GRFPC0.N_19992\);
\GRFPC0_OP1_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19925\,
dataf => \FPO.RES\(0),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(0));
\GRFPC0_OP1_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19991\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.MEM.RREG.RES\(0),
datad => \GRFPC0.DIV.RESULT\(0));
\GRFPC0_OP1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(0),
dataf => \GRFPC0.N_20254\,
datae => N_99877_0,
datad => \GRFPC0.N_19925\,
datac => N_99878_0,
datab => \GRFPC0.N_19991\);
\GRFPC0_OP1_1_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19956\,
dataf => \FPO.RES\(31),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(31));
\GRFPC0_OP1_2_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20022\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(31),
datad => \GRFPC0.MEM.RREG.RES\(31));
\GRFPC0_OP1_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(31),
dataf => \GRFPC0.N_20285\,
datae => N_99877_1,
datad => \GRFPC0.N_19956\,
datac => N_99878_1,
datab => \GRFPC0.N_20022\);
\GRFPC0_OP1_1_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19955\,
dataf => \FPO.RES\(30),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(30));
\GRFPC0_OP1_2_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20021\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(30),
datad => \GRFPC0.MEM.RREG.RES\(30));
\GRFPC0_OP1_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(30),
dataf => \GRFPC0.N_20284\,
datae => N_99877_1,
datad => \GRFPC0.N_19955\,
datac => N_99878_1,
datab => \GRFPC0.N_20021\);
\GRFPC0_OP1_1_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19954\,
dataf => \FPO.RES\(29),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(29));
\GRFPC0_OP1_2_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20020\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(29),
datad => \GRFPC0.MEM.RREG.RES\(29));
\GRFPC0_OP1_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(29),
dataf => \GRFPC0.N_20283\,
datae => N_99877_1,
datad => \GRFPC0.N_19954\,
datac => N_99878_1,
datab => \GRFPC0.N_20020\);
\GRFPC0_OP1_1_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19953\,
dataf => \FPO.RES\(28),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(28));
\GRFPC0_OP1_2_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20019\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(28),
datad => \GRFPC0.MEM.RREG.RES\(28));
\GRFPC0_OP1_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(28),
dataf => \GRFPC0.N_20282\,
datae => N_99877_1,
datad => \GRFPC0.N_19953\,
datac => N_99878_1,
datab => \GRFPC0.N_20019\);
\GRFPC0_OP1_1_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19952\,
dataf => \FPO.RES\(27),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(27));
\GRFPC0_OP1_2_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20018\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(27),
datad => \GRFPC0.MEM.RREG.RES\(27));
\GRFPC0_OP1_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(27),
dataf => \GRFPC0.N_20281\,
datae => N_99877_1,
datad => \GRFPC0.N_19952\,
datac => N_99878_1,
datab => \GRFPC0.N_20018\);
\GRFPC0_OP1_1_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19951\,
dataf => \FPO.RES\(26),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(26));
\GRFPC0_OP1_2_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20017\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(26),
datad => \GRFPC0.MEM.RREG.RES\(26));
\GRFPC0_OP1_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(26),
dataf => \GRFPC0.N_20280\,
datae => N_99877_1,
datad => \GRFPC0.N_19951\,
datac => N_99878_1,
datab => \GRFPC0.N_20017\);
\GRFPC0_OP1_2_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20016\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(25),
datad => \GRFPC0.MEM.RREG.RES\(25));
\GRFPC0_OP1_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(25),
dataf => \GRFPC0.N_20279\,
datae => N_99877_1,
datad => \GRFPC0.N_19950\,
datac => N_99878_1,
datab => \GRFPC0.N_20016\);
GRFPU0_GRFPU_X0_SGNF_0_SQMUXA_57_I_A2_24: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000300000000")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_24\,
dataf => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA_57_I_A2_16\,
datae => \FPI.OP1\(31),
datad => \FPI.OP1\(30),
datac => \FPI.OP1\(29),
datab => \FPI.OP1\(28));
GRFPU0_GRFPU_X0_COMB_UNPACK_FLUSH0_IV_I_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.N_18805\,
dataf => \FPI.OP1\(52),
datae => \FPI.OP1\(53),
datad => \FPI.OP1\(54),
datac => \FPI.FLOP\(1));
\GRFPC0_OP1_2_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20013\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(22),
datad => \GRFPC0.MEM.RREG.RES\(22));
\GRFPC0_OP1_1_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19947\,
dataf => \FPO.RES\(22),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(22));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_27_3198_I_A3_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000f003300ff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_27_3198_I_A3_0\,
dataf => N_99904_2,
datae => \GRFPU0.GRFPU_X0.N_400\,
datad => \GRFPC0.DIV.RESULT_0_0_13__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(13),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(13));
\GRFPC0_WRDATA_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(13),
dataf => N_444,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(45),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(13));
\GRFPC0_FP_PIPELINE_WRDATA_3_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(13),
dataf => \GRFPC0.DIV.RESULT\(13),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(13),
datab => \FPO.RES\(13));
\GRFPC0_FP_PIPELINE_WRDATA_3_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(45),
dataf => \GRFPC0.DIV.RESULT\(45),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(45),
datab => \GRFPU0.GRFPU_X0.N_20272_I_0\);
\GRFPC0_OP1_1_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19938\,
dataf => \FPO.RES\(13),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(13));
\GRFPC0_OP1_2_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20004\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(13),
datad => \GRFPC0.MEM.RREG.RES\(13));
\GRFPC0_OP1_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(13),
dataf => \GRFPC0.N_20267\,
datae => N_99877_0,
datad => \GRFPC0.N_19938\,
datac => N_99878_0,
datab => \GRFPC0.N_20004\);
\GRFPC0_OP1_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(45),
dataf => \GRFPC0.N_20233\,
datae => N_99877,
datad => \GRFPC0.N_20167\,
datac => \GRFPC0.RFA2.RS1SEL_0\(7),
datab => \GRFPC0.N_20102\);
\GRFPC0_OP1_4_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20167\,
dataf => N_99879_0,
datae => N_640,
datad => N_704);
\GRFPC0_OP1_3_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20102\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(45),
datad => \GRFPC0.WR.RREG.RES\(45));
GRFPC0_MEM_CTRL_PEND_RNO_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000030f")
port map (
combout => \GRFPC0.MEM.CTRL.PEND_0_0_G2_2\,
dataf => \GRFPC0.MEM.CTRL.LD\,
datae => \GRFPC0.MEM.CTRL.VCNT\(1),
datad => \GRFPC0.MEM.CTRL.VCNT\(0),
datac => \GRFPC0.DIV.EXC_MB_2_I_0\,
datab => N_39);
GRFPC0_MEM_CTRL_PEND_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000030303000")
port map (
combout => \GRFPC0.MEM.CTRL.PEND_0_0_N_5\,
dataf => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datae => \GRFPC0.N_23696\,
datad => \GRFPC0.N_23699\,
datac => \GRFPC0.MEM.CTRL.PEND\,
datab => \GRFPC0.DIV.EXC_MB_2_I_0\);
GRFPC0_MEM_CTRL_PEND_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc00ffff0000")
port map (
combout => \GRFPC0.MEM.CTRL.PEND_0_0_G1\,
dataf => CPO_EXCZ,
datae => \GRFPC0.MEM.CTRL.PEND_0_0_N_5\,
datad => \GRFPC0.MEM.CTRL.PEND_0_0_G2_2\,
datac => \GRFPC0.MEM.CTRL.RDWR\,
datab => \GRFPC0.MEM.CTRL.CCWR\);
GRFPC0_V_STDATA_0_SQMUXA_2_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ff00000000")
port map (
combout => \GRFPC0.N_19\,
dataf => \GRFPC0.N_23712\,
datae => N_249,
datad => N_248);
\GRFPC0_R_FSR_FTT_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c0c0c00000f00")
port map (
combout => \GRFPC0.R.FSR.FTT_0_0_0__G1\,
dataf => \GRFPC0.V.FSR.FTT_1_SQMUXA_2\,
datae => \GRFPC0.V.FSR.FTT_1_SQMUXA_1\,
datad => \GRFPC0.V.FSR.FTT_2_SQMUXA\,
datac => \GRFPC0.WR2.CTRL.SEQERR\,
datab => \GRFPC0.R.FSR.FTT\(0));
GRFPC0_V_FSR_CEXC_0_SQMUXA_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000f00000")
port map (
combout => \GRFPC0.V.FSR.CEXC_0_SQMUXA_0\,
dataf => \GRFPC0.FP_PIPELINE.UN11_FPEXC\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datad => N_44718_1,
datac => \GRFPC0.WR2.RREG.EXCT\(5));
GRFPC0_V_FSR_FTT_1_SQMUXA_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccc000c000c000")
port map (
combout => \GRFPC0.V.FSR.FTT_1_SQMUXA_1\,
dataf => \GRFPC0.FP_PIPELINE.V.STATE6\,
datae => \GRFPC0.V.FSR.CEXC_0_SQMUXA_0\,
datad => N_44718_1,
datac => \GRFPC0.DIV.EXCT\(5),
datab => N_35);
GRFPC0_V_FSR_FTT_1_SQMUXA_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cc0c0000")
port map (
combout => \GRFPC0.V.FSR.FTT_1_SQMUXA_2\,
dataf => N_46992,
datae => \GRFPC0.V.FSR.FTT_1_SQMUXA_2_1_0\,
datad => \GRFPC0.WR2.CTRL.LD\,
datac => \GRFPC0.WR2.CTRL.AFSR\,
datab => N_35);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(44),
dataf => \GRFPU0.GRFPU_X0.N_21\,
datae => \GRFPU0.GRFPU_X0.N_18746\,
datad => \FPI.OP1\(47),
datac => \FPI.OP1\(44));
\GRFPC0_OP1_4_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20169\,
dataf => N_99879_0,
datae => N_642,
datad => N_706);
\GRFPC0_OP1_3_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_20104\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(47),
datad => \GRFPC0.WR.RREG.RES\(47));
\GRFPC0_OP1_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffc0c0000fc0c")
port map (
combout => \FPI.OP1\(47),
dataf => \GRFPC0.N_20235\,
datae => N_99877,
datad => \GRFPC0.N_20169\,
datac => \GRFPC0.RFA2.RS1SEL_0\(7),
datab => \GRFPC0.N_20104\);
GRFPC0_V_FSR_NONSTD_0_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.V.FSR.NONSTD_0_SQMUXA\,
dataf => \GRFPC0.WR2.CTRL.LD\,
datae => \GRFPC0.WR2.CTRL.AFSR\);
\GRFPC0_WRDATA_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(15),
dataf => N_446,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(47),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(15));
\GRFPC0_FP_PIPELINE_WRDATA_3_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(47),
dataf => \GRFPC0.DIV.RESULT\(47),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(47),
datab => \GRFPU0.GRFPU_X0.N_19240_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(15),
dataf => \GRFPC0.DIV.RESULT\(15),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(15),
datab => \FPO.RES\(15));
GRFPC0_V_FSR_FTT_1_SQMUXA_2_1_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff000000ffff")
port map (
combout => \GRFPC0.V.FSR.FTT_1_SQMUXA_2_1_0\,
dataf => \GRFPC0.FP_PIPELINE.UN25_HOLDN_1\,
datae => \GRFPC0.DIV.VALID\,
datad => \GRFPC0.WR2.CTRL.LD\);
\GRFPC0_MEM_CTRL_VCNT_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.MEM.CTRL.VCNT_0_0_0__G1\,
dataf => \GRFPC0.EX.CTRL.VCNT\(1),
datae => \GRFPC0.EX.CTRL.VCNT\(0));
GRFPC0_FP_PIPELINE_ORV_TMP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.ORV.TMP\,
dataf => \GRFPC0.EX.CTRL.VCNT\(0),
datae => \GRFPC0.EX.CTRL.VCNT\(1));
\GRFPC0_MEM_CTRL_VCNT_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.MEM.CTRL.VCNT_0_0_1__G1\,
dataf => \GRFPC0.EX.CTRL.VCNT\(1),
datae => \GRFPC0.EX.CTRL.VCNT\(0));
GRFPC0_FP_PIPELINE_UN1_HOLDN_6_4_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_HOLDN_6_4_0\,
dataf => \GRFPC0.FIFO.FULL\,
datae => N_112,
datad => N_113);
GRFPC0_FP_PIPELINE_CNTX14_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000f00003333")
port map (
combout => \GRFPC0.FP_PIPELINE.CNTX14_0\,
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.VCNT_0\(0),
datad => \GRFPC0.FIFO.VCNT_1\(0),
datac => \GRFPC0.FIFO.VCNT_1\(2),
datab => \GRFPC0.FIFO.VCNT_0\(2));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_250\,
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.PC_0\(19),
datad => \GRFPC0.FIFO.PC_1\(19));
GRFPC0_EX_CTRL_PEND_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f000000000")
port map (
combout => \GRFPC0.EX.CTRL.PEND_0_0_G2_3\,
dataf => \GRFPC0.EX.CTRL.PEND_0_0_G2_1\,
datae => \GRFPC0.EX.CTRL.RDWR\,
datad => \GRFPC0.EX.CTRL.LD\,
datac => \GRFPC0.EX.CTRL.CCWR\);
GRFPC0_FP_PIPELINE_FPUSTART_7_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff0000ffff")
port map (
combout => \FPI.START_3\,
dataf => \GRFPC0.RFA.READ_RS1\,
datae => \GRFPC0.RFA2.RS2DEP\,
datad => \GRFPC0.RFA2.RS1DEP\);
GRFPC0_FP_PIPELINE_UN6_FIFOV: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN6_FIFOV\,
dataf => \GRFPC0.RFA.LD\,
datae => \GRFPC0.RFA.ST\);
GRFPC0_FP_PIPELINE_FPUSTART_7_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccccccf0ccf0")
port map (
combout => \FPI.START_1\,
dataf => \GRFPC0.RFA2.FOP\(0),
datae => \GRFPC0.FPR.ALLOW\(1),
datad => \GRFPC0.RFA2.FOP\(1),
datac => \GRFPC0.FPR.ALLOW\(2),
datab => \GRFPC0.FPR.ALLOW\(0));
\GRFPC0_EX_CTRL_ID_RNO_1_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000f0fff0ff")
port map (
combout => N_45188,
dataf => \GRFPC0.RFA2.FOP\(0),
datae => \GRFPC0.FPR.ALLOW\(1),
datad => \GRFPC0.RFA2.FOP\(1),
datac => \GRFPC0.FPR.ALLOW\(0));
GRFPC0_VWR2_CTRL_PEND_0_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000000000000000")
port map (
combout => \GRFPC0.VWR2.CTRL.PEND_0_SQMUXA\,
dataf => N_459,
datae => N_423,
datad => N_424,
datac => N_425);
GRFPC0_FP_PIPELINE_VDIV_VALID_7_F1_A0_C: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID_7_F1_A0_C\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.VALID2_0\,
datae => \GRFPC0.DIV.VALID\);
GRFPC0_RFA2_DIVLCK_RNIN5H8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => N_45196_1,
dataf => \GRFPC0.RFA.WRITE_RD\,
datae => \GRFPC0.RFA2.DIVLCK\);
GRFPC0_DIV_PEND_RNO: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffcccc0000ccc0")
port map (
combout => N_27009,
dataf => \GRFPC0.DIV.PEND_0_0_G5\,
datae => \GRFPC0.DIV.PEND_0_0_N_5\,
datad => \GRFPC0.N_23687\,
datac => \GRFPC0.N_23694\,
datab => \GRFPC0.DIV.PEND\);
GRFPC0_DIV_PEND_RNO_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c000f300")
port map (
combout => \GRFPC0.DIV.PEND_0_0_G5\,
dataf => \GRFPC0.N_23746\,
datae => N_44718_1,
datad => \GRFPC0.DIV.PEND_0_0_G5_0\,
datac => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datab => \GRFPC0.WR2.CTRL.SEQERR\);
GRFPC0_DIV_PEND_RNO_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffcfffffcfc")
port map (
combout => \GRFPC0.DIV.PEND_0_0_N_5\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => N_44718_1,
datad => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datac => \GRFPC0.WR2.CTRL.SEQERR\,
datab => \GRFPC0.DIV.EXC_MB_2_I_0\);
GRFPC0_UN1_WR2_EXC_I_O4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffff00f0")
port map (
combout => \GRFPC0.N_23712\,
dataf => \GRFPC0.DIV.PEND\,
datae => \GRFPC0.WR2.EXC\,
datad => \GRFPC0.DIV.EXC\,
datac => \GRFPC0.WR2.CTRL.PEND\);
GRFPC0_UN1_DIV_EXC_I_A4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffffff0000")
port map (
combout => N_99867,
dataf => \GRFPC0.DIV.PEND\,
datae => \GRFPC0.DIV.EXC\,
datad => \GRFPC0.WR2.EXC\);
GRFPC0_FP_PIPELINE_VWR2_EXC_1_IV_I_O2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0fffffff")
port map (
combout => \GRFPC0.N_23694\,
dataf => \GRFPC0.WR2.CNT\(0),
datae => \GRFPC0.WR2.CTRL.STDFQ\,
datad => \GRFPC0.WR2.CNT\(1),
datac => N_37);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(48),
dataf => \GRFPU0.GRFPU_X0.N_21\,
datae => \GRFPU0.GRFPU_X0.N_18746\,
datad => \FPI.OP1\(51),
datac => \FPI.OP1\(48));
\GRFPU0_GRFPU_X0_ST1_CCSEL_RNO_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3333f30c0000c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_13447\,
dataf => \GRFPU0.GRFPU_X0.UN1_RAW1\(0),
datae => \GRFPU0.GRFPU_X0.N_18838\,
datad => \FPI.OP1\(52),
datac => \FPI.OP2\(52),
datab => \FPI.FLOP\(1));
\GRFPU0_GRFPU_X0_UN1_DP_0_X2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18838\,
dataf => \FPI.OP1\(53),
datae => \FPI.OP2\(53));
\GRFPU0_GRFPU_X0_UN1_RAW1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0000f0f00f000")
port map (
combout => \GRFPU0.GRFPU_X0.UN1_RAW1\(0),
dataf => \FPI.OP2\(55),
datae => \FPI.OP2\(56),
datad => \FPI.OP1\(55),
datac => \FPI.OP1\(56));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(49),
dataf => \GRFPU0.GRFPU_X0.N_21\,
datae => \GRFPU0.GRFPU_X0.N_18746\,
datad => \FPI.OP1\(52),
datac => \FPI.OP1\(49));
GRFPU0_GRFPU_X0_UN1_VST1_ID3_2_0_O2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18882_1\,
dataf => \FPI.OP2\(52),
datae => \FPI.OP2\(53));
\GRFPC0_FP_PIPELINE_WRDATA_3_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(61),
dataf => \GRFPC0.DIV.RESULT\(61),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(61),
datab => \FPO.RES\(61));
\GRFPC0_OP1_1_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19986\,
dataf => \FPO.RES\(61),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(61));
\GRFPC0_OP1_2_61_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20052\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(61),
datad => \GRFPC0.MEM.RREG.RES\(61));
\GRFPU0_GRFPU_X0_UN38_EXP_M_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcff3000fc0030")
port map (
combout => \FPI.OP2\(58),
dataf => \GRFPC0.N_19751\,
datae => \GRFPC0.N_19685\,
datad => N_99880,
datac => \GRFPC0.N_19620\,
datab => \GRFPC0.RFA2.RS2SEL\(7));
\GRFPC0_OP2_3_58_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19620\,
dataf => \GRFPC0.RFA2.RS2SEL_0\(1),
datae => \GRFPC0.EX.RREG.RES\(58),
datad => \GRFPC0.WR.RREG.RES\(58));
GRFPC0_FP_PIPELINE_RSDEC_RS1V12_I_O2_I_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_23795\,
dataf => \GRFPC0.N_23631\,
datae => \GRFPC0.INST\(9));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M3_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_23982\,
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.PC_0\(8),
datad => \GRFPC0.FIFO.PC_1\(8));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(25),
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.PC_0\(25),
datad => \GRFPC0.FIFO.PC_1\(25));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M1_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M1\(23),
dataf => \GRFPC0.N_23667\,
datae => \GRFPC0.WR.CTRL.INST\(23),
datad => \GRFPC0.WR.CTRL.PC\(23));
\GRFPC0_FP_PIPELINE_V_STDATA_1_M6_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ffcc00f000cc")
port map (
combout => \GRFPC0.FP_PIPELINE.V.STDATA_1_M6\(23),
dataf => \GRFPC0.FP_PIPELINE.V.STDATA_1_M5\(23),
datae => \GRFPC0.N_23669\,
datad => \GRFPC0.FP_PIPELINE.V.STDATA_1_SM4\,
datac => \GRFPC0.MEM.CTRL.INST\(23),
datab => \GRFPC0.MEM.CTRL.PC\(23));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.VEX.CTRL.PC_3\(23),
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.PC_0\(23),
datad => \GRFPC0.FIFO.PC_1\(23));
\GRFPC0_FP_PIPELINE_VFIFO_RD_3_I_O2_0_X2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPC0.N_23766\,
dataf => \FPI.START\,
datae => \GRFPC0.FIFO.RD_3\(0));
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"030f33ff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\,
dataf => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_3_2\,
datae => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
datad => \FPO.EXC\(0),
datac => \GRFPC0.R.FSR.TEM\(3),
datab => \GRFPC0.R.FSR.TEM\(0));
GRFPC0_FP_PIPELINE_UN11_FPEXC: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN11_FPEXC\,
dataf => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC\,
datae => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datad => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datac => \GRFPC0.FPO_I_6_I_0\(69),
datab => \GRFPC0.FPR.RDY\);
GRFPC0_V_FSR_CEXC_2_SQMUXA_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.V.FSR.CEXC_3_SQMUXA_3\,
dataf => \GRFPC0.FP_PIPELINE.UN11_FPEXC\,
datae => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datad => N_44718_1,
datac => \GRFPC0.WR2.RREG.EXCT\(5));
GRFPC0_UN1_VFIFO_VCNT_0_1_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccfcff0000f0ff")
port map (
combout => \GRFPC0.UN1_VFIFO.VCNT_0_1_SQMUXA\,
dataf => CPO_EXCZ,
datae => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datac => \GRFPC0.FP_PIPELINE.0.UN78_PENDEXC\,
datab => N_35);
GRFPC0_UN1_VFIFO_VCNT_1_1_SQMUXA: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccfcff0000f0ff")
port map (
combout => \GRFPC0.UN1_VFIFO.VCNT_1_1_SQMUXA\,
dataf => CPO_EXCZ,
datae => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datad => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datac => \GRFPC0.FP_PIPELINE.1.UN87_PENDEXC\,
datab => N_35);
GRFPC0_FP_PIPELINE_1_UN87_PENDEXC: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPC0.FP_PIPELINE.1.UN87_PENDEXC\,
dataf => \GRFPC0.FIFO.VCNT_1\(0),
datae => \GRFPC0.FIFO.VCNT_1\(2),
datad => \GRFPC0.FIFO.VCNT_1\(1));
GRFPC0_FP_PIPELINE_0_UN78_PENDEXC: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN78_PENDEXC\,
dataf => \GRFPC0.FIFO.VCNT_0\(0),
datae => \GRFPC0.FIFO.VCNT_0\(1),
datad => \GRFPC0.FIFO.VCNT_0\(2));
\GRFPC0_FP_PIPELINE_8_0_REGDEPX_149_0_A2_2_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.N_23963\,
dataf => \GRFPC0.FIFO.INST_0\(17),
datae => \GRFPC0.FIFO.INST_0\(16));
\GRFPC0_FP_PIPELINE_11_0_REGDEPX_203_0_A2_0_I_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_23923\,
dataf => \GRFPC0.FIFO.INST_0\(18),
datae => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_FP_PIPELINE_9_REGDEPX_174_0_A4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000f33300000000")
port map (
combout => \GRFPC0.N_24957\,
dataf => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.9.0.CHECK_DEP.DEP_2_I\(0),
datad => \GRFPC0.N_24921\,
datac => \GRFPC0.FP_PIPELINE.9.REGDEPX_174_0_A2_0_1\(0),
datab => \GRFPC0.FIFO.INST_0\(19));
GRFPC0_FP_PIPELINE_0_STDDEP_26_IV_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000c0000000c000")
port map (
combout => \GRFPC0.N_21391\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_14\(0),
datad => \GRFPC0.N_505\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP\,
datab => \GRFPC0.EX.CTRL.RDWR\);
GRFPC0_FP_PIPELINE_11_1_CHECK_DEP_UN3616_REGDEPX_1_I_O4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_24936\,
dataf => \GRFPC0.FIFO.INST_1\(26),
datae => \GRFPC0.FIFO.INST_1\(27));
\GRFPC0_FP_PIPELINE_14_STDEP_568_3_0_O2_0_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_23802\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_9_1_CHECK_DEP_DEP_2_IV_0_A4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0f0f00000000")
port map (
combout => N_40557,
dataf => \GRFPC0.N_22237\,
datae => \GRFPC0.FIFO.INST_1\(12),
datad => \GRFPC0.FIFO.INST_1\(8),
datac => \GRFPC0.FIFO.INST_1\(25));
\GRFPC0_FIFO_INST_1_RNI7BKF2_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00f0f0f000000000")
port map (
combout => N_99871,
dataf => \GRFPC0.N_22237\,
datae => \GRFPC0.FIFO.INST_1\(12),
datad => \GRFPC0.FIFO.INST_1\(8),
datac => \GRFPC0.FIFO.INST_1\(25));
\GRFPC0_FP_PIPELINE_12_CHECK_DEP_DEP_7_0_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_482\,
dataf => \GRFPC0.N_579\,
datae => \GRFPC0.MEM.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_8_CHECK_DEP_DEP_15_I_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcffffffffff")
port map (
combout => \GRFPC0.N_15\,
dataf => \GRFPC0.N_482\,
datae => \GRFPC0.MEM.CTRL.RD\(2),
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_8_CHECK_DEP_DEP_15_I_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcffffffffff")
port map (
combout => \GRFPC0.N_13\,
dataf => \GRFPC0.N_470\,
datae => \GRFPC0.MEM.CTRL.RD\(2),
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(3));
GRFPC0_DEP_1_SQMUXA_88_0_A3_0_I2_1_I2_0_0_I_O2_RNI145H_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FIFO.INST_0_I_M_11\(25),
dataf => \GRFPC0.N_22777\,
datae => \GRFPC0.FIFO.INST_0\(25));
GRFPC0_DEP_1_SQMUXA_88_0_A3_0_I2_1_I2_0_0_I_O2_RNI145H: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FIFO.INST_0_M_11\(25),
dataf => \GRFPC0.N_22777\,
datae => \GRFPC0.FIFO.INST_0\(25));
\GRFPC0_FP_PIPELINE_12_0_REGDEPX_221_0_O2_I_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_24926\,
dataf => \GRFPC0.FIFO.INST_0\(6),
datae => \GRFPC0.FIFO.INST_0\(0));
GRFPC0_STDDEP_0_SQMUXA_87_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_87_1\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.FIFO.INST_1\(29),
datad => \GRFPC0.FIFO.INST_1\(28),
datac => \GRFPC0.FIFO.INST_1\(26),
datab => \GRFPC0.FIFO.INST_1\(27));
GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_UN97_REGDEPX_2_0_A2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN97_REGDEPX_2\,
dataf => \GRFPC0.FIFO.INST_0\(3),
datae => \GRFPC0.FIFO.INST_0\(4));
\GRFPC0_FP_PIPELINE_7_0_CHECK_DEP_DEP_1_I_O2_0_I_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_25011\,
dataf => \GRFPC0.FIFO.INST_0\(3),
datae => \GRFPC0.FIFO.INST_0\(4));
GRFPC0_FP_PIPELINE_6_1_CHECK_DEP_UN2072_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2072_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(17),
datae => \GRFPC0.FIFO.INST_1\(18),
datad => \GRFPC0.FIFO.INST_1\(15),
datac => \GRFPC0.FIFO.INST_1\(16));
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O3_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00ffff00")
port map (
combout => \GRFPC0.N_21626\,
dataf => \GRFPC0.FIFO.INST_1\(19),
datae => \GRFPC0.FIFO.INST_1\(12),
datad => \GRFPC0.FIFO.INST_1\(11));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_89_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffeac0")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_89\(1),
dataf => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85\(1),
datae => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_15\(1),
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_8\(1),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
datab => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1300_REGDEPX2\,
dataa => \GRFPC0.DIV.RS1V\);
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1271_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1271_REGDEPX2\,
dataf => \GRFPC0.WR2.CTRL.INST\(15),
datae => \GRFPC0.WR2.CTRL.INST\(16),
datad => \GRFPC0.WR2.CTRL.INST\(18),
datac => \GRFPC0.WR2.CTRL.INST\(17));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1257_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1257_REGDEPX2\,
dataf => \GRFPC0.WR2.CTRL.INST\(29),
datae => \GRFPC0.WR2.CTRL.INST\(28),
datad => \GRFPC0.WR2.CTRL.INST\(26),
datac => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_83_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffeca0cc00")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_83\(1),
dataf => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80\(1),
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(1),
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1271_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1257_REGDEPX2\,
dataa => \GRFPC0.WR2.CTRL.RS1V\);
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1286_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1286_REGDEPX2\,
dataf => \GRFPC0.WR2.CTRL.INST\(1),
datae => \GRFPC0.WR2.CTRL.INST\(2),
datad => \GRFPC0.WR2.CTRL.INST\(4),
datac => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_20_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000030")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_20\(1),
dataf => \GRFPC0.N_705\,
datae => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(18),
datac => \GRFPC0.WR.CTRL.INST\(16),
datab => \GRFPC0.WR.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_21_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_21\(1),
dataf => \GRFPC0.N_707\,
datae => \GRFPC0.WR.CTRL.INST\(26),
datad => \GRFPC0.WR.CTRL.INST\(29),
datac => \GRFPC0.WR.CTRL.INST\(28),
datab => \GRFPC0.WR.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_5_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_5\(1),
dataf => \GRFPC0.N_703\,
datae => \GRFPC0.WR.CTRL.INST\(4),
datad => \GRFPC0.WR.CTRL.INST\(3),
datac => \GRFPC0.WR.CTRL.INST\(1),
datab => \GRFPC0.WR.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_A2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_25687\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN695_REGDEPX2_2\,
datad => \GRFPC0.EX.CTRL.INST\(15),
datac => \GRFPC0.EX.CTRL.INST\(16),
datab => \GRFPC0.N_24327\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_0\(1),
dataf => \GRFPC0.N_25687\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datad => \GRFPC0.N_25460\,
datac => \GRFPC0.N_24189\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_65_0_A2_0_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_8_0\(1),
dataf => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_O2_2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffcfffccff0fff00")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_O2_2_1\(1),
dataf => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_A2_8_0\(1),
datae => \GRFPC0.FP_PIPELINE.2.REGDEPX2_65_0_A2_0\(0),
datad => \GRFPC0.N_25727\,
datac => \GRFPC0.V.STDATA_14_I_M_10\(0),
datab => \GRFPC0.N_24484\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_80_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcccccc80")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80\(1),
dataf => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75\(1),
datae => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_5\(1),
datad => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_21\(1),
datac => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_20\(1),
datab => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
dataa => \GRFPC0.WR.CTRL.RS1V\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_85_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00c0ffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_85\(1),
dataf => \GRFPC0.FP_PIPELINE.2.REGDEPX2_83\(1),
datae => \GRFPC0.FP_PIPELINE.2.REGDEPX2_80\(1),
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(1),
datab => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1286_REGDEPX2\);
\GRFPC0_FP_PIPELINE_2_CHECK_DEP_DEP_15_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.DEP_15\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datae => \GRFPC0.DIV.INST\(2),
datad => \GRFPC0.DIV.INST\(3),
datac => \GRFPC0.DIV.INST\(1),
datab => \GRFPC0.DIV.INST\(4));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1300_REGDEPX2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f00")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1300_REGDEPX2\,
dataf => \GRFPC0.DIV.RD\(3),
datae => \GRFPC0.DIV.RD\(4),
datad => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.DIV.RD\(1));
GRFPC0_FP_PIPELINE_7_CHECK_DEP_UN2334_DEP_0_A3_1_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffffffffffffff")
port map (
combout => \GRFPC0.N_21817\,
dataf => \GRFPC0.WR.CTRL.RD\(3),
datae => \GRFPC0.WR.CTRL.RD\(2),
datad => \GRFPC0.WR.CTRL.RD\(1),
datac => \GRFPC0.WR.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_12_STDEP_492_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffffff00c033c0")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_492\(1),
dataf => \GRFPC0.FP_PIPELINE.12.STDEP_488\(1),
datae => \GRFPC0.N_104\,
datad => \GRFPC0.N_18814\,
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_13_4\,
datab => \GRFPC0.N_470\);
\GRFPC0_WR_CTRL_RD_RNIVS202_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fffffffffffff")
port map (
combout => \GRFPC0.N_21241\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_11_STDEP_448_SEL0_0_1_I_O3_0_O3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff3fffffffffff")
port map (
combout => \GRFPC0.N_21725\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_0_STDEP_362_0_IV_I_A3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_21192\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(0),
datae => \GRFPC0.RFA.LD\,
datad => N_174,
datac => \GRFPC0.N_801\,
datab => N_173);
\GRFPC0_FP_PIPELINE_8_STDEP_350_0_IV_I_A4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000300000")
port map (
combout => \GRFPC0.N_22282\,
dataf => \GRFPC0.FIFO.INST_0_M_11\(25),
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_24935\,
datac => \GRFPC0.N_23961\,
datab => \GRFPC0.FIFO.INST_0\(19));
GRFPC0_STDDEP_0_SQMUXA_115_1_0_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00ffff")
port map (
combout => \GRFPC0.N_24819\,
dataf => \GRFPC0.FIFO.INST_0\(26),
datae => \GRFPC0.FIFO.INST_0\(27),
datad => \GRFPC0.FIFO.INST_0\(28));
\GRFPC0_FIFO_INST_0_RNI73OP_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_23522_I_1\,
dataf => \GRFPC0.FIFO.INST_0\(19),
datae => \GRFPC0.FIFO.INST_0\(29));
GRFPC0_FP_PIPELINE_0_0_IS_RS1V_TMP_I_O2_I_O2_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00ffff00")
port map (
combout => \GRFPC0.N_24921\,
dataf => \GRFPC0.FIFO.INST_0\(19),
datae => \GRFPC0.FIFO.INST_0\(11),
datad => \GRFPC0.FIFO.INST_0\(12));
\GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_DEP_2_1_I_O3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_22427\,
dataf => \GRFPC0.FIFO.INST_0\(6),
datae => \GRFPC0.FIFO.INST_0\(14));
GRFPC0_FP_PIPELINE_2_0_CHECK_DEP_UN735_REGDEPX_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.0.CHECK_DEP.UN735_REGDEPX_1\,
dataf => \GRFPC0.FIFO.INST_0\(2),
datae => \GRFPC0.FIFO.INST_0\(1));
\GRFPC0_FP_PIPELINE_11_0_REGDEPX_203_0_A2_1_A2_0_A2_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_23887\,
dataf => \GRFPC0.FIFO.INST_0\(4),
datae => \GRFPC0.FIFO.INST_0\(3));
\GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_DEP_2_I_O3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_22429\,
dataf => \GRFPC0.FIFO.INST_0\(6),
datae => \GRFPC0.FIFO.INST_0\(0));
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_I_A2_0_0_A3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_21948_1\,
dataf => \GRFPC0.N_114\,
datae => \GRFPC0.WR.CTRL.RDD\);
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_0_O2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcffffffffff")
port map (
combout => \GRFPC0.N_23808\,
dataf => \GRFPC0.N_494\,
datae => \GRFPC0.N_469\,
datad => \GRFPC0.WR.CTRL.RDWR\,
datac => \GRFPC0.WR.CTRL.RD\(3),
datab => \GRFPC0.WR.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN2644_DEP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2644_DEP\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2));
\GRFPC0_FP_PIPELINE_8_STDEP_332_3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00fff0ff00ffc0")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_332\(0),
dataf => \GRFPC0.N_22173_I\,
datae => \GRFPC0.N_362\,
datad => \GRFPC0.FP_PIPELINE.8.STDEP_332_1\(0),
datac => \GRFPC0.FP_PIPELINE.8.STDEP_332_3_0_A2_1_1\(0),
datab => \GRFPC0.N_458\);
\GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_DEP_2_1_I_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_22250\,
dataf => \GRFPC0.FIFO.INST_1\(6),
datae => \GRFPC0.FIFO.INST_1\(14));
\GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_DEP_2_1_I_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_22243\,
dataf => \GRFPC0.FIFO.INST_1\(6),
datae => \GRFPC0.FIFO.INST_1\(14));
\GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_DEP_2_I_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_22252\,
dataf => \GRFPC0.FIFO.INST_1\(6),
datae => \GRFPC0.FIFO.INST_1\(0));
\GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_DEP_2_I_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_22253\,
dataf => \GRFPC0.FIFO.INST_1\(6),
datae => \GRFPC0.FIFO.INST_1\(0));
\GRFPC0_V_STDATA_14_I_M2_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \FPI.FLOP\(1),
dataf => \GRFPC0.FIFO.INST_0\(6),
datae => \GRFPC0.FIFO.INST_1\(6),
datad => \GRFPC0.FIFO.RD\(0));
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN3424_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3424_REGDEPX\,
dataf => N_95,
datae => N_93,
datad => N_96,
datac => N_94);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_0_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_24818\,
dataf => N_84,
datae => N_92);
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN3439_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.10.CHECK_DEP.UN3439_REGDEPX\,
dataf => N_81,
datae => N_79,
datad => N_82,
datac => N_80);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O2_1_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_24820\,
dataf => N_84,
datae => N_78);
GRFPC0_FP_PIPELINE_6_CHECK_DEP_UN2176_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2176_REGDEPX\,
dataf => N_96,
datae => N_93,
datad => N_95,
datac => N_94);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O3_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_23976\,
dataf => N_84,
datae => N_92);
GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_UN207_REGDEPX_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => \GRFPC0.N_25085\,
dataf => \GRFPC0.FIFO.INST_1\(2),
datae => \GRFPC0.FIFO.INST_1\(4),
datad => \GRFPC0.FIFO.INST_1\(1));
\GRFPC0_FP_PIPELINE_7_1_CHECK_DEP_DEP_0_A2_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_25010\,
dataf => \GRFPC0.FIFO.INST_1\(4),
datae => \GRFPC0.FIFO.INST_1\(1));
GRFPC0_FP_PIPELINE_0_1_CHECK_DEP_UN207_REGDEPX_2_0_A4_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.2.1.CHECK_DEP.UN839_REGDEPX_2\,
dataf => \GRFPC0.FIFO.INST_1\(3),
datae => \GRFPC0.FIFO.INST_1\(4));
GRFPC0_FP_PIPELINE_11_1_CHECK_DEP_UN3647_REGDEPX_1_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_24911\,
dataf => \GRFPC0.FIFO.INST_1\(2),
datae => \GRFPC0.FIFO.INST_1\(1));
GRFPC0_FP_PIPELINE_13_1_CHECK_DEP_UN4271_REGDEPX_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1775_REGDEPX_1\,
dataf => \GRFPC0.FIFO.INST_1\(3),
datae => \GRFPC0.FIFO.INST_1\(1));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN4687_REGDEPX_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2191_REGDEPX_1\,
dataf => N_80,
datae => N_81);
GRFPC0_FP_PIPELINE_6_CHECK_DEP_UN2191_REGDEPX_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2191_REGDEPX_0\,
dataf => N_79,
datae => N_82);
\GRFPC0_FP_PIPELINE_VD_LDLCK_1_0_O3_0_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_23978\,
dataf => N_78,
datae => N_84);
GRFPC0_FP_PIPELINE_8_STDEP_332_SEL0_0_1_0_O4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffcffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.8.STDEP_332_SEL0_1\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(2),
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_2_STDEP_92_3_I_0_O3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccffffffcfffffff")
port map (
combout => \GRFPC0.N_22718\,
dataf => \GRFPC0.N_22173_I\,
datae => \GRFPC0.N_805\,
datad => \GRFPC0.N_481\,
datac => \GRFPC0.N_458\,
datab => \GRFPC0.FP_PIPELINE.2.STDEP_92_3_0_O2_2_0\(1));
GRFPC0_STDDEP_0_SQMUXA_54: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.N_18814\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_54_0\,
datae => \GRFPC0.MEM.CTRL.RD\(2),
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPC0_MEM_CTRL_RD_RNIBEDQ_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000c0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_13_4\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(2),
datad => \GRFPC0.MEM.CTRL.RD\(4),
datac => \GRFPC0.MEM.CTRL.RD\(1),
datab => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_14_CHECK_DEP_DEP_16_I_I2_0_S_0_O3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_469\,
dataf => \GRFPC0.WR.CTRL.RD\(1),
datae => \GRFPC0.WR.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN3956_DEP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.12.CHECK_DEP.UN3956_DEP\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2));
\GRFPC0_FP_PIPELINE_12_STDEP_492_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33ffffff00c0ccc0")
port map (
combout => \GRFPC0.FP_PIPELINE.12.STDEP_492\(0),
dataf => \GRFPC0.FP_PIPELINE.12.STDEP_488\(0),
datae => \GRFPC0.N_104\,
datad => \GRFPC0.N_18814\,
datac => \GRFPC0.FP_PIPELINE.0.RESV10_I_M_13_4\,
datab => \GRFPC0.N_470\);
\GRFPC0_FP_PIPELINE_15_STDEP_604_0_IV_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000c0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.15.STDEP_604\(0),
dataf => \GRFPC0.N_22173_I\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datad => \GRFPC0.N_481\,
datac => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4940_DEP\,
datab => \GRFPC0.N_458\);
GRFPC0_FP_PIPELINE_9_CHECK_DEP_UN2972_DEP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000f000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN2972_DEP\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2));
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN1368_DEP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\,
dataf => \GRFPC0.MEM.CTRL.RD\(2),
datae => \GRFPC0.MEM.CTRL.RD\(4),
datad => \GRFPC0.MEM.CTRL.RD\(1),
datac => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_4_STDEP_172_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3fffff003f00ff")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_172\(0),
dataf => \GRFPC0.FP_PIPELINE.4.STDEP_168\(0),
datae => \GRFPC0.N_104\,
datad => \GRFPC0.FP_PIPELINE.4.STDEP_172_SEL0\,
datac => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN1368_DEP\,
datab => \GRFPC0.STDDEP_0_SQMUXA_54_0\);
GRFPC0_FP_PIPELINE_4_1_CHECK_DEP_UN1432_REGDEPX_2_0_A2_RNIAM3J1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_22689\,
dataf => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datae => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX_2\,
datad => \GRFPC0.FIFO.INST_1\(19),
datac => \GRFPC0.FIFO.INST_1\(28),
datab => \GRFPC0.FIFO.INST_1\(26));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_4_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000f0")
port map (
combout => \GRFPC0.N_9477\,
dataf => N_105,
datae => N_104,
datad => N_107,
datac => N_106);
GRFPC0_STDDEP_0_SQMUXA_14_I_0_O4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_14_I_1\,
dataf => \GRFPC0.RFA.LD\,
datae => N_175,
datad => N_173,
datac => N_176,
datab => N_174);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_17_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(0),
dataf => \GRFPC0.RFA.RDD\,
datae => N_172);
\GRFPC0_FP_PIPELINE_9_STDEP_376_3_I_O3_0_0_O3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff3fffffffff")
port map (
combout => \GRFPC0.N_500\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_0_UN1_FPO_7_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_1\,
dataf => \FPO.IDOUT\(0),
datae => \FPO.IDOUT\(4),
datad => \GRFPC0.WR.CTRL.ID\(0),
datac => \GRFPC0.WR.CTRL.ID\(4));
GRFPC0_FP_PIPELINE_0_UN1_FPO_7_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0300c0300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_4\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_1\,
datae => \FPO.IDOUT\(3),
datad => \FPO.IDOUT\(1),
datac => \GRFPC0.WR.CTRL.ID\(3),
datab => \GRFPC0.WR.CTRL.ID\(1));
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_I_O2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0300ffff0000")
port map (
combout => \GRFPC0.N_114\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_3\,
datae => \GRFPC0.N_173\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_FPO_7_4\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_FPO_2_5\,
datab => \GRFPC0.WR.CTRL.ID\(7));
GRFPC0_FP_PIPELINE_4_STDEP_168_SEL1_I_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_18769\,
dataf => \GRFPC0.STDDEP_0_SQMUXA_58_0_A2_0\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_4_STDEP_168_SEL0_0_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcffffffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL0_1\,
dataf => \GRFPC0.WR.CTRL.RDWR\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(1),
datab => \GRFPC0.WR.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_4_STDEP_168_3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfffffff00303030")
port map (
combout => \GRFPC0.FP_PIPELINE.4.STDEP_168\(0),
dataf => \GRFPC0.FP_PIPELINE.4.STDEP_164\(0),
datae => \GRFPC0.N_114\,
datad => \GRFPC0.N_18769\,
datac => \GRFPC0.N_494\,
datab => \GRFPC0.FP_PIPELINE.4.STDEP_168_SEL0_1\);
\GRFPC0_FP_PIPELINE_3_CHECK_DEP_DEP_19_0_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff000000")
port map (
combout => \GRFPC0.N_23478\,
dataf => N_244,
datae => N_243,
datad => N_242);
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1022_DEP_I_O3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.N_465\,
dataf => \GRFPC0.WR.CTRL.RD\(1),
datae => \GRFPC0.WR.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_13_1_CHECK_DEP_UN4240_REGDEPX_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX_1\,
dataf => \GRFPC0.FIFO.INST_1\(28),
datae => \GRFPC0.FIFO.INST_1\(26));
GRFPC0_FP_PIPELINE_4_1_CHECK_DEP_UN1432_REGDEPX_2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.5.1.CHECK_DEP.UN1744_REGDEPX_2\,
dataf => \GRFPC0.FIFO.INST_1\(29),
datae => \GRFPC0.FIFO.INST_1\(27));
\GRFPC0_FP_PIPELINE_13_0_CHECK_DEP_DEP_2_IV_0_O2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffffffffff")
port map (
combout => \GRFPC0.N_22517\,
dataf => \GRFPC0.FIFO.INST_0\(26),
datae => \GRFPC0.FIFO.INST_0\(27),
datad => \GRFPC0.FIFO.INST_0\(28));
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_O3_6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f00000f3f0033")
port map (
combout => \GRFPC0.N_21617\,
dataf => \GRFPC0.N_543_1\,
datae => \GRFPC0.FP_PIPELINE.0.1.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_22517\,
datac => \GRFPC0.STDDEP_0_SQMUXA_123_I_I_A2_I_O2_0\,
datab => \GRFPC0.FIFO.INST_0\(29));
GRFPC0_FP_PIPELINE_0_STDDEP_48_IV_0_A2_0_I_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_841\,
dataf => \GRFPC0.FP_PIPELINE.0.RESV14_I_1\,
datae => \GRFPC0.N_106_I\);
GRFPC0_STDDEP_0_SQMUXA_13_I_O4_1_0_RNI5L301: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_22606\,
dataf => \GRFPC0.N_594\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => N_245,
datac => N_243,
datab => \GRFPC0.STDDEP_0_SQMUXA_13_I_O4_1_0\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_14_I_O2_I_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_505\,
dataf => \GRFPC0.N_106_I\,
datae => \GRFPC0.EX.CTRL.RD\(0));
GRFPC0_STDDEP_0_SQMUXA_13_I_O4_1_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_13_I_O4_1_0\,
dataf => N_242,
datae => N_244);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_15_I_O2_0_0_I_O2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_21454\,
dataf => \GRFPC0.N_106_I\,
datae => N_241);
\GRFPC0_FP_PIPELINE_0_STDEP_242_0_IV_I_A2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPC0.N_22564\,
dataf => \GRFPC0.N_21454\,
datae => \GRFPC0.EX.CTRL.LD\,
datad => N_245,
datac => N_243,
datab => \GRFPC0.STDDEP_0_SQMUXA_13_I_O4_1_0\);
GRFPC0_FP_PIPELINE_0_STDDEP_268_IV_0_A3_1_I_O2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0ffffffffffffff")
port map (
combout => \GRFPC0.N_467\,
dataf => \GRFPC0.MEM.CTRL.RDWR\,
datae => \GRFPC0.MEM.CTRL.RD\(4),
datad => \GRFPC0.MEM.CTRL.RD\(1),
datac => \GRFPC0.MEM.CTRL.RD\(3));
GRFPC0_FP_PIPELINE_11_STDEP_452_SEL1_I_0_A2_I_I_A3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPC0.N_664\,
dataf => \GRFPC0.N_467\,
datae => \GRFPC0.N_579\,
datad => \GRFPC0.MEM.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_0_STDDEP_136_IV_0_O3_9_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_461\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_DEP\);
GRFPC0_EX_CTRL_LD_RNIA6811_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_22406_I\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_244,
datad => N_243,
datac => N_245,
datab => N_242);
GRFPC0_FP_PIPELINE_6_CHECK_DEP_UN2217_DEP_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.N_661_1\,
dataf => N_174,
datae => N_175);
\GRFPC0_D_STLCK_RNO_4_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0300000000000000")
port map (
combout => \GRFPC0.N_22063\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datae => \GRFPC0.RFA.LD\,
datad => \GRFPC0.N_661_1\,
datac => N_176,
datab => N_173);
GRFPC0_FP_PIPELINE_6_1_CHECK_DEP_UN2056_REGDEPX: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.1.CHECK_DEP.UN2056_REGDEPX\,
dataf => \GRFPC0.FIFO.INST_1\(29),
datae => \GRFPC0.FIFO.INST_1\(28),
datad => \GRFPC0.FIFO.INST_1\(26),
datac => \GRFPC0.FIFO.INST_1\(27));
\GRFPC0_FP_PIPELINE_6_0_STDEP_265_0_IV_I_A2_1_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000c0")
port map (
combout => \GRFPC0.N_22080\,
dataf => \GRFPC0.N_543_1\,
datae => \GRFPC0.FIFO.INST_0\(29),
datad => \GRFPC0.FIFO.INST_0\(26),
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28));
\GRFPC0_FP_PIPELINE_6_0_CHECK_DEP_DEP_2_IV_0_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff3f")
port map (
combout => \GRFPC0.FP_PIPELINE.6.0.CHECK_DEP.DEP_2_I\(1),
dataf => \GRFPC0.FIFO.INST_0_I_M_11\(25),
datae => \GRFPC0.FIFO.INST_0\(29),
datad => \GRFPC0.FIFO.INST_0\(26),
datac => \GRFPC0.FIFO.INST_0\(27),
datab => \GRFPC0.FIFO.INST_0\(28));
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_0_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"003f003fc03f003f")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_0_0\(1),
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datae => \GRFPC0.N_102\,
datad => \GRFPC0.N_73\,
datac => \GRFPC0.STDDEP_0_SQMUXA_54_0\,
datab => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2024_DEP\);
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_0_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff00003000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_0_1\(1),
dataf => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_0_0\(1),
datae => \GRFPC0.N_114\,
datad => \GRFPC0.N_76\,
datac => \GRFPC0.N_74\,
datab => \GRFPC0.N_22000\);
GRFPC0_UN1_STDEP2530: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0fff00000f000000")
port map (
combout => \GRFPC0.UN1_STDEP2530\,
dataf => \GRFPC0.N_481\,
datae => \GRFPC0.FP_PIPELINE.15.CHECK_DEP.UN4940_DEP\,
datad => \GRFPC0.N_458\,
datac => \GRFPC0.N_74_I_I\);
GRFPC0_FP_PIPELINE_12_STDEP_488_SEL1_I_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_58_0_A2_0\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR.CTRL.RDWR\);
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3664_DEP_1_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_25886\,
dataf => \GRFPC0.MEM.CTRL.RD\(2),
datae => \GRFPC0.MEM.CTRL.RD\(1));
GRFPC0_FP_PIPELINE_15_CHECK_DEP_UN4994_DEP_I_O3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_23330\,
dataf => \GRFPC0.EX.CTRL.RD\(2),
datae => \GRFPC0.EX.CTRL.RD\(1));
\GRFPU0_GRFPU_X0_COMB_UN58_FLUSH_ALTB_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3f33033f330300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.ALTB\(3),
dataf => \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.ALTB\(1),
datae => \FPI.FLUSHID\(3),
datad => \FPI.FLUSHID\(2),
datac => \GRFPU0.GRFPU_X0.ST3.ID\(2),
datab => \GRFPU0.GRFPU_X0.ST3.ID\(3));
GRFPU0_GRFPU_X0_RDY_F0_I_0_X2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f30c0cf330cfcf30")
port map (
combout => \GRFPU0.GRFPU_X0.N_172_I_I\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN58_FLUSH.ALTB\(3),
datae => \GRFPU0.GRFPU_X0.ST3.ID\(5),
datad => \FPI.FLUSHID\(5),
datac => \FPI.FLUSHID\(4),
datab => \GRFPU0.GRFPU_X0.ST3.ID\(4));
\GRFPU0_GRFPU_X0_COMB_UN74_FLUSH_ALTB_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff3f0f033f0f0300")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH.ALTB\(2),
datae => \FPI.FLUSHID\(4),
datad => \FPI.FLUSHID\(3),
datac => \GRFPU0.GRFPU_X0.ITER.ID\(4),
datab => \GRFPU0.GRFPU_X0.ITER.ID\(3));
\GRFPU0_GRFPU_X0_ITER_IDCST_RNIU8PI_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_6736_I_I_X2_0\,
dataf => \GRFPU0.GRFPU_X0.ITER.ID\(5),
datae => \FPI.FLUSHID\(5));
GRFPU0_GRFPU_X0_RDY_F0_I_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000003000")
port map (
combout => \GRFPU0.GRFPU_X0.N_245\,
dataf => \GRFPU0.GRFPU_X0.COMB.UN74_FLUSH\,
datae => \GRFPU0.GRFPU_X0.N_6736_I_I_X2_0\,
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \FPI.FLUSH\,
datab => \GRFPU0.GRFPU_X0.ST3.V\);
GRFPU0_GRFPU_X0_RDY_F0_I_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000cc0cff3f")
port map (
combout => \GRFPU0.GRFPU_X0.N_18528_I\,
dataf => \GRFPU0.GRFPU_X0.N_245\,
datae => \GRFPU0.GRFPU_X0.N_73\,
datad => \GRFPU0.GRFPU_X0.N_172_I_I\,
datac => \FPI.FLUSH\,
datab => \GRFPU0.GRFPU_X0.ST3.V\);
GRFPC0_FP_PIPELINE_0_UN1_FPO_8_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_1\,
dataf => \FPO.IDOUT\(0),
datae => \FPO.IDOUT\(4),
datad => \GRFPC0.MEM.CTRL.ID\(0),
datac => \GRFPC0.MEM.CTRL.ID\(4));
GRFPC0_FP_PIPELINE_0_UN1_FPO_8_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c0300c0300000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_4\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_1\,
datae => \FPO.IDOUT\(3),
datad => \FPO.IDOUT\(1),
datac => \GRFPC0.MEM.CTRL.ID\(3),
datab => \GRFPC0.MEM.CTRL.ID\(1));
GRFPC0_FP_PIPELINE_0_UN1_FPO_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3003000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_3\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8_4\,
datad => \FPO.IDOUT\(5),
datac => \GRFPC0.MEM.CTRL.ID\(5),
datab => \GRFPC0.MEM.CTRL.ID\(7));
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_0_O2_0_RNIA66E_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_104\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_FPO_8\,
datae => \GRFPC0.N_102\);
\GRFPC0_EX_CTRL_RD_RNIBEA7_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_473_1\,
dataf => \GRFPC0.EX.CTRL.RDWR\,
datae => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_3_STDEP_132_SEL1_I_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.STDDEP_0_SQMUXA_54_0\,
dataf => \GRFPC0.N_579\,
datae => \GRFPC0.MEM.CTRL.RDWR\);
GRFPC0_FP_PIPELINE_6_CHECK_DEP_UN2024_DEP_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000f000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2024_DEP\,
dataf => \GRFPC0.MEM.CTRL.RD\(2),
datae => \GRFPC0.MEM.CTRL.RD\(4),
datad => \GRFPC0.MEM.CTRL.RD\(1),
datac => \GRFPC0.MEM.CTRL.RD\(3));
\GRFPC0_FP_PIPELINE_3_STDEP_128_3_0_O2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_494\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_6_CHECK_DEP_UN2006_DEP_2_I: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_561\,
dataf => \GRFPC0.WR.CTRL.RD\(3),
datae => \GRFPC0.WR.CTRL.RD\(2));
\GRFPC0_FP_PIPELINE_6_STDEP_244_0_IV_I_O2_I_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.N_842\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_VDIV.EXEC\,
datae => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(3),
datad => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(4),
datac => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(1),
datab => \GRFPC0.FP_PIPELINE.VDIV.RD_1\(2));
\GRFPC0_FP_PIPELINE_6_STDEP_252_3_I_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0ff00ffc0ffc0")
port map (
combout => \GRFPC0.N_28\,
dataf => \GRFPC0.N_842\,
datae => N_40688,
datad => \GRFPC0.FP_PIPELINE.6.STDEP_252_3_I_0\(0),
datac => \GRFPC0.N_73\,
datab => \GRFPC0.N_76\);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_12: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.N_9465\,
dataf => N_105,
datae => N_104,
datad => N_107,
datac => N_106);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN243_DEP_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN243_DEP_1\,
dataf => N_173,
datae => N_174);
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN64_DEP_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN64_DEP_2\,
dataf => \GRFPC0.EX.CTRL.RD\(3),
datae => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.N_9453\,
dataf => N_106,
datae => N_105,
datad => N_107,
datac => N_104);
\GRFPC0_D_STLCK_RNO_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00c000c000c000")
port map (
combout => \GRFPC0.N_751\,
dataf => \GRFPC0.N_62\,
datae => \GRFPC0.FP_PIPELINE.VRFA.LD_1\,
datad => \GRFPC0.N_9453\,
datac => \GRFPC0.FP_PIPELINE.0.UN1_DEP\,
datab => \GRFPC0.N_59\);
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN694_DEP_I_O3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_453\,
dataf => \GRFPC0.WR.CTRL.RD\(1),
datae => \GRFPC0.WR.CTRL.RD\(4));
\GRFPC0_FP_PIPELINE_10_STDEP_412_3_0_I_O2_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffff00")
port map (
combout => \GRFPC0.N_484\,
dataf => \GRFPC0.N_114\,
datae => \GRFPC0.WR.CTRL.RDD\,
datad => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_D_STLCK_RNO_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff3ffff00f000fc")
port map (
combout => \GRFPC0.N_557\,
dataf => \GRFPC0.N_428\,
datae => \GRFPC0.N_104\,
datad => \GRFPC0.N_477\,
datac => \GRFPC0.N_579\,
datab => \GRFPC0.MEM.CTRL.RD\(0));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN259_DEP_2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN919_DEP_2\,
dataf => N_244,
datae => N_245);
GRFPC0_FP_PIPELINE_1_1_CHECK_DEP_UN496_REGDEPX_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN496_REGDEPX_0\,
dataf => \GRFPC0.FIFO.INST_1\(26),
datae => \GRFPC0.FIFO.INST_1\(27));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_7_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.N_9480\,
dataf => N_107,
datae => N_106,
datad => N_105,
datac => N_104);
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN2698_DEP_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN3026_DEP_2\,
dataf => \GRFPC0.EX.CTRL.RD\(3),
datae => \GRFPC0.EX.CTRL.RD\(2));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN4666_DEP_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN2698_DEP_1\,
dataf => \GRFPC0.EX.CTRL.RD\(1),
datae => \GRFPC0.EX.CTRL.RD\(4));
GRFPC0_FP_PIPELINE_14_0_CHECK_DEP_UN4447_REGDEPX_I_0_O3_I_A2_0_I_O4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.N_24935\,
dataf => \GRFPC0.FIFO.INST_0\(29),
datae => \GRFPC0.FIFO.INST_0\(26));
GRFPC0_FP_PIPELINE_9_0_CHECK_DEP_UN2887_REGDEPX_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.N_23961\,
dataf => \GRFPC0.FIFO.INST_0\(27),
datae => \GRFPC0.FIFO.INST_0\(28));
GRFPC0_FP_PIPELINE_0_STDDEP_202_IV_0_O2_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00300000ffffffff")
port map (
combout => \GRFPC0.N_21227_2\,
dataf => \GRFPC0.N_22231\,
datae => \GRFPC0.FP_PIPELINE.0.0.FIFO_INST_V.TMP\,
datad => \GRFPC0.N_24935\,
datac => \GRFPC0.N_23961\,
datab => \GRFPC0.FIFO.INST_0\(19));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_17_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
dataf => \GRFPC0.RFA.RDD\,
datae => N_172);
GRFPC0_FP_PIPELINE_11_CHECK_DEP_UN3857_DEP_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_801\,
dataf => N_176,
datae => N_175);
\GRFPC0_D_STLCK_RNO_9_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0030000000000000")
port map (
combout => \GRFPC0.N_21203\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_17\(1),
datae => \GRFPC0.RFA.LD\,
datad => N_174,
datac => \GRFPC0.N_801\,
datab => N_173);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_15_0_1_I_O2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_594\,
dataf => \GRFPC0.N_106_I\,
datae => N_241);
\GRFPC0_FP_PIPELINE_0_STDEP_362_0_IV_I_O3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3ffffffff")
port map (
combout => \GRFPC0.N_60\,
dataf => \GRFPC0.EX.CTRL.LD\,
datae => N_243,
datad => N_242,
datac => N_244,
datab => N_245);
\GRFPC0_FIFO_INST_1_RNISOJ61_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffffffff")
port map (
combout => \GRFPC0.N_531\,
dataf => \GRFPC0.FIFO.INST_1\(29),
datae => \GRFPC0.FIFO.INST_1\(28),
datad => \GRFPC0.FIFO.INST_1\(27));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_8: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f00000000")
port map (
combout => \GRFPC0.N_9481\,
dataf => N_107,
datae => N_106,
datad => N_105,
datac => N_104);
GRFPC0_FP_PIPELINE_0_0_CHECK_DEP_UN61_REGDEPX_2_I_O3_I_A2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.0.CHECK_DEP.UN61_REGDEPX_2\,
dataf => \GRFPC0.FIFO.INST_0\(29),
datae => \GRFPC0.FIFO.INST_0\(28));
\GRFPC0_RS1_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_RD1ADDRZ(2),
dataf => N_429,
datae => N_423,
datad => N_37,
datac => \GRFPC0.N_24062\,
datab => \GRFPC0.RFA.RS1\(3));
\GRFPC0_RS1_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_RD1ADDRZ(3),
dataf => N_430,
datae => N_423,
datad => N_37,
datac => \GRFPC0.N_24063\,
datab => \GRFPC0.RFA.RS1\(4));
\GRFPC0_WRDATA_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(4),
dataf => N_435,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(36),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(4));
\GRFPC0_FP_PIPELINE_WRDATA_3_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(36),
dataf => \GRFPC0.DIV.RESULT\(36),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(36),
datab => \FPO.RES\(36));
\GRFPC0_FP_PIPELINE_WRDATA_3_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(4),
dataf => \GRFPC0.DIV.RESULT\(4),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(4),
datab => \FPO.RES\(4));
\GRFPC0_WRDATA_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(11),
dataf => N_442,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(43),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(11));
\GRFPC0_FP_PIPELINE_WRDATA_3_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(43),
dataf => \GRFPC0.DIV.RESULT\(43),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(43),
datab => \GRFPU0.GRFPU_X0.N_20290_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(11),
dataf => \GRFPC0.DIV.RESULT\(11),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(11),
datab => \FPO.RES\(11));
\GRFPC0_MEM_RREG_RES_RNO_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fffff0f0f0f0")
port map (
combout => N_47199,
dataf => N_99847,
datae => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_36_2964_I_A3_0_0_0\,
datad => N_99904_1,
datac => \GRFPC0.EX.RREG.RES\(4),
datab => \GRFPU0.GRFPU_X0.ST4.REG\(4));
\GRFPC0_R_FSR_FCC_0_0_0__G0_I_O4\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffffffffffffff")
port map (
combout => \GRFPC0.R.FSR.FCC_0_0_1__N_5\,
dataf => N_423,
datae => N_424,
datad => N_425);
\GRFPC0_OP1_1_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19935\,
dataf => \FPO.RES\(10),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(10));
\GRFPC0_OP1_2_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20001\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(10),
datad => \GRFPC0.MEM.RREG.RES\(10));
\GRFPC0_OP1_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(10),
dataf => \GRFPC0.N_20264\,
datae => N_99877_0,
datad => \GRFPC0.N_19935\,
datac => N_99878_0,
datab => \GRFPC0.N_20001\);
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_29_3146_I_A3_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000f003300ff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_29_3146_I_A3_0\,
dataf => N_99904_2,
datae => \GRFPU0.GRFPU_X0.N_400\,
datad => \GRFPC0.DIV.RESULT_0_0_11__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(11),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(11));
\GRFPC0_OP1_1_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19936\,
dataf => \FPO.RES\(11),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(11));
\GRFPC0_OP1_2_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20002\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(11),
datad => \GRFPC0.MEM.RREG.RES\(11));
\GRFPC0_OP1_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(11),
dataf => \GRFPC0.N_20265\,
datae => N_99877_0,
datad => \GRFPC0.N_19936\,
datac => N_99878_0,
datab => \GRFPC0.N_20002\);
\GRFPC0_OP1_1_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19933\,
dataf => \FPO.RES\(8),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(8));
\GRFPC0_OP1_2_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19999\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(8),
datad => \GRFPC0.MEM.RREG.RES\(8));
\GRFPC0_OP1_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(8),
dataf => \GRFPC0.N_20262\,
datae => N_99877_0,
datad => \GRFPC0.N_19933\,
datac => N_99878_0,
datab => \GRFPC0.N_19999\);
\GRFPC0_OP1_1_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19934\,
dataf => \FPO.RES\(9),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(9));
\GRFPC0_OP1_2_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20000\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(9),
datad => \GRFPC0.MEM.RREG.RES\(9));
\GRFPC0_OP1_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(9),
dataf => \GRFPC0.N_20263\,
datae => N_99877_0,
datad => \GRFPC0.N_19934\,
datac => N_99878_0,
datab => \GRFPC0.N_20000\);
GRFPC0_FP_PIPELINE_DEBUG_UNIT: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.WREN_0_SQMUXA_1_0\,
dataf => N_423,
datae => N_424);
\GRFPC0_MEM_CTRL_ID_RNIMO172_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => N_99846,
dataf => \GRFPC0.N_24428\,
datae => N_37);
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_35_2990_I_A3_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000f003300ff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_35_2990_I_A3_0\,
dataf => N_99904_2,
datae => \GRFPU0.GRFPU_X0.N_400\,
datad => \GRFPC0.DIV.RESULT_0_0_5__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(5),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(5));
\GRFPC0_OP1_1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19930\,
dataf => \FPO.RES\(5),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(5));
\GRFPC0_OP1_2_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19996\,
dataf => \GRFPC0.RFA2.RS1SEL_0\(2),
datae => \GRFPC0.DIV.RESULT\(5),
datad => \GRFPC0.MEM.RREG.RES\(5));
\GRFPC0_OP1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(5),
dataf => \GRFPC0.N_20259\,
datae => N_99877_0,
datad => \GRFPC0.N_19930\,
datac => N_99878_0,
datab => \GRFPC0.N_19996\);
\GRFPC0_FP_PIPELINE_WRDATA_3_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(37),
dataf => \GRFPC0.DIV.RESULT\(37),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(37),
datab => \GRFPU0.GRFPU_X0.N_20275_I_0\);
\GRFPC0_FP_PIPELINE_WRDATA_3_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(5),
dataf => \GRFPC0.DIV.RESULT\(5),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(5),
datab => \FPO.RES\(5));
\GRFPC0_WRDATA_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(5),
dataf => N_436,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(37),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(5));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF1_1_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(38),
dataf => \GRFPU0.GRFPU_X0.N_21\,
datae => \GRFPU0.GRFPU_X0.N_18746\,
datad => \FPI.OP1\(38),
datac => \FPI.OP1\(41));
\GRFPC0_WRDATA_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => RFI2_WRDATAZ(18),
dataf => N_449,
datae => \GRFPC0.WREN_0_SQMUXA_1_0\,
datad => \GRFPC0.FP_PIPELINE.UN45_WREN\,
datac => \GRFPC0.FP_PIPELINE.WRDATA_3\(50),
datab => \GRFPC0.FP_PIPELINE.WRDATA_3\(18));
\GRFPC0_FP_PIPELINE_WRDATA_3_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(50),
dataf => \GRFPC0.DIV.RESULT\(50),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(50),
datab => \FPO.RES\(50));
\GRFPC0_FP_PIPELINE_WRDATA_3_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffff0cc0000f0cc")
port map (
combout => \GRFPC0.FP_PIPELINE.WRDATA_3\(18),
dataf => \GRFPC0.DIV.RESULT\(18),
datae => \GRFPC0.FP_PIPELINE.UN29_WREN\,
datad => \GRFPC0.WR2.RREG.RESV\,
datac => \GRFPC0.WR2.RREG.RES\(18),
datab => \FPO.RES\(18));
GRFPC0_FP_PIPELINE_VWR_RREG_RES_1_16_3484_I_A3_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000f003300ff")
port map (
combout => \GRFPC0.FP_PIPELINE.VWR.RREG.RES_1_16_3484_I_A3_0\,
dataf => N_99904_2,
datae => \GRFPU0.GRFPU_X0.N_400_1\,
datad => \GRFPC0.DIV.RESULT_0_0_24__G5\,
datac => \GRFPU0.GRFPU_X0.ST4.REG\(24),
datab => \GRFPU0.GRFPU_X0.ST4.MSGNF\(24));
\GRFPC0_OP1_1_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19949\,
dataf => \FPO.RES\(24),
datae => \GRFPC0.RFA2.RS1SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(24));
\GRFPC0_OP1_2_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_20015\,
dataf => \GRFPC0.RFA2.RS1SEL_1\(2),
datae => \GRFPC0.DIV.RESULT\(24),
datad => \GRFPC0.MEM.RREG.RES\(24));
\GRFPC0_OP1_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fc0cfffffc0c0000")
port map (
combout => \FPI.OP1\(24),
dataf => \GRFPC0.N_20278\,
datae => N_99877_1,
datad => \GRFPC0.N_19949\,
datac => N_99878_1,
datab => \GRFPC0.N_20015\);
GRFPC0_FP_PIPELINE_QNE2_I_O2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_23687\,
dataf => \GRFPC0.DIV.EXC\,
datae => \GRFPC0.WR2.EXC\);
GRFPC0_V_STDATA_0_SQMUXA_I_O4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_23697\,
dataf => \GRFPC0.DIV.PEND\,
datae => \GRFPC0.WR2.CTRL.PEND\);
\GRFPC0_FP_PIPELINE_UN4_CNTX_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN4_CNTX\(1),
dataf => \GRFPC0.FIFO.RD_2\(0),
datae => \GRFPC0.FIFO.VCNT_0\(1),
datad => \GRFPC0.FIFO.VCNT_1\(1));
GRFPC0_FP_PIPELINE_UN1_FIFO_RD_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0000000000ff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_1\,
dataf => \GRFPC0.FIFO.WR\(0),
datae => \GRFPC0.FIFO.RD_2\(0),
datad => \GRFPC0.FIFO.FULL\);
GRFPC0_FP_PIPELINE_UN1_FIFO_RD_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000f33")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_2\,
dataf => \GRFPC0.FP_PIPELINE.UN4_CNTX\(1),
datae => \GRFPC0.FP_PIPELINE.UN1_FIFO.RD_1\,
datad => \GRFPC0.FIFO.RD_2\(0),
datac => \GRFPC0.FIFO.VCNT_1\(2),
datab => \GRFPC0.FIFO.VCNT_0\(2));
GRFPC0_FP_PIPELINE_UN27_PENDEXC_I_0_O4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.N_23695\,
dataf => \GRFPC0.R.STATE\(0),
datae => \GRFPC0.R.STATE\(1));
GRFPC0_CCWR_0_SQMUXA_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.CCWR_0_SQMUXA_1\,
dataf => N_100,
datae => N_98,
datad => N_102,
datac => N_101);
GRFPC0_FP_PIPELINE_UN26_OP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0c0c000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN26_OP\,
dataf => \GRFPC0.FP_PIPELINE.UN24_OP\,
datae => \GRFPC0.N_9203\,
datad => \GRFPC0.N_313\,
datac => N_109,
datab => N_108);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000030000")
port map (
combout => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A2_0\,
dataf => N_100,
datae => N_102,
datad => N_112,
datac => \GRFPC0.FP_PIPELINE.UN1_CPI\,
datab => N_113);
GRFPC0_FP_PIPELINE_ORV_TMP_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.ORV.TMP_1\,
dataf => \GRFPC0.MEM.CTRL.VCNT\(1),
datae => \GRFPC0.MEM.CTRL.VCNT\(0));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_243_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.8.REGDEPX2_243\(0),
dataf => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_24_IV\(0),
datae => \GRFPC0.N_25658\,
datad => \FPI.FLOP\(6),
datac => \GRFPC0.N_23975\,
datab => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.UN3680_REGDEPX2_0\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN23_DP_0_O2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.N_18870\,
dataf => \FPI.OP2\(52),
datae => \FPI.OP2\(53),
datad => \FPI.OP2\(54));
\GRFPC0_OP2_1_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19451\,
dataf => \FPO.RES\(21),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(21));
\GRFPC0_OP2_2_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19517\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(21),
datad => \GRFPC0.MEM.RREG.RES\(21));
\GRFPC0_OP2_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(21),
dataf => \GRFPC0.N_19451\,
datae => \GRFPC0.N_19780\,
datad => N_99880_0,
datac => \GRFPC0.N_19517\,
datab => N_99881);
\GRFPC0_OP2_1_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19450\,
dataf => \FPO.RES\(20),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(20));
\GRFPC0_OP2_2_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19516\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(20),
datad => \GRFPC0.MEM.RREG.RES\(20));
\GRFPC0_OP2_20_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(20),
dataf => \GRFPC0.N_19450\,
datae => \GRFPC0.N_19779\,
datad => N_99880_0,
datac => \GRFPC0.N_19516\,
datab => N_99881);
\GRFPC0_OP2_1_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19449\,
dataf => \FPO.RES\(19),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(19));
\GRFPC0_OP2_2_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19515\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(19),
datad => \GRFPC0.MEM.RREG.RES\(19));
\GRFPC0_OP2_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(19),
dataf => \GRFPC0.N_19449\,
datae => \GRFPC0.N_19778\,
datad => N_99880_0,
datac => \GRFPC0.N_19515\,
datab => N_99881);
\GRFPC0_OP2_1_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19448\,
dataf => \FPO.RES\(18),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(18));
\GRFPC0_OP2_2_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19514\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(18),
datad => \GRFPC0.MEM.RREG.RES\(18));
\GRFPC0_OP2_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(18),
dataf => \GRFPC0.N_19448\,
datae => \GRFPC0.N_19777\,
datad => N_99880_0,
datac => \GRFPC0.N_19514\,
datab => N_99881);
\GRFPC0_OP2_1_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19447\,
dataf => \FPO.RES\(17),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(17));
\GRFPC0_OP2_2_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19513\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(17),
datad => \GRFPC0.MEM.RREG.RES\(17));
\GRFPC0_OP2_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(17),
dataf => \GRFPC0.N_19447\,
datae => \GRFPC0.N_19776\,
datad => N_99880_0,
datac => \GRFPC0.N_19513\,
datab => N_99881);
\GRFPC0_OP2_1_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19446\,
dataf => \FPO.RES\(16),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(16));
\GRFPC0_OP2_2_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19512\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(16),
datad => \GRFPC0.MEM.RREG.RES\(16));
\GRFPC0_OP2_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(16),
dataf => \GRFPC0.N_19446\,
datae => \GRFPC0.N_19775\,
datad => N_99880_0,
datac => \GRFPC0.N_19512\,
datab => N_99881);
\GRFPC0_OP2_1_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19445\,
dataf => \FPO.RES\(15),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(15));
\GRFPC0_OP2_2_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19511\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(15),
datad => \GRFPC0.MEM.RREG.RES\(15));
\GRFPC0_OP2_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(15),
dataf => \GRFPC0.N_19445\,
datae => \GRFPC0.N_19774\,
datad => N_99880_0,
datac => \GRFPC0.N_19511\,
datab => N_99881);
\GRFPC0_OP2_1_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19444\,
dataf => \FPO.RES\(14),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(14));
\GRFPC0_OP2_2_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19510\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(14),
datad => \GRFPC0.MEM.RREG.RES\(14));
\GRFPC0_OP2_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(14),
dataf => \GRFPC0.N_19444\,
datae => \GRFPC0.N_19773\,
datad => N_99880_0,
datac => \GRFPC0.N_19510\,
datab => N_99881);
\GRFPC0_OP2_1_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19439\,
dataf => \FPO.RES\(9),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(9));
\GRFPC0_OP2_2_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19505\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(9),
datad => \GRFPC0.MEM.RREG.RES\(9));
\GRFPC0_OP2_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(9),
dataf => \GRFPC0.N_19439\,
datae => \GRFPC0.N_19768\,
datad => N_99880_0,
datac => \GRFPC0.N_19505\,
datab => N_99881);
\GRFPC0_OP2_1_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19438\,
dataf => \FPO.RES\(8),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(8));
\GRFPC0_OP2_2_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19504\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(8),
datad => \GRFPC0.MEM.RREG.RES\(8));
\GRFPC0_OP2_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(8),
dataf => \GRFPC0.N_19438\,
datae => \GRFPC0.N_19767\,
datad => N_99880_0,
datac => \GRFPC0.N_19504\,
datab => N_99881);
\GRFPC0_OP2_1_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19460\,
dataf => \FPO.RES\(30),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(30));
\GRFPC0_OP2_2_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19526\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(30),
datad => \GRFPC0.MEM.RREG.RES\(30));
\GRFPC0_OP2_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(30),
dataf => \GRFPC0.N_19460\,
datae => \GRFPC0.N_19789\,
datad => N_99880_1,
datac => \GRFPC0.N_19526\,
datab => N_99881);
\GRFPC0_OP2_1_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19459\,
dataf => \FPO.RES\(29),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(29));
\GRFPC0_OP2_2_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19525\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(29),
datad => \GRFPC0.MEM.RREG.RES\(29));
\GRFPC0_OP2_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(29),
dataf => \GRFPC0.N_19459\,
datae => \GRFPC0.N_19788\,
datad => N_99880_1,
datac => \GRFPC0.N_19525\,
datab => N_99881);
\GRFPC0_OP2_1_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19443\,
dataf => \FPO.RES\(13),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(13));
\GRFPC0_OP2_2_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19509\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(13),
datad => \GRFPC0.MEM.RREG.RES\(13));
\GRFPC0_OP2_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(13),
dataf => \GRFPC0.N_19443\,
datae => \GRFPC0.N_19772\,
datad => N_99880_0,
datac => \GRFPC0.N_19509\,
datab => N_99881);
\GRFPC0_OP2_1_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19442\,
dataf => \FPO.RES\(12),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(12));
\GRFPC0_OP2_2_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19508\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(12),
datad => \GRFPC0.MEM.RREG.RES\(12));
\GRFPC0_OP2_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(12),
dataf => \GRFPC0.N_19442\,
datae => \GRFPC0.N_19771\,
datad => N_99880_0,
datac => \GRFPC0.N_19508\,
datab => N_99881);
\GRFPC0_OP2_1_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19441\,
dataf => \FPO.RES\(11),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(11));
\GRFPC0_OP2_2_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19507\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(11),
datad => \GRFPC0.MEM.RREG.RES\(11));
\GRFPC0_OP2_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(11),
dataf => \GRFPC0.N_19441\,
datae => \GRFPC0.N_19770\,
datad => N_99880_0,
datac => \GRFPC0.N_19507\,
datab => N_99881);
\GRFPC0_OP2_1_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19440\,
dataf => \FPO.RES\(10),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(10));
\GRFPC0_OP2_2_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19506\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(10),
datad => \GRFPC0.MEM.RREG.RES\(10));
\GRFPC0_OP2_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(10),
dataf => \GRFPC0.N_19440\,
datae => \GRFPC0.N_19769\,
datad => N_99880_0,
datac => \GRFPC0.N_19506\,
datab => N_99881);
\GRFPC0_OP2_2_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19499\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(3),
datad => \GRFPC0.MEM.RREG.RES\(3));
\GRFPC0_OP2_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(3),
dataf => \GRFPC0.N_19433\,
datae => \GRFPC0.N_19762\,
datad => N_99880_0,
datac => \GRFPC0.N_19499\,
datab => N_99881);
\GRFPC0_OP2_2_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19498\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(2),
datad => \GRFPC0.MEM.RREG.RES\(2));
\GRFPC0_OP2_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(2),
dataf => \GRFPC0.N_19432\,
datae => \GRFPC0.N_19761\,
datad => N_99880_0,
datac => \GRFPC0.N_19498\,
datab => N_99881);
\GRFPC0_OP2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19431\,
dataf => \FPO.RES\(1),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(1));
\GRFPC0_OP2_2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19497\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.MEM.RREG.RES\(1),
datad => \GRFPC0.DIV.RESULT\(1));
\GRFPC0_OP2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(1),
dataf => \GRFPC0.N_19431\,
datae => \GRFPC0.N_19760\,
datad => N_99880_0,
datac => \GRFPC0.N_19497\,
datab => N_99881);
\GRFPC0_OP2_1_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19430\,
dataf => \FPO.RES\(0),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(0));
\GRFPC0_OP2_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_19496\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.MEM.RREG.RES\(0),
datad => \GRFPC0.DIV.RESULT\(0));
\GRFPC0_OP2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(0),
dataf => \GRFPC0.N_19430\,
datae => \GRFPC0.N_19759\,
datad => N_99880_0,
datac => \GRFPC0.N_19496\,
datab => N_99881);
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_A2_4_19_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_4_19\(4),
dataf => \FPI.OP2\(1),
datae => \FPI.OP2\(0),
datad => \FPI.OP2\(3),
datac => \FPI.OP2\(2));
\GRFPC0_OP2_2_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19527\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(31),
datad => \GRFPC0.MEM.RREG.RES\(31));
\GRFPC0_OP2_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(31),
dataf => \GRFPC0.N_19461\,
datae => \GRFPC0.N_19790\,
datad => N_99880_1,
datac => \GRFPC0.N_19527\,
datab => N_99881);
\GRFPC0_OP2_2_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19524\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(28),
datad => \GRFPC0.MEM.RREG.RES\(28));
\GRFPC0_OP2_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(28),
dataf => \GRFPC0.N_19458\,
datae => \GRFPC0.N_19787\,
datad => N_99880_1,
datac => \GRFPC0.N_19524\,
datab => N_99881);
\GRFPC0_OP2_1_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19453\,
dataf => \FPO.RES\(23),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(23));
\GRFPC0_OP2_2_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19519\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(23),
datad => \GRFPC0.MEM.RREG.RES\(23));
\GRFPC0_OP2_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(23),
dataf => \GRFPC0.N_19453\,
datae => \GRFPC0.N_19782\,
datad => N_99880_0,
datac => \GRFPC0.N_19519\,
datab => N_99881);
\GRFPC0_OP2_1_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19452\,
dataf => \FPO.RES\(22),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(22));
\GRFPC0_OP2_2_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19518\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(22),
datad => \GRFPC0.MEM.RREG.RES\(22));
\GRFPC0_OP2_22_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(22),
dataf => \GRFPC0.N_19452\,
datae => \GRFPC0.N_19781\,
datad => N_99880_0,
datac => \GRFPC0.N_19518\,
datab => N_99881);
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_A2_4_18_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_4_18\(4),
dataf => \FPI.OP2\(23),
datae => \FPI.OP2\(22),
datad => \FPI.OP2\(28),
datac => \FPI.OP2\(31));
\GRFPC0_OP2_1_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19437\,
dataf => \FPO.RES\(7),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(7));
\GRFPC0_OP2_2_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19503\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(7),
datad => \GRFPC0.MEM.RREG.RES\(7));
\GRFPC0_OP2_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(7),
dataf => \GRFPC0.N_19437\,
datae => \GRFPC0.N_19766\,
datad => N_99880_0,
datac => \GRFPC0.N_19503\,
datab => N_99881);
\GRFPC0_OP2_1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19436\,
dataf => \FPO.RES\(6),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(6));
\GRFPC0_OP2_2_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19502\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(6),
datad => \GRFPC0.MEM.RREG.RES\(6));
\GRFPC0_OP2_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(6),
dataf => \GRFPC0.N_19436\,
datae => \GRFPC0.N_19765\,
datad => N_99880_0,
datac => \GRFPC0.N_19502\,
datab => N_99881);
\GRFPC0_OP2_1_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19435\,
dataf => \FPO.RES\(5),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(5));
\GRFPC0_OP2_2_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19501\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(5),
datad => \GRFPC0.MEM.RREG.RES\(5));
\GRFPC0_OP2_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(5),
dataf => \GRFPC0.N_19435\,
datae => \GRFPC0.N_19764\,
datad => N_99880_0,
datac => \GRFPC0.N_19501\,
datab => N_99881);
\GRFPC0_OP2_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19434\,
dataf => \FPO.RES\(4),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(4));
\GRFPC0_OP2_2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19500\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(4),
datad => \GRFPC0.MEM.RREG.RES\(4));
\GRFPC0_OP2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(4),
dataf => \GRFPC0.N_19434\,
datae => \GRFPC0.N_19763\,
datad => N_99880_0,
datac => \GRFPC0.N_19500\,
datab => N_99881);
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_A2_4_17_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_4_17\(4),
dataf => \FPI.OP2\(5),
datae => \FPI.OP2\(4),
datad => \FPI.OP2\(7),
datac => \FPI.OP2\(6));
\GRFPC0_OP2_1_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19457\,
dataf => \FPO.RES\(27),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(27));
\GRFPC0_OP2_2_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19523\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(27),
datad => \GRFPC0.MEM.RREG.RES\(27));
\GRFPC0_OP2_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(27),
dataf => \GRFPC0.N_19457\,
datae => \GRFPC0.N_19786\,
datad => N_99880_1,
datac => \GRFPC0.N_19523\,
datab => N_99881);
\GRFPC0_OP2_1_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19456\,
dataf => \FPO.RES\(26),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(26));
\GRFPC0_OP2_2_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19522\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(26),
datad => \GRFPC0.MEM.RREG.RES\(26));
\GRFPC0_OP2_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(26),
dataf => \GRFPC0.N_19456\,
datae => \GRFPC0.N_19785\,
datad => N_99880_1,
datac => \GRFPC0.N_19522\,
datab => N_99881);
\GRFPC0_OP2_2_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19521\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(25),
datad => \GRFPC0.MEM.RREG.RES\(25));
\GRFPC0_OP2_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff30fffc003000")
port map (
combout => \FPI.OP2\(25),
dataf => \GRFPC0.N_19784\,
datae => \GRFPC0.N_19455\,
datad => N_99880_1,
datac => \GRFPC0.N_19521\,
datab => N_99881);
\GRFPC0_OP2_1_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19454\,
dataf => \FPO.RES\(24),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(24));
\GRFPC0_OP2_2_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19520\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(24),
datad => \GRFPC0.MEM.RREG.RES\(24));
\GRFPC0_OP2_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(24),
dataf => \GRFPC0.N_19454\,
datae => \GRFPC0.N_19783\,
datad => N_99880_0,
datac => \GRFPC0.N_19520\,
datab => N_99881);
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_A2_4_16_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_4_16\(4),
dataf => \FPI.OP2\(24),
datae => \FPI.OP2\(27),
datad => \FPI.OP2\(26),
datac => \FPI.OP2\(25));
\GRFPC0_OP2_2_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19543\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(47),
datad => \GRFPC0.MEM.RREG.RES\(47));
\GRFPC0_OP2_2_32_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19528\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(32),
datad => \GRFPC0.MEM.RREG.RES\(32));
\GRFPC0_OP2_2_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19541\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(45),
datad => \GRFPC0.MEM.RREG.RES\(45));
\GRFPC0_OP2_2_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19533\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(37),
datad => \GRFPC0.MEM.RREG.RES\(37));
\GRFPC0_OP2_2_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19536\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(40),
datad => \GRFPC0.MEM.RREG.RES\(40));
\GRFPC0_OP2_2_35_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19531\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(35),
datad => \GRFPC0.MEM.RREG.RES\(35));
\GRFPC0_OP2_2_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19544\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(48),
datad => \GRFPC0.MEM.RREG.RES\(48));
\GRFPC0_OP2_2_43_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19539\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(43),
datad => \GRFPC0.MEM.RREG.RES\(43));
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_A2_2_10_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_2_10\(4),
dataf => \FPI.OP2\(43),
datae => \FPI.OP2\(35),
datad => \FPI.OP2\(40),
datac => \FPI.OP2\(48));
\GRFPC0_OP2_2_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19532\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(36),
datad => \GRFPC0.MEM.RREG.RES\(36));
\GRFPC0_OP2_36_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff30fffc003000")
port map (
combout => \FPI.OP2\(36),
dataf => \GRFPC0.N_19795\,
datae => \GRFPC0.N_19466\,
datad => N_99880_1,
datac => \GRFPC0.N_19532\,
datab => N_99881);
\GRFPC0_OP2_2_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19529\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(33),
datad => \GRFPC0.MEM.RREG.RES\(33));
\GRFPC0_OP2_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(33),
dataf => \GRFPC0.N_19463\,
datae => \GRFPC0.N_19792\,
datad => N_99880_1,
datac => \GRFPC0.N_19529\,
datab => N_99881);
\GRFPC0_OP2_2_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19540\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(44),
datad => \GRFPC0.MEM.RREG.RES\(44));
\GRFPC0_OP2_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff30fffc003000")
port map (
combout => \FPI.OP2\(44),
dataf => \GRFPC0.N_19803\,
datae => \GRFPC0.N_19474\,
datad => N_99880_1,
datac => \GRFPC0.N_19540\,
datab => N_99881);
\GRFPC0_OP2_2_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19530\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(34),
datad => \GRFPC0.MEM.RREG.RES\(34));
\GRFPC0_OP2_34_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcff30fffc003000")
port map (
combout => \FPI.OP2\(34),
dataf => \GRFPC0.N_19793\,
datae => \GRFPC0.N_19464\,
datad => N_99880_1,
datac => \GRFPC0.N_19530\,
datab => N_99881);
\GRFPC0_OP2_2_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19542\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(46),
datad => \GRFPC0.MEM.RREG.RES\(46));
\GRFPC0_OP2_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(46),
dataf => \GRFPC0.N_19476\,
datae => \GRFPC0.N_19805\,
datad => N_99880_1,
datac => \GRFPC0.N_19542\,
datab => N_99881);
\GRFPC0_OP2_2_41_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19537\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(41),
datad => \GRFPC0.MEM.RREG.RES\(41));
\GRFPC0_OP2_2_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19538\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(42),
datad => \GRFPC0.MEM.RREG.RES\(42));
\GRFPC0_OP2_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(42),
dataf => \GRFPC0.N_19472\,
datae => \GRFPC0.N_19801\,
datad => N_99880_1,
datac => \GRFPC0.N_19538\,
datab => N_99881);
\GRFPC0_OP2_2_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19535\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(39),
datad => \GRFPC0.MEM.RREG.RES\(39));
\GRFPC0_OP2_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(39),
dataf => \GRFPC0.N_19469\,
datae => \GRFPC0.N_19798\,
datad => N_99880_1,
datac => \GRFPC0.N_19535\,
datab => N_99881);
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_A2_2_12_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_2_12\(4),
dataf => \FPI.OP2\(41),
datae => \FPI.OP2\(42),
datad => \FPI.OP2\(39),
datac => \FPI.OP2\(46));
\GRFPC0_OP2_1_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19479\,
dataf => \GRFPU0.GRFPU_X0.N_20292_I_0\,
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(49));
\GRFPC0_OP2_2_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19545\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(49),
datad => \GRFPC0.MEM.RREG.RES\(49));
\GRFPC0_OP2_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(49),
dataf => \GRFPC0.N_19479\,
datae => \GRFPC0.N_19808\,
datad => N_99880_1,
datac => \GRFPC0.N_19545\,
datab => N_99881);
\GRFPC0_OP2_1_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19468\,
dataf => \GRFPU0.GRFPU_X0.N_20296_I_0\,
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(38));
\GRFPC0_OP2_2_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19534\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(38),
datad => \GRFPC0.MEM.RREG.RES\(38));
\GRFPC0_OP2_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(38),
dataf => \GRFPC0.N_19468\,
datae => \GRFPC0.N_19797\,
datad => N_99880_1,
datac => \GRFPC0.N_19534\,
datab => N_99881);
\GRFPC0_OP2_1_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_19480\,
dataf => \FPO.RES\(50),
datae => \GRFPC0.RFA2.RS2SEL\(4),
datad => \GRFPC0.WR2.RREG.RES\(50));
\GRFPC0_OP2_2_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_19546\,
dataf => \GRFPC0.RFA2.RS2SEL\(2),
datae => \GRFPC0.DIV.RESULT\(50),
datad => \GRFPC0.MEM.RREG.RES\(50));
\GRFPC0_OP2_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcfffc0030ff3000")
port map (
combout => \FPI.OP2\(50),
dataf => \GRFPC0.N_19480\,
datae => \GRFPC0.N_19809\,
datad => N_99880,
datac => \GRFPC0.N_19546\,
datab => N_99881);
\GRFPU0_GRFPU_X0_VST1_FLTYPE2_1_I_A2_2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0003000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_18947\,
dataf => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_2_16\(4),
datae => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_I_A2_2_12\(4),
datad => \FPI.OP2\(38),
datac => \FPI.OP2\(49),
datab => \FPI.OP2\(50));
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_9_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000f000")
port map (
combout => \GRFPC0.N_9482\,
dataf => N_106,
datae => N_105,
datad => N_107,
datac => N_104);
GRFPC0_FP_PIPELINE_UN205_HOLDN_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN205_HOLDN_0\,
dataf => N_39,
datae => N_37);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_12_I_M2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_22355\,
dataf => \GRFPC0.D.LDLCK\(23),
datae => \GRFPC0.D.LDLCK\(31),
datad => N_106);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_11_I_M2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_22354\,
dataf => \GRFPC0.D.LDLCK\(7),
datae => \GRFPC0.D.LDLCK\(15),
datad => N_106);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_9_I_M2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_22352\,
dataf => \GRFPC0.D.LDLCK\(21),
datae => \GRFPC0.D.LDLCK\(29),
datad => N_106);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_8_I_M2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_22351\,
dataf => \GRFPC0.D.LDLCK\(5),
datae => \GRFPC0.D.LDLCK\(13),
datad => N_106);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_14_I_M2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fb73ea62d951c840")
port map (
combout => \GRFPC0.N_22357\,
dataf => \GRFPC0.N_22352\,
datae => \GRFPC0.N_22351\,
datad => \GRFPC0.N_22355\,
datac => \GRFPC0.N_22354\,
datab => N_104,
dataa => N_107);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_15_I_M2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffcf3f00f0c0300")
port map (
combout => \GRFPC0.N_22358\,
dataf => \GRFPC0.N_22357\,
datae => \GRFPC0.N_22349\,
datad => \GRFPC0.N_22346\,
datac => N_105,
datab => N_104);
GRFPC0_FP_PIPELINE_UN1_CPI: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_CPI\,
dataf => N_110,
datae => N_111);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_A3_4_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A3_4_0\,
dataf => N_97,
datae => N_101);
GRFPC0_LDLOCK_15_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fb73ea62d951c840")
port map (
combout => \GRFPC0.N_23591\,
dataf => \GRFPC0.N_196\,
datae => \GRFPC0.N_193\,
datad => \GRFPC0.N_23590\,
datac => \GRFPC0.N_200\,
datab => N_105,
dataa => N_104);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_A3_4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8080800000800000")
port map (
combout => \GRFPC0.N_21983\,
dataf => \GRFPC0.N_23591\,
datae => \GRFPC0.D.FSTLCK\,
datad => N_98,
datac => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A3_4_0\,
datab => N_109,
dataa => N_108);
GRFPC0_FP_PIPELINE_LDLOCK27: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_9172\,
dataf => N_109,
datae => N_108);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_O3_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff4000ffff0000")
port map (
combout => \GRFPC0.N_21933\,
dataf => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datae => \GRFPC0.N_21983\,
datad => \GRFPC0.FIFO.FULL\,
datac => N_101,
datab => \GRFPC0.N_9172\,
dataa => N_98);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_A3_1_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A3_1\,
dataf => N_109,
datae => N_108,
datad => N_101,
datac => N_98);
GRFPC0_LDLOCK_1_29_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fb73ea62d951c840")
port map (
combout => \GRFPC0.N_189\,
dataf => \GRFPC0.N_184\,
datae => \GRFPC0.N_183\,
datad => \GRFPC0.N_187\,
datac => \GRFPC0.N_186\,
datab => N_104,
dataa => N_103);
GRFPC0_LDLOCK_1_22_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fb73ea62d951c840")
port map (
combout => \GRFPC0.N_23589\,
dataf => \GRFPC0.N_23585\,
datae => \GRFPC0.N_23584\,
datad => \GRFPC0.N_23587\,
datac => \GRFPC0.N_23586\,
datab => N_104,
dataa => N_103);
GRFPC0_LDLOCK_1_14_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fb73ea62d951c840")
port map (
combout => \GRFPC0.N_23582\,
dataf => \GRFPC0.N_23580\,
datae => \GRFPC0.N_23579\,
datad => \GRFPC0.N_172\,
datac => \GRFPC0.N_171\,
datab => N_104,
dataa => N_103);
GRFPC0_LDLOCK_1_7_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fb73ea62d951c840")
port map (
combout => \GRFPC0.N_167\,
dataf => \GRFPC0.N_23575\,
datae => \GRFPC0.N_161\,
datad => \GRFPC0.N_23577\,
datac => \GRFPC0.N_164\,
datab => N_104,
dataa => N_103);
GRFPC0_LDLOCK_1_31: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fb73ea62d951c840")
port map (
combout => \GRFPC0.LDLOCK_1\,
dataf => \GRFPC0.N_23582\,
datae => \GRFPC0.N_167\,
datad => \GRFPC0.N_189\,
datac => \GRFPC0.N_23589\,
datab => N_106,
dataa => N_105);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_A3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3c000c0030000000")
port map (
combout => \GRFPC0.N_21984\,
dataf => \GRFPC0.LDLOCK_1\,
datae => \GRFPC0.D.FLDLCK\,
datad => \GRFPC0.FP_PIPELINE.LDLOCK_1_IV_0_A3_1\,
datac => N_97,
datab => N_99);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_0_O3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00ffff0000")
port map (
combout => \GRFPC0.N_21934\,
dataf => \GRFPC0.N_21933\,
datae => \GRFPC0.N_21984\,
datad => N_99);
GRFPC0_FP_PIPELINE_UN205_HOLDN: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffffffe")
port map (
combout => \GRFPC0.FP_PIPELINE.UN205_HOLDN\,
dataf => CPO_EXCZ,
datae => \GRFPC0.N_21965\,
datad => \GRFPC0.N_21108\,
datac => \GRFPC0.FP_PIPELINE.UN205_HOLDN_0\,
datab => N_112,
dataa => N_113);
GRFPC0_FP_PIPELINE_VRFA_RDD_1_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.RDD_1\,
dataf => \GRFPC0.FP_PIPELINE.UN205_HOLDN\,
datae => \GRFPC0.N_22615\);
GRFPC0_LDLOCK_1_27_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_187\,
dataf => \GRFPC0.D.STLCK\(15),
datae => \GRFPC0.D.STLCK\(31),
datad => N_107);
GRFPC0_LDLOCK_1_26_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_186\,
dataf => \GRFPC0.D.STLCK\(14),
datae => \GRFPC0.D.STLCK\(30),
datad => N_107);
GRFPC0_LDLOCK_1_24_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_184\,
dataf => \GRFPC0.D.STLCK\(13),
datae => \GRFPC0.D.STLCK\(29),
datad => N_107);
GRFPC0_LDLOCK_1_23_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_183\,
dataf => \GRFPC0.D.STLCK\(12),
datae => \GRFPC0.D.STLCK\(28),
datad => N_107);
GRFPC0_LDLOCK_1_20_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_23587\,
dataf => \GRFPC0.D.STLCK\(11),
datae => \GRFPC0.D.STLCK\(27),
datad => N_107);
GRFPC0_LDLOCK_1_19_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_23586\,
dataf => \GRFPC0.D.STLCK\(10),
datae => \GRFPC0.D.STLCK\(26),
datad => N_107);
GRFPC0_LDLOCK_1_17_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_23585\,
dataf => \GRFPC0.D.STLCK\(9),
datae => \GRFPC0.D.STLCK\(25),
datad => N_107);
GRFPC0_LDLOCK_1_16_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_23584\,
dataf => \GRFPC0.D.STLCK\(8),
datae => \GRFPC0.D.STLCK\(24),
datad => N_107);
GRFPC0_LDLOCK_1_12_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_172\,
dataf => \GRFPC0.D.STLCK\(7),
datae => \GRFPC0.D.STLCK\(23),
datad => N_107);
GRFPC0_LDLOCK_1_11_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_171\,
dataf => \GRFPC0.D.STLCK\(6),
datae => \GRFPC0.D.STLCK\(22),
datad => N_107);
GRFPC0_LDLOCK_1_9_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_23580\,
dataf => \GRFPC0.D.STLCK\(5),
datae => \GRFPC0.D.STLCK\(21),
datad => N_107);
GRFPC0_LDLOCK_1_8_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_23579\,
dataf => \GRFPC0.D.STLCK\(4),
datae => \GRFPC0.D.STLCK\(20),
datad => N_107);
GRFPC0_LDLOCK_1_5_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_23577\,
dataf => \GRFPC0.D.STLCK\(3),
datae => \GRFPC0.D.STLCK\(19),
datad => N_107);
GRFPC0_LDLOCK_1_4_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_164\,
dataf => \GRFPC0.D.STLCK\(2),
datae => \GRFPC0.D.STLCK\(18),
datad => N_107);
GRFPC0_LDLOCK_1_2_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_23575\,
dataf => \GRFPC0.D.STLCK\(1),
datae => \GRFPC0.D.STLCK\(17),
datad => N_107);
GRFPC0_LDLOCK_1_1_I_M2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.N_161\,
dataf => \GRFPC0.D.STLCK\(0),
datae => \GRFPC0.D.STLCK\(16),
datad => N_107);
\GRFPC0_FP_PIPELINE_DEPMUX_TMP_15_I_M2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fb73ea62d951c840")
port map (
combout => \GRFPC0.N_206\,
dataf => \GRFPC0.N_17502\,
datae => \GRFPC0.N_17496\,
datad => \GRFPC0.N_17516\,
datac => \GRFPC0.N_17510\,
datab => N_105,
dataa => N_104);
GRFPC0_FP_PIPELINE_VRFA_ST_1_U_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VRFA.ST_1_1\,
dataf => N_109,
datae => N_108,
datad => N_101,
datac => N_100);
GRFPC0_FP_PIPELINE_UN4_LDLOCK3_10_1_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_9475_1\,
dataf => N_105,
datae => N_104);
GRFPC0_FP_PIPELINE_VRFA_RDD_1_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_22615\,
dataf => \GRFPC0.N_220\,
datae => N_98,
datad => N_97,
datac => N_109,
datab => N_108);
\GRFPC0_FP_PIPELINE_0_STDEP_442_0_IV_I_O3_4_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ffffffff")
port map (
combout => \GRFPC0.N_23514\,
dataf => N_103,
datae => \GRFPC0.N_22615\);
GRFPC0_FP_PIPELINE_LDLOCK23_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000c")
port map (
combout => \GRFPC0.N_9203\,
dataf => N_100,
datae => N_98,
datad => N_101,
datac => N_99,
datab => N_102);
GRFPC0_FP_PIPELINE_LDLOCK_1_IV_642_0_A2_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.N_220\,
dataf => N_99,
datae => N_102,
datad => N_101,
datac => N_100);
GRFPC0_RFA_RDWR_0_0_G1_0_1554_X2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffff0000")
port map (
combout => N_45119_I,
dataf => N_97,
datae => N_98);
GRFPC0_FP_PIPELINE_4_CHECK_DEP_UN2004_REGDEPX2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.4.CHECK_DEP.UN2004_REGDEPX2_1\,
dataf => \GRFPC0.EX.CTRL.INST\(26),
datae => \GRFPC0.EX.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_6_REGDEPX2_200_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc00fcf000000000")
port map (
combout => \GRFPC0.N_24145\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datae => \GRFPC0.N_706\,
datad => \GRFPC0.N_25516_2\,
datac => \GRFPC0.FP_PIPELINE.6.CHECK_DEP.UN2976_REGDEPX2\,
datab => \GRFPC0.FP_PIPELINE.6.REGDEPX2_200_0_A2_6_0\(0));
GRFPC0_FP_PIPELINE_6_CHECK_DEP_UN2976_REGDEPX2_2_I_O3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_25497\,
dataf => \GRFPC0.WR.CTRL.INST\(27),
datae => \GRFPC0.WR.CTRL.INST\(28));
\GRFPC0_WR2SEL_1_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0f00000f0f0f00")
port map (
combout => \GRFPC0.WR2SEL_1\(4),
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datae => \GRFPC0.WR2.RREG.RESV\,
datad => \GRFPC0.FPR.RDY\,
datac => N_37);
\GRFPC0_WRSEL_1_I_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ffffff00ff00ff")
port map (
combout => \GRFPC0.N_24359\,
dataf => \GRFPC0.N_24361\,
datae => \GRFPC0.WR.RREG.RESV\,
datad => N_37);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_20_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffff080008ff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_20\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_18\(0),
datae => \GRFPC0.N_25362\,
datad => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
datac => \GRFPC0.N_702\,
datab => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN800_REGDEPX2_1\,
dataa => \GRFPC0.N_25293_1\);
GRFPC0_FP_PIPELINE_UN86_HOLDN_NE_RNI5FRQ: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f00000f0f0f000")
port map (
combout => \GRFPC0.WR2SEL_1\(7),
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datae => \GRFPC0.WR2.RREG.RESV\,
datad => \GRFPC0.FPR.RDY\,
datac => N_37);
GRFPC0_UN1_WRENX2_2_4_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000f0000f0000f")
port map (
combout => \GRFPC0.UN1_WRENX2_2_4_0\,
dataf => \GRFPC0.N_23714\,
datae => \GRFPC0.FP_PIPELINE.RS1_6\(1),
datad => \GRFPC0.DIV.RD\(2),
datac => \GRFPC0.DIV.RD\(1));
GRFPC0_FP_PIPELINE_0_REGDEP14_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000e1004b00")
port map (
combout => \GRFPC0.UN1_WRENX2_2_3_0\,
dataf => \GRFPC0.N_56_I\,
datae => \GRFPC0.N_24063\,
datad => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datac => \GRFPC0.DIV.RD\(4),
datab => \GRFPC0.RFA.RS1\(4),
dataa => N_37);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_21_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
dataf => \GRFPC0.DIV.RDD\,
datae => \GRFPC0.DIV.INST\(0));
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_7_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_7\(1),
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_21\(1),
datae => \GRFPC0.DIV.INST\(3),
datad => \GRFPC0.DIV.INST\(2),
datac => \GRFPC0.DIV.INST\(4),
datab => \GRFPC0.DIV.INST\(1));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_299_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffc000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_299\(1),
dataf => \GRFPC0.FP_PIPELINE.9.REGDEPX2_296\(1),
datae => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_7\(1),
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(1),
datac => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4401_REGDEPX2\,
datab => \GRFPC0.DIV.RS1V\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_A2_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000c0000000")
port map (
combout => \GRFPC0.N_25250\,
dataf => \GRFPC0.N_705\,
datae => \GRFPC0.N_25250_3\,
datad => \GRFPC0.WR.CTRL.RS1V\,
datac => \GRFPC0.WR.CTRL.INST\(15),
datab => \GRFPC0.WR.CTRL.INST\(18));
GRFPC0_FP_PIPELINE_9_CHECK_DEP_UN4401_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000f00000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4401_REGDEPX2\,
dataf => \GRFPC0.DIV.INST\(17),
datae => \GRFPC0.DIV.INST\(15),
datad => \GRFPC0.DIV.INST\(16),
datac => \GRFPC0.DIV.INST\(18));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_8_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_8\(1),
dataf => \GRFPC0.DIV.RDD\,
datae => \GRFPC0.DIV.INST\(14));
GRFPC0_FP_PIPELINE_0_UN1_DIV_RD_1_2_0_X2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffff0f0ff0f00")
port map (
combout => \GRFPC0.N_56_I\,
dataf => \GRFPC0.N_24062\,
datae => \GRFPC0.DIV.RD\(3),
datad => \GRFPC0.RFA.RS1\(3),
datac => N_37);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_296_0_A2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPC0.N_24118\,
dataf => \GRFPC0.DIV.RD\(4),
datae => \GRFPC0.DIV.RD\(2),
datad => \GRFPC0.DIV.RD\(1));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_19_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_19\(1),
dataf => \GRFPC0.DIV.RDD\,
datae => \GRFPC0.DIV.RD\(0));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_7_I_A3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_704\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_7_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000000003")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_7\(0),
dataf => \GRFPC0.N_704\,
datae => \GRFPC0.WR.CTRL.INST\(15),
datad => \GRFPC0.WR.CTRL.INST\(16),
datac => \GRFPC0.WR.CTRL.INST\(18),
datab => \GRFPC0.WR.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_17_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.N_25294_1\,
dataf => \GRFPC0.WR.CTRL.INST\(26),
datae => \GRFPC0.WR.CTRL.INST\(29));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN253_REGDEPX2_1_0_A2_0_A2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN253_REGDEPX2_1\,
dataf => \GRFPC0.EX.CTRL.INST\(2),
datae => \GRFPC0.EX.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_15_I_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3f003f3f3f3f3f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_I_0\(0),
dataf => \GRFPC0.N_25460\,
datae => \GRFPC0.N_25388\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN253_REGDEPX2_1\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_I_A2_0_1\(0),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(0));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN271_REGDEPX2_0_O2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_25380\,
dataf => \GRFPC0.MEM.CTRL.INST\(26),
datae => \GRFPC0.MEM.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_15_I_TZ_TZ_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000cccffffffff")
port map (
combout => \GRFPC0.N_25362_TZ_TZ\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
datae => \GRFPC0.N_25448\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN302_REGDEPX2\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0),
datab => \GRFPC0.N_25384\);
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_12_0_A2_0_A2_0_A2_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.N_25190\,
dataf => \GRFPC0.EX.CTRL.INST\(15),
datae => \GRFPC0.EX.CTRL.INST\(16));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_15_I_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3fff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_I_2\(0),
dataf => \GRFPC0.N_25362_TZ_TZ\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_I_0\(0),
datad => \GRFPC0.N_24765_1\,
datac => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN695_REGDEPX2_2\,
datab => \GRFPC0.N_25190\);
\GRFPC0_FIFO_INST_0_RNIQ3RP_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.V.STDATA_14\(31),
dataf => \GRFPC0.FIFO.RD_0\(0),
datae => \GRFPC0.FIFO.INST_0\(31),
datad => \GRFPC0.FIFO.INST_1\(31));
\GRFPC0_V_STDATA_14_I_M2_24_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_24035\,
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(24),
datad => \GRFPC0.FIFO.INST_1\(24));
\GRFPC0_V_STDATA_14_I_M2_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \FPI.FLOP\(3),
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_1\(8),
datad => \GRFPC0.FIFO.INST_0\(8));
\GRFPC0_V_STDATA_14_I_M2_19_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPC0.N_236\,
dataf => \GRFPC0.FIFO.INST_1\(19),
datae => \GRFPC0.FIFO.INST_0\(19),
datad => \GRFPC0.FIFO.RD\(0));
\GRFPC0_V_STDATA_14_I_M2_21_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_222\,
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(21),
datad => \GRFPC0.FIFO.INST_1\(21));
\GRFPC0_V_STDATA_14_I_M2_9_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \FPI.FLOP\(4),
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(9),
datad => \GRFPC0.FIFO.INST_1\(9));
\GRFPC0_V_STDATA_14_I_M2_13_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \FPI.FLOP\(8),
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(13),
datad => \GRFPC0.FIFO.INST_1\(13));
\GRFPC0_V_STDATA_14_I_M2_12_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \FPI.FLOP\(7),
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_1\(12),
datad => \GRFPC0.FIFO.INST_0\(12));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_2_9_5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_9_5\(0),
dataf => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_9_2\(0),
datae => \FPI.FLOP\(3),
datad => \GRFPC0.V.STDATA_14\(31),
datac => \GRFPC0.DIVI_0_SQMUXA_1_2\,
datab => \GRFPC0.N_24035\);
\GRFPC0_V_STDATA_14_I_M2_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \FPI.FLOP\(0),
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(5),
datad => \GRFPC0.FIFO.INST_1\(5));
\GRFPC0_R_STATE_RNIBIPV1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0f00")
port map (
combout => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
dataf => N_44718_1,
datae => \GRFPC0.WR2.CTRL.SEQERR\,
datad => \GRFPC0.R.STATE\(0),
datac => \GRFPC0.R.STATE\(1));
\GRFPC0_V_STDATA_14_I_M2_23_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_24034\,
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(23),
datad => \GRFPC0.FIFO.INST_1\(23));
\GRFPC0_V_STDATA_14_I_M2_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \FPI.FLOP\(2),
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(7),
datad => \GRFPC0.FIFO.INST_1\(7));
GRFPC0_FP_PIPELINE_UN1_V_FSR_CEXC_2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f00ff0f0fffff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN1_V.FSR.CEXC_2_1\,
dataf => \GRFPC0.R.FSR.TEM\(0),
datae => \GRFPC0.R.FSR.TEM\(4),
datad => \GRFPC0.WR2.RREG.EXCT\(0),
datac => \GRFPC0.WR2.RREG.EXCT\(4));
\GRFPC0_R_FSR_TEM_RNIKDDI5_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f0f8f0f0f0")
port map (
combout => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\,
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datae => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
datad => \FPO.EXC\(0),
datac => \GRFPC0.FP_PIPELINE.UN1_WR2.RREG.RESV\,
datab => \GRFPC0.FPR.RDY\,
dataa => \GRFPC0.R.FSR.TEM\(0));
\GRFPC0_DIV_EXCT_0_0_2__G0_0_A3_0\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.DIV.EXCT_0_0_2__G0_0_A3_0\,
dataf => \GRFPC0.DIV.EXCT_0_0_5__I0_I_1\,
datae => \GRFPU0.GRFPU_X0.ST4.MOF\,
datad => \GRFPU0.GRFPU_X0.ST4.IOF\,
datac => \GRFPU0.GRFPU_X0.ST4.ADDOF\);
GRFPU0_GRFPU_X0_COMB_VEXC_5_5_I_0_O3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_20301\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(2));
GRFPC0_FP_PIPELINE_UN86_HOLDN_NE_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffffffff00")
port map (
combout => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_0\,
dataf => \GRFPC0.FPR.ID\(0),
datae => \GRFPC0.WR2.CTRL.ID\(0),
datad => \GRFPC0.WR2.CTRL.ID\(7));
GRFPC0_FP_PIPELINE_UN86_HOLDN_NE_3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"7fbfdfeff7fbfdfe")
port map (
combout => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_3\,
dataf => \GRFPC0.FPR.ID\(5),
datae => \GRFPC0.FPR.ID\(4),
datad => \GRFPC0.FPR.ID\(2),
datac => \GRFPC0.WR2.CTRL.ID\(5),
datab => \GRFPC0.WR2.CTRL.ID\(4),
dataa => \GRFPC0.WR2.CTRL.ID\(2));
GRFPC0_FP_PIPELINE_UN86_HOLDN_NE: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff7bde")
port map (
combout => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_3\,
datae => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE_0\,
datad => \GRFPC0.FPR.ID\(3),
datac => \GRFPC0.FPR.ID\(1),
datab => \GRFPC0.WR2.CTRL.ID\(3),
dataa => \GRFPC0.WR2.CTRL.ID\(1));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_5_0_A2_2_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcf0000cfff0000")
port map (
combout => \GRFPC0.DIVI_0_SQMUXA_8\,
dataf => \GRFPC0.FPEXC_0_SQMUXA_D\,
datae => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_2_0_3\(0),
datad => \GRFPC0.FIFO.VCNT_0_0_0__G1_1_4236_I_O6_1_0\,
datac => \GRFPC0.FP_PIPELINE.UN1_HOLDN_3\,
datab => N_44718_1);
\GRFPC0_FIFO_INST_1_RNIK0J73_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.N_23966\,
dataf => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\);
\GRFPC0_FP_PIPELINE_0_REGDEPX2_15_I_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"003000f03030f0f0")
port map (
combout => \GRFPC0.N_25362\,
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.N_23946_2\,
datad => \GRFPC0.N_25377\,
datac => \GRFPC0.FP_PIPELINE.0.REGDEPX2_15_I_2\(0),
datab => \GRFPC0.FP_PIPELINE.0.REGDEPX2_5_0_A2_1_0\(0));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_6_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.N_25293_1\,
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_2_I_A3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_702\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR.CTRL.INST\(0));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN771_REGDEPX2_1_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN771_REGDEPX2_1\,
dataf => \GRFPC0.WR.CTRL.INST\(27),
datae => \GRFPC0.WR.CTRL.INST\(28));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN800_REGDEPX2_1_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN800_REGDEPX2_1\,
dataf => \GRFPC0.WR.CTRL.INST\(3),
datae => \GRFPC0.WR.CTRL.INST\(2));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3917_REGDEPX2_0_A2_0_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff0000")
port map (
combout => \GRFPC0.N_267\,
dataf => \GRFPC0.WR2.CTRL.INST\(16),
datae => \GRFPC0.WR2.CTRL.INST\(18),
datad => \GRFPC0.WR2.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_13_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13\(1),
dataf => \GRFPC0.WR2.CTRL.RDD\,
datae => \GRFPC0.WR2.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_A2_7_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPC0.N_25282\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.DIV\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_13\(1),
datad => \GRFPC0.N_267\,
datac => \GRFPC0.WR2.CTRL.RS1V\,
datab => \GRFPC0.WR2.CTRL.INST\(15));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN816_REGDEPX2_1_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_25227\,
dataf => \GRFPC0.WR2.CTRL.INST\(28),
datae => \GRFPC0.WR2.CTRL.INST\(27));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_16_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_16\(1),
dataf => \GRFPC0.WR2.CTRL.RDD\,
datae => \GRFPC0.WR2.CTRL.INST\(25));
GRFPC0_FP_PIPELINE_10_CHECK_DEP_UN4664_REGDEPX2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_25316\,
dataf => \GRFPC0.EX.CTRL.INST\(18),
datae => \GRFPC0.EX.CTRL.INST\(17));
GRFPC0_FP_PIPELINE_1_CHECK_DEP_UN845_REGDEPX2_1_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.N_25226\,
dataf => \GRFPC0.WR2.CTRL.INST\(2),
datae => \GRFPC0.WR2.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_10_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_10\(1),
dataf => \GRFPC0.WR2.CTRL.RDD\,
datae => \GRFPC0.WR2.CTRL.INST\(0));
\GRFPC0_FP_PIPELINE_10_CHECK_DEP_DEP_20_2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_24160_1\,
dataf => \GRFPC0.EX.CTRL.INST\(29),
datae => \GRFPC0.EX.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_A2_12_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000c00000")
port map (
combout => \GRFPC0.N_25274\,
dataf => \GRFPC0.EX.CTRL.INST\(3),
datae => \GRFPC0.EX.CTRL.INST\(4),
datad => \GRFPC0.EX.CTRL.INST\(2),
datac => \GRFPC0.EX.CTRL.INST\(1),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_O2_3_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffc0ff00")
port map (
combout => \GRFPC0.FP_PIPELINE.9.REGDEPX2_295_0_O2_3_1\(1),
dataf => \GRFPC0.N_25273\,
datae => \GRFPC0.N_24160_1\,
datad => \GRFPC0.N_25274\,
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1),
datab => \GRFPC0.N_24325\);
\GRFPC0_FP_PIPELINE_9_REGDEPX2_295_0_O2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffc000ffff0000")
port map (
combout => \GRFPC0.N_25237\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datae => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_19\(1),
datad => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4254_REGDEPX2_2\,
datac => \GRFPC0.MEM.CTRL.INST\(26),
datab => \GRFPC0.MEM.CTRL.INST\(29));
\GRFPC0_FP_PIPELINE_9_CHECK_DEP_DEP_19_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000c000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.DEP_19\(1),
dataf => \GRFPC0.MEM.CTRL.INST\(1),
datae => \GRFPC0.MEM.CTRL.INST\(4),
datad => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST\(3),
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1));
GRFPC0_FP_PIPELINE_8_CHECK_DEP_UN3813_REGDEPX2_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.9.CHECK_DEP.UN4254_REGDEPX2_2\,
dataf => \GRFPC0.MEM.CTRL.INST\(27),
datae => \GRFPC0.MEM.CTRL.INST\(28));
GRFPC0_FP_PIPELINE_0_UN1_WR2_CTRL_RD_1_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff0ff0f00fff00")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_3\,
dataf => \GRFPC0.N_24062\,
datae => \GRFPC0.RFA.RS1\(3),
datad => \GRFPC0.WR2.CTRL.RD\(3),
datac => N_37);
GRFPC0_FP_PIPELINE_0_WR2EN2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000fc0330cf")
port map (
combout => \GRFPC0.FP_PIPELINE.0.WR2EN2_1\,
dataf => \GRFPC0.FP_PIPELINE.0.UN1_WR2.CTRL.RD_2_3\,
datae => \GRFPC0.N_24063\,
datad => \GRFPC0.WR2.CTRL.RD\(4),
datac => \GRFPC0.RFA.RS1\(4),
datab => N_37);
\GRFPC0_FP_PIPELINE_RS1_6_I_M3_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccfff00f00")
port map (
combout => \GRFPC0.N_22825\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.ST_1\,
datae => \GRFPC0.N_22826\,
datad => \GRFPC0.N_22827\,
datac => \GRFPC0.N_23766\,
datab => N_103);
\GRFPC0_FP_PIPELINE_RS1_6_I_M3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPC0.N_22829\,
dataf => \GRFPC0.N_22825\,
datae => \GRFPC0.RFA.RS1\(0),
datad => N_37);
\GRFPC0_FP_PIPELINE_RS1_6_I_M2_0_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccfff00f00")
port map (
combout => \GRFPC0.N_116\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.ST_1\,
datae => \GRFPC0.N_23706\,
datad => \GRFPC0.N_23705\,
datac => \GRFPC0.N_23766\,
datab => N_105);
\GRFPC0_FP_PIPELINE_RS1_6_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccccccccfff00f00")
port map (
combout => \GRFPC0.N_17951\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.ST_1\,
datae => \GRFPC0.VFIFO.INST_1_4\(15),
datad => \GRFPC0.VFIFO.INST_0_4\(15),
datac => \GRFPC0.N_23766\,
datab => N_104);
GRFPC0_FP_PIPELINE_0_WRENX2_I_S_0_4_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0ffff0ffff0ffff0")
port map (
combout => \GRFPC0.FP_PIPELINE.0.WRENX2_I_S_0_4_1\,
dataf => \GRFPC0.N_23714\,
datae => \GRFPC0.FP_PIPELINE.RS1_6\(1),
datad => \GRFPC0.WR.CTRL.RD\(2),
datac => \GRFPC0.WR.CTRL.RD\(1));
\GRFPC0_INST_I_0_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000f3300330f")
port map (
combout => \GRFPC0.INST_I_0\(18),
dataf => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datae => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_0\(18),
datab => \GRFPC0.FIFO.INST_1\(18));
\GRFPC0_FP_PIPELINE_RS1_6_0_I_M2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f00000ccff")
port map (
combout => \GRFPC0.N_24063\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.ST_1\,
datae => \GRFPC0.INST_I_0\(18),
datad => \GRFPC0.N_24061\,
datac => N_107,
datab => N_96);
GRFPC0_FP_PIPELINE_0_REGDEP46_I_S_0_X2_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffff0f0ff0f00")
port map (
combout => \GRFPC0.N_513_I\,
dataf => \GRFPC0.N_24063\,
datae => \GRFPC0.WR.CTRL.RD\(4),
datad => \GRFPC0.RFA.RS1\(4),
datac => N_37);
\GRFPC0_INST_I_0_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000330f000f33")
port map (
combout => \GRFPC0.INST_I_0\(17),
dataf => \GRFPC0.VFIFO.INST_1_1_SQMUXA\,
datae => \GRFPC0.VFIFO.PC_0_1_SQMUXA\,
datad => \GRFPC0.N_23766\,
datac => \GRFPC0.FIFO.INST_1\(17),
datab => \GRFPC0.FIFO.INST_0\(17));
\GRFPC0_FP_PIPELINE_RS1_6_0_I_M2_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0f0f00000ccff")
port map (
combout => \GRFPC0.N_24062\,
dataf => \GRFPC0.FP_PIPELINE.VRFA.ST_1\,
datae => \GRFPC0.INST_I_0\(17),
datad => \GRFPC0.N_24061\,
datac => N_106,
datab => N_95);
GRFPC0_FP_PIPELINE_0_REGDEP46_I_S_0_X2_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000ffff0f0ff0f00")
port map (
combout => \GRFPC0.N_512_I\,
dataf => \GRFPC0.N_24062\,
datae => \GRFPC0.WR.CTRL.RD\(3),
datad => \GRFPC0.RFA.RS1\(3),
datac => N_37);
GRFPC0_FP_PIPELINE_0_WRENX2_I_S_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff7fffffffb")
port map (
combout => \GRFPC0.N_21346\,
dataf => \GRFPC0.N_22829\,
datae => \GRFPC0.FP_PIPELINE.0.WRENX2_I_S_0_4_1\,
datad => \GRFPC0.N_513_I\,
datac => \GRFPC0.N_512_I\,
datab => \GRFPC0.WR.CTRL.RDWR\,
dataa => \GRFPC0.WR.CTRL.RD\(0));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_3_RNO_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000cffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_O2_0_845_0\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datae => \GRFPC0.N_25710\,
datad => \GRFPC0.N_25376\,
datac => \GRFPC0.MEM.CTRL.INST\(26),
datab => \GRFPC0.MEM.CTRL.INST\(27));
GRFPC0_FP_PIPELINE_14_CHECK_DEP_UN6443_REGDEPX2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_24189\,
dataf => \GRFPC0.EX.CTRL.INST\(2),
datae => \GRFPC0.EX.CTRL.INST\(1));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_75_0_3_RNO_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffc0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_O2_0_845_1\,
dataf => \GRFPC0.FP_PIPELINE.2.REGDEPX2_75_0_O2_0_845_0\,
datae => \GRFPC0.FP_PIPELINE.0.UN1_EX.CTRL.DIV\,
datad => \GRFPC0.N_25460\,
datac => \GRFPC0.N_24189\,
datab => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1));
\GRFPC0_FP_PIPELINE_8_REGDEPX2_250_0_A2_4_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000c00000000")
port map (
combout => \GRFPC0.N_25301\,
dataf => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datab => \GRFPC0.N_24484\);
\GRFPC0_FP_PIPELINE_6_REGDEPX2_195_0_A2_3_A2_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_24180\,
dataf => \GRFPC0.MEM.CTRL.INST\(16),
datae => \GRFPC0.MEM.CTRL.INST\(15));
\GRFPC0_FP_PIPELINE_2_REGDEPX2_64_0_A2_4_A2_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff0000")
port map (
combout => \GRFPC0.N_24539\,
dataf => \GRFPC0.FIFO.INST_0\(17),
datae => \GRFPC0.FIFO.INST_0\(16),
datad => \GRFPC0.FIFO.INST_0\(15));
GRFPC0_FP_PIPELINE_2_CHECK_DEP_UN1181_REGDEPX2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000f0000")
port map (
combout => \GRFPC0.FP_PIPELINE.2.CHECK_DEP.UN1181_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(15),
datae => \GRFPC0.MEM.CTRL.INST\(16),
datad => \GRFPC0.MEM.CTRL.INST\(18),
datac => \GRFPC0.MEM.CTRL.INST\(17));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN302_REGDEPX2_0_A2_1_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000000f")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN302_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(1),
datae => \GRFPC0.MEM.CTRL.INST\(4),
datad => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST\(3));
\GRFPC0_FP_PIPELINE_8_CHECK_DEP_DEP_24_IV_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff3ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.8.CHECK_DEP.DEP_24_IV\(0),
dataf => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datab => \GRFPC0.N_25649\);
\GRFPC0_V_STDATA_14_10_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \FPI.FLOP\(5),
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.INST_0\(10),
datad => \GRFPC0.FIFO.INST_1\(10));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_334_0_A2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000c00000000000")
port map (
combout => \GRFPC0.N_24500\,
dataf => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datab => \GRFPC0.N_24484\);
\GRFPC0_FP_PIPELINE_2_REGDEPX2_64_0_A2_3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_23530_2\,
dataf => \GRFPC0.FIFO.INST_1\(17),
datae => \GRFPC0.FIFO.INST_1\(16));
\GRFPC0_FP_PIPELINE_5_REGDEPX2_153_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"30000000ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.5.REGDEPX2_153\(1),
dataf => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_22_IV\(1),
datae => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.UN2357_REGDEPX2_1\,
datad => \GRFPC0.N_25221\,
datac => \FPI.FLOP\(6),
datab => \GRFPC0.V.STDATA_14\(18));
\GRFPC0_FP_PIPELINE_5_CHECK_DEP_DEP_22_IV_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff3ffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.5.CHECK_DEP.DEP_22_IV\(1),
dataf => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datab => \GRFPC0.N_24484\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_410_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffcccccc80")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_410\(1),
dataf => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405\(1),
datae => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_17\(1),
datad => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_4\(1),
datac => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.DEP_10\(1),
datab => \GRFPC0.FP_PIPELINE.0.UN1_WR.CTRL.DIV\,
dataa => \GRFPC0.WR.CTRL.RS1V\);
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1653_REGDEPX2_2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1653_REGDEPX2_2\,
dataf => \GRFPC0.WR.CTRL.INST\(26),
datae => \GRFPC0.WR.CTRL.INST\(27));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1653_REGDEPX2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1653_REGDEPX2_0\,
dataf => \GRFPC0.WR.CTRL.INST\(29),
datae => \GRFPC0.WR.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_12_I_A3_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.N_706\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_VEX_CTRL_PC_3_I_M2_30_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_256\,
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.PC_0\(30),
datad => \GRFPC0.FIFO.PC_1\(30));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN430_REGDEPX2_2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.1.CHECK_DEP.UN873_REGDEPX2_2\,
dataf => \GRFPC0.DIV.INST\(17),
datae => \GRFPC0.DIV.INST\(18));
\GRFPC0_FP_PIPELINE_0_REGDEPX2_330_0_A2_9_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f000300000000000")
port map (
combout => \GRFPC0.N_263\,
dataf => \GRFPC0.FP_PIPELINE.UN1_DIV.EXEC\,
datae => \GRFPC0.DIV.RDD\,
datad => \GRFPC0.DIV.INST\(16),
datac => \GRFPC0.DIV.RS1V\,
datab => \GRFPC0.DIV.INST\(14));
GRFPC0_FP_PIPELINE_0_CHECK_DEP_UN369_REGDEPX2_1_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.UN369_REGDEPX2_1\,
dataf => \GRFPC0.WR2.CTRL.INST\(26),
datae => \GRFPC0.WR2.CTRL.INST\(27));
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN6092_REGDEPX2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f00000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.CHECK_DEP.UN6092_REGDEPX2\,
dataf => \GRFPC0.WR.CTRL.INST\(4),
datae => \GRFPC0.WR.CTRL.INST\(3),
datad => \GRFPC0.WR.CTRL.INST\(1),
datac => \GRFPC0.WR.CTRL.INST\(2));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_2_I_A3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.N_703\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR.CTRL.INST\(0));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5636_REGDEPX2_2_I_O3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_25498\,
dataf => \GRFPC0.WR.CTRL.INST\(18),
datae => \GRFPC0.WR.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_7_I_A3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.N_705\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_400_0_A2_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_400_0_A2_2_0\(1),
dataf => \GRFPC0.EX.CTRL.INST\(16),
datae => \GRFPC0.EX.CTRL.INST\(15),
datad => \GRFPC0.EX.CTRL.INST\(18),
datac => \GRFPC0.EX.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A2_2_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_24181\,
dataf => \GRFPC0.MEM.CTRL.INST\(15),
datae => \GRFPC0.MEM.CTRL.INST\(16));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5591_REGDEPX2_1_I_O2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_24137\,
dataf => \GRFPC0.MEM.CTRL.INST\(17),
datae => \GRFPC0.MEM.CTRL.INST\(18));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_400_0_A2_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c00000000000000")
port map (
combout => \GRFPC0.N_25153\,
dataf => \GRFPC0.N_25686_1\,
datae => \GRFPC0.EX.CTRL.INST\(3),
datad => \GRFPC0.EX.CTRL.INST\(4),
datac => \GRFPC0.EX.CTRL.INST\(2),
datab => \GRFPC0.EX.CTRL.INST\(1));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5606_REGDEPX2_1_I_O3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_25383\,
dataf => \GRFPC0.MEM.CTRL.INST\(4),
datae => \GRFPC0.MEM.CTRL.INST\(3));
GRFPC0_FP_PIPELINE_0_UN1_MEM_CTRL_DIV_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.0.UN1_MEM.CTRL.DIV\,
dataf => \GRFPC0.MEM.RREG.RESV\,
datae => \GRFPC0.MEM.CTRL.DIV\);
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00c0000000000000")
port map (
combout => \GRFPC0.N_24166\,
dataf => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(1),
datae => \GRFPC0.N_24199\,
datad => \GRFPC0.MEM.CTRL.INST\(27),
datac => \GRFPC0.MEM.CTRL.INST\(29),
datab => \GRFPC0.MEM.CTRL.INST\(28));
GRFPC0_FP_PIPELINE_1_0_CHECK_DEP_UN408_REGDEPX_1_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffff0000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.0.CHECK_DEP.UN408_REGDEPX_1\,
dataf => \GRFPC0.FIFO.INST_0\(16),
datae => \GRFPC0.FIFO.INST_0\(15));
GRFPC0_FP_PIPELINE_13_CHECK_DEP_UN5885_REGDEPX2_0_A2_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.FP_PIPELINE.1.1.CHECK_DEP.UN512_REGDEPX_0\,
dataf => \GRFPC0.FIFO.INST_1\(15),
datae => \GRFPC0.FIFO.INST_1\(16));
\GRFPC0_FP_PIPELINE_13_REGDEPX2_405_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffff8fff8fff8")
port map (
combout => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405\(1),
dataf => \GRFPC0.DIVI_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.13.REGDEPX2_394\(1),
datad => \GRFPC0.FP_PIPELINE.13.REGDEPX2_405_0_2\(1),
datac => \GRFPC0.N_24168\,
datab => \GRFPC0.N_280\,
dataa => \GRFPC0.FP_PIPELINE.13.REGDEPX2_400_0_A2_2_0\(1));
GRFPC0_FP_PIPELINE_12_CHECK_DEP_UN5622_REGDEPX2_2_I_O3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_25496\,
dataf => \GRFPC0.WR.CTRL.INST\(29),
datae => \GRFPC0.WR.CTRL.INST\(28));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_12_I_A3_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.N_707\,
dataf => \GRFPC0.WR.CTRL.RDD\,
datae => \GRFPC0.WR.CTRL.INST\(25));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_103_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffc0ff00ffffffff")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_103\(0),
dataf => \GRFPC0.N_27\,
datae => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(0),
datad => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.DEP_17\(0),
datac => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1622_REGDEPX2\,
datab => \GRFPC0.MEM.CTRL.RS1V\);
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1637_REGDEPX2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000f0000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1637_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(1),
datae => \GRFPC0.MEM.CTRL.INST\(4),
datad => \GRFPC0.MEM.CTRL.INST\(2),
datac => \GRFPC0.MEM.CTRL.INST\(3));
GRFPC0_FP_PIPELINE_3_CHECK_DEP_UN1622_REGDEPX2_0_A2_0_A2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.CHECK_DEP.UN1622_REGDEPX2\,
dataf => \GRFPC0.MEM.CTRL.INST\(15),
datae => \GRFPC0.MEM.CTRL.INST\(16),
datad => \GRFPC0.MEM.CTRL.INST\(18),
datac => \GRFPC0.MEM.CTRL.INST\(17));
\GRFPC0_FP_PIPELINE_0_CHECK_DEP_DEP_2_20_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_20\(0),
dataf => \GRFPC0.N_579\,
datae => \GRFPC0.MEM.CTRL.INST\(14));
\GRFPC0_FP_PIPELINE_3_REGDEPX2_94_0_A2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000c000")
port map (
combout => \GRFPC0.N_24655\,
dataf => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
datab => \GRFPC0.N_25649\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_94_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3000")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_94\(0),
dataf => \GRFPC0.N_24655\,
datae => \GRFPC0.N_24656\,
datad => \GRFPC0.N_24657_2\,
datac => \GRFPC0.N_23975\,
datab => \GRFPC0.N_24271\);
\GRFPC0_FP_PIPELINE_3_REGDEPX2_100_I_A4_1_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0f0fffff030f33ff")
port map (
combout => \GRFPC0.FP_PIPELINE.3.REGDEPX2_100_I_A4_1_0\(0),
dataf => \GRFPC0.N_25122\,
datae => \GRFPC0.N_25197\,
datad => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(0),
datac => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(0),
datab => \GRFPC0.N_24322\);
\GRFPC0_FIFO_INST_1_RNI04SP_25_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.V.STDATA_14\(25),
dataf => \GRFPC0.FIFO.INST_0\(25),
datae => \GRFPC0.FIFO.RD_0\(0),
datad => \GRFPC0.FIFO.INST_1\(25));
\GRFPC0_FIFO_INST_1_RNI2CSP_26_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
dataf => \GRFPC0.FIFO.INST_0\(26),
datae => \GRFPC0.FIFO.RD_0\(0),
datad => \GRFPC0.FIFO.INST_1\(26));
\GRFPC0_FIFO_RD_0_RNI6SSP_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
dataf => \GRFPC0.FIFO.INST_0\(28),
datae => \GRFPC0.FIFO.INST_1\(28),
datad => \GRFPC0.FIFO.RD_0\(0));
\GRFPC0_FIFO_INST_1_RNI4KSP_27_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.EX.CTRL.RD_0_0_2__G3\,
dataf => \GRFPC0.FIFO.INST_0\(27),
datae => \GRFPC0.FIFO.RD_0\(0),
datad => \GRFPC0.FIFO.INST_1\(27));
\GRFPC0_FIFO_RD_0_RNI84TP_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
dataf => \GRFPC0.FIFO.INST_0\(29),
datae => \GRFPC0.FIFO.INST_1\(29),
datad => \GRFPC0.FIFO.RD_0\(0));
\GRFPC0_FP_PIPELINE_7_REGDEPX2_215_I_O3_1_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffff0fffffff")
port map (
combout => \GRFPC0.N_24568\,
dataf => \GRFPC0.EX.CTRL.RD_0_0_4__G3\,
datae => \GRFPC0.EX.CTRL.RD_0_0_3__G3\,
datad => \GRFPC0.EX.CTRL.RD_0_0_1__G3\,
datac => \GRFPC0.EX.CTRL.RD_0_0_2__G3\);
\GRFPC0_V_STDATA_14_I_M2_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff000000ff00")
port map (
combout => \GRFPC0.N_226\,
dataf => \GRFPC0.FIFO.INST_1\(3),
datae => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.FIFO.INST_0\(3));
\GRFPC0_V_STDATA_14_I_M2_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_225\,
dataf => \GRFPC0.FIFO.INST_0\(2),
datae => \GRFPC0.FIFO.RD\(0),
datad => \GRFPC0.FIFO.INST_1\(2));
\GRFPC0_V_STDATA_14_I_1_M2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffffff000000")
port map (
combout => \GRFPC0.N_24039\,
dataf => \GRFPC0.FIFO.INST_0\(1),
datae => \GRFPC0.FIFO.RD_3\(0),
datad => \GRFPC0.FIFO.INST_1\(1));
\GRFPC0_V_STDATA_14_I_M2_4_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_227\,
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_1\(4),
datad => \GRFPC0.FIFO.INST_0\(4));
\GRFPC0_V_STDATA_14_I_M2_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_223\,
dataf => \GRFPC0.FIFO.RD_3\(0),
datae => \GRFPC0.FIFO.INST_0\(0),
datad => \GRFPC0.FIFO.INST_1\(0));
\GRFPC0_V_STDATA_14_I_M2_17_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPC0.N_24489\,
dataf => \GRFPC0.FIFO.INST_1\(17),
datae => \GRFPC0.FIFO.INST_0\(17),
datad => \GRFPC0.FIFO.RD\(0));
\GRFPC0_V_STDATA_14_I_M2_16_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_24488\,
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(16),
datad => \GRFPC0.FIFO.INST_1\(16));
\GRFPC0_V_STDATA_14_0_A2_I_O2_18_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => \GRFPC0.N_24643\,
dataf => \GRFPC0.FIFO.INST_1\(18),
datae => \GRFPC0.FIFO.RD_3\(0));
\GRFPC0_FP_PIPELINE_11_REGDEPX2_334_0_A2_3_0_A2_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffff00000000")
port map (
combout => \GRFPC0.N_24531\,
dataf => \GRFPC0.FIFO.INST_0\(18),
datae => \GRFPC0.FIFO.RD_1\(0));
\GRFPC0_V_STDATA_14_I_M2_15_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000ff00ff00")
port map (
combout => \GRFPC0.N_24487\,
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_1\(15),
datad => \GRFPC0.FIFO.INST_0\(15));
\GRFPC0_V_STDATA_14_I_M2_14_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPC0.N_235\,
dataf => \GRFPC0.FIFO.RD\(0),
datae => \GRFPC0.FIFO.INST_0\(14),
datad => \GRFPC0.FIFO.INST_1\(14));
GRFPC0_FP_PIPELINE_UN77_PENDEXC_0_A4: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPC0.FP_PIPELINE.UN77_PENDEXC\,
dataf => \GRFPC0.R.STATE\(0),
datae => \GRFPC0.R.STATE\(1));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M82_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_0_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M81_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03\,
datae => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M79_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00f0000f000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M78_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000f00f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M77_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff000f00f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M75_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fcf0ccc03c300c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M75_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M79_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M74_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M74_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M78_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M73_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fccc3c0cf0c03000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_2_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M73_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M77_0_03\,
datac => \GRFPU0.GRFPU_X0.ST2.REG\(55),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_VST3_REG_33_C1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffffffffff")
port map (
combout => N_32260,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M83_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ffff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M83_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(51));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M82_0_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0f0ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M82_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(51),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(50));
GRFPU0_GRFPU_X0_COMB_SHR_CNV_SHIFT_2_M81_0_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ccccf0f0ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHR.CNV_SHIFT_2.M81_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(49),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(51),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(50));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M7_2_01: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_2_01\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M3_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M7_0_03\,
datad => \GRFPU0.GRFPU_X0.ST2.REG\(54));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M2_0_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M2_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(21),
datab => \GRFPU0.GRFPU_X0.ST2.REG\(22));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M1_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M1_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(20),
datac => \GRFPU0.GRFPU_X0.ST2.REG\(21));
GRFPU0_GRFPU_X0_COMB_SHL_CNV_SHIFT2_2_M0_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHL.CNV_SHIFT2_2.M0_0_03\,
dataf => \GRFPU0.GRFPU_X0.ST2.REG\(53),
datae => \GRFPU0.GRFPU_X0.ST2.REG\(52),
datad => \GRFPU0.GRFPU_X0.ST2.REG\(20));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M104_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M103_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M101_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M100_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M99_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M98_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M102_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M98_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M97_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M101_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M97_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M96_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M100_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M96_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M95_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M99_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M95_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M106_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M106_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M105_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M105_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M104_0_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ffffff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M104_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_1_M103_0_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1.M103_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI_1\(0),
datad => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
datac => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
datab => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M104_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M103_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M101_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000f00f00000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M100_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M99_2_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00f0000f0000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_0_03\,
datad => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M98_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M102_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M98_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M97_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f0f3c0c33033000")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M101_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M97_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M96_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M100_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M96_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M95_2_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f3c33300f0c0300")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_2_03\,
dataf => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03\,
datae => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M99_0_03\,
datad => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M95_0_03\,
datac => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(3),
datab => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(2));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M106_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M106_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M105_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffffff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M105_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.DIVROM0.RADDR\(7));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M104_0_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000fffff0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M104_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.DIVROM0.RADDR\(6),
datac => \GRFPU0.DIVROM0.RADDR\(7));
GRFPU0_GRFPU_X0_ADD_SHIFT_OUT_M103_0_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffccccf0f0ff00")
port map (
combout => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT.M103_0_03\,
dataf => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(1),
datae => \GRFPU0.GRFPU_X0.COMB.SHR.POSI\(0),
datad => \GRFPU0.DIVROM0.RADDR\(5),
datac => \GRFPU0.DIVROM0.RADDR\(6),
datab => \GRFPU0.DIVROM0.RADDR\(7));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M7_2_01: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff0000ff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_2_01\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M3_0_03\,
datae => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M7_0_03\,
datad => \GRFPU0.GRFPU_X0.L4_4\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M2_0_03_0_G0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff00f0f0cccc")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M2_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(0),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(1),
datab => \GRFPU0.GRFPU_X0.ST2.DIFF\(2));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M1_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ff00f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M1_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(0),
datac => \GRFPU0.GRFPU_X0.ST2.DIFF\(1));
GRFPU0_GRFPU_X0_COMB_VST3_FARRES_2_M0_0_03: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000ff00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M0_0_03\,
dataf => \GRFPU0.GRFPU_X0.L4_4\(1),
datae => \GRFPU0.GRFPU_X0.L4_4\(0),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(0));
\GRFPU0_GRFPU_X0_BIAS_4_0_0_0_O2_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff3fff")
port map (
combout => \GRFPU0.GRFPU_X0.N_19691\,
dataf => \GRFPU0.GRFPU_X0.N_5777_I_I_O2_I_O2_2_0_0\,
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(0));
\GRFPU0_GRFPU_X0_BIAS_4_0_0_0_O2_RNI931H_7_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_19700\,
dataf => \GRFPU0.GRFPU_X0.N_19691\,
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(1));
\GRFPU0_GRFPU_X0_ST2_FLOP_RNIMOTG_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.N_5777_I_I_O2_I_O2_2_0_0\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(4),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(8));
\GRFPU0_GRFPU_X0_ST2_FLOP_RNIQGR11_0_0_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff0ffffffffffff")
port map (
combout => \GRFPU0.GRFPU_X0.N_5777_I_I_O2_I_O2_2\,
dataf => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
datae => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(0));
\GRFPU0_GRFPU_X0_ST2_FLOP_RNIHU5C2_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffffffff3f")
port map (
combout => \GRFPU0.GRFPU_X0.ST3.REG_V_0_0_0__I3_I_3\,
dataf => \GRFPU0.GRFPU_X0.N_5777_I_I_O2_I_O2_2\,
datae => \GRFPU0.GRFPU_X0.N_5777_I_I_O2_I_O2_2_0_0\,
datad => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
datac => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
datab => \GRFPU0.GRFPU_X0.ST2.FLOP\(6));
\GRFPU0_SQRTROM0_DATA_1_0_6__ROM_3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccccccfff33ff33")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_0\(4),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(2),
datab => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPU0_SQRTROM0_DATA_1_0_6__ROM_2\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"015755eeaa55ab55")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_0\(3),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPU0_SQRTROM0_DATA_1_0_6__ROM_1\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"54bdaa442301fe77")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_0\(2),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPU0_SQRTROM0_DATA_1_0_6__ROM_0\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3ee91146dc163e9d")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_0\(1),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPU0_SQRTROM0_DATA_1_0_6_0__ROM\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"d270272d9e70d2db")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_0\(0),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPU0_SQRTROM0_DATA_1_1_6__ROM_5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"55555555555755ff")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_1\(6),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPU0_SQRTROM0_DATA_1_1_6__ROM_4\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaaaaaaaa8aa00")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_1\(5),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPU0_SQRTROM0_DATA_1_1_6__ROM_3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aaaaaaaaaaa8aa15")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_1\(4),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPU0_SQRTROM0_DATA_1_1_6__ROM_2\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00aa02bffffdff40")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_1\(3),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPU0_SQRTROM0_DATA_1_1_6__ROM_1\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"aa55bd402afdbf40")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_1\(2),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPU0_SQRTROM0_DATA_1_1_6__ROM_0\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"7f15e8ea95bd6240")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_1\(1),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPU0_SQRTROM0_DATA_1_1_6_0__ROM\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"9163e943c169c963")
port map (
combout => \GRFPU0.SQRTROM0.DATA_1_1\(0),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(6));
\GRFPU0_DIVROM0_DATA_1_0_6__ROM_4\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000037ffffffff")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_0\(5),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_0_6__ROM_3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"33ffffc800ff03ff")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_0\(4),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_0_6__ROM_2\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccff00c81301fcff")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_0\(3),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_0_6__ROM_1\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cc033fc8ec363c37")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_0\(2),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_0_6__ROM_0\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"4d34d3cb255af05b")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_0\(1),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_0_6_0__ROM\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"867961396aaa54ab")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_0\(0),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_1_6__ROM_5\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000000ff3fff")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_1\(6),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2));
\GRFPU0_DIVROM0_DATA_1_1_6__ROM_4\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff00c000")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_1\(5),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2));
\GRFPU0_DIVROM0_DATA_1_1_6__ROM_3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff37ffff00c000")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_1\(4),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_1_6__ROM_2\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00c837ff00c0ff")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_1\(3),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_1_6__ROM_1\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3f37c8c8377fc003")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_1\(2),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_1_6__ROM_0\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c1c9c9c9c993c334")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_1\(1),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_1_6_0__ROM\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"d25a5a5a5aa7f158")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_1\(0),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_2_6__ROM_4\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000003ffffff")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_2\(5),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2));
\GRFPU0_DIVROM0_DATA_1_2_6__ROM_3\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffc000000")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_2\(4),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2));
\GRFPU0_DIVROM0_DATA_1_2_6__ROM_2\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00fffc00007f")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_2\(3),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_2_6__ROM_1\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1300ff37fcff0080")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_2\(2),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_2_6__ROM_0\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ec0337c87c133783")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_2\(1),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_2_6_0__ROM\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"2c34db4bb42ddbb0")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_2\(0),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_3_6__ROM_2\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000003ffffff00")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_3\(3),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2));
\GRFPU0_DIVROM0_DATA_1_3_6__ROM_1\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff01fc00ff3700")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_3\(2),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_3_6__ROM_0\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0103fefc133fc801")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_3\(1),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
\GRFPU0_DIVROM0_DATA_1_3_6_0__ROM\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3634363c6cd3c932")
port map (
combout => \GRFPU0.DIVROM0.DATA_1_3\(0),
dataf => \GRFPU0.DIVROM0.RADDR\(5),
datae => \GRFPU0.DIVROM0.RADDR\(3),
datad => \GRFPU0.DIVROM0.RADDR\(4),
datac => \GRFPU0.DIVROM0.RADDR\(1),
datab => \GRFPU0.DIVROM0.RADDR\(2),
dataa => \GRFPU0.DIVROM0.RADDR\(0));
GRFPC0_FP_PIPELINE_11_REGDEPX2_345_N_4L6: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.11.REGDEPX2_345_N_4\,
dataf => \GRFPC0.MEM.CTRL.RS1V\,
datae => \GRFPC0.MEM.CTRL.INST\(16),
datad => \GRFPC0.MEM.CTRL.INST\(15),
datac => \GRFPC0.MEM.CTRL.INST\(18),
datab => \GRFPC0.MEM.CTRL.INST\(17));
GRFPC0_FP_PIPELINE_1_REGDEP132_RNIRO4V2: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cf3f0000fcf30000")
port map (
combout => \GRFPC0.G6\,
dataf => \GRFPC0.N_23598_I_0\,
datae => \GRFPC0.FP_PIPELINE.1.REGDEP132\,
datad => \GRFPC0.FP_PIPELINE.RS2_1\(0),
datac => \GRFPC0.WR.CTRL.RDD\,
datab => \GRFPC0.WR.CTRL.RD\(0));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_11_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0000000f0f00000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10098\,
dataf => \GRFPU0.GRFPU_X0.N_134\,
datae => \GRFPU0.GRFPU_X0.N_10088_1\,
datad => \GRFPU0.GRFPU_X0.ITER.SQRT\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
\GRFPU0_GRFPU_X0_ITER_STATE_RNO_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ccf00000fff00000")
port map (
combout => \GRFPU0.GRFPU_X0.N_10101\,
dataf => \GRFPU0.GRFPU_X0.N_19703\,
datae => \GRFPU0.GRFPU_X0.N_10088_1\,
datad => \GRFPU0.GRFPU_X0.ITER.V\,
datac => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(9));
GRFPC0_RFA2_RS1SEL_RET_7_RNIOEVM_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003fff0000ffff")
port map (
combout => N_99878,
dataf => \GRFPC0.UN1_WRENX2_2_4_RETO\,
datae => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.FPUSEL_6_1_RETO\(7),
datac => \GRFPC0.UN1_WRENX2_2_3_0_RETO\,
datab => \GRFPC0.DIV.VALID_RETO\);
N_113274 <= not N_99844;
N_113276 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(2);
N_113277 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(3);
N_113278 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(4);
N_113279 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(5);
N_113280 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(6);
N_113281 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(7);
N_113282 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(8);
N_113283 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(9);
N_113284 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(10);
N_113285 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(11);
N_113286 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(12);
N_113287 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(13);
N_113288 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(14);
N_113289 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(15);
N_113290 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(16);
N_113291 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(17);
N_113292 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(18);
N_113293 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(19);
N_113294 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(20);
N_113295 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(21);
N_113296 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(22);
N_113297 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(23);
N_113298 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(24);
N_113299 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(25);
N_113300 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(26);
N_113301 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(27);
N_113302 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(28);
N_113303 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(29);
N_113304 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(30);
N_113305 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(31);
N_113306 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(32);
N_113307 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(33);
N_113308 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(34);
N_113309 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(35);
N_113310 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(36);
N_113311 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(37);
N_113312 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(38);
N_113313 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(39);
N_113314 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(40);
N_113315 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(41);
N_113316 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(42);
N_113317 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(43);
N_113318 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(44);
N_113319 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(45);
N_113320 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(46);
N_113321 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(47);
N_113322 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(48);
N_113323 <= not \GRFPU0.GRFPU_X0.UN2_DIFF1\(49);
\GRFPU0_GRFPU_X0_ITER_STATE_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(0),
d => \GRFPU0.GRFPU_X0.N_10109\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_IDCST_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ID\(0),
d => \GRFPU0.GRFPU_X0.ST1.ID\(0),
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_IDCST_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.ID\(0),
d => \GRFPU0.GRFPU_X0.ST2.ID\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(8),
d => \GRFPU0.GRFPU_X0.N_10101\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_SQRT: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.SQRT\,
d => N_26925,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_IDCST_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ID\(4),
d => \GRFPU0.GRFPU_X0.ST1.ID\(4),
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_IDCST_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.ID\(4),
d => \GRFPU0.GRFPU_X0.ST2.ID\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FLOP_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FLOP\(1),
d => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FLOP_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FLOP\(0),
d => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FLOP_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FLOP\(2),
d => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FLOP_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FLOP\(5),
d => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FLOP_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FLOP\(4),
d => \GRFPU0.GRFPU_X0.ST2.FLOP\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(20),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(20),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(23),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(23),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(27),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(27),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(25),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(25),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(26),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(26),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(22),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(22),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(7),
d => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1\(7),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(59),
d => \GRFPU0.GRFPU_X0.VST3.REG_47\(59),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(60),
d => \GRFPU0.GRFPU_X0.VST3.REG_47\(60),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(61),
d => \GRFPU0.GRFPU_X0.VST3.REG_47\(61),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(62),
d => \GRFPU0.GRFPU_X0.VST3.REG_47\(62),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_NX: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.NX\,
d => N_53554,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(27),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(27),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(26),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(26),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(29),
d => \GRFPC0.MEM.CTRL.INSTI\(29),
clk => N_36,
clrn => VCC,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(28),
d => \GRFPC0.MEM.CTRL.INSTI\(28),
clk => N_36,
clrn => VCC,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_INST_RET_1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(1),
d => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_RETI\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(1),
d => \GRFPC0.EX.CTRL.INST\(1),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(2),
d => \GRFPC0.EX.CTRL.INST\(2),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(4),
d => \GRFPC0.EX.CTRL.INST\(4),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(3),
d => \GRFPC0.EX.CTRL.INST\(3),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(50),
d => \GRFPU0.GRFPU_X0.VST2.DIFF_1\(50),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(52),
d => \GRFPU0.GRFPU_X0.VST2.DIFF_1\(52),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(51),
d => \GRFPU0.GRFPU_X0.VST2.DIFF_1\(51),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(53),
d => \GRFPU0.GRFPU_X0.VST2.DIFF_1\(53),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(53),
d => \GRFPU0.GRFPU_X0.VST3.REG_47\(53),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(54),
d => \GRFPU0.GRFPU_X0.VST3.REG_47\(54),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_R2_RET_1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_22\,
d => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_22_RETI\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_R2_RET_3: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_18\,
d => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_18_RETI\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(18),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(18),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(17),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(17),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(20),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(20),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(19),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(19),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_R2_RET_2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_14\,
d => \GRFPU0.GRFPU_X0.COMB.ORV.TMP_7_3_14_RETI\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(38),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(38),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(37),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(37),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(40),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(40),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(39),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(39),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_28: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(68),
d => \GRFPU0.MULO.MRES_RETI\(68),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_25: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(69),
d => \GRFPU0.MULO.MRES_RETI\(69),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_NORM: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.NORM\,
d => N_26926,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_BMLSB_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.BMLSB\(0),
d => \GRFPU0.GRFPU_X0.ITER.BMLSB_0_0_0__N_5\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_INST_RET: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(1),
d => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_RETI\(1),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(3),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(3),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(4),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(4),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(2),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(2),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(1),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(1),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(54),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(1),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(2),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(55),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(0),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_STICKY: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.STICKY\,
d => \GRFPU0.GRFPU_X0.N_10071\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_RNDMODE_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(0),
d => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(0),
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_RNDMODE_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.RNDMODE\(1),
d => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(1),
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(52),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(52),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(23),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(23),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(14),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(14),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(3),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_FARRES_RET_1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.S_SP_14\,
d => \GRFPU0.GRFPU_X0.S_SP_14_RETI\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(45),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(45),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(42),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(42),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(47),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(47),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(49),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(49),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(1),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(2),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(3),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(4),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(0),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(5),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(5),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(6),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(6),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(7),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(7),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(8),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(8),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(9),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(9),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(10),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(10),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(11),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(11),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(12),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(12),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(13),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(13),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(14),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(14),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(15),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(15),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(16),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(16),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(17),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(17),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(18),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(18),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(19),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(19),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(20),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(20),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(21),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(21),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(22),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(22),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(23),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(23),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(24),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(24),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(25),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(25),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(26),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(26),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(27),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(27),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(28),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(28),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(15),
d => \GRFPU0.GRFPU_X0.VST3.REG_37\(15),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(14),
d => \GRFPU0.GRFPU_X0.VST3.REG_37\(14),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(13),
d => \GRFPU0.GRFPU_X0.VST3.REG_37\(13),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(12),
d => \GRFPU0.GRFPU_X0.VST3.REG_37\(12),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(15),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(15),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(26),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(26),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(24),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(24),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_FID_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.FLUSHID\(1),
d => \GRFPC0.FID_1\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_FID_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.FLUSHID\(0),
d => \GRFPC0.FID_1\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_IDCST_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.ID\(1),
d => \GRFPU0.GRFPU_X0.ST2.ID\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_FID_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.FLUSHID\(2),
d => \GRFPC0.FID_1\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_IDCST_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ID\(2),
d => \GRFPU0.GRFPU_X0.ST1.ID\(2),
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_IDCST_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ID\(1),
d => \GRFPU0.GRFPU_X0.ST1.ID\(1),
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_DP: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DP\,
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(40),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(40),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(11),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(11),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(58),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(58),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(49),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(49),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(48),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(48),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(45),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(45),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_REG_RET: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_13\,
d => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_1_13_RETI\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(17),
d => \GRFPU0.GRFPU_X0.VST3.REG_37\(17),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(16),
d => \GRFPU0.GRFPU_X0.VST3.REG_37\(16),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(1),
d => \GRFPU0.GRFPU_X0.VST3.REG_37\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(0),
d => \GRFPU0.GRFPU_X0.VST3.REG_37\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(17),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(17),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(18),
d => \GRFPC0.EX.CTRL.INST_0_0_18__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_RDD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.N_579\,
d => \GRFPC0.N_579I\,
clk => N_36,
clrn => VCC,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(14),
d => \GRFPC0.EX.CTRL.INST\(14),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(25),
d => \GRFPC0.MEM.CTRL.INSTI\(25),
clk => N_36,
clrn => VCC,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_SIGN: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.SIGN\,
d => N_53558,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(9),
d => \GRFPU0.GRFPU_X0.N_10100\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_3__G0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(16),
d => \GRFPC0.EX.CTRL.INST\(16),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(15),
d => \GRFPC0.EX.CTRL.INST\(15),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(18),
d => \GRFPC0.EX.CTRL.INST\(18),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(17),
d => \GRFPC0.EX.CTRL.INST\(17),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(48),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(48),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(38),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(38),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS1SEL_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS1SEL\(2),
d => \GRFPC0.FPUSEL_6\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS2SEL_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS2SEL\(7),
d => \GRFPC0.N_10561\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS2SEL_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS2SEL\(1),
d => \GRFPC0.FPUSEL_1\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS2SEL_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS2SEL\(3),
d => \GRFPC0.FPUSEL_1\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_39: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.V_RETO\,
d => \GRFPU0.GRFPU_X0.ITER.V\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_38: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.N_5673_RETO\,
d => \GRFPU0.GRFPU_X0.N_5673_0\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_37: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_93112_RETO,
d => N_93112,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_36: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.N_18527_RETO\,
d => \GRFPU0.GRFPU_X0.N_18527\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_35: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_RETO\(46),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(46),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_32: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_93121_RETO,
d => N_93121,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_30: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_RETO\(39),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(39),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_27: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_93113_RETO,
d => N_93113,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_20: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_RETO\(44),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV\(44),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_26: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.DIVAPPR_RETO\(3),
d => \GRFPU0.DIVAPPR\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_24: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_57_M4_E_2_RETO\,
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_57_M4_E_2\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_23: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_RETO\(55),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(55),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_17: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => D_N_5_2_RETO,
d => D_N_5_2,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_16: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_RETO\(55),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(55),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_INST_RET_3: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.N_24183\,
d => \GRFPC0.N_24183_RETI\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_22: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.DIVAPPR_RETO\(1),
d => \GRFPU0.DIVAPPR\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_19: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_RETO\(53),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(53),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_13: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => D_N_5_4_RETO,
d => D_N_5_4,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_12: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_RETO\(53),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(53),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_FARRES_RET_3: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.S_SP_22\,
d => \GRFPU0.GRFPU_X0.S_SP_22_RETI\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(22),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(22),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(17),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(17),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(28),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(28),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(27),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(27),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_FARRES_RET_2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.S_SP_21\,
d => \GRFPU0.GRFPU_X0.S_SP_21_RETI\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(20),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(20),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(19),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(19),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(6),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(6),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(5),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(5),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_32: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(1),
d => \FPI.OP1\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_18: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.DIVAPPR_RETO\(4),
d => \GRFPU0.DIVAPPR\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_15: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_RETO\(56),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(56),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_8: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_82240_RETO,
d => N_82240,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_7: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_RETO\(56),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(56),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_14: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.DIVAPPR_RETO\(6),
d => \GRFPU0.DIVAPPR\(6),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_11: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_RETO\(58),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(58),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_10: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => D_N_5_1_RETO,
d => D_N_5_1,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_3: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_RETO\(58),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(58),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_9: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.DIVAPPR_RETO\(5),
d => \GRFPU0.DIVAPPR\(5),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_6: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5_RETO\(57),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(57),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_5: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => D_N_5_3_RETO,
d => D_N_5_3,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_0: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37_RETO\(57),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(57),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_30: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(2),
d => \FPI.OP1\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_29: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(3),
d => \FPI.OP1\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_28: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(4),
d => \FPI.OP1\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_27: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(5),
d => \FPI.OP1\(5),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_26: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(6),
d => \FPI.OP1\(6),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_INST_RET_2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.N_25384\,
d => \GRFPC0.N_25384_RETI\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(26),
d => \GRFPC0.MEM.CTRL.INSTI\(26),
clk => N_36,
clrn => VCC,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(27),
d => \GRFPC0.MEM.CTRL.INSTI\(27),
clk => N_36,
clrn => VCC,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_INST_RET: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6\(0),
d => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_6_RETI\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_25: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(7),
d => \FPI.OP1\(7),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_24: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(8),
d => \FPI.OP1\(8),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_R2_RET_4: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.NXX_1_48_11\,
d => \GRFPU0.GRFPU_X0.NXX_1_48_11_RETI\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_65_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(65),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(65),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_23: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(9),
d => \FPI.OP1\(9),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_22: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(10),
d => \FPI.OP1\(10),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_20: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(11),
d => \FPI.OP1\(11),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_19: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(12),
d => \FPI.OP1\(12),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_18: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(13),
d => \FPI.OP1\(13),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_17: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(14),
d => \FPI.OP1\(14),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_16: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(15),
d => \FPI.OP1\(15),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_15: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(0),
d => \FPI.OP1\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_14: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(16),
d => \FPI.OP1\(16),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET_2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_93111_RETO,
d => N_93111,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_R_I_RET: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_RETO\(59),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(59),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_13: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(17),
d => \FPI.OP1\(17),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_12: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(18),
d => \FPI.OP1\(18),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_10: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(19),
d => \FPI.OP1\(19),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_9: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(20),
d => \FPI.OP1\(20),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.N_18750_RETO\,
d => \GRFPU0.GRFPU_X0.N_18750\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_8: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(21),
d => \FPI.OP1\(21),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_7: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(22),
d => \FPI.OP1\(22),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_6: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(23),
d => \FPI.OP1\(23),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_5: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(24),
d => \FPI.OP1\(24),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_4: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(25),
d => \FPI.OP1\(25),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_3: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(26),
d => \FPI.OP1\(26),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(27),
d => \FPI.OP1\(27),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SGNF1_RET_1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.OP1_RETO\(28),
d => \FPI.OP1\(28),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_INST_RET_6: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.N_24325\,
d => \GRFPC0.N_24325_RETI\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_INST_RET_5: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(0),
d => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_RETI\(0),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_RDD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.N_106_I\,
d => N_47178,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(14),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(14),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_INST_RET_4: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2\(1),
d => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_RETI\(1),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_INST_RET_3: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18\(0),
d => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_18_RETI\(0),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(0),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(0),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_RDD_RET_1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.N_24327\,
d => \GRFPC0.N_24327_RETI\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_RS1V: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.RS1V\,
d => \GRFPC0.EX.CTRL.RS1V_0_0_G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_INST_RET_2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.N_24322\,
d => \GRFPC0.N_24322_RETI\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(29),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(29),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(28),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(28),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_INST_RET_1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(0),
d => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_RETI\(0),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(25),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(25),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_INST_RET_0: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1\(1),
d => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_1_RETI\(1),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_38: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.N_82_RETO\,
d => \GRFPC0.N_82\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_37: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RESV_RETO\,
d => \GRFPC0.EX.RREG.RESV\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_OP2NX_RET_1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.OP2NX_0_0_G0_I_MUX2_RETO\,
d => \GRFPU0.GRFPU_X0.ST1.OP2NX_0_0_N_6\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_OP2NX_RET: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.N_10059_I_RETO\,
d => \GRFPU0.GRFPU_X0.N_10059_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(5),
d => \GRFPU0.GRFPU_X0.VST3.REG_37\(5),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(4),
d => \GRFPU0.GRFPU_X0.VST3.REG_37\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(3),
d => \GRFPU0.GRFPU_X0.VST3.REG_37\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(2),
d => \GRFPU0.GRFPU_X0.VST3.REG_37\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_R2_RET_20: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_9\,
d => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_9_RETI\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_12: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(82),
d => \GRFPU0.MULO.MRES_RETI\(82),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_18: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(76),
d => \GRFPU0.MULO.MRES_RETI\(76),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_19: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(75),
d => \GRFPU0.MULO.MRES_RETI\(75),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_20: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(74),
d => \GRFPU0.MULO.MRES_RETI\(74),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(13),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(13),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(4),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(12),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(12),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(11),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(11),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(0),
d => \GRFPC0.MEM.CTRL.INSTI\(0),
clk => N_36,
clrn => VCC,
ena => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_32: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.N_24428_RETO\,
d => \GRFPC0.N_24428\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_31: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RESV_RETO\,
d => \GRFPC0.MEM.RREG.RESV\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_29: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPUSEL_6_3_RETO\(1),
d => \GRFPC0.FPUSEL_6_3\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPUSEL_6_2_RETO\(1),
d => \GRFPC0.FPUSEL_6_2\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(25),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(25),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(18),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(18),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(21),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(21),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(16),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(16),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(10),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(10),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(9),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(9),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(8),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(8),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(7),
d => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_1\(7),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_R2_RET_22: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_11\,
d => \GRFPU0.GRFPU_X0.COMB.ORV.STICKY_I_A2_11_RETI\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_17: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(77),
d => \GRFPU0.MULO.MRES_RETI\(77),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_16: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(78),
d => \GRFPU0.MULO.MRES_RETI\(78),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_15: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(79),
d => \GRFPU0.MULO.MRES_RETI\(79),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_21: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(73),
d => \GRFPU0.MULO.MRES_RETI\(73),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_22: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(72),
d => \GRFPU0.MULO.MRES_RETI\(72),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_INST_RET_0: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3\(0),
d => \GRFPC0.FP_PIPELINE.0.CHECK_DEP.DEP_2_3_RETI\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_27: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => HOLDN_RETO,
d => N_37,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_26: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RESV_RETO\,
d => \GRFPC0.WR.RREG.RESV\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_25: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.N_24361_RETO\,
d => \GRFPC0.N_24361\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_24: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FP_PIPELINE.0.EXEN2_RETO\,
d => \GRFPC0.FP_PIPELINE.0.EXEN2\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.N_21346_RETO\,
d => \GRFPC0.N_21346\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_22: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPUSEL_6_1_RETO\(7),
d => \GRFPC0.FPUSEL_6_1\(7),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_20: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2SEL_1_RETO\(4),
d => \GRFPC0.WR2SEL_1\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_19: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.N_24359_RETO\,
d => \GRFPC0.N_24359\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_17: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RD_RETO\(0),
d => \GRFPC0.DIV.RD\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_16: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.N_22829_RETO\,
d => \GRFPC0.N_22829\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_15: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.UN1_WRENX2_2_4_0_RETO\,
d => \GRFPC0.UN1_WRENX2_2_4_0\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_23: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(71),
d => \GRFPU0.MULO.MRES_RETI\(71),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_24: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(70),
d => \GRFPU0.MULO.MRES_RETI\(70),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_13: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2SEL_1_RETO\(7),
d => \GRFPC0.WR2SEL_1\(7),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_12: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FP_PIPELINE.0.WR2EN2_RETO\,
d => \GRFPC0.FP_PIPELINE.0.WR2EN2\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_10: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.UN1_WRENX2_2_3_0_RETO\,
d => \GRFPC0.UN1_WRENX2_2_3_0\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_7: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.VALID_RETO\,
d => \GRFPC0.DIV.VALID\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_4: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPUSEL_6_0_3__G0_E_0_RETO\,
d => \GRFPC0.FPUSEL_6_0_3__G0_E_0\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_3: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPUSEL_6_0_3__G0_E_2_RETO\,
d => \GRFPC0.FPUSEL_6_0_3__G0_E_2\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPUSEL_6_0_3__G0_E_1_RETO\,
d => \GRFPC0.FPUSEL_6_0_3__G0_E_1\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_DEFERNX_RET_1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.DEFERNX_0_0_G0_I_MUX2_RETO\,
d => \GRFPU0.GRFPU_X0.ST1.DEFERNX_0_0_G0_I_1\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_41: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(100),
d => \GRFPU0.MULO.DRES_1S_RETI\(100),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_55: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\,
d => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0_RETI\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_21: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(100),
d => \GRFPU0.MULO.DRES_1_RETI\(100),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_0: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27\,
d => \GRFPU0.FPMUL0.UN1_SIN_2_CARRY_27_RETI\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_19: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(102),
d => \GRFPU0.MULO.DRES_1_RETI\(102),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS2SEL_RET: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_99881,
d => N_99881_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS2SEL_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS2SEL\(2),
d => \GRFPC0.FPUSEL_1\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_R2_RET: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_16\(0),
d => \GRFPU0.GRFPU_X0.UN1_INC_SP_I_A2_0_16_RETI\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_7: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(87),
d => \GRFPU0.MULO.MRES_RETI\(87),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(93),
d => \GRFPU0.MULO.MRES_RETI\(93),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
d => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27_RETI\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_94_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(94),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(94),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_162: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(96),
d => \GRFPU0.MULO.MRES_RETI\(96),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_107: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28057,
d => N_28057_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_96_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(96),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(96),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_161: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(95),
d => \GRFPU0.MULO.MRES_RETI\(95),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_108: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28055,
d => N_28055_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_95_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(95),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(95),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_44: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28117,
d => N_28117_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_43: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28119,
d => N_28119_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_42: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28121,
d => N_28121_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_40: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28125,
d => N_28125_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_39: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28127,
d => N_28127_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_38: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28129,
d => N_28129_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_37: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28131,
d => N_28131_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_36: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28133,
d => N_28133_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_35: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28135,
d => N_28135_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_34: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28137,
d => N_28137_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_33: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28139,
d => N_28139_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_32: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28141,
d => N_28141_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_31: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28143,
d => N_28143_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_30: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28145,
d => N_28145_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_29: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28147,
d => N_28147_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_28: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28149,
d => N_28149_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_27: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28151,
d => N_28151_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_26: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28153,
d => N_28153_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_25: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28155,
d => N_28155_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_24: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28157,
d => N_28157_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_0: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28159,
d => N_28159_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28163,
d => N_28163_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_97_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(97),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(97),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.CS_DP_R\,
d => \GRFPU0.MULI.DP\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_98_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(98),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(98),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_99_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(99),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(99),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_100_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(100),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(100),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_101_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(101),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(101),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_102_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(102),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(102),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_103_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(103),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(103),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_104_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(104),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(104),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_105_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(105),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(105),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_106_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(106),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(106),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_107_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(107),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(107),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_108_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(108),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(108),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_109_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(109),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(109),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_110_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(110),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(110),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_111_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(111),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(111),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_112_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(112),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(112),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_113_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(113),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(113),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_114_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(114),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(114),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_115_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(115),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(115),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_116_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(116),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(116),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_117_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(117),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(117),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_118_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(118),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(118),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_119_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(119),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(119),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_120_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(120),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(120),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_23: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28174,
d => N_28174_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_22: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28176,
d => N_28176_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_20: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28180,
d => N_28180_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_18: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28184,
d => N_28184_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_17: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28186,
d => N_28186_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_16: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28188,
d => N_28188_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_15: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28190,
d => N_28190_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_14: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28192,
d => N_28192_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_13: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28194,
d => N_28194_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_12: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28196,
d => N_28196_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_11: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28198,
d => N_28198_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_10: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28200,
d => N_28200_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_9: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28202,
d => N_28202_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_8: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28204,
d => N_28204_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_7: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28206,
d => N_28206_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_6: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28208,
d => N_28208_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_5: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28210,
d => N_28210_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_4: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28212,
d => N_28212_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_3: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28214,
d => N_28214_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28216,
d => N_28216_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_DP_R_RET_1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28220,
d => N_28220_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_121_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(121),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(121),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_160: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28116,
d => N_28116_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_159: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28114,
d => N_28114_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_158: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28112,
d => N_28112_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_157: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28118,
d => N_28118_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_156: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28120,
d => N_28120_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_155: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28122,
d => N_28122_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_153: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28126,
d => N_28126_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_152: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28128,
d => N_28128_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_151: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28130,
d => N_28130_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_150: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28132,
d => N_28132_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_149: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28134,
d => N_28134_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_148: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28136,
d => N_28136_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_147: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28138,
d => N_28138_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_146: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28140,
d => N_28140_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_145: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28142,
d => N_28142_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_144: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28144,
d => N_28144_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_143: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28146,
d => N_28146_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_142: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28148,
d => N_28148_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_141: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28150,
d => N_28150_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_140: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28152,
d => N_28152_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_139: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28154,
d => N_28154_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_138: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28156,
d => N_28156_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_137: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28158,
d => N_28158_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_136: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28160,
d => N_28160_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_135: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28164,
d => N_28164_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_93_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(93),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(93),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_134: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28173,
d => N_28173_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_133: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28171,
d => N_28171_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_132: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28169,
d => N_28169_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_131: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28175,
d => N_28175_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_130: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28177,
d => N_28177_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_128: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28181,
d => N_28181_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_126: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28185,
d => N_28185_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_125: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28187,
d => N_28187_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_124: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28189,
d => N_28189_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_123: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28191,
d => N_28191_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_122: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28193,
d => N_28193_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_121: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28195,
d => N_28195_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_120: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28197,
d => N_28197_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_119: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28199,
d => N_28199_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_118: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28201,
d => N_28201_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_117: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28203,
d => N_28203_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_116: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28205,
d => N_28205_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_115: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28207,
d => N_28207_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_114: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28209,
d => N_28209_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_113: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28211,
d => N_28211_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_112: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28213,
d => N_28213_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_111: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28215,
d => N_28215_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_110: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28217,
d => N_28217_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_109: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28221,
d => N_28221_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_106: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28059,
d => N_28059_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_105: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28061,
d => N_28061_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_104: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28063,
d => N_28063_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_103: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28065,
d => N_28065_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_102: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28067,
d => N_28067_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_101: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28069,
d => N_28069_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_100: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28071,
d => N_28071_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_99: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28073,
d => N_28073_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_98: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28075,
d => N_28075_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_97: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28077,
d => N_28077_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_96: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28079,
d => N_28079_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_95: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28081,
d => N_28081_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_94: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28083,
d => N_28083_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_93: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28085,
d => N_28085_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_92: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28087,
d => N_28087_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_91: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28089,
d => N_28089_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_90: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28091,
d => N_28091_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_89: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28093,
d => N_28093_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_88: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28095,
d => N_28095_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_87: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28097,
d => N_28097_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_86: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28099,
d => N_28099_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_85: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28101,
d => N_28101_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_84: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28103,
d => N_28103_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_83: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28105,
d => N_28105_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_82: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => N_28107,
d => N_28107_RETI,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_81: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(67),
d => \GRFPU0.MULO.DRES_1S_RETI\(67),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_80: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(68),
d => \GRFPU0.MULO.DRES_1S_RETI\(68),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_79: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(69),
d => \GRFPU0.MULO.DRES_1S_RETI\(69),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_78: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(70),
d => \GRFPU0.MULO.DRES_1S_RETI\(70),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_77: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(71),
d => \GRFPU0.MULO.DRES_1S_RETI\(71),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_76: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(72),
d => \GRFPU0.MULO.DRES_1S_RETI\(72),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_75: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(73),
d => \GRFPU0.MULO.DRES_1S_RETI\(73),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_74: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(74),
d => \GRFPU0.MULO.DRES_1S_RETI\(74),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_73: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(75),
d => \GRFPU0.MULO.DRES_1S_RETI\(75),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_72: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(76),
d => \GRFPU0.MULO.DRES_1S_RETI\(76),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_71: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(77),
d => \GRFPU0.MULO.DRES_1S_RETI\(77),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_70: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(78),
d => \GRFPU0.MULO.DRES_1S_RETI\(78),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_69: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(79),
d => \GRFPU0.MULO.DRES_1S_RETI\(79),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_68: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(80),
d => \GRFPU0.MULO.DRES_1S_RETI\(80),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_67: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(81),
d => \GRFPU0.MULO.DRES_1S_RETI\(81),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_66: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(82),
d => \GRFPU0.MULO.DRES_1S_RETI\(82),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_65: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(83),
d => \GRFPU0.MULO.DRES_1S_RETI\(83),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_64: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(84),
d => \GRFPU0.MULO.DRES_1S_RETI\(84),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_63: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(85),
d => \GRFPU0.MULO.DRES_1S_RETI\(85),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_62: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(86),
d => \GRFPU0.MULO.DRES_1S_RETI\(86),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_61: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(87),
d => \GRFPU0.MULO.DRES_1S_RETI\(87),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_60: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(88),
d => \GRFPU0.MULO.DRES_1S_RETI\(88),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_59: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(89),
d => \GRFPU0.MULO.DRES_1S_RETI\(89),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_58: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(90),
d => \GRFPU0.MULO.DRES_1S_RETI\(90),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_57: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(91),
d => \GRFPU0.MULO.DRES_1S_RETI\(91),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_56: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1S\(92),
d => \GRFPU0.MULO.DRES_1S_RETI\(92),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_67_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES_1\(67),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(67),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_66_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES_1\(66),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(66),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_CS_ITER_R_0_0: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.CS_ITER_R\,
d => \GRFPU0.GRFPU_X0.N_13398_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_68_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES_1S\(68),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(68),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_69_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(69),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(69),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_70_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(70),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(70),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_71_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(71),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(71),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_72_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(72),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(72),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_73_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(73),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(73),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_74_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(74),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(74),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_75_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(75),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(75),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_76_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(76),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(76),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_77_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(77),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(77),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_78_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(78),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(78),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_79_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(79),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(79),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_80_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(80),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(80),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_81_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(81),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(81),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_82_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(82),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(82),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_83_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(83),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(83),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_84_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(84),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(84),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_85_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(85),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(85),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_86_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(86),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(86),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_87_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(87),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(87),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_88_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(88),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(88),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_89_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(89),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(89),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_90_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(90),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(90),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_91_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(91),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(91),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_92_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.FPMUL0.SX\(92),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(92),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_54: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(68),
d => \GRFPU0.MULO.DRES_1_RETI\(68),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_53: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(69),
d => \GRFPU0.MULO.DRES_1_RETI\(69),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_52: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(70),
d => \GRFPU0.MULO.DRES_1_RETI\(70),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_51: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(71),
d => \GRFPU0.MULO.DRES_1_RETI\(71),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_50: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(72),
d => \GRFPU0.MULO.DRES_1_RETI\(72),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_49: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(73),
d => \GRFPU0.MULO.DRES_1_RETI\(73),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_48: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(74),
d => \GRFPU0.MULO.DRES_1_RETI\(74),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_47: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(75),
d => \GRFPU0.MULO.DRES_1_RETI\(75),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_46: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(76),
d => \GRFPU0.MULO.DRES_1_RETI\(76),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_45: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(77),
d => \GRFPU0.MULO.DRES_1_RETI\(77),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_44: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(78),
d => \GRFPU0.MULO.DRES_1_RETI\(78),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_43: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(79),
d => \GRFPU0.MULO.DRES_1_RETI\(79),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_42: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(80),
d => \GRFPU0.MULO.DRES_1_RETI\(80),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_41: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(81),
d => \GRFPU0.MULO.DRES_1_RETI\(81),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_40: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(82),
d => \GRFPU0.MULO.DRES_1_RETI\(82),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_39: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(83),
d => \GRFPU0.MULO.DRES_1_RETI\(83),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_38: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(84),
d => \GRFPU0.MULO.DRES_1_RETI\(84),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_37: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(85),
d => \GRFPU0.MULO.DRES_1_RETI\(85),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_36: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(86),
d => \GRFPU0.MULO.DRES_1_RETI\(86),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_35: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(87),
d => \GRFPU0.MULO.DRES_1_RETI\(87),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_34: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(88),
d => \GRFPU0.MULO.DRES_1_RETI\(88),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_33: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(89),
d => \GRFPU0.MULO.DRES_1_RETI\(89),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_32: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(90),
d => \GRFPU0.MULO.DRES_1_RETI\(90),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_31: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(91),
d => \GRFPU0.MULO.DRES_1_RETI\(91),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_30: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(92),
d => \GRFPU0.MULO.DRES_1_RETI\(92),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_29: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.DRES_1\(93),
d => \GRFPU0.MULO.DRES_1_RETI\(93),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_27: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(67),
d => \GRFPU0.MULO.MRES_RETI\(67),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_26: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(66),
d => \GRFPU0.MULO.MRES_RETI\(66),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_14: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(80),
d => \GRFPU0.MULO.MRES_RETI\(80),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_13: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(81),
d => \GRFPU0.MULO.MRES_RETI\(81),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_11: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(83),
d => \GRFPU0.MULO.MRES_RETI\(83),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_10: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(84),
d => \GRFPU0.MULO.MRES_RETI\(84),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_9: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(85),
d => \GRFPU0.MULO.MRES_RETI\(85),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_8: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(86),
d => \GRFPU0.MULO.MRES_RETI\(86),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_6: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(88),
d => \GRFPU0.MULO.MRES_RETI\(88),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_5: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(89),
d => \GRFPU0.MULO.MRES_RETI\(89),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_4: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(90),
d => \GRFPU0.MULO.MRES_RETI\(90),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_3: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(91),
d => \GRFPU0.MULO.MRES_RETI\(91),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_FPMUL0_R2_RET_2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(92),
d => \GRFPU0.MULO.MRES_RETI\(92),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(17),
d => \GRFPU0.GRFPU_X0.N_10092\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_3__G0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(20),
d => \GRFPU0.GRFPU_X0.N_10089\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_3__G0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(21),
d => \GRFPU0.GRFPU_X0.N_10088\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_3__G0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(7),
d => \GRFPU0.GRFPU_X0.N_10102\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_3__G0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(6),
d => \GRFPU0.GRFPU_X0.N_10103\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_3__G0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(15),
d => \GRFPU0.GRFPU_X0.N_10094\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_3__G0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(14),
d => \GRFPU0.GRFPU_X0.N_10095\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_3__G0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(19),
d => \GRFPU0.GRFPU_X0.N_10090\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_3__G0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(12),
d => \GRFPU0.GRFPU_X0.N_10097\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_3__G0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(2),
d => \GRFPU0.GRFPU_X0.N_10107\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_3__G0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(4),
d => \GRFPU0.GRFPU_X0.N_10105\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_3__G0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(10),
d => \GRFPU0.GRFPU_X0.N_10099\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_3__G0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(3),
d => \GRFPU0.GRFPU_X0.N_10106\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_3__G0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(11),
d => \GRFPU0.GRFPU_X0.N_10098\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_3__G0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_DIV_EXC: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.EXC\,
d => N_53562,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXPOP_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXPOP\(1),
d => N_53561,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXPOP_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXPOP\(0),
d => N_53560,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXPT_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXPT\(2),
d => N_53559,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_ODDEXP: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ODDEXP\,
d => N_53557,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_LOB: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.LOB\,
d => N_53556,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_EMAXP1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EMAXP1\,
d => N_53555,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_FLUSH0: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.FLUSH0\,
d => N_53553,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_RREG_EXCT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.EXCT\(0),
d => N_53552,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_RREG_EXCT_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.EXCT\(2),
d => N_53551,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(63),
d => N_27415,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(60),
d => N_27412,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(57),
d => N_27409,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(54),
d => N_27406,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(52),
d => N_27404,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(51),
d => N_27403,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(49),
d => N_27401,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(48),
d => N_27400,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(47),
d => N_27399,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(46),
d => N_27398,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(45),
d => N_27397,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(44),
d => N_27396,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(43),
d => N_27395,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(42),
d => N_27394,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(41),
d => N_27393,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(40),
d => N_27392,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(39),
d => N_27391,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(38),
d => N_27390,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(37),
d => N_27389,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(35),
d => N_27387,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(34),
d => N_27386,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(32),
d => N_27384,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(63),
d => N_27351,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(60),
d => N_27348,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(57),
d => N_27345,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(54),
d => N_27342,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(52),
d => N_27340,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(51),
d => N_27339,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(49),
d => N_27337,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(48),
d => N_27336,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(47),
d => N_27335,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(46),
d => N_27334,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(45),
d => N_27333,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(44),
d => N_27332,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(43),
d => N_27331,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(42),
d => N_27330,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(41),
d => N_27329,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(40),
d => N_27328,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(39),
d => N_27327,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(38),
d => N_27326,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(37),
d => N_27325,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(35),
d => N_27323,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(34),
d => N_27322,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(32),
d => N_27320,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_RREG_EXCT_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.EXCT\(5),
d => N_27223,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_RREG_EXCT_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.EXCT\(4),
d => N_27222,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_RREG_EXCT_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.EXCT\(3),
d => N_27221,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_RREG_EXCT_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.EXCT\(2),
d => N_27220,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_RREG_EXCT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.EXCT\(1),
d => N_27219,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_RREG_EXCT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.EXCT\(0),
d => N_27218,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_EXCT_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.EXCT\(5),
d => N_27217,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_EXCT_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.EXCT\(4),
d => N_27216,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_EXCT_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.EXCT\(3),
d => N_27215,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_EXCT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.EXCT\(1),
d => N_27213,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_EXCT_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.EXCT\(5),
d => N_27211,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_EXCT_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.EXCT\(4),
d => N_27210,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_EXCT_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.EXCT\(3),
d => N_27209,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_EXCT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.EXCT\(1),
d => N_27207,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
RST_I <= not N_35;
\GRFPC0_R_STATE_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STATE\(1),
d => N_82237,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.R.STATE_0_0_1__G0\,
sclr => RST_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_R_STATE_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STATE\(0),
d => \GRFPC0.R.STATE_0_0_0__G2\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.R.STATE_0_0_1__G0\,
sclr => RST_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
GRFPC0_FPR_RDY: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPR.RDY\,
d => \GRFPU0.GRFPU_X0.N_18528_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_DIV_RDD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RDD\,
d => \GRFPC0.WR2.CTRL.RDD\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_FLUSH: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.FLUSH\,
d => \GRFPC0.FP_PIPELINE.FLUSH_1\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_DIVLCK: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.DIVLCK\,
d => \GRFPC0.FP_PIPELINE.DEPMUX.RES\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS2DEP: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS2DEP\,
d => \GRFPC0.N_10557\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1DEP: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS1DEP\,
d => \GRFPC0.N_10559\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_DIV_VALID: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.VALID\,
d => \GRFPC0.FP_PIPELINE.VDIV.VALID_1\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_RREG_RESV: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RESV\,
d => \GRFPC0.N_10569\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_RREG_RESV: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RESV\,
d => \GRFPC0.N_10571\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_RREG_RESV: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RESV\,
d => \GRFPC0.MEM.RREG.RESV_0_0_G0_0\,
clk => N_36,
clrn => VCC,
sclr => RST_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
GRFPC0_DIV_EXEC: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.EXEC\,
d => \GRFPC0.FP_PIPELINE.VDIV.EXEC_1\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_RREG_RESV: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RESV\,
d => \GRFPC0.N_10577\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_FOP_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.FOP\(0),
d => \GRFPC0.N_10564\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_FOP_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.FOP\(1),
d => \GRFPC0.N_10565\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS2SEL_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS2SEL\(4),
d => \GRFPC0.FPUSEL_1\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FPR_ALLOW_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPR.ALLOW\(0),
d => \GRFPC0.FPRIN.ALLOW\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FPR_ALLOW_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPR.ALLOW\(1),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ALLOW_1\(1),
clk => N_36,
clrn => VCC,
sclr => RST_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_FPR_ALLOW_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPR.ALLOW\(2),
d => \GRFPU0.GRFPU_X0.N_4364\,
clk => N_36,
clrn => VCC,
sclr => RST_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_RFA_RS1_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS1\(0),
d => \GRFPC0.N_22825\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RS1_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS1\(1),
d => \GRFPC0.N_17951\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RS1_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS1\(2),
d => \GRFPC0.N_116\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RS1_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS1\(3),
d => \GRFPC0.N_24062\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RS1_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS1\(4),
d => \GRFPC0.N_24063\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_FID_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.FLUSHID\(3),
d => \GRFPC0.FID_1\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_FID_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.FLUSHID\(4),
d => \GRFPC0.FID_1\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_FID_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.FLUSHID\(5),
d => \GRFPC0.FID_1\(5),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RS2_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS2\(0),
d => \GRFPC0.INST\(0),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RS2_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS2\(1),
d => \GRFPC0.INST\(1),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RS2_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS2\(2),
d => \GRFPC0.INST\(2),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RS2_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS2\(3),
d => \GRFPC0.N_23921\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RS2_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS2\(4),
d => \GRFPC0.N_25334\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RD_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RD\(0),
d => \GRFPC0.WR2.CTRL.RD\(0),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RD_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RD\(1),
d => \GRFPC0.WR2.CTRL.RD\(1),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RD_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RD\(2),
d => \GRFPC0.WR2.CTRL.RD\(2),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RD_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RD\(3),
d => \GRFPC0.WR2.CTRL.RD\(3),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RD_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RD\(4),
d => \GRFPC0.WR2.CTRL.RD\(4),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FPR_ID_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPR.ID\(0),
d => \FPO.IDOUT\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FPR_ID_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPR.ID\(1),
d => \FPO.IDOUT\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FPR_ID_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPR.ID\(2),
d => \FPO.IDOUT\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FPR_ID_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPR.ID\(3),
d => \FPO.IDOUT\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FPR_ID_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPR.ID\(4),
d => \FPO.IDOUT\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FPR_ID_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FPR.ID\(5),
d => \FPO.IDOUT\(5),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_EMAX: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.EMAX\,
d => \GRFPU0.GRFPU_X0.COMB.VST3.EMAX_1\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_EMIN: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.EMIN\,
d => \GRFPU0.GRFPU_X0.COMB.VST3.EMIN_1\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_ADD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.ADD\,
d => \GRFPU0.GRFPU_X0.COMB.VST2.ADD_1_1\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_INF: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.INF\,
d => \GRFPU0.GRFPU_X0.COMB.VST2.INF_1\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST4_ADDOF: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.ADDOF\,
d => \GRFPU0.GRFPU_X0.COMB.VST4.ADDOF_1\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST4_MOF: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MOF\,
d => \GRFPU0.GRFPU_X0.COMB.VST4.MOF_1\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_EMINM1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.EMINM1\,
d => \GRFPU0.GRFPU_X0.ST2.EMINM1\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_DIFFV: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.DIFFV\,
d => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_DEFERNX: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.N_3207\,
d => \GRFPU0.GRFPU_X0.N_3206\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_DEFERNX: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.N_3206\,
d => \GRFPU0.GRFPU_X0.ST1.DEFERNX\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST4_DEFERNX: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.DEFERNX\,
d => \GRFPU0.GRFPU_X0.N_3207\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_QSNAN: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.QSNAN\,
d => \GRFPU0.GRFPU_X0.N_20518\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_RDY: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.RDY\,
d => \GRFPU0.GRFPU_X0.N_10035\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_INF: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.INF\,
d => \GRFPU0.GRFPU_X0.N_10037\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_STICKY: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.STICKY\,
d => \GRFPU0.GRFPU_X0.N_10039\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_RDY: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.RDY\,
d => \GRFPU0.GRFPU_X0.N_10041\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_ZERO: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.ZERO\,
d => \GRFPU0.GRFPU_X0.N_10043\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_ZERO: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.ZERO\,
d => \GRFPU0.GRFPU_X0.N_10045\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST4_RDY: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.RDY\,
d => \GRFPU0.GRFPU_X0.N_10047\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_QSNAN: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.QSNAN\,
d => \GRFPU0.GRFPU_X0.N_10049\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_V: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.V\,
d => \GRFPU0.GRFPU_X0.N_102_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_V: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.V\,
d => \GRFPU0.GRFPU_X0.ITER.V_0_0_G0_3\,
clk => N_36,
clrn => VCC,
sclr => RST_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_EMINM1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.EMINM1\,
d => \GRFPU0.GRFPU_X0.N_10079\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_DIFFV: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
d => \GRFPU0.GRFPU_X0.ST2.DIFFN_0_0_G0_0\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST2_DIFFN: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFFN\,
d => \GRFPU0.GRFPU_X0.N_10083\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_OP1NX: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.OP1NX\,
d => \GRFPU0.GRFPU_X0.N_10118\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0.GRFPU_X0.N_10059_I_I\ <= not \GRFPU0.GRFPU_X0.N_10059_I\;
GRFPU0_GRFPU_X0_ST1_V: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.V\,
d => \GRFPU0.GRFPU_X0.ST1.V_0_0_G0_0\,
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SIGN2: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SIGN2\,
d => \FPI.OP2\(63),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST1_SIGN1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SIGN1\,
d => \FPI.OP1\(63),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST3_V: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.V\,
d => \GRFPU0.GRFPU_X0.N_10189\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ST4_IOF: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.IOF\,
d => \GRFPU0.GRFPU_X0.N_10191\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RNDMODE_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(0),
d => \FPI.RNDMODE\(0),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RNDMODE_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RNDMODE\(1),
d => \FPI.RNDMODE\(1),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_RNDMODE_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.RNDMODE\(0),
d => \GRFPU0.GRFPU_X0.N_10179\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_RNDMODE_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.RNDMODE\(1),
d => \GRFPU0.GRFPU_X0.N_10180\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_GUARDS_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.GUARDS\(0),
d => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(52),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(52),
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0.GRFPU_X0.C_I\(11) <= not \GRFPU0.GRFPU_X0.C\(11);
\GRFPU0_GRFPU_X0_ST2_GUARDS_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.GUARDS\(1),
d => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(53),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(53),
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(0),
d => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(54),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(54),
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(1),
d => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(55),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(55),
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(2),
d => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(56),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(56),
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(3),
d => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(57),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(57),
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(4),
d => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT_1\(58),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ADD_SHIFT_OUT\(58),
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(5),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_5__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_5__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(6),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_6__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_6__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(7),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_7__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_7__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(8),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_8__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_8__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(9),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_9__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_9__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(10),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_10__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_10__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(11),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_11__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_11__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(12),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_12__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_12__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(13),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_13__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_13__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(14),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_14__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_14__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(15),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_15__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_15__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(16),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_16__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_16__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(17),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_17__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_17__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(18),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_18__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_18__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(19),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_19__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_19__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(20),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_20__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_20__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(21),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_21__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_21__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(22),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_22__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_22__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(23),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_23__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_23__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(24),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_24__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_24__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(25),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_25__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_25__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(26),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_26__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_26__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(27),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_27__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_27__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(28),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_28__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_28__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(29),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_29__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_29__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(30),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_30__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_30__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(31),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_31__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_31__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(32),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_32__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_32__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(33),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_33__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_33__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(34),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_34__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_34__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(35),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_35__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_35__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(36),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_36__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_36__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(37),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_37__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_37__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(38),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_38__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_38__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(39),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_39__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_39__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(40),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_40__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_40__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(41),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_41__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_41__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(42),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_42__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_42__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(43),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_43__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_43__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(44),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_44__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_44__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(45),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_45__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_45__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(46),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_46__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_46__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(47),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_47__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_47__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(48),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_48__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_48__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(49),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_49__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_49__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(50),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_50__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_50__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(51),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_51__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_51__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_SGNF2_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.SGNF2\(52),
d => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_52__G4\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.ST2.SGNF2_0_0_52__G3\,
sclr => \GRFPU0.GRFPU_X0.COMB.SHV2\,
sload => \GRFPU0.GRFPU_X0.C_I\(11),
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ST2_EXC_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.EXC\(4),
d => \GRFPU0.GRFPU_X0.N_10113\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_EXC_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.EXC\(5),
d => \GRFPU0.GRFPU_X0.N_10114\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(24),
d => \GRFPU0.GRFPU_X0.N_10085\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(23),
d => \GRFPU0.GRFPU_X0.N_10086\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(22),
d => \GRFPU0.GRFPU_X0.N_10087\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(18),
d => \GRFPU0.GRFPU_X0.N_10091\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(16),
d => \GRFPU0.GRFPU_X0.ITER.STATE_0_0_16__G0_0\,
clk => N_36,
clrn => VCC,
sclr => RST_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(13),
d => \GRFPU0.GRFPU_X0.N_10096\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(5),
d => \GRFPU0.GRFPU_X0.N_10104\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_STATE_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.STATE\(1),
d => \GRFPU0.GRFPU_X0.N_10108\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_EXPT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.EXPT\(0),
d => \GRFPU0.GRFPU_X0.N_10075\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_EXPT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.EXPT\(1),
d => \GRFPU0.GRFPU_X0.N_10076\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_EXPT_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.EXPT\(2),
d => \GRFPU0.GRFPU_X0.N_10077\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_EXC_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.EXC\(0),
d => \GRFPU0.GRFPU_X0.N_10064\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_EXC_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.EXCT_0_0_1__I1_I_3\,
d => \GRFPU0.GRFPU_X0.N_10065\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_EXC_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.EXC\(2),
d => \GRFPU0.GRFPU_X0.N_10066\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_EXC_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.EXC\(3),
d => \GRFPU0.GRFPU_X0.N_10067\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_EXC_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.EXCT_0_0_4__I1_I_2\,
d => \GRFPU0.GRFPU_X0.N_10068\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_EXC_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.EXCT_0_0_5__I1_I_1\,
d => \GRFPU0.GRFPU_X0.N_10069\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SEL_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
d => \GRFPU0.GRFPU_X0.N_10060\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SEL_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SEL\(1),
d => \GRFPU0.GRFPU_X0.N_18441_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SEL_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
d => \GRFPU0.GRFPU_X0.N_18442_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_IDCST_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.ID\(0),
d => \FPI.OPID\(0),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_IDCST_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.ID\(1),
d => \FPI.OPID\(1),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_IDCST_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.ID\(2),
d => \FPI.OPID\(2),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_IDCST_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.ID\(3),
d => \FPI.OPID\(3),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_IDCST_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.ID\(4),
d => \FPI.OPID\(4),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_IDCST_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.ID\(5),
d => \FPI.OPID\(5),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_IDCST_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.ID\(0),
d => \GRFPU0.GRFPU_X0.ST1.ID\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_IDCST_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.ID\(1),
d => \GRFPU0.GRFPU_X0.ST1.ID\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_IDCST_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.ID\(2),
d => \GRFPU0.GRFPU_X0.ST1.ID\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_IDCST_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.ID\(3),
d => \GRFPU0.GRFPU_X0.ST1.ID\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_IDCST_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.ID\(4),
d => \GRFPU0.GRFPU_X0.ST1.ID\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_IDCST_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.ID\(5),
d => \GRFPU0.GRFPU_X0.ST1.ID\(5),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_EXC_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.EXC\(0),
d => \GRFPU0.GRFPU_X0.VST2.EXC_8\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_EXC_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.EXC\(1),
d => \GRFPU0.GRFPU_X0.N_3406\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(8),
d => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(7),
d => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(6),
d => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(5),
d => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(4),
d => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLTYPE2_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLTYPE2\(3),
d => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_IDCST_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.ID\(2),
d => \GRFPU0.GRFPU_X0.ST2.ID\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_IDCST_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.ID\(3),
d => \GRFPU0.GRFPU_X0.ST2.ID\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_IDCST_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.ID\(5),
d => \GRFPU0.GRFPU_X0.ST2.ID\(5),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(0),
d => \GRFPU0.GRFPU_X0.N_18618\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15794\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(1),
d => \GRFPU0.GRFPU_X0.N_15847\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15795\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(2),
d => \GRFPU0.GRFPU_X0.N_18619\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15796\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(3),
d => \GRFPU0.GRFPU_X0.N_74\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15797\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(4),
d => \GRFPU0.GRFPU_X0.N_15850\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15798\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(5),
d => \GRFPU0.GRFPU_X0.N_15851\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15799\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(6),
d => \GRFPU0.GRFPU_X0.N_15852\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15800\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(7),
d => \GRFPU0.GRFPU_X0.N_15853\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15801\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(8),
d => \GRFPU0.GRFPU_X0.N_15854\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15802\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(9),
d => \GRFPU0.GRFPU_X0.N_15855\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15803\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(10),
d => \GRFPU0.GRFPU_X0.N_15856\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15804\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(11),
d => \GRFPU0.GRFPU_X0.N_15857\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15805\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(12),
d => \GRFPU0.GRFPU_X0.N_15858\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15806\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(13),
d => \GRFPU0.GRFPU_X0.N_15859\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15807\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(14),
d => \GRFPU0.GRFPU_X0.N_15860\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15808\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(15),
d => \GRFPU0.GRFPU_X0.N_15861\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15809\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(16),
d => \GRFPU0.GRFPU_X0.N_15862\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15810\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(17),
d => \GRFPU0.GRFPU_X0.N_15863\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15811\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(18),
d => \GRFPU0.GRFPU_X0.N_15864\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15812\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(19),
d => \GRFPU0.GRFPU_X0.N_15865\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15813\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(20),
d => \GRFPU0.GRFPU_X0.N_15866\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15814\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(21),
d => \GRFPU0.GRFPU_X0.N_15867\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15815\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(22),
d => \GRFPU0.GRFPU_X0.N_15868\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15816\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(23),
d => \GRFPU0.GRFPU_X0.N_15869\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15817\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(24),
d => \GRFPU0.GRFPU_X0.N_15870\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15818\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(25),
d => \GRFPU0.GRFPU_X0.N_15871\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15819\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(26),
d => \GRFPU0.GRFPU_X0.N_15872\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15820\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(27),
d => \GRFPU0.GRFPU_X0.N_15873\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15821\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(28),
d => \GRFPU0.GRFPU_X0.N_15874\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15822\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(29),
d => \GRFPU0.GRFPU_X0.N_15875\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15823\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(30),
d => \GRFPU0.GRFPU_X0.N_15876\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15824\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(31),
d => \GRFPU0.GRFPU_X0.N_18620\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15825\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(32),
d => \GRFPU0.GRFPU_X0.N_18621\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15826\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(33),
d => \GRFPU0.GRFPU_X0.N_18622\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15827\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(34),
d => \GRFPU0.GRFPU_X0.N_18623\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15828\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(35),
d => \GRFPU0.GRFPU_X0.N_18624\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15829\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(36),
d => \GRFPU0.GRFPU_X0.N_18625\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15830\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(37),
d => \GRFPU0.GRFPU_X0.N_18626\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15831\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(38),
d => \GRFPU0.GRFPU_X0.N_15884\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15832\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(39),
d => \GRFPU0.GRFPU_X0.N_15885\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15833\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(40),
d => \GRFPU0.GRFPU_X0.N_15886\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15834\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(41),
d => \GRFPU0.GRFPU_X0.N_15887\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15835\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(42),
d => \GRFPU0.GRFPU_X0.N_15888\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15836\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(43),
d => \GRFPU0.GRFPU_X0.N_15889\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15837\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(44),
d => \GRFPU0.GRFPU_X0.N_15890\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15838\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(45),
d => \GRFPU0.GRFPU_X0.N_15891\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_18615\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(46),
d => \GRFPU0.GRFPU_X0.N_15892\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_18616\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(47),
d => \GRFPU0.GRFPU_X0.N_15893\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_18617\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(48),
d => \GRFPU0.GRFPU_X0.N_15894\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15842\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(49),
d => \GRFPU0.GRFPU_X0.N_15895\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15843\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(50),
d => \GRFPU0.GRFPU_X0.N_15896\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15844\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MSGNF_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MSGNF\(51),
d => \GRFPU0.GRFPU_X0.N_15897\,
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.N_15845\,
sload => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(0),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(1),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(2),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_2__N_11\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(3),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_3__N_16\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(4),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_4__N_21\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(5),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_5__N_26\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(6),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_6__N_31\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(7),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_7__N_36\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(8),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_8__N_41\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(9),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_46\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_MEXP_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.MEXP\(10),
d => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_10__N_51\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(6),
d => \GRFPU0.GRFPU_X0.VST3.REG_37\(6),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(7),
d => \GRFPU0.GRFPU_X0.VST3.REG_37\(7),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(8),
d => \GRFPU0.GRFPU_X0.VST3.REG_37\(8),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(9),
d => \GRFPU0.GRFPU_X0.VST3.REG_37\(9),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(10),
d => \GRFPU0.GRFPU_X0.VST3.REG_37\(10),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(11),
d => \GRFPU0.GRFPU_X0.VST3.REG_37\(11),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(18),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(18),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(19),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(19),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(21),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(21),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(24),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(24),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(28),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(28),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(63),
d => \GRFPU0.GRFPU_X0.VST3.REG_1\(63),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(0),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(1),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(2),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(3),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(4),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(5),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(5),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(6),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(6),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(7),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(7),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(8),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(8),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(9),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(9),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_AEXP_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.AEXP\(10),
d => \GRFPU0.GRFPU_X0.COMB.VST4.AEXP_2\(10),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPO.CC\(0),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_0__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPO.CC\(1),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_1__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(2),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_2__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(3),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_3__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(4),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_4__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(5),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_5__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(6),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_6__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(7),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_7__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(8),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_8__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(9),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_9__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(10),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_10__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(11),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_11__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(12),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_12__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(13),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_13__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(14),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_14__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(15),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_15__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(16),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_16__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(17),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_17__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(18),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_18__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(19),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_19__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(20),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_20__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(21),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_21__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(22),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_22__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(23),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_23__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(24),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_24__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(25),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_25__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(26),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_26__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(27),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_27__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(28),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_28__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(29),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_29__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(30),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_30__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(31),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_0_31__N_6\,
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(32),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(32),
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(33),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(33),
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(34),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(34),
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(35),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(35),
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(36),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(36),
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(37),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(37),
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(38),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(38),
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(39),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(39),
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(40),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(40),
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(41),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(41),
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(42),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(42),
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(43),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(43),
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(44),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_24_MUX2\(44),
clk => N_36,
clrn => VCC,
sclr => N_99909_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(45),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(45),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(46),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(46),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(47),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(47),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(48),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(48),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(49),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(49),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(50),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(50),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(51),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(51),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(52),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(52),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(53),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(53),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(54),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(54),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(55),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(55),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(56),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(56),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(57),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(57),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(58),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(58),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(59),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(59),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(60),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(60),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(61),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(61),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.REG\(62),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(62),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_REG_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPO.RES\(63),
d => \GRFPU0.GRFPU_X0.COMB.VST4.REG_1\(63),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(0),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(1),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(2),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(3),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(4),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(5),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(5),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(6),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(6),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(7),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(7),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(60),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(60),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(0),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(1),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(2),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(3),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(4),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(5),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(5),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(6),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(6),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(7),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(7),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(8),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(8),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(9),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(9),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(10),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(10),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(11),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(11),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(12),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(12),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(13),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(13),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(14),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(14),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(15),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(15),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(16),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(16),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(17),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(17),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(18),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(18),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(19),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(19),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(20),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(20),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(21),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(21),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(22),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(22),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(23),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(23),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(24),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(24),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(25),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(25),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(26),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(26),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(27),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(27),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(28),
d => \GRFPU0.GRFPU_X0.UN3_S3ADDO1\(28),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(29),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(29),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(30),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(30),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(31),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(31),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(32),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(32),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(33),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(33),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(34),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(34),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(35),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(35),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(36),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(36),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(37),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(37),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(38),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(38),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(39),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(39),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(40),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(40),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(41),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(41),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(42),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(42),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(43),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(43),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(44),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(44),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(45),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(45),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(46),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(46),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(47),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(47),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(48),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(48),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(49),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(49),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(50),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(50),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SGNF_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SGNF\(51),
d => \GRFPU0.GRFPU_X0.VST4.SGNF_1\(51),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_EXC_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.EXC\(0),
d => \GRFPU0.GRFPU_X0.VST3.EXC_1\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_EXC_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.EXC\(1),
d => \GRFPU0.GRFPU_X0.VST3.EXC_1\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_EXC_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.EXC\(2),
d => \GRFPU0.GRFPU_X0.N_5937\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_EXC_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.EXC\(3),
d => \GRFPU0.GRFPU_X0.N_6321\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_EXC_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.EXC\(4),
d => \GRFPU0.GRFPU_X0.VST3.EXC_1\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_EXC_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.EXC\(5),
d => \GRFPU0.GRFPU_X0.VST3.EXC_1\(5),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(0),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(1),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(2),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(3),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(4),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(5),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(5),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(6),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(6),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(7),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(7),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(8),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(8),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(9),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(9),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(10),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(10),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(11),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(11),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(12),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(12),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(13),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(13),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(14),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(14),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(15),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(15),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(16),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(16),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(17),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(17),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(18),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(18),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(19),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(19),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(20),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(20),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(21),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(21),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(22),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(22),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(23),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(23),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(24),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(24),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(25),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(25),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(26),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(26),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(27),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(27),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(28),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(28),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(29),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(29),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(30),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(30),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(31),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(31),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(32),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(32),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(33),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(33),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(34),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(34),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(35),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(35),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(36),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(36),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(37),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(37),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(38),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(38),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(39),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(39),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(40),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(40),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(41),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(41),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(42),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(42),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(43),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(43),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(44),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(44),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(45),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(45),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(46),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(46),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(47),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(47),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(48),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(48),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(49),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(49),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(50),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(50),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(51),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(51),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(63),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1_IV_I\(63),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(0),
d => \GRFPU0.GRFPU_X0.DIFFIN2_4\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(1),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(2),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(2),
clk => N_36,
clrn => VCC,
asdata => N_113276,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(3),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(3),
clk => N_36,
clrn => VCC,
asdata => N_113277,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(4),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(4),
clk => N_36,
clrn => VCC,
asdata => N_113278,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(5),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(5),
clk => N_36,
clrn => VCC,
asdata => N_113279,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(6),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(6),
clk => N_36,
clrn => VCC,
asdata => N_113280,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(7),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(7),
clk => N_36,
clrn => VCC,
asdata => N_113281,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(8),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(8),
clk => N_36,
clrn => VCC,
asdata => N_113282,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(9),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(9),
clk => N_36,
clrn => VCC,
asdata => N_113283,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(10),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(10),
clk => N_36,
clrn => VCC,
asdata => N_113284,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(11),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(11),
clk => N_36,
clrn => VCC,
asdata => N_113285,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(12),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(12),
clk => N_36,
clrn => VCC,
asdata => N_113286,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(13),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(13),
clk => N_36,
clrn => VCC,
asdata => N_113287,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(14),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(14),
clk => N_36,
clrn => VCC,
asdata => N_113288,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(15),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(15),
clk => N_36,
clrn => VCC,
asdata => N_113289,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(16),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(16),
clk => N_36,
clrn => VCC,
asdata => N_113290,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(17),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(17),
clk => N_36,
clrn => VCC,
asdata => N_113291,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(18),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(18),
clk => N_36,
clrn => VCC,
asdata => N_113292,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(19),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(19),
clk => N_36,
clrn => VCC,
asdata => N_113293,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(20),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(20),
clk => N_36,
clrn => VCC,
asdata => N_113294,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(21),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(21),
clk => N_36,
clrn => VCC,
asdata => N_113295,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(22),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(22),
clk => N_36,
clrn => VCC,
asdata => N_113296,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(23),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(23),
clk => N_36,
clrn => VCC,
asdata => N_113297,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(24),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(24),
clk => N_36,
clrn => VCC,
asdata => N_113298,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(25),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(25),
clk => N_36,
clrn => VCC,
asdata => N_113299,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(26),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(26),
clk => N_36,
clrn => VCC,
asdata => N_113300,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(27),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(27),
clk => N_36,
clrn => VCC,
asdata => N_113301,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(28),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(28),
clk => N_36,
clrn => VCC,
asdata => N_113302,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(29),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(29),
clk => N_36,
clrn => VCC,
asdata => N_113303,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(30),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(30),
clk => N_36,
clrn => VCC,
asdata => N_113304,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(31),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(31),
clk => N_36,
clrn => VCC,
asdata => N_113305,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(32),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(32),
clk => N_36,
clrn => VCC,
asdata => N_113306,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(33),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(33),
clk => N_36,
clrn => VCC,
asdata => N_113307,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(34),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(34),
clk => N_36,
clrn => VCC,
asdata => N_113308,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(35),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(35),
clk => N_36,
clrn => VCC,
asdata => N_113309,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(36),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(36),
clk => N_36,
clrn => VCC,
asdata => N_113310,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(37),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(37),
clk => N_36,
clrn => VCC,
asdata => N_113311,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(38),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(38),
clk => N_36,
clrn => VCC,
asdata => N_113312,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(39),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(39),
clk => N_36,
clrn => VCC,
asdata => N_113313,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(40),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(40),
clk => N_36,
clrn => VCC,
asdata => N_113314,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(41),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(41),
clk => N_36,
clrn => VCC,
asdata => N_113315,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(42),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(42),
clk => N_36,
clrn => VCC,
asdata => N_113316,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(43),
clk => N_36,
clrn => VCC,
asdata => N_113317,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(44),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(44),
clk => N_36,
clrn => VCC,
asdata => N_113318,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(45),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(45),
clk => N_36,
clrn => VCC,
asdata => N_113319,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(46),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(46),
clk => N_36,
clrn => VCC,
asdata => N_113320,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(47),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(47),
clk => N_36,
clrn => VCC,
asdata => N_113321,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(48),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(48),
clk => N_36,
clrn => VCC,
asdata => N_113322,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST2_DIFF_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFF\(49),
d => \GRFPU0.GRFPU_X0.UN8_DIFF2\(49),
clk => N_36,
clrn => VCC,
asdata => N_113323,
sload => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_ALLOW_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ALLOW\(0),
d => \GRFPU0.GRFPU_X0.N_18198_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ALLOW_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ALLOW\(1),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ALLOW_1\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ALLOW_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ALLOW\(2),
d => \GRFPU0.GRFPU_X0.N_4364\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
d => \GRFPU0.GRFPU_X0.N_18744_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(6),
d => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1\(6),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(5),
d => \GRFPU0.GRFPU_X0.VST1.FLTYPE1_1_0_5__G0_0\,
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(4),
d => \GRFPU0.GRFPU_X0.N_18752_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE1_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(3),
d => \GRFPU0.GRFPU_X0.N_18751_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(0),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(1),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(2),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(3),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(4),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(5),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(5),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(6),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(6),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(7),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(7),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(8),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(8),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(9),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(9),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(10),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(10),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(11),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(11),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(12),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(12),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(13),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(13),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(14),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(14),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(15),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(15),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(16),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(16),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(17),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(17),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(18),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(18),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(19),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(19),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(20),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(20),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(21),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(21),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(22),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(22),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(23),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(23),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(24),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(24),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(25),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(25),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(26),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(26),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(27),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(27),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(28),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(28),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(29),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(29),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(30),
d => \GRFPU0.GRFPU_X0.N_18684\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(31),
d => \GRFPU0.GRFPU_X0.N_18683\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(32),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(32),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(33),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(33),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(34),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(34),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(35),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(35),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(36),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(36),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(37),
d => \GRFPU0.GRFPU_X0.N_18337\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(38),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(38),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(39),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(39),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(40),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(40),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(41),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(41),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(42),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(42),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(43),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(43),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(44),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(44),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(45),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(45),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(46),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(46),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(47),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(47),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(48),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(48),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(49),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(49),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(50),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(50),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(51),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(51),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(52),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(52),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(53),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(53),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(54),
d => \GRFPU0.GRFPU_X0.N_18336\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(55),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(55),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(56),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(56),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(57),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(57),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(58),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(58),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(59),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(59),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_ND_I_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ND_I\(60),
d => \GRFPU0.GRFPU_X0.COMB.VITER.ND_I_1\(60),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_CCSEL_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
d => \GRFPU0.GRFPU_X0.N_13447\,
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_CCSEL_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1),
d => \GRFPU0.GRFPU_X0.COMB.VST1.CCSEL_1_0_0_1__G1\,
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
d => \GRFPU0.GRFPU_X0.N_18841_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(7),
d => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1\(7),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(6),
d => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1\(6),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(5),
d => \GRFPU0.GRFPU_X0.VST1.FLTYPE2_1_0_5__G1\,
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(4),
d => \GRFPU0.GRFPU_X0.N_18860_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLTYPE2_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(3),
d => \GRFPU0.GRFPU_X0.N_18859_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(29),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(27),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M28_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(30),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(26),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M29_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(31),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(25),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M30_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(32),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(24),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2.M31_4_03_0_G1\,
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(33),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(23),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(33),
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(34),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(22),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(34),
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(35),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(21),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(35),
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(36),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(20),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(36),
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(37),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(19),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(37),
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(38),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(18),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(38),
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(39),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(17),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(39),
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(40),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(16),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(40),
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(41),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(15),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(41),
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(42),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(14),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(42),
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(43),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(13),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(43),
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(44),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(12),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(44),
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(45),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(11),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(45),
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(46),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(10),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(46),
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(47),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(9),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(47),
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(48),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(8),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(48),
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(49),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(7),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(49),
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(50),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(6),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(50),
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(51),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(5),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(51),
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(52),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(4),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(52),
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST3_FARRES_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FARRES\(53),
d => \GRFPU0.GRFPU_X0.UN1_ADDSUBI2\(3),
clk => N_36,
clrn => VCC,
asdata => \GRFPU0.GRFPU_X0.COMB.VST3.FARRES_2\(53),
sload => \GRFPU0.GRFPU_X0.ST2.DIFFV\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(29),
d => \GRFPU0.GRFPU_X0.N_18842_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(30),
d => \GRFPU0.GRFPU_X0.N_18843_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(31),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(31),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(32),
d => \GRFPU0.GRFPU_X0.N_18844_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(33),
d => \GRFPU0.GRFPU_X0.N_18845_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(34),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(34),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(35),
d => \GRFPU0.GRFPU_X0.N_18846_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(36),
d => \GRFPU0.GRFPU_X0.N_18847_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(37),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(37),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(38),
d => \GRFPU0.GRFPU_X0.N_18848_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(39),
d => \GRFPU0.GRFPU_X0.N_18849_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(40),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1\(40),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(41),
d => \GRFPU0.GRFPU_X0.N_18850_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(42),
d => \GRFPU0.GRFPU_X0.N_18851_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF2_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF2\(43),
d => \GRFPU0.GRFPU_X0.N_18852_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(29),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(29),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(30),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(30),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(31),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(31),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(32),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(32),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(33),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(33),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(34),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(34),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(35),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(35),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(36),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(36),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(37),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(37),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(38),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(38),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(39),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(39),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(40),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(40),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(41),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(41),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(42),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(42),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(43),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(43),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(44),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(44),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(45),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(45),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(46),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(46),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(47),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(47),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(48),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(48),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(49),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(49),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(50),
d => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF1_1\(50),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_SGNF1_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.SGNF1\(51),
d => \GRFPU0.GRFPU_X0.N_18747_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLOP_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLOP\(0),
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLOP_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLOP\(1),
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLOP_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLOP\(2),
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLOP_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLOP_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLOP\(4),
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLOP_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLOP\(5),
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLOP_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLOP_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(7),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_FLOP_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.FLOP\(8),
d => \GRFPU0.GRFPU_X0.ST1.FLOP\(8),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLOP_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLOP\(0),
d => \FPI.FLOP\(0),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLOP_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLOP\(1),
d => \FPI.FLOP\(1),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLOP_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
d => \FPI.FLOP\(2),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLOP_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLOP\(3),
d => \FPI.FLOP\(3),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLOP_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLOP\(4),
d => \FPI.FLOP\(4),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLOP_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLOP\(5),
d => \FPI.FLOP\(5),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLOP_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLOP\(6),
d => \FPI.FLOP\(6),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLOP_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLOP\(7),
d => \FPI.FLOP\(7),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_FLOP_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.FLOP\(8),
d => \FPI.FLOP\(8),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_LZCNT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.LZCNT\(0),
d => \GRFPU0.GRFPU_X0.L4_4\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_LZCNT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.LZCNT\(1),
d => \GRFPU0.GRFPU_X0.L4_4\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_LZCNT_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.LZCNT\(2),
d => \GRFPU0.GRFPU_X0.L4_4\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_LZCNT_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.LZCNT\(3),
d => \GRFPU0.GRFPU_X0.L4_4\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_LZCNT_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.LZCNT\(4),
d => \GRFPU0.GRFPU_X0.L4_4\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_LZCNT_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.LZCNT\(5),
d => \GRFPU0.GRFPU_X0.N_9666\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_RNDMODE_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
d => \GRFPU0.GRFPU_X0.ST2.RNDMODE\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_RNDMODE_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
d => \GRFPU0.GRFPU_X0.ST2.RNDMODE\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(0),
d => \FPI.OP2\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(1),
d => \FPI.OP2\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(2),
d => \FPI.OP2\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(3),
d => \FPI.OP2\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(4),
d => \FPI.OP2\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(5),
d => \FPI.OP2\(5),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(6),
d => \FPI.OP2\(6),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(7),
d => \FPI.OP2\(7),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(8),
d => \FPI.OP2\(8),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(9),
d => \FPI.OP2\(9),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(10),
d => \FPI.OP2\(10),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(11),
d => \FPI.OP2\(11),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(12),
d => \FPI.OP2\(12),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(13),
d => \FPI.OP2\(13),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(14),
d => \FPI.OP2\(14),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(15),
d => \FPI.OP2\(15),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(16),
d => \FPI.OP2\(16),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(17),
d => \FPI.OP2\(17),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(18),
d => \FPI.OP2\(18),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(19),
d => \FPI.OP2\(19),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(20),
d => \FPI.OP2\(20),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(21),
d => \FPI.OP2\(21),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(22),
d => \FPI.OP2\(22),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(23),
d => \FPI.OP2\(23),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(24),
d => \FPI.OP2\(24),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(25),
d => \FPI.OP2\(25),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(26),
d => \FPI.OP2\(26),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(27),
d => \FPI.OP2\(27),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(28),
d => \FPI.OP2\(28),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(29),
d => \FPI.OP2\(29),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(30),
d => \FPI.OP2\(30),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(31),
d => \FPI.OP2\(31),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(32),
d => \FPI.OP2\(32),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(33),
d => \FPI.OP2\(33),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(34),
d => \FPI.OP2\(34),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(35),
d => \FPI.OP2\(35),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(36),
d => \FPI.OP2\(36),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(37),
d => \FPI.OP2\(37),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(38),
d => \FPI.OP2\(38),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(39),
d => \FPI.OP2\(39),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(40),
d => \FPI.OP2\(40),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(41),
d => \FPI.OP2\(41),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(42),
d => \FPI.OP2\(42),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(43),
d => \FPI.OP2\(43),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(44),
d => \FPI.OP2\(44),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(45),
d => \FPI.OP2\(45),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(46),
d => \FPI.OP2\(46),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(47),
d => \FPI.OP2\(47),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(48),
d => \FPI.OP2\(48),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(49),
d => \FPI.OP2\(49),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(50),
d => \FPI.OP2\(50),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(51),
d => \FPI.OP2\(51),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(52),
d => \FPI.OP2\(52),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(53),
d => \FPI.OP2\(53),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(54),
d => \FPI.OP2\(54),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(55),
d => \FPI.OP2\(55),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(56),
d => \FPI.OP2\(56),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(57),
d => \FPI.OP2\(57),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(58),
d => \FPI.OP2\(58),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(59),
d => \FPI.OP2\(59),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(60),
d => \FPI.OP2\(60),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(61),
d => \FPI.OP2\(61),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(62),
d => \FPI.OP2\(62),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW2_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW2\(63),
d => \FPI.OP2\(63),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(29),
d => \FPI.OP1\(29),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(30),
d => \FPI.OP1\(30),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(31),
d => \FPI.OP1\(31),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(32),
d => \FPI.OP1\(32),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(33),
d => \FPI.OP1\(33),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(34),
d => \FPI.OP1\(34),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(35),
d => \FPI.OP1\(35),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(36),
d => \FPI.OP1\(36),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(37),
d => \FPI.OP1\(37),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(38),
d => \FPI.OP1\(38),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(39),
d => \FPI.OP1\(39),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(40),
d => \FPI.OP1\(40),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(41),
d => \FPI.OP1\(41),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(42),
d => \FPI.OP1\(42),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(43),
d => \FPI.OP1\(43),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(44),
d => \FPI.OP1\(44),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(45),
d => \FPI.OP1\(45),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(46),
d => \FPI.OP1\(46),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(47),
d => \FPI.OP1\(47),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(48),
d => \FPI.OP1\(48),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(49),
d => \FPI.OP1\(49),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(50),
d => \FPI.OP1\(50),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(51),
d => \FPI.OP1\(51),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(52),
d => \FPI.OP1\(52),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(53),
d => \FPI.OP1\(53),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(54),
d => \FPI.OP1\(54),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(55),
d => \FPI.OP1\(55),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(56),
d => \FPI.OP1\(56),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(57),
d => \FPI.OP1\(57),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(58),
d => \FPI.OP1\(58),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(59),
d => \FPI.OP1\(59),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(60),
d => \FPI.OP1\(60),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(61),
d => \FPI.OP1\(61),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(62),
d => \FPI.OP1\(62),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_RAW1_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.RAW1\(63),
d => \FPI.OP1\(63),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FLOP_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FLOP\(3),
d => \GRFPU0.GRFPU_X0.ST2.FLOP\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FLOP_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FLOP\(6),
d => \GRFPU0.GRFPU_X0.ST2.FLOP\(6),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FLOP_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FLOP\(7),
d => \GRFPU0.GRFPU_X0.ST2.FLOP\(7),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_FLOP_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.FLOP\(8),
d => \GRFPU0.GRFPU_X0.ST2.FLOP\(8),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_DIVROM0_RADDR_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.DIVROM0.RADDR\(0),
d => \GRFPU0.GRFPU_X0.N_18853_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_DIVROM0_RADDR_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.DIVROM0.RADDR\(1),
d => \GRFPU0.DIVROMI\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_DIVROM0_RADDR_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.DIVROM0.RADDR\(2),
d => \GRFPU0.GRFPU_X0.N_18854_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_DIVROM0_RADDR_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.DIVROM0.RADDR\(3),
d => \GRFPU0.GRFPU_X0.N_18855_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_DIVROM0_RADDR_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.DIVROM0.RADDR\(4),
d => \GRFPU0.DIVROMI\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_DIVROM0_RADDR_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.DIVROM0.RADDR\(5),
d => \GRFPU0.GRFPU_X0.N_18856_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_DIVROM0_RADDR_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.DIVROM0.RADDR\(6),
d => \GRFPU0.GRFPU_X0.N_18857_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_DIVROM0_RADDR_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.DIVROM0.RADDR\(7),
d => \GRFPU0.GRFPU_X0.N_18858_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_SGNFEQ: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.SGNFEQ\,
d => \GRFPU0.GRFPU_X0.VITER.SGNFEQ_0_SQMUXA\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.N_5673\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_ITER_EMIN: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EMIN\,
d => N_26927,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_BMLSB_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.BMLSB\(1),
d => \GRFPU0.GRFPU_X0.ITER.BMLSB_0_0_1__N_5\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(0),
d => \GRFPU0.GRFPU_X0.N_16931\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_16985\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(1),
d => \GRFPU0.GRFPU_X0.N_16932\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_16986\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(2),
d => \GRFPU0.GRFPU_X0.N_16933\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_16987\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(3),
d => \GRFPU0.GRFPU_X0.N_16934\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_16988\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(4),
d => \GRFPU0.GRFPU_X0.N_16935\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_16989\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(5),
d => \GRFPU0.GRFPU_X0.N_16936\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_16990\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(6),
d => \GRFPU0.GRFPU_X0.N_16937\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_16991\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(7),
d => \GRFPU0.GRFPU_X0.N_16938\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_18563\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(8),
d => \GRFPU0.GRFPU_X0.N_16939\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_16993\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(9),
d => \GRFPU0.GRFPU_X0.N_16940\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_16994\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(10),
d => \GRFPU0.GRFPU_X0.N_16941\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_16995\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(11),
d => \GRFPU0.GRFPU_X0.N_16942\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_16996\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(12),
d => \GRFPU0.GRFPU_X0.N_16943\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_16997\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(13),
d => \GRFPU0.GRFPU_X0.N_16944\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_16998\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(14),
d => \GRFPU0.GRFPU_X0.N_16945\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_16999\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(15),
d => \GRFPU0.GRFPU_X0.N_16946\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17000\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(16),
d => \GRFPU0.GRFPU_X0.N_16947\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17001\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(17),
d => \GRFPU0.GRFPU_X0.N_16948\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17002\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(18),
d => \GRFPU0.GRFPU_X0.N_16949\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17003\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(19),
d => \GRFPU0.GRFPU_X0.N_16950\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17004\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(20),
d => \GRFPU0.GRFPU_X0.N_16951\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17005\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(21),
d => \GRFPU0.GRFPU_X0.N_16952\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17006\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(22),
d => \GRFPU0.GRFPU_X0.N_16953\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17007\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(23),
d => \GRFPU0.GRFPU_X0.N_16954\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17008\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(24),
d => \GRFPU0.GRFPU_X0.N_16955\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17009\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(25),
d => \GRFPU0.GRFPU_X0.N_16956\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17010\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(26),
d => \GRFPU0.GRFPU_X0.N_16957\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17011\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(27),
d => \GRFPU0.GRFPU_X0.N_18981\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17012\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(28),
d => \GRFPU0.GRFPU_X0.N_16959\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17013\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(29),
d => \GRFPU0.GRFPU_X0.N_16960\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17014\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(30),
d => \GRFPU0.GRFPU_X0.N_16961\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17015\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(31),
d => \GRFPU0.GRFPU_X0.N_16962\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17016\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(32),
d => \GRFPU0.GRFPU_X0.N_16963\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17017\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(33),
d => \GRFPU0.GRFPU_X0.N_16964\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17018\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(34),
d => \GRFPU0.GRFPU_X0.N_16965\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17019\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(35),
d => \GRFPU0.GRFPU_X0.N_16966\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17020\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(36),
d => \GRFPU0.GRFPU_X0.N_16967\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17021\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(37),
d => \GRFPU0.GRFPU_X0.N_16968\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17022\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(38),
d => \GRFPU0.GRFPU_X0.N_16969\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17023\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(39),
d => \GRFPU0.GRFPU_X0.N_16970\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17024\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(40),
d => \GRFPU0.GRFPU_X0.N_16971\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17025\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(41),
d => \GRFPU0.GRFPU_X0.N_16972\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17026\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(42),
d => \GRFPU0.GRFPU_X0.N_16973\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17027\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(43),
d => \GRFPU0.GRFPU_X0.N_16974\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17028\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(44),
d => \GRFPU0.GRFPU_X0.N_16975\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17029\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(45),
d => \GRFPU0.GRFPU_X0.N_16976\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17030\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(46),
d => \GRFPU0.GRFPU_X0.N_16977\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17031\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(47),
d => \GRFPU0.GRFPU_X0.N_16978\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17032\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(48),
d => \GRFPU0.GRFPU_X0.N_16979\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17033\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(49),
d => \GRFPU0.GRFPU_X0.N_16980\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17034\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(50),
d => \GRFPU0.GRFPU_X0.N_16981\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17035\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(51),
d => \GRFPU0.GRFPU_X0.N_16982\,
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_17036\,
sload => N_113274,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(52),
d => \GRFPU0.MULO.MRES\(112),
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_16923\,
sclr => N_99844,
sload => N_99908_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(53),
d => \GRFPU0.MULO.MRES\(113),
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_18340\,
sclr => N_99844,
sload => N_99908_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(54),
d => \GRFPU0.MULO.MRES\(114),
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_16925\,
sclr => N_99844,
sload => N_99908_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(55),
d => \GRFPU0.MULO.MRES\(115),
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_16926\,
sclr => N_99844,
sload => N_99908_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(56),
d => \GRFPU0.MULO.MRES\(116),
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_16927\,
sclr => N_99844,
sload => N_99908_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(57),
d => \GRFPU0.MULO.MRES\(117),
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_16928\,
sclr => N_99844,
sload => N_99908_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(58),
d => \GRFPU0.MULO.MRES\(118),
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.N_16929\,
sclr => N_99844,
sload => N_99908_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(59),
d => \GRFPU0.MULO.MRES\(119),
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.ITER.DBUF\(59),
sclr => N_99844,
sload => N_99908_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ITER_DBUF_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.DBUF\(60),
d => \GRFPU0.MULO.MRES\(120),
clk => N_36,
clrn => VCC,
ena => N_99907,
asdata => \GRFPU0.GRFPU_X0.ITER.DBUF\(60),
sclr => N_99844,
sload => N_99908_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPU0_GRFPU_X0_ITER_EXPT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXPT\(0),
d => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1\(0),
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.N_5673\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXPT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXPT\(1),
d => \GRFPU0.GRFPU_X0.COMB.VITER.EXPT_1\(1),
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.N_5673\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_IDCST_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ID\(3),
d => \GRFPU0.GRFPU_X0.ST1.ID\(3),
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_IDCST_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.ID\(5),
d => \GRFPU0.GRFPU_X0.ST1.ID\(5),
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.DP_0_0_G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_DIV_PEND: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PEND\,
d => N_27009,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_RS2D: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS2D\,
d => \GRFPC0.N_23598_I_0\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_WRITE_RD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.WRITE_RD\,
d => \GRFPC0.RFA.WRITE_RD_0_0_G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_READ_RS1: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.READ_RS1\,
d => \GRFPC0.RFA.READ_RS1_0_0_G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_RS1D: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RS1D\,
d => \GRFPC0.N_23599_I_0\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_FIFO_FULL: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.FULL\,
d => \GRFPC0.FIFO.FULL_0_0_G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_D_FSTLCK: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.FSTLCK\,
d => \GRFPC0.D.FSTLCK_0_0_G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_D_FLDLCK: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.FLDLCK\,
d => \GRFPC0.D.FLDLCK_0_0_G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_RDWR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.RDWR\,
d => N_47179,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_CTRL_SEQERR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.SEQERR\,
d => N_44766,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_CTRL_AFSR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.AFSR\,
d => N_44776,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_PEND: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PEND\,
d => \GRFPC0.MEM.CTRL.PEND_0_0_G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_PEND: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PEND\,
d => \GRFPC0.EX.CTRL.PEND_0_0_G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_PEND: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PEND\,
d => \GRFPC0.WR.CTRL.PEND_0_0_G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_INST_1_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(31),
d => N_109,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(31),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(31),
d => N_109,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(31),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(21),
d => N_99,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(21),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(21),
d => N_99,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(21),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_WR_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.WR\(0),
d => \GRFPC0.FIFO.WR_0_0_0__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_CTRL_STDFQ: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.STDFQ\,
d => N_44787,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_CTRL_RDWR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.RDWR\,
d => N_47180,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_CTRL_LD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.LD\,
d => N_44808,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_CTRL_DIV: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.DIV\,
d => N_47181,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_CTRL_CCWR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.CCWR\,
d => N_47182,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_SEQERR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.SEQERR\,
d => N_47183,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_RDWR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.RDWR\,
d => N_47184,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_LD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.LD\,
d => N_44868,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_DIV: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.DIV\,
d => N_47185,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_CCWR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.CCWR\,
d => N_47186,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_AFSR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.AFSR\,
d => N_47187,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_SEQERR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.SEQERR\,
d => N_47188,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_RDWR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.RDWR\,
d => N_47189,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_LD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.LD\,
d => N_44946,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_DIV: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.DIV\,
d => N_47190,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_CCWR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.CCWR\,
d => N_47191,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_AFSR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.AFSR\,
d => N_47192,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_ST: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.ST\,
d => N_45010,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_RD_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.RD\(0),
d => \GRFPC0.FIFO.RD_0_0_0__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_DIV: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.DIV\,
d => \GRFPC0.EX.CTRL.DIV_0_0_G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_SEQERR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.SEQERR\,
d => N_45021,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_CCWR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.CCWR\,
d => N_45038,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_SEQERR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.SEQERR\,
d => N_45054,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_LD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.LD\,
d => N_45066,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_AFSR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.AFSR\,
d => N_45076,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_EXC: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.EXC\,
d => \GRFPC0.WR2.EXC_0_0_G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_CTRL_RDD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.RDD\,
d => \GRFPC0.WR2.CTRL.RDD_0_0_G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_STDFQ: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.STDFQ\,
d => \GRFPC0.WR.CTRL.STDFQ_0_0_G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR_CTRL_RDD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.RDD\,
d => \GRFPC0.WR.CTRL.RDD_0_0_G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_MEM_CTRL_STDFQ: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.STDFQ\,
d => \GRFPC0.MEM.CTRL.STDFQ_0_0_G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_EX_CTRL_STDFQ: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.STDFQ\,
d => N_45085,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_CTRL_PEND: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PEND\,
d => \GRFPC0.WR2.CTRL.PEND_0_0_G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_STDFQ: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.STDFQ\,
d => N_45102,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_RDWR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RDWR\,
d => N_45120,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_RDD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RDD\,
d => N_45139,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_LD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.LD\,
d => N_45157,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA_AFSR: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.AFSR\,
d => N_45173,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_ID_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.ID\(7),
d => N_45174_TZ,
clk => N_36,
clrn => VCC,
ena => N_37,
sclr => RST_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_DIV_ID_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.ID\(7),
d => \GRFPC0.WR2.CTRL.ID\(7),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_DIV_RS1V: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RS1V\,
d => \GRFPC0.WR2.CTRL.RS1V\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_R_FSR_NONSTD: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.NONSTD\,
d => \GRFPC0.R.FSR.NONSTD_0_0_G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_WR2_CTRL_RS1V: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.RS1V\,
d => \GRFPC0.WR.CTRL.RS1V\,
clk => N_36,
clrn => VCC,
ena => N_37,
sclr => RST_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
GRFPC0_WR_CTRL_RS1V: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.RS1V\,
d => \GRFPC0.MEM.CTRL.RS1V\,
clk => N_36,
clrn => VCC,
ena => N_37,
sclr => RST_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
GRFPC0_MEM_CTRL_RS1V: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.RS1V\,
d => \GRFPC0.EX.CTRL.RS1V\,
clk => N_36,
clrn => VCC,
ena => N_37,
sclr => RST_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_WR_CTRL_ID_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.ID\(7),
d => \GRFPC0.MEM.CTRL.ID\(7),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_ID_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.ID\(7),
d => \GRFPC0.WR.CTRL.ID\(7),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_ID_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.ID\(7),
d => \GRFPC0.EX.CTRL.ID\(7),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_VCNT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.VCNT\(0),
d => \GRFPC0.MEM.CTRL.VCNT\(1),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CNT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CNT\(0),
d => N_386,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CNT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CNT\(1),
d => N_387,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_RD_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.RD\(0),
d => \GRFPC0.EX.CTRL.RD\(0),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_RD_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.RD\(1),
d => \GRFPC0.EX.CTRL.RD\(1),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_RD_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.RD\(2),
d => \GRFPC0.EX.CTRL.RD\(2),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_RD_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.RD\(3),
d => \GRFPC0.EX.CTRL.RD\(3),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_RD_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.RD\(4),
d => \GRFPC0.EX.CTRL.RD\(4),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RD_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RD\(0),
d => N_103,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RD_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RD\(1),
d => N_104,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RD_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RD\(2),
d => N_105,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RD_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RD\(3),
d => N_106,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA_RD_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA.RD\(4),
d => N_107,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_RD_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.RD\(0),
d => \GRFPC0.WR.CTRL.RD\(0),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_RD_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.RD\(1),
d => \GRFPC0.WR.CTRL.RD\(1),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_RD_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.RD\(2),
d => \GRFPC0.WR.CTRL.RD\(2),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_RD_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.RD\(3),
d => \GRFPC0.WR.CTRL.RD\(3),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_RD_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.RD\(4),
d => \GRFPC0.WR.CTRL.RD\(4),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_ID_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.ID\(0),
d => \GRFPC0.EX.CTRL.ID\(0),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_ID_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.ID\(1),
d => \GRFPC0.EX.CTRL.ID\(1),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_ID_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.ID\(2),
d => \GRFPC0.EX.CTRL.ID\(2),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_ID_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.ID\(3),
d => \GRFPC0.EX.CTRL.ID\(3),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_ID_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.ID\(4),
d => \GRFPC0.EX.CTRL.ID\(4),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_ID_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.ID\(5),
d => \GRFPC0.EX.CTRL.ID\(5),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_ID_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.ID\(0),
d => \GRFPC0.WR.CTRL.ID\(0),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_ID_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.ID\(1),
d => \GRFPC0.WR.CTRL.ID\(1),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_ID_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.ID\(2),
d => \GRFPC0.WR.CTRL.ID\(2),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_ID_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.ID\(3),
d => \GRFPC0.WR.CTRL.ID\(3),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_ID_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.ID\(4),
d => \GRFPC0.WR.CTRL.ID\(4),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_ID_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.ID\(5),
d => \GRFPC0.WR.CTRL.ID\(5),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_RD_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.RD\(0),
d => \GRFPC0.MEM.CTRL.RD\(0),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_RD_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.RD\(1),
d => \GRFPC0.MEM.CTRL.RD\(1),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_RD_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.RD\(2),
d => \GRFPC0.MEM.CTRL.RD\(2),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_RD_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.RD\(3),
d => \GRFPC0.MEM.CTRL.RD\(3),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_RD_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.RD\(4),
d => \GRFPC0.MEM.CTRL.RD\(4),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_ID_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.ID\(0),
d => \GRFPC0.MEM.CTRL.ID\(0),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_ID_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.ID\(1),
d => \GRFPC0.MEM.CTRL.ID\(1),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_ID_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.ID\(2),
d => \GRFPC0.MEM.CTRL.ID\(2),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_ID_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.ID\(3),
d => \GRFPC0.MEM.CTRL.ID\(3),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_ID_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.ID\(4),
d => \GRFPC0.MEM.CTRL.ID\(4),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_ID_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.ID\(5),
d => \GRFPC0.MEM.CTRL.ID\(5),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_VCNT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.VCNT\(0),
d => \GRFPC0.MEM.CTRL.VCNT_0_0_0__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_VCNT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.VCNT\(1),
d => \GRFPC0.MEM.CTRL.VCNT_0_0_1__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_EXCT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.EXCT\(0),
d => \FPO.EXC\(0),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_EXCT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.EXCT\(1),
d => \GRFPU0.GRFPU_X0.N_18290_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_EXCT_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.EXCT\(2),
d => N_27123,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_EXCT_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.EXCT\(3),
d => \GRFPU0.GRFPU_X0.COMB.VEXC_5_IV_I_0\(3),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_EXCT_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.EXCT\(4),
d => \GRFPU0.GRFPU_X0.N_18289_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_EXCT_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.EXCT\(5),
d => \GRFPC0.FPO_I_6_I_0\(69),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(0),
d => \FPO.RES\(0),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(1),
d => \FPO.RES\(1),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(2),
d => \FPO.RES\(2),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(3),
d => \FPO.RES\(3),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(4),
d => \FPO.RES\(4),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(5),
d => \FPO.RES\(5),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(6),
d => \FPO.RES\(6),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(7),
d => \FPO.RES\(7),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(8),
d => \FPO.RES\(8),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(9),
d => \FPO.RES\(9),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(10),
d => \FPO.RES\(10),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(11),
d => \FPO.RES\(11),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(12),
d => \FPO.RES\(12),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(13),
d => \FPO.RES\(13),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(14),
d => \FPO.RES\(14),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(15),
d => \FPO.RES\(15),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(16),
d => \FPO.RES\(16),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(17),
d => \FPO.RES\(17),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(18),
d => \FPO.RES\(18),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(19),
d => \FPO.RES\(19),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(20),
d => \FPO.RES\(20),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(21),
d => \FPO.RES\(21),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(22),
d => \FPO.RES\(22),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(23),
d => \FPO.RES\(23),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(24),
d => \FPO.RES\(24),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(25),
d => \FPO.RES\(25),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(26),
d => \FPO.RES\(26),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(27),
d => \FPO.RES\(27),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(28),
d => \FPO.RES\(28),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(29),
d => \FPO.RES\(29),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(30),
d => \FPO.RES\(30),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(31),
d => \FPO.RES\(31),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(32),
d => \GRFPU0.GRFPU_X0.N_20294_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(33),
d => \FPO.RES\(33),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(34),
d => \GRFPU0.GRFPU_X0.N_20274_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(35),
d => \GRFPU0.GRFPU_X0.N_20295_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(36),
d => \FPO.RES\(36),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(37),
d => \GRFPU0.GRFPU_X0.N_20275_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(38),
d => \GRFPU0.GRFPU_X0.N_20296_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(39),
d => \GRFPU0.GRFPU_X0.N_19153_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(40),
d => \GRFPU0.GRFPU_X0.N_20289_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(41),
d => \GRFPU0.GRFPU_X0.N_20297_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(42),
d => \GRFPU0.GRFPU_X0.N_20271_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(43),
d => \GRFPU0.GRFPU_X0.N_20290_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(44),
d => \GRFPU0.GRFPU_X0.N_20298_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(45),
d => \GRFPU0.GRFPU_X0.N_20272_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(46),
d => \GRFPU0.GRFPU_X0.N_20291_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(47),
d => \GRFPU0.GRFPU_X0.N_19240_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(48),
d => \GRFPU0.GRFPU_X0.N_20273_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(49),
d => \GRFPU0.GRFPU_X0.N_20292_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(50),
d => \FPO.RES\(50),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(51),
d => \GRFPU0.GRFPU_X0.N_20285_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(52),
d => \GRFPU0.GRFPU_X0.N_20293_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(53),
d => \FPO.RES\(53),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(54),
d => \GRFPU0.GRFPU_X0.N_20286_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(55),
d => \FPO.RES\(55),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(56),
d => N_46771_3,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(57),
d => \GRFPU0.GRFPU_X0.N_20287_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(58),
d => \FPO.RES\(58),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(59),
d => \FPO.RES\(59),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(60),
d => \GRFPU0.GRFPU_X0.N_20288_I_0\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(61),
d => \FPO.RES\(61),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(62),
d => \FPO.RES\(62),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_RESULT_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.RESULT\(63),
d => \FPO.RES\(63),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.VDIV.VALID2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_VCNT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.VCNT\(0),
d => \GRFPC0.EX.CTRL.VCNT_0_0_0__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_VCNT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.VCNT\(1),
d => \GRFPC0.EX.CTRL.VCNT_0_0_1__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_RD_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.RNDMODE\(0),
d => \GRFPC0.R.FSR.RD_0_0_0__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_RD_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \FPI.RNDMODE\(1),
d => \GRFPC0.R.FSR.RD_0_0_1__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_TEM_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.TEM\(0),
d => \GRFPC0.R.FSR.TEM_0_0_0__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_TEM_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.TEM\(1),
d => \GRFPC0.R.FSR.TEM_0_0_1__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_TEM_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.TEM\(2),
d => \GRFPC0.R.FSR.TEM_0_0_2__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_TEM_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.TEM\(3),
d => \GRFPC0.R.FSR.TEM_0_0_3__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_TEM_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.TEM\(4),
d => \GRFPC0.R.FSR.TEM_0_0_4__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_RREG_EXCT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.EXCT\(1),
d => N_27201,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_RREG_EXCT_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.EXCT\(3),
d => N_27203,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_RREG_EXCT_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.EXCT\(4),
d => N_27204,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_RREG_EXCT_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.EXCT\(5),
d => N_27205,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_EXCT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.EXCT\(0),
d => N_47193,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_EXCT_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.EXCT\(2),
d => N_45216,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_EXCT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.EXCT\(0),
d => N_47194,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_EXCT_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.EXCT\(2),
d => N_45251,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_RREG_RES_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(0),
d => \FPI.OP1\(0),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(0),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
HOLDN_I <= not N_37;
\GRFPC0_EX_RREG_RES_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(1),
d => \FPI.OP1\(1),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(1),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(2),
d => \FPI.OP1\(2),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(2),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(3),
d => \FPI.OP1\(3),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(3),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(4),
d => \FPI.OP1\(4),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(4),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(5),
d => \FPI.OP1\(5),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(5),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(6),
d => \FPI.OP1\(6),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(6),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(7),
d => \FPI.OP1\(7),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(7),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(8),
d => \FPI.OP1\(8),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(8),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(9),
d => \FPI.OP1\(9),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(9),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(10),
d => \FPI.OP1\(10),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(10),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(11),
d => \FPI.OP1\(11),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(11),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(12),
d => \FPI.OP1\(12),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(12),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(13),
d => \FPI.OP1\(13),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(13),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(14),
d => \FPI.OP1\(14),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(14),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(15),
d => \FPI.OP1\(15),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(15),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(16),
d => \FPI.OP1\(16),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(16),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(17),
d => \FPI.OP1\(17),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(17),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(18),
d => \FPI.OP1\(18),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(18),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(19),
d => \FPI.OP1\(19),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(19),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(20),
d => \FPI.OP1\(20),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(20),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(21),
d => \FPI.OP1\(21),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(21),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(22),
d => \FPI.OP1\(22),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(22),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(23),
d => \FPI.OP1\(23),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(23),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(24),
d => \FPI.OP1\(24),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(24),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(25),
d => \FPI.OP1\(25),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(25),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(26),
d => \FPI.OP1\(26),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(26),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(27),
d => \FPI.OP1\(27),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(27),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(28),
d => \FPI.OP1\(28),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(28),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(29),
d => \FPI.OP1\(29),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(29),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(30),
d => \FPI.OP1\(30),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(30),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(31),
d => \FPI.OP1\(31),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(31),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(32),
d => \FPI.OP1\(32),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \GRFPU0.GRFPU_X0.N_20294_I_0\,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(33),
d => \FPI.OP1\(33),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(33),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(34),
d => \FPI.OP1\(34),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \GRFPU0.GRFPU_X0.N_20274_I_0\,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(35),
d => \FPI.OP1\(35),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \GRFPU0.GRFPU_X0.N_20295_I_0\,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(36),
d => \FPI.OP1\(36),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(36),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(37),
d => \FPI.OP1\(37),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \GRFPU0.GRFPU_X0.N_20275_I_0\,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(38),
d => \FPI.OP1\(38),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \GRFPU0.GRFPU_X0.N_20296_I_0\,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(39),
d => \FPI.OP1\(39),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \GRFPU0.GRFPU_X0.N_19153_I_0\,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(40),
d => \FPI.OP1\(40),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \GRFPU0.GRFPU_X0.N_20289_I_0\,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(41),
d => \FPI.OP1\(41),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \GRFPU0.GRFPU_X0.N_20297_I_0\,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(42),
d => \FPI.OP1\(42),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \GRFPU0.GRFPU_X0.N_20271_I_0\,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(43),
d => \FPI.OP1\(43),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \GRFPU0.GRFPU_X0.N_20290_I_0\,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(44),
d => \FPI.OP1\(44),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \GRFPU0.GRFPU_X0.N_20298_I_0\,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(45),
d => \FPI.OP1\(45),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \GRFPU0.GRFPU_X0.N_20272_I_0\,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(46),
d => \FPI.OP1\(46),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \GRFPU0.GRFPU_X0.N_20291_I_0\,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(47),
d => \FPI.OP1\(47),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \GRFPU0.GRFPU_X0.N_19240_I_0\,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(48),
d => \FPI.OP1\(48),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \GRFPU0.GRFPU_X0.N_20273_I_0\,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(49),
d => \FPI.OP1\(49),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \GRFPU0.GRFPU_X0.N_20292_I_0\,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(50),
d => \FPI.OP1\(50),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(50),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(51),
d => \FPI.OP1\(51),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \GRFPU0.GRFPU_X0.N_20285_I_0\,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(52),
d => \FPI.OP1\(52),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \GRFPU0.GRFPU_X0.N_20293_I_0\,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(53),
d => \FPI.OP1\(53),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(53),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(54),
d => \FPI.OP1\(54),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \GRFPU0.GRFPU_X0.N_20286_I_0\,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(55),
d => \FPI.OP1\(55),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(55),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(56),
d => \FPI.OP1\(56),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => N_46771_3,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(57),
d => \FPI.OP1\(57),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \GRFPU0.GRFPU_X0.N_20287_I_0\,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(58),
d => \FPI.OP1\(58),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(58),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(59),
d => \FPI.OP1\(59),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(59),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(60),
d => \FPI.OP1\(60),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \GRFPU0.GRFPU_X0.N_20288_I_0\,
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(61),
d => \FPI.OP1\(61),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(61),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(62),
d => \FPI.OP1\(62),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(62),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_EX_RREG_RES_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.RREG.RES\(63),
d => \FPI.OP1\(63),
clk => N_36,
clrn => VCC,
ena => N_99868,
asdata => \FPO.RES\(63),
sload => HOLDN_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_RREG_RES_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(0),
d => N_47195,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(1),
d => N_47196,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(2),
d => N_47197,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(3),
d => N_47198,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(4),
d => N_47199,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(5),
d => N_47200,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(6),
d => N_47201,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(7),
d => N_47202,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(8),
d => N_47203,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(9),
d => N_47204,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(10),
d => N_47205,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(11),
d => N_47206,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(12),
d => N_47207,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(13),
d => N_47208,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(14),
d => N_47209,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(15),
d => N_47210,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(16),
d => N_47211,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(17),
d => N_47212,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(18),
d => N_47213,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(19),
d => N_47214,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(20),
d => N_47215,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(21),
d => N_47216,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(22),
d => N_47217,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(23),
d => N_47218,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(24),
d => N_47219,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(25),
d => N_47220,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(26),
d => N_47221,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(27),
d => N_47222,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(28),
d => N_47223,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(29),
d => N_47224,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(30),
d => N_47225,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(31),
d => N_47226,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(33),
d => N_47227,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(36),
d => N_47228,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(50),
d => N_47229,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(53),
d => N_47230,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(55),
d => N_47231,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(56),
d => N_47232,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(58),
d => N_47233,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(59),
d => N_47234,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(61),
d => N_47235,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_RREG_RES_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.RREG.RES\(62),
d => N_47236,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VMEM.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(0),
d => N_47237,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(1),
d => N_47238,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(2),
d => N_47239,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(3),
d => N_47240,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(4),
d => N_47241,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(5),
d => N_47242,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(6),
d => N_47243,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(7),
d => N_47244,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(8),
d => N_47245,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(9),
d => N_47246,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(10),
d => N_47247,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(11),
d => N_47248,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(12),
d => N_47249,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(13),
d => N_47250,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(14),
d => N_47251,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(15),
d => N_47252,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(16),
d => N_47253,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(17),
d => N_47254,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(18),
d => N_47255,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(19),
d => N_47256,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(20),
d => N_47257,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(21),
d => N_47258,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(22),
d => N_47259,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(23),
d => N_47260,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(24),
d => N_47261,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(25),
d => N_47262,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(26),
d => N_47263,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(27),
d => N_47264,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(28),
d => N_47265,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(29),
d => N_47266,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(30),
d => N_47267,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(31),
d => N_47268,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(33),
d => N_47269,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(36),
d => N_47270,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(50),
d => N_47271,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(53),
d => N_47272,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(55),
d => N_47273,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(56),
d => N_47274,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(58),
d => N_47275,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(59),
d => N_47276,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(61),
d => N_47277,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_RREG_RES_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.RREG.RES\(62),
d => N_47278,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR.RREG.RESV_0_SQMUXA_1\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(0),
d => \GRFPC0.R.STDATA_0_0_0__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(1),
d => \GRFPC0.R.STDATA_0_0_1__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(2),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(2),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(3),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(3),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(4),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(4),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(5),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(5),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(6),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(6),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(7),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(7),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(8),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(8),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(9),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(9),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(10),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(10),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(11),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(11),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(12),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(12),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(13),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(13),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(14),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(14),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(15),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(15),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(16),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(16),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(17),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(17),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(18),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(18),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(19),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(19),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(20),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(20),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(21),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(21),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(22),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(22),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(23),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(23),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(24),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(24),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(25),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(25),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(26),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(26),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(27),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(27),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(28),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(28),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(29),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(29),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(30),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(30),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_STDATA_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.STDATA\(31),
d => \GRFPC0.FP_PIPELINE.V.STDATA_1\(31),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_ID_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.ID\(0),
d => \GRFPC0.WR2.CTRL.ID\(0),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_ID_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.ID\(1),
d => \GRFPC0.WR2.CTRL.ID\(1),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_ID_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.ID\(2),
d => \GRFPC0.WR2.CTRL.ID\(2),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_ID_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.ID\(3),
d => \GRFPC0.WR2.CTRL.ID\(3),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_ID_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.ID\(4),
d => \GRFPC0.WR2.CTRL.ID\(4),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_ID_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.ID\(5),
d => \GRFPC0.WR2.CTRL.ID\(5),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.FP_PIPELINE.UN68_HOLDN\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_RREG_RES_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(0),
d => \GRFPC0.N_19199\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19264\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(1),
d => \GRFPC0.N_19200\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19265\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(2),
d => \GRFPC0.N_19201\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19266\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(3),
d => \GRFPC0.N_19202\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19267\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(4),
d => \GRFPC0.N_19203\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19268\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(5),
d => \GRFPC0.N_19204\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19269\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(6),
d => \GRFPC0.N_19205\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19270\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(7),
d => \GRFPC0.N_19206\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19271\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(8),
d => \GRFPC0.N_19207\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19272\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(9),
d => \GRFPC0.N_19208\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19273\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(10),
d => \GRFPC0.N_19209\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19274\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(11),
d => \GRFPC0.N_19210\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19275\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(12),
d => \GRFPC0.N_19211\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19276\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(13),
d => \GRFPC0.N_19212\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19277\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(14),
d => \GRFPC0.N_19213\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19278\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(15),
d => \GRFPC0.N_19214\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19279\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(16),
d => \GRFPC0.N_19215\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19280\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(17),
d => \GRFPC0.N_19216\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19281\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(18),
d => \GRFPC0.N_19217\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19282\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(19),
d => \GRFPC0.N_19218\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19283\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(20),
d => \GRFPC0.N_19219\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19284\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(21),
d => \GRFPC0.N_19220\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19285\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(22),
d => \GRFPC0.N_19221\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19286\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(23),
d => \GRFPC0.N_19222\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19287\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(24),
d => \GRFPC0.N_19223\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19288\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(25),
d => \GRFPC0.N_19224\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19289\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(26),
d => \GRFPC0.N_19225\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19290\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(27),
d => \GRFPC0.N_19226\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19291\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(28),
d => \GRFPC0.N_19227\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19292\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(29),
d => \GRFPC0.N_19228\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19293\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(30),
d => \GRFPC0.N_19229\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19294\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(31),
d => \GRFPC0.N_19230\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19295\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(32),
d => \GRFPC0.N_19231\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19296\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(33),
d => \GRFPC0.N_19232\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19297\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(34),
d => \GRFPC0.N_19233\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19298\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(35),
d => \GRFPC0.N_19234\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19299\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(36),
d => \GRFPC0.N_19235\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19300\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(37),
d => \GRFPC0.N_19236\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19301\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(38),
d => \GRFPC0.N_19237\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19302\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(39),
d => \GRFPC0.N_19238\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19303\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(40),
d => \GRFPC0.N_19239\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19304\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(41),
d => \GRFPC0.N_19240\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19305\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(42),
d => \GRFPC0.N_19241\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19306\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(43),
d => \GRFPC0.N_19242\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19307\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(44),
d => \GRFPC0.N_19243\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19308\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(45),
d => \GRFPC0.N_19244\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19309\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(46),
d => \GRFPC0.N_19245\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19310\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(47),
d => \GRFPC0.N_19246\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19311\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(48),
d => \GRFPC0.N_19247\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19312\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(49),
d => \GRFPC0.N_19248\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19313\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(50),
d => \GRFPC0.N_19249\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19314\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(51),
d => \GRFPC0.N_19250\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19315\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(52),
d => \GRFPC0.N_19251\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19316\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(53),
d => \GRFPC0.N_19252\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19317\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(54),
d => \GRFPC0.N_19253\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19318\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(55),
d => \GRFPC0.N_19254\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19319\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(56),
d => \GRFPC0.N_19255\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19320\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(57),
d => \GRFPC0.N_19256\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19321\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(58),
d => \GRFPC0.N_19257\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19322\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(59),
d => \GRFPC0.N_19258\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19323\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(60),
d => \GRFPC0.N_19259\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19324\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(61),
d => \GRFPC0.N_19260\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19325\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(62),
d => \GRFPC0.N_19261\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19326\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_WR2_RREG_RES_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.RREG.RES\(63),
d => \GRFPC0.N_19262\,
clk => N_36,
clrn => VCC,
ena => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1\,
asdata => \GRFPC0.N_19327\,
sload => N_99866_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND,
	sclr => GND);
\GRFPC0_MEM_CTRL_INST_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(5),
d => \GRFPC0.EX.CTRL.INST\(5),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(6),
d => \GRFPC0.EX.CTRL.INST\(6),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(7),
d => \GRFPC0.EX.CTRL.INST\(7),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(8),
d => \GRFPC0.EX.CTRL.INST\(8),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(9),
d => \GRFPC0.EX.CTRL.INST\(9),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(10),
d => \GRFPC0.EX.CTRL.INST\(10),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(11),
d => \GRFPC0.EX.CTRL.INST\(11),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(12),
d => \GRFPC0.EX.CTRL.INST\(12),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(13),
d => \GRFPC0.EX.CTRL.INST\(13),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(19),
d => \GRFPC0.EX.CTRL.INST\(19),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(20),
d => \GRFPC0.EX.CTRL.INST\(20),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(21),
d => \GRFPC0.EX.CTRL.INST\(21),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(22),
d => \GRFPC0.EX.CTRL.INST\(22),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(23),
d => \GRFPC0.EX.CTRL.INST\(23),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(24),
d => \GRFPC0.EX.CTRL.INST\(24),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(30),
d => \GRFPC0.EX.CTRL.INST\(30),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_INST_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.INST\(31),
d => \GRFPC0.EX.CTRL.INST\(31),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(2),
d => \GRFPC0.EX.CTRL.PC\(2),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(3),
d => \GRFPC0.EX.CTRL.PC\(3),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(4),
d => \GRFPC0.EX.CTRL.PC\(4),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(5),
d => \GRFPC0.EX.CTRL.PC\(5),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(6),
d => \GRFPC0.EX.CTRL.PC\(6),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(7),
d => \GRFPC0.EX.CTRL.PC\(7),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(8),
d => \GRFPC0.EX.CTRL.PC\(8),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(9),
d => \GRFPC0.EX.CTRL.PC\(9),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(10),
d => \GRFPC0.EX.CTRL.PC\(10),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(11),
d => \GRFPC0.EX.CTRL.PC\(11),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(12),
d => \GRFPC0.EX.CTRL.PC\(12),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(13),
d => \GRFPC0.EX.CTRL.PC\(13),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(14),
d => \GRFPC0.EX.CTRL.PC\(14),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(15),
d => \GRFPC0.EX.CTRL.PC\(15),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(16),
d => \GRFPC0.EX.CTRL.PC\(16),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(17),
d => \GRFPC0.EX.CTRL.PC\(17),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(18),
d => \GRFPC0.EX.CTRL.PC\(18),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(19),
d => \GRFPC0.EX.CTRL.PC\(19),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(20),
d => \GRFPC0.EX.CTRL.PC\(20),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(21),
d => \GRFPC0.EX.CTRL.PC\(21),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(22),
d => \GRFPC0.EX.CTRL.PC\(22),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(23),
d => \GRFPC0.EX.CTRL.PC\(23),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(24),
d => \GRFPC0.EX.CTRL.PC\(24),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(25),
d => \GRFPC0.EX.CTRL.PC\(25),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(26),
d => \GRFPC0.EX.CTRL.PC\(26),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(27),
d => \GRFPC0.EX.CTRL.PC\(27),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(28),
d => \GRFPC0.EX.CTRL.PC\(28),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(29),
d => \GRFPC0.EX.CTRL.PC\(29),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(30),
d => \GRFPC0.EX.CTRL.PC\(30),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_MEM_CTRL_PC_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.MEM.CTRL.PC\(31),
d => \GRFPC0.EX.CTRL.PC\(31),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(0),
d => \GRFPC0.MEM.CTRL.INST\(0),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(1),
d => \GRFPC0.MEM.CTRL.INST\(1),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(2),
d => \GRFPC0.MEM.CTRL.INST\(2),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(3),
d => \GRFPC0.MEM.CTRL.INST\(3),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(4),
d => \GRFPC0.MEM.CTRL.INST\(4),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(5),
d => \GRFPC0.MEM.CTRL.INST\(5),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(6),
d => \GRFPC0.MEM.CTRL.INST\(6),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(7),
d => \GRFPC0.MEM.CTRL.INST\(7),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(8),
d => \GRFPC0.MEM.CTRL.INST\(8),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(9),
d => \GRFPC0.MEM.CTRL.INST\(9),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(10),
d => \GRFPC0.MEM.CTRL.INST\(10),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(11),
d => \GRFPC0.MEM.CTRL.INST\(11),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(12),
d => \GRFPC0.MEM.CTRL.INST\(12),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(13),
d => \GRFPC0.MEM.CTRL.INST\(13),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(14),
d => \GRFPC0.MEM.CTRL.INST\(14),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(15),
d => \GRFPC0.MEM.CTRL.INST\(15),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(16),
d => \GRFPC0.MEM.CTRL.INST\(16),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(17),
d => \GRFPC0.MEM.CTRL.INST\(17),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(18),
d => \GRFPC0.MEM.CTRL.INST\(18),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(19),
d => \GRFPC0.MEM.CTRL.INST\(19),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(20),
d => \GRFPC0.MEM.CTRL.INST\(20),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(21),
d => \GRFPC0.MEM.CTRL.INST\(21),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(22),
d => \GRFPC0.MEM.CTRL.INST\(22),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(23),
d => \GRFPC0.MEM.CTRL.INST\(23),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(24),
d => \GRFPC0.MEM.CTRL.INST\(24),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(25),
d => \GRFPC0.MEM.CTRL.INST\(25),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(26),
d => \GRFPC0.MEM.CTRL.INST\(26),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(27),
d => \GRFPC0.MEM.CTRL.INST\(27),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(28),
d => \GRFPC0.MEM.CTRL.INST\(28),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(29),
d => \GRFPC0.MEM.CTRL.INST\(29),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(30),
d => \GRFPC0.MEM.CTRL.INST\(30),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_INST_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.INST\(31),
d => \GRFPC0.MEM.CTRL.INST\(31),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(2),
d => \GRFPC0.MEM.CTRL.PC\(2),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(3),
d => \GRFPC0.MEM.CTRL.PC\(3),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(4),
d => \GRFPC0.MEM.CTRL.PC\(4),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(5),
d => \GRFPC0.MEM.CTRL.PC\(5),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(6),
d => \GRFPC0.MEM.CTRL.PC\(6),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(7),
d => \GRFPC0.MEM.CTRL.PC\(7),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(8),
d => \GRFPC0.MEM.CTRL.PC\(8),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(9),
d => \GRFPC0.MEM.CTRL.PC\(9),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(10),
d => \GRFPC0.MEM.CTRL.PC\(10),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(11),
d => \GRFPC0.MEM.CTRL.PC\(11),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(12),
d => \GRFPC0.MEM.CTRL.PC\(12),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(13),
d => \GRFPC0.MEM.CTRL.PC\(13),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(14),
d => \GRFPC0.MEM.CTRL.PC\(14),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(15),
d => \GRFPC0.MEM.CTRL.PC\(15),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(16),
d => \GRFPC0.MEM.CTRL.PC\(16),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(17),
d => \GRFPC0.MEM.CTRL.PC\(17),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(18),
d => \GRFPC0.MEM.CTRL.PC\(18),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(19),
d => \GRFPC0.MEM.CTRL.PC\(19),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(20),
d => \GRFPC0.MEM.CTRL.PC\(20),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(21),
d => \GRFPC0.MEM.CTRL.PC\(21),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(22),
d => \GRFPC0.MEM.CTRL.PC\(22),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(23),
d => \GRFPC0.MEM.CTRL.PC\(23),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(24),
d => \GRFPC0.MEM.CTRL.PC\(24),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(25),
d => \GRFPC0.MEM.CTRL.PC\(25),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(26),
d => \GRFPC0.MEM.CTRL.PC\(26),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(27),
d => \GRFPC0.MEM.CTRL.PC\(27),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(28),
d => \GRFPC0.MEM.CTRL.PC\(28),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(29),
d => \GRFPC0.MEM.CTRL.PC\(29),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(30),
d => \GRFPC0.MEM.CTRL.PC\(30),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR_CTRL_PC_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR.CTRL.PC\(31),
d => \GRFPC0.MEM.CTRL.PC\(31),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(0),
d => \GRFPC0.WR.CTRL.INST\(0),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(1),
d => \GRFPC0.WR.CTRL.INST\(1),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(2),
d => \GRFPC0.WR.CTRL.INST\(2),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(3),
d => \GRFPC0.WR.CTRL.INST\(3),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(4),
d => \GRFPC0.WR.CTRL.INST\(4),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(5),
d => \GRFPC0.WR.CTRL.INST\(5),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(6),
d => \GRFPC0.WR.CTRL.INST\(6),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(7),
d => \GRFPC0.WR.CTRL.INST\(7),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(8),
d => \GRFPC0.WR.CTRL.INST\(8),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(9),
d => \GRFPC0.WR.CTRL.INST\(9),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(10),
d => \GRFPC0.WR.CTRL.INST\(10),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(11),
d => \GRFPC0.WR.CTRL.INST\(11),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(12),
d => \GRFPC0.WR.CTRL.INST\(12),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(13),
d => \GRFPC0.WR.CTRL.INST\(13),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(14),
d => \GRFPC0.WR.CTRL.INST\(14),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(15),
d => \GRFPC0.WR.CTRL.INST\(15),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(16),
d => \GRFPC0.WR.CTRL.INST\(16),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(17),
d => \GRFPC0.WR.CTRL.INST\(17),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(18),
d => \GRFPC0.WR.CTRL.INST\(18),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(19),
d => \GRFPC0.WR.CTRL.INST\(19),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(20),
d => \GRFPC0.WR.CTRL.INST\(20),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(21),
d => \GRFPC0.WR.CTRL.INST\(21),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(22),
d => \GRFPC0.WR.CTRL.INST\(22),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(23),
d => \GRFPC0.WR.CTRL.INST\(23),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(24),
d => \GRFPC0.WR.CTRL.INST\(24),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(25),
d => \GRFPC0.WR.CTRL.INST\(25),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(26),
d => \GRFPC0.WR.CTRL.INST\(26),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(27),
d => \GRFPC0.WR.CTRL.INST\(27),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(28),
d => \GRFPC0.WR.CTRL.INST\(28),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(29),
d => \GRFPC0.WR.CTRL.INST\(29),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(30),
d => \GRFPC0.WR.CTRL.INST\(30),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_INST_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.INST\(31),
d => \GRFPC0.WR.CTRL.INST\(31),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(2),
d => \GRFPC0.WR.CTRL.PC\(2),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(3),
d => \GRFPC0.WR.CTRL.PC\(3),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(4),
d => \GRFPC0.WR.CTRL.PC\(4),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(5),
d => \GRFPC0.WR.CTRL.PC\(5),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(6),
d => \GRFPC0.WR.CTRL.PC\(6),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(7),
d => \GRFPC0.WR.CTRL.PC\(7),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(8),
d => \GRFPC0.WR.CTRL.PC\(8),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(9),
d => \GRFPC0.WR.CTRL.PC\(9),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(10),
d => \GRFPC0.WR.CTRL.PC\(10),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(11),
d => \GRFPC0.WR.CTRL.PC\(11),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(12),
d => \GRFPC0.WR.CTRL.PC\(12),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(13),
d => \GRFPC0.WR.CTRL.PC\(13),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(14),
d => \GRFPC0.WR.CTRL.PC\(14),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(15),
d => \GRFPC0.WR.CTRL.PC\(15),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(16),
d => \GRFPC0.WR.CTRL.PC\(16),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(17),
d => \GRFPC0.WR.CTRL.PC\(17),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(18),
d => \GRFPC0.WR.CTRL.PC\(18),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(19),
d => \GRFPC0.WR.CTRL.PC\(19),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(20),
d => \GRFPC0.WR.CTRL.PC\(20),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(21),
d => \GRFPC0.WR.CTRL.PC\(21),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(22),
d => \GRFPC0.WR.CTRL.PC\(22),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(23),
d => \GRFPC0.WR.CTRL.PC\(23),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(24),
d => \GRFPC0.WR.CTRL.PC\(24),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(25),
d => \GRFPC0.WR.CTRL.PC\(25),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(26),
d => \GRFPC0.WR.CTRL.PC\(26),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(27),
d => \GRFPC0.WR.CTRL.PC\(27),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(28),
d => \GRFPC0.WR.CTRL.PC\(28),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(29),
d => \GRFPC0.WR.CTRL.PC\(29),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(30),
d => \GRFPC0.WR.CTRL.PC\(30),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_WR2_CTRL_PC_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.WR2.CTRL.PC\(31),
d => \GRFPC0.WR.CTRL.PC\(31),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.WR.CTRL.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(0),
d => \GRFPC0.WR2.CTRL.INST\(0),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(1),
d => \GRFPC0.WR2.CTRL.INST\(1),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(2),
d => \GRFPC0.WR2.CTRL.INST\(2),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(3),
d => \GRFPC0.WR2.CTRL.INST\(3),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(4),
d => \GRFPC0.WR2.CTRL.INST\(4),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(5),
d => \GRFPC0.WR2.CTRL.INST\(5),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(6),
d => \GRFPC0.WR2.CTRL.INST\(6),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(7),
d => \GRFPC0.WR2.CTRL.INST\(7),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(8),
d => \GRFPC0.WR2.CTRL.INST\(8),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(9),
d => \GRFPC0.WR2.CTRL.INST\(9),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(10),
d => \GRFPC0.WR2.CTRL.INST\(10),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(11),
d => \GRFPC0.WR2.CTRL.INST\(11),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(12),
d => \GRFPC0.WR2.CTRL.INST\(12),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(13),
d => \GRFPC0.WR2.CTRL.INST\(13),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(14),
d => \GRFPC0.WR2.CTRL.INST\(14),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(15),
d => \GRFPC0.WR2.CTRL.INST\(15),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(16),
d => \GRFPC0.WR2.CTRL.INST\(16),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(17),
d => \GRFPC0.WR2.CTRL.INST\(17),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(18),
d => \GRFPC0.WR2.CTRL.INST\(18),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(19),
d => \GRFPC0.WR2.CTRL.INST\(19),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(20),
d => \GRFPC0.WR2.CTRL.INST\(20),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(21),
d => \GRFPC0.WR2.CTRL.INST\(21),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(22),
d => \GRFPC0.WR2.CTRL.INST\(22),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(23),
d => \GRFPC0.WR2.CTRL.INST\(23),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(24),
d => \GRFPC0.WR2.CTRL.INST\(24),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(25),
d => \GRFPC0.WR2.CTRL.INST\(25),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(26),
d => \GRFPC0.WR2.CTRL.INST\(26),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(27),
d => \GRFPC0.WR2.CTRL.INST\(27),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(28),
d => \GRFPC0.WR2.CTRL.INST\(28),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(29),
d => \GRFPC0.WR2.CTRL.INST\(29),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(30),
d => \GRFPC0.WR2.CTRL.INST\(30),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_INST_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.INST\(31),
d => \GRFPC0.WR2.CTRL.INST\(31),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(2),
d => \GRFPC0.WR2.CTRL.PC\(2),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(3),
d => \GRFPC0.WR2.CTRL.PC\(3),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(4),
d => \GRFPC0.WR2.CTRL.PC\(4),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(5),
d => \GRFPC0.WR2.CTRL.PC\(5),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(6),
d => \GRFPC0.WR2.CTRL.PC\(6),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(7),
d => \GRFPC0.WR2.CTRL.PC\(7),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(8),
d => \GRFPC0.WR2.CTRL.PC\(8),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(9),
d => \GRFPC0.WR2.CTRL.PC\(9),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(10),
d => \GRFPC0.WR2.CTRL.PC\(10),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(11),
d => \GRFPC0.WR2.CTRL.PC\(11),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(12),
d => \GRFPC0.WR2.CTRL.PC\(12),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(13),
d => \GRFPC0.WR2.CTRL.PC\(13),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(14),
d => \GRFPC0.WR2.CTRL.PC\(14),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(15),
d => \GRFPC0.WR2.CTRL.PC\(15),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(16),
d => \GRFPC0.WR2.CTRL.PC\(16),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(17),
d => \GRFPC0.WR2.CTRL.PC\(17),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(18),
d => \GRFPC0.WR2.CTRL.PC\(18),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(19),
d => \GRFPC0.WR2.CTRL.PC\(19),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(20),
d => \GRFPC0.WR2.CTRL.PC\(20),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(21),
d => \GRFPC0.WR2.CTRL.PC\(21),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(22),
d => \GRFPC0.WR2.CTRL.PC\(22),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(23),
d => \GRFPC0.WR2.CTRL.PC\(23),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(24),
d => \GRFPC0.WR2.CTRL.PC\(24),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(25),
d => \GRFPC0.WR2.CTRL.PC\(25),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(26),
d => \GRFPC0.WR2.CTRL.PC\(26),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(27),
d => \GRFPC0.WR2.CTRL.PC\(27),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(28),
d => \GRFPC0.WR2.CTRL.PC\(28),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(29),
d => \GRFPC0.WR2.CTRL.PC\(29),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(30),
d => \GRFPC0.WR2.CTRL.PC\(30),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_DIV_PC_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.DIV.PC\(31),
d => \GRFPC0.WR2.CTRL.PC\(31),
clk => N_36,
clrn => VCC,
ena => \GRFPC0.DIV.PC_0_0_9__G2\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_FCC_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.FCC\(0),
d => \GRFPC0.R.FSR.FCC_0_0_0__N_6\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_FCC_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.FCC\(1),
d => \GRFPC0.R.FSR.FCC_0_0_1__N_6\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_RD_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.RD\(0),
d => N_46866,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_RD_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.RD\(1),
d => N_46892,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_RD_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.RD\(2),
d => N_46918,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_RD_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.RD\(3),
d => N_46944,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_RD_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.RD\(4),
d => N_46970,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_FTT_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.FTT\(0),
d => \GRFPC0.R.FSR.FTT_0_0_0__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_FTT_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.FTT\(1),
d => \GRFPC0.R.FSR.FTT_0_0_1__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_FTT_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.FTT\(2),
d => N_27777,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_AEXC_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.AEXC\(0),
d => \GRFPC0.R.FSR.AEXC_0_0_0__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_AEXC_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.AEXC\(1),
d => \GRFPC0.R.FSR.AEXC_0_0_1__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_AEXC_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.AEXC\(2),
d => \GRFPC0.R.FSR.AEXC_0_0_2__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_AEXC_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.AEXC\(3),
d => \GRFPC0.R.FSR.AEXC_0_0_3__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_AEXC_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.AEXC\(4),
d => \GRFPC0.R.FSR.AEXC_0_0_4__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_CEXC_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.CEXC\(0),
d => \GRFPC0.R.FSR.CEXC_0_0_0__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_CEXC_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.CEXC\(1),
d => \GRFPC0.R.FSR.CEXC_0_0_1__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_CEXC_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.CEXC\(2),
d => \GRFPC0.R.FSR.CEXC_0_0_2__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_CEXC_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.CEXC\(3),
d => \GRFPC0.R.FSR.CEXC_0_0_3__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_R_FSR_CEXC_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.R.FSR.CEXC\(4),
d => \GRFPC0.R.FSR.CEXC_0_0_4__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_INST_0_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(0),
d => N_78,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(0),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(1),
d => N_79,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(1),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(2),
d => N_80,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(2),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(3),
d => N_81,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(3),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(4),
d => N_82,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(4),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(5),
d => N_83,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(5),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(6),
d => N_84,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(6),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(7),
d => N_85,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(7),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(8),
d => N_86,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(8),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(9),
d => N_87,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(9),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(10),
d => N_88,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(10),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(11),
d => N_89,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(11),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(12),
d => N_90,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(12),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(13),
d => N_91,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(13),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(14),
d => N_92,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(14),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(15),
d => N_93,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(15),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(16),
d => N_94,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(16),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(17),
d => N_95,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(17),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(18),
d => N_96,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(18),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(19),
d => N_97,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(19),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(0),
d => N_78,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(0),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(1),
d => N_79,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(1),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(2),
d => N_80,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(2),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(3),
d => N_81,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(3),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(4),
d => N_82,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(4),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(5),
d => N_83,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(5),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(6),
d => N_84,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(6),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(7),
d => N_85,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(7),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(8),
d => N_86,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(8),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(9),
d => N_87,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(9),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(10),
d => N_88,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(10),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(11),
d => N_89,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(11),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(12),
d => N_90,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(12),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(13),
d => N_91,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(13),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(14),
d => N_92,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(14),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(15),
d => N_93,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(15),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(16),
d => N_94,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(16),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(17),
d => N_95,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(17),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(18),
d => N_96,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(18),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(19),
d => N_97,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(19),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(23),
d => N_101,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(23),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(24),
d => N_102,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(24),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(25),
d => N_103,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(25),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(26),
d => N_104,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(26),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(27),
d => N_105,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(27),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(28),
d => N_106,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(28),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_0_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_0\(29),
d => N_107,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_0\(29),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(23),
d => N_101,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(23),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(24),
d => N_102,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(24),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(25),
d => N_103,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(25),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(26),
d => N_104,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(26),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(27),
d => N_105,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(27),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(28),
d => N_106,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(28),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_INST_1_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.INST_1\(29),
d => N_107,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.INST_1\(29),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_EX_CTRL_INST_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(5),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(5),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(6),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(6),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(7),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(7),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(8),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(8),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(9),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(9),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(10),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(10),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(11),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(11),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(12),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(12),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(13),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(13),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(15),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(15),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(16),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(16),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(19),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(19),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(20),
d => N_47279,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(21),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(21),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(22),
d => N_47280,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(23),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(23),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(24),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(24),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(30),
d => N_47281,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_INST_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.INST\(31),
d => \GRFPC0.FP_PIPELINE.VEX.CTRL.INST_1\(31),
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(2),
d => \GRFPC0.EX.CTRL.PC_0_0_2__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(3),
d => \GRFPC0.EX.CTRL.PC_0_0_3__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(4),
d => \GRFPC0.EX.CTRL.PC_0_0_4__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(5),
d => \GRFPC0.EX.CTRL.PC_0_0_5__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(6),
d => \GRFPC0.EX.CTRL.PC_0_0_6__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(7),
d => \GRFPC0.EX.CTRL.PC_0_0_7__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(8),
d => \GRFPC0.EX.CTRL.PC_0_0_8__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(9),
d => \GRFPC0.EX.CTRL.PC_0_0_9__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(10),
d => \GRFPC0.EX.CTRL.PC_0_0_10__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(11),
d => \GRFPC0.EX.CTRL.PC_0_0_11__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(12),
d => \GRFPC0.EX.CTRL.PC_0_0_12__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(13),
d => \GRFPC0.EX.CTRL.PC_0_0_13__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(14),
d => \GRFPC0.EX.CTRL.PC_0_0_14__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(15),
d => \GRFPC0.EX.CTRL.PC_0_0_15__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(16),
d => \GRFPC0.EX.CTRL.PC_0_0_16__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(17),
d => \GRFPC0.EX.CTRL.PC_0_0_17__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(18),
d => \GRFPC0.EX.CTRL.PC_0_0_18__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(19),
d => \GRFPC0.EX.CTRL.PC_0_0_19__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(20),
d => \GRFPC0.EX.CTRL.PC_0_0_20__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(21),
d => \GRFPC0.EX.CTRL.PC_0_0_21__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(22),
d => \GRFPC0.EX.CTRL.PC_0_0_22__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(23),
d => \GRFPC0.EX.CTRL.PC_0_0_23__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(24),
d => \GRFPC0.EX.CTRL.PC_0_0_24__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(25),
d => \GRFPC0.EX.CTRL.PC_0_0_25__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(26),
d => \GRFPC0.EX.CTRL.PC_0_0_26__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(27),
d => \GRFPC0.EX.CTRL.PC_0_0_27__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(28),
d => \GRFPC0.EX.CTRL.PC_0_0_28__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(29),
d => \GRFPC0.EX.CTRL.PC_0_0_29__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(30),
d => \GRFPC0.EX.CTRL.PC_0_0_30__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_PC_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.PC\(31),
d => \GRFPC0.EX.CTRL.PC_0_0_31__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_PC_0_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(2),
d => N_48,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(2),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(3),
d => N_49,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(3),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(4),
d => N_50,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(4),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(5),
d => N_51,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(5),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(6),
d => N_52,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(6),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(7),
d => N_53,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(7),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(8),
d => N_54,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(8),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(9),
d => N_55,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(9),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(10),
d => N_56,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(10),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(11),
d => N_57,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(11),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(12),
d => N_58,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(12),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(13),
d => N_59,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(13),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(14),
d => N_60,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(14),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(15),
d => N_61,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(15),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(16),
d => N_62,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(16),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(17),
d => N_63,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(17),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(18),
d => N_64,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(18),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(19),
d => N_65,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(19),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(20),
d => N_66,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(20),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(21),
d => N_67,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(21),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(22),
d => N_68,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(22),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(23),
d => N_69,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(23),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(24),
d => N_70,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(24),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(25),
d => N_71,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(25),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(26),
d => N_72,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(26),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(27),
d => N_73,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(27),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(28),
d => N_74,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(28),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(29),
d => N_75,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(29),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(30),
d => N_76,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(30),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_0_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_0\(31),
d => N_77,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_0\(31),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_0_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(2),
d => N_48,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(2),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(3),
d => N_49,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(3),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(4),
d => N_50,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(4),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(5),
d => N_51,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(5),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(6),
d => N_52,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(6),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(7),
d => N_53,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(7),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(8),
d => N_54,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(8),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(9),
d => N_55,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(9),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(10),
d => N_56,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(10),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(11),
d => N_57,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(11),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(12),
d => N_58,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(12),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(13),
d => N_59,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(13),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(14),
d => N_60,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(14),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(15),
d => N_61,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(15),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(16),
d => N_62,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(16),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(17),
d => N_63,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(17),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(18),
d => N_64,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(18),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(19),
d => N_65,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(19),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(20),
d => N_66,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(20),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(21),
d => N_67,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(21),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(22),
d => N_68,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(22),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(23),
d => N_69,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(23),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(24),
d => N_70,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(24),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(25),
d => N_71,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(25),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(26),
d => N_72,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(26),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(27),
d => N_73,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(27),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(28),
d => N_74,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(28),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(29),
d => N_75,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(29),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(30),
d => N_76,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(30),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_PC_1_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.PC_1\(31),
d => N_77,
clk => N_36,
clrn => VCC,
ena => N_37,
asdata => \GRFPC0.FIFO.PC_1\(31),
sclr => RST_I,
sload => \GRFPC0.VFIFO.INST_1_1_0\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	aload => GND);
\GRFPC0_FIFO_VCNT_0_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.VCNT_0\(0),
d => N_47282,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_VCNT_0_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.VCNT_0\(1),
d => N_47283,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_VCNT_0_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.VCNT_0\(2),
d => \GRFPC0.FIFO.VCNT_0_0_0_2__G2\,
clk => N_36,
clrn => VCC,
ena => N_37,
sclr => RST_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_FIFO_VCNT_1_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.VCNT_1\(0),
d => N_47284,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_VCNT_1_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.VCNT_1\(1),
d => N_47285,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_VCNT_1_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.VCNT_1\(2),
d => \GRFPC0.FIFO.VCNT_1_0_0_2__G2\,
clk => N_36,
clrn => VCC,
ena => N_37,
sclr => RST_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_D_STDLCK_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(0),
d => \GRFPC0.D.STDLCK_0_0_0__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(1),
d => \GRFPC0.D.STDLCK_0_0_1__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(2),
d => \GRFPC0.D.STDLCK_0_0_2__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(3),
d => \GRFPC0.D.STDLCK_0_0_3__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(4),
d => \GRFPC0.D.STDLCK_0_0_4__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(5),
d => \GRFPC0.D.STDLCK_0_0_5__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(6),
d => \GRFPC0.D.STDLCK_0_0_6__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(7),
d => \GRFPC0.D.STDLCK_0_0_7__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(8),
d => \GRFPC0.D.STDLCK_0_0_8__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(9),
d => \GRFPC0.D.STDLCK_0_0_9__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(10),
d => \GRFPC0.D.STDLCK_0_0_10__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(11),
d => \GRFPC0.D.STDLCK_0_0_11__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(12),
d => \GRFPC0.D.STDLCK_0_0_12__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(13),
d => \GRFPC0.D.STDLCK_0_0_13__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(14),
d => \GRFPC0.D.STDLCK_0_0_14__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STDLCK_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STDLCK\(15),
d => \GRFPC0.D.STDLCK_0_0_15__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(0),
d => \GRFPC0.D.LDLCK_0_0_0__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(1),
d => \GRFPC0.D.LDLCK_0_0_1__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(2),
d => \GRFPC0.D.LDLCK_0_0_2__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(3),
d => \GRFPC0.D.LDLCK_0_0_3__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(4),
d => \GRFPC0.D.LDLCK_0_0_4__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(5),
d => \GRFPC0.D.LDLCK_0_0_5__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(6),
d => \GRFPC0.D.LDLCK_0_0_6__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(7),
d => \GRFPC0.D.LDLCK_0_0_7__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(8),
d => \GRFPC0.D.LDLCK_0_0_8__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(9),
d => \GRFPC0.D.LDLCK_0_0_9__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(10),
d => \GRFPC0.D.LDLCK_0_0_10__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(11),
d => \GRFPC0.D.LDLCK_0_0_11__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(12),
d => \GRFPC0.D.LDLCK_0_0_12__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(13),
d => \GRFPC0.D.LDLCK_0_0_13__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(14),
d => \GRFPC0.D.LDLCK_0_0_14__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(15),
d => \GRFPC0.D.LDLCK_0_0_15__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(16),
d => \GRFPC0.D.LDLCK_0_0_16__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(17),
d => \GRFPC0.D.LDLCK_0_0_17__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(18),
d => \GRFPC0.D.LDLCK_0_0_18__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(19),
d => \GRFPC0.D.LDLCK_0_0_19__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(20),
d => \GRFPC0.D.LDLCK_0_0_20__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(21),
d => \GRFPC0.D.LDLCK_0_0_21__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(22),
d => \GRFPC0.D.LDLCK_0_0_22__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(23),
d => \GRFPC0.D.LDLCK_0_0_23__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(24),
d => \GRFPC0.D.LDLCK_0_0_24__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(25),
d => \GRFPC0.D.LDLCK_0_0_25__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(26),
d => \GRFPC0.D.LDLCK_0_0_26__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(27),
d => \GRFPC0.D.LDLCK_0_0_27__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(28),
d => \GRFPC0.D.LDLCK_0_0_28__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(29),
d => \GRFPC0.D.LDLCK_0_0_29__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(30),
d => \GRFPC0.D.LDLCK_0_0_30__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_LDLCK_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.LDLCK\(31),
d => \GRFPC0.D.LDLCK_0_0_31__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(0),
d => \GRFPC0.D.STLCK_0_0_0__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(1),
d => \GRFPC0.D.STLCK_0_0_1__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(2),
d => \GRFPC0.D.STLCK_0_0_2__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(3),
d => \GRFPC0.D.STLCK_0_0_3__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(4),
d => \GRFPC0.D.STLCK_0_0_4__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(5),
d => \GRFPC0.D.STLCK_0_0_5__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(6),
d => \GRFPC0.D.STLCK_0_0_6__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(7),
d => \GRFPC0.D.STLCK_0_0_7__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(8),
d => \GRFPC0.D.STLCK_0_0_8__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(9),
d => \GRFPC0.D.STLCK_0_0_9__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(10),
d => \GRFPC0.D.STLCK_0_0_10__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_11_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(11),
d => \GRFPC0.D.STLCK_0_0_11__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(12),
d => \GRFPC0.D.STLCK_0_0_12__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(13),
d => \GRFPC0.D.STLCK_0_0_13__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(14),
d => \GRFPC0.D.STLCK_0_0_14__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(15),
d => \GRFPC0.D.STLCK_0_0_15__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(16),
d => \GRFPC0.D.STLCK_0_0_16__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(17),
d => \GRFPC0.D.STLCK_0_0_17__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(18),
d => \GRFPC0.D.STLCK_0_0_18__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(19),
d => \GRFPC0.D.STLCK_0_0_19__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(20),
d => \GRFPC0.D.STLCK_0_0_20__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(21),
d => \GRFPC0.D.STLCK_0_0_21__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(22),
d => \GRFPC0.D.STLCK_0_0_22__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(23),
d => \GRFPC0.D.STLCK_0_0_23__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(24),
d => \GRFPC0.D.STLCK_0_0_24__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(25),
d => \GRFPC0.D.STLCK_0_0_25__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(26),
d => \GRFPC0.D.STLCK_0_0_26__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(27),
d => \GRFPC0.D.STLCK_0_0_27__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(28),
d => \GRFPC0.D.STLCK_0_0_28__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(29),
d => \GRFPC0.D.STLCK_0_0_29__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(30),
d => \GRFPC0.D.STLCK_0_0_30__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_D_STLCK_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.D.STLCK\(31),
d => \GRFPC0.D.STLCK_0_0_31__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_TZR_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.TZR\(0),
d => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_0__N_7\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_7\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_TZR_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.TZR\(1),
d => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_1__N_6\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_7\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_TZR_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.TZR\(2),
d => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_6\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_7\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_TZR_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.TZR\(3),
d => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_3__N_4_I\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_7\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_TZR_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.TZR\(4),
d => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_4__N_6\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_7\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_TZR_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.TZR\(5),
d => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_5__N_6\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_7\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_TZR_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.TZR\(6),
d => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_6__N_4_I\,
clk => N_36,
clrn => VCC,
ena => \GRFPU0.GRFPU_X0.ITER.TZR_1_0_2__N_7\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_EX_CTRL_ID_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.ID\(0),
d => \FPI.OPID\(0),
clk => N_36,
clrn => VCC,
ena => N_37,
sclr => RST_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_EX_CTRL_ID_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.ID\(1),
d => \FPI.OPID\(1),
clk => N_36,
clrn => VCC,
ena => N_37,
sclr => RST_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_EX_CTRL_ID_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.ID\(2),
d => \FPI.OPID\(2),
clk => N_36,
clrn => VCC,
ena => N_37,
sclr => RST_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_EX_CTRL_ID_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.ID\(3),
d => \FPI.OPID\(3),
clk => N_36,
clrn => VCC,
ena => N_37,
sclr => RST_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_EX_CTRL_ID_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.ID\(4),
d => \FPI.OPID\(4),
clk => N_36,
clrn => VCC,
ena => N_37,
sclr => RST_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPC0_EX_CTRL_ID_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.EX.CTRL.ID\(5),
d => \FPI.OPID\(5),
clk => N_36,
clrn => VCC,
ena => N_37,
sclr => RST_I,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(0),
d => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(1),
d => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(2),
d => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(3),
d => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(4),
d => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(5),
d => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(5),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(6),
d => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(6),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(7),
d => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(7),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(8),
d => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(8),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(9),
d => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(9),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP2_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP2\(10),
d => \GRFPU0.GRFPU_X0.COMB.VST1.EXP2_1\(10),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(0),
d => N_82234,
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(1),
d => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(1),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(2),
d => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(2),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(3),
d => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(3),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(4),
d => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(4),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(5),
d => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(5),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(6),
d => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(6),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(7),
d => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(7),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(8),
d => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(8),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(9),
d => \GRFPU0.GRFPU_X0.ST1.EXP1_V_MUX2\(9),
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST1_EXP1_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST1.EXP1\(10),
d => N_82241,
clk => N_36,
clrn => VCC,
sclr => \GRFPU0.GRFPU_X0.N_10059_I_I\,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(8),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(8),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(9),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(9),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(10),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(10),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_12_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(12),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(12),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_13_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(13),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(13),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_14_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(14),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(14),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_15_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(15),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(15),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(16),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(16),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_17_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(17),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(17),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_18_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(18),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(18),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_19_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(19),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(19),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_20_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(20),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(20),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_21_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(21),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(21),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_22_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(22),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(22),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_23_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(23),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(23),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_24_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(24),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(24),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(25),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(25),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(26),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(26),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(27),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(27),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(28),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(28),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(29),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(29),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(30),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(30),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(31),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(31),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(32),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(32),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(33),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(33),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(34),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(34),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(35),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(35),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(36),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(36),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(37),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(37),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(41),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(41),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(43),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(43),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(50),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(50),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(51),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(51),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_R_I_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.R_I\(54),
d => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(54),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(0),
d => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(0),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(1),
d => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(2),
d => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_3_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(3),
d => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(3),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_4_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(4),
d => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(4),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_5_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(5),
d => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(5),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_6_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(6),
d => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(6),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_7_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(7),
d => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(7),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_8_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(8),
d => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(8),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_9_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(9),
d => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(9),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ITER_EXP_10_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ITER.EXP\(10),
d => \GRFPU0.GRFPU_X0.COMB.VITER.EXP_1\(10),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(52),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(52),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(53),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(53),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_54_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(54),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(54),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(55),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(55),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(56),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_1\(56),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(57),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(57),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(58),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(58),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(59),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(59),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(60),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(60),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(61),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(61),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST2_REG_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.REG\(62),
d => \GRFPU0.GRFPU_X0.COMB.VST2.REG_68\(62),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_29_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(29),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(29),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_30_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(30),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(30),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_31_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(31),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(31),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_32_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(32),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(32),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_33_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(33),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(33),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_34_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(34),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(34),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_35_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(35),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(35),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_36_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(36),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(36),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_37_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(37),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(37),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_38_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(38),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(38),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_39_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(39),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(39),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_40_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(40),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(40),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_41_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(41),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(41),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_42_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(42),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(42),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_43_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(43),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(43),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_44_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(44),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(44),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_45_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(45),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(45),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(46),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(46),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_47_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(47),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(47),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_48_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(48),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(48),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_49_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(49),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(49),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(50),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(50),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_51_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(51),
d => \GRFPU0.GRFPU_X0.COMB.VST3.REG_62\(51),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_52_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(52),
d => \GRFPU0.GRFPU_X0.VST3.REG_47\(52),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(55),
d => \GRFPU0.GRFPU_X0.VST3.REG_47\(55),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(56),
d => \GRFPU0.GRFPU_X0.VST3.REG_47\(56),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(57),
d => \GRFPU0.GRFPU_X0.VST3.REG_47\(57),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST3_REG_58_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST3.REG\(58),
d => \GRFPU0.GRFPU_X0.VST3.REG_47\(58),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_16_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(16),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(16),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_25_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(25),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(25),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_26_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(26),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(26),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_27_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(27),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(27),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_28_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(28),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(28),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_46_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(46),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(46),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_50_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(50),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(50),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_53_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(53),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(53),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_55_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(55),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(55),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_56_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(56),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(56),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_57_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(57),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(57),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_59_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(59),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(59),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_60_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(60),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(60),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_61_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(61),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(61),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_62_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(62),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(62),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_63_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(63),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(63),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_FPMUL0_INFMUL0_MULT0_GEN0_MUL0_R2_64_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.MULO.MRES\(64),
d => \GRFPU0.FPMUL0.INFMUL0.MULT0.GEN0.MUL0.R1D\(64),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_COMB_TMP3_1_1_0_IV_RNIFHOQ1_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003f0000003fc0")
port map (
combout => N_99909_I_0,
dataf => \GRFPU0.GRFPU_X0.COMB.DPRES_1_I\,
datae => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(2),
datad => \GRFPU0.GRFPU_X0.COMB.TMP3_1_1\(1),
datac => \GRFPU0.GRFPU_X0.ST3.RDY\,
datab => \GRFPU0.GRFPU_X0.ST3.QSNAN\);
\GRFPC0_R_STATE_RNI86TTF_0_1_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000000000cc0c")
port map (
combout => \GRFPC0.WR.CTRL.PC_0_0_9__G2_0\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datad => \GRFPC0.R.STATE\(0),
datac => \GRFPC0.R.STATE\(1),
datab => N_37);
GRFPU0_GRFPU_X0_COMB_VST2_DIFF2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000ff00000000")
port map (
combout => \GRFPU0.GRFPU_X0.VST2.DIFF_1_0_2__G3_0\,
dataf => \GRFPU0.GRFPU_X0.UN2_DIFF1\(53),
datae => \GRFPU0.GRFPU_X0.ST1.CCSEL\(0),
datad => \GRFPU0.GRFPU_X0.ST1.CCSEL\(1));
\GRFPU0_GRFPU_X0_ST1_FLOP_RNI5L6H1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_5673_0\,
dataf => \GRFPU0.GRFPU_X0.ST1.FLTYPE2\(8),
datae => \GRFPU0.GRFPU_X0.ST1.V\,
datad => \GRFPU0.GRFPU_X0.ST1.FLTYPE1\(8),
datac => \GRFPU0.GRFPU_X0.ST1.FLOP\(2),
datab => \GRFPU0.GRFPU_X0.ST1.FLOP\(3));
GRFPU0_GRFPU_X0_COMB_VITER_DBUF_1_SN_M3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffc0ccffffffff")
port map (
combout => N_99908_I_0,
dataf => \GRFPU0.GRFPU_X0.N_8\,
datae => \GRFPU0.GRFPU_X0.N_6\,
datad => \GRFPU0.GRFPU_X0.N_3407\,
datac => \GRFPU0.GRFPU_X0.ITER.EXPT_0_0_2__N_7_1\,
datab => \GRFPU0.GRFPU_X0.ITER.STATE\(12));
GRFPC0_VFIFO_INST_0_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffff0ffff")
port map (
combout => \GRFPC0.VFIFO.INST_0_1_0_0\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.VFIFO.WR_0_SQMUXA_3\,
datad => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datac => \GRFPC0.FIFO.WR\(0));
GRFPC0_VFIFO_INST_1_1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff0fffff")
port map (
combout => \GRFPC0.VFIFO.INST_1_1_0_0\,
dataf => \GRFPC0.PENDEXC_0_SQMUXA\,
datae => \GRFPC0.VFIFO.WR_0_SQMUXA_3\,
datad => \GRFPC0.FP_PIPELINE.FLUSH_1_2\,
datac => \GRFPC0.FIFO.WR\(0));
GRFPC0_FP_PIPELINE_VDIV_VALID2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3000000000000000")
port map (
combout => \GRFPC0.FP_PIPELINE.VDIV.VALID2_0\,
dataf => \GRFPC0.FP_PIPELINE.VDIV.VALID2_6\,
datae => \GRFPC0.FP_PIPELINE.VDIV.VALID2_2\,
datad => \GRFPC0.DIV.EXEC\,
datac => \GRFPC0.FPR.RDY\,
datab => \GRFPC0.DIV.ID\(7));
GRFPU0_GRFPU_X0_COMB_SHV2LTO10: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003fff3fff3fff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SHV2_0\,
dataf => \GRFPU0.GRFPU_X0.N_18258\,
datae => N_60912_TZ,
datad => \GRFPU0.GRFPU_X0.C\(11),
datac => \GRFPU0.GRFPU_X0.COMB.SHV2LTO10_0_A5_3\,
datab => \GRFPU0.GRFPU_X0.N_20729\);
\GRFPU0_GRFPU_X0_COMB_VST4_MEXP_1_0_2__G0_0_M2_0\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff00ff0000ffff")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST4.MEXP_1_0_9__N_4_I_0\,
dataf => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datae => \GRFPU0.FPMUL0.SX\(121),
datad => N_28107);
GRFPC0_VWR2_RREG_RESV_0_SQMUXA_1_0_A2_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffffff00")
port map (
combout => \GRFPC0.VWR2.RREG.RESV_0_SQMUXA_1_0\,
dataf => \GRFPC0.FP_PIPELINE.UN86_HOLDN_NE\,
datae => \GRFPC0.FPR.RDY\,
datad => N_37);
GRFPU0_GRFPU_X0_ST2_DIFFV_0: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST2.DIFFV_0\,
d => \GRFPU0.GRFPU_X0.ST2.DIFFN_0_0_G0_0\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_RD_0_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.RD_0\(0),
d => \GRFPC0.FIFO.RD_0_0_0__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_RD_1_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.RD_1\(0),
d => \GRFPC0.FIFO.RD_0_0_0__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_RD_2_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.RD_2\(0),
d => \GRFPC0.FIFO.RD_0_0_0__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_FIFO_RD_3_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.FIFO.RD_3\(0),
d => \GRFPC0.FIFO.RD_0_0_0__G1\,
clk => N_36,
clrn => VCC,
ena => N_37,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SEL_0_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SEL_0\(2),
d => \GRFPU0.GRFPU_X0.N_18442_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SEL_1_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SEL_1\(2),
d => \GRFPU0.GRFPU_X0.N_18442_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SEL_2_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SEL_2\(2),
d => \GRFPU0.GRFPU_X0.N_18442_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SEL_0_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SEL_0\(1),
d => \GRFPU0.GRFPU_X0.N_18441_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SEL_1_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SEL_1\(1),
d => \GRFPU0.GRFPU_X0.N_18441_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SEL_2_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SEL_2\(1),
d => \GRFPU0.GRFPU_X0.N_18441_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SEL_0_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SEL_0\(0),
d => \GRFPU0.GRFPU_X0.N_10060\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SEL_1_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SEL_1\(0),
d => \GRFPU0.GRFPU_X0.N_10060\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SEL_2_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SEL_2\(0),
d => \GRFPU0.GRFPU_X0.N_10060\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS2SEL_0_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS2SEL_0\(1),
d => \GRFPC0.FPUSEL_1\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS2SEL_1_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS2SEL_1\(1),
d => \GRFPC0.FPUSEL_1\(1),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS1SEL_0_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS1SEL_0\(2),
d => \GRFPC0.FPUSEL_6\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPC0_RFA2_RS1SEL_1_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPC0.RFA2.RS1SEL_1\(2),
d => \GRFPC0.FPUSEL_6\(2),
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPC0_RFA2_RS1SEL_RET_7_RNIOEVM_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003fff0000ffff")
port map (
combout => N_99878_0,
dataf => \GRFPC0.UN1_WRENX2_2_4_RETO\,
datae => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.FPUSEL_6_1_RETO\(7),
datac => \GRFPC0.UN1_WRENX2_2_3_0_RETO\,
datab => \GRFPC0.DIV.VALID_RETO\);
GRFPC0_RFA2_RS1SEL_RET_7_RNIOEVM: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00003fff0000ffff")
port map (
combout => N_99878_1,
dataf => \GRFPC0.UN1_WRENX2_2_4_RETO\,
datae => \GRFPC0.RFA2.RS1SEL\(2),
datad => \GRFPC0.FPUSEL_6_1_RETO\(7),
datac => \GRFPC0.UN1_WRENX2_2_3_0_RETO\,
datab => \GRFPC0.DIV.VALID_RETO\);
\GRFPU0_GRFPU_X0_RES_1_6_0_A3_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_400_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(0));
\GRFPU0_GRFPU_X0_RES_1_6_0_A3_2_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000ff0000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_400_1\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(0));
\GRFPU0_GRFPU_X0_RES_1_6_I_A3_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00ff000000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_404_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL\(0),
datae => \GRFPU0.GRFPU_X0.ST4.SEL\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL\(1));
\GRFPU0_GRFPU_X0_RES_1_6_0_O7_0_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000000000ff")
port map (
combout => N_99904_0,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(0));
\GRFPU0_GRFPU_X0_RES_1_6_0_O7_1_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000000000ff")
port map (
combout => N_99904_1,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(0));
\GRFPU0_GRFPU_X0_RES_1_6_0_O7_2_6_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff0000000000ff")
port map (
combout => N_99904_2,
dataf => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(1),
datae => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(2),
datad => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(0));
GRFPC0_RFA_RS1D_RNI8F091: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0c0c00ff0c0c0000")
port map (
combout => N_99879_0,
dataf => \GRFPC0.N_235\,
datae => \GRFPC0.RFA.ST\,
datad => \GRFPC0.RFA.RS1D\,
datac => N_167,
datab => N_172);
GRFPC0_RFA2_RS1SEL_RET_2_RNIKO4O3_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => N_99877_0,
dataf => \GRFPC0.RFA2.RS1SEL\(7),
datae => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL\(3));
GRFPC0_RFA2_RS1SEL_RET_2_RNIKO4O3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => N_99877_1,
dataf => \GRFPC0.RFA2.RS1SEL\(7),
datae => \GRFPC0.RFA2.RS1SEL\(1),
datad => \GRFPC0.RFA2.RS1SEL\(3));
GRFPU0_GRFPU_X0_SGNF_2_SQMUXA_I_A2_RNIBUAPF_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffff3fffff0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_21_0\,
dataf => \GRFPU0.GRFPU_X0.N_18833\,
datae => \GRFPU0.GRFPU_X0.N_18837\,
datad => \GRFPU0.GRFPU_X0.N_18831\,
datac => \GRFPU0.GRFPU_X0.N_10059_I\,
datab => \FPI.FLOP\(1));
GRFPU0_GRFPU_X0_SGNF_2_SQMUXA_I_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffff0fffcff")
port map (
combout => \GRFPU0.GRFPU_X0.N_18746_0\,
dataf => \GRFPU0.GRFPU_X0.N_18833\,
datae => \GRFPU0.GRFPU_X0.N_18768\,
datad => \GRFPU0.GRFPU_X0.N_10059_I\,
datac => \FPI.FLOP\(1),
datab => \FPI.NONSTD\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN24_DP_I_O2_RNI3IU86: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000ffc0c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.N_8869_0\,
dataf => \GRFPU0.GRFPU_X0.N_18880\,
datae => \GRFPU0.GRFPU_X0.N_18954\,
datad => \GRFPU0.GRFPU_X0.N_18948\,
datac => \GRFPU0.GRFPU_X0.N_18871\,
datab => \FPI.NONSTD\);
GRFPC0_RFA2_RS1SEL_RET_13_RNIGE2H_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8b000000bb000000")
port map (
combout => \GRFPC0.RFA2.RS1SEL_0\(7),
dataf => \GRFPC0.UN1_WRENX2_2_4_RETO\,
datae => \GRFPC0.FPUSEL_6_1_RETO\(7),
datad => \GRFPC0.N_21346_RETO\,
datac => \GRFPC0.UN1_WRENX2_2_3_0_RETO\,
datab => \GRFPC0.FP_PIPELINE.0.WR2EN2_RETO\,
dataa => \GRFPC0.WR2SEL_1_RETO\(7));
GRFPC0_RFA2_RS1SEL_RET_13_RNIGE2H: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"8b000000bb000000")
port map (
combout => \GRFPC0.RFA2.RS1SEL_1\(7),
dataf => \GRFPC0.UN1_WRENX2_2_4_RETO\,
datae => \GRFPC0.FPUSEL_6_1_RETO\(7),
datad => \GRFPC0.N_21346_RETO\,
datac => \GRFPC0.UN1_WRENX2_2_3_0_RETO\,
datab => \GRFPC0.FP_PIPELINE.0.WR2EN2_RETO\,
dataa => \GRFPC0.WR2SEL_1_RETO\(7));
GRFPC0_RFA2_RS1SEL_RET_37_RNIE90O: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f3000000")
port map (
combout => \GRFPC0.RFA2.RS1SEL_0\(1),
dataf => HOLDN_RETO,
datae => \GRFPC0.FPUSEL_6_2_RETO\(1),
datad => \GRFPC0.FPUSEL_6_3_RETO\(1),
datac => \GRFPC0.EX.RREG.RESV_RETO\,
datab => \GRFPC0.N_82_RETO\);
GRFPC0_RFA2_RS1SEL_RET_37_RNIE90O_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f3000000")
port map (
combout => \GRFPC0.RFA2.RS1SEL_1\(1),
dataf => HOLDN_RETO,
datae => \GRFPC0.FPUSEL_6_2_RETO\(1),
datad => \GRFPC0.FPUSEL_6_3_RETO\(1),
datac => \GRFPC0.EX.RREG.RESV_RETO\,
datab => \GRFPC0.N_82_RETO\);
\GRFPC0_RFA2_RS2SEL_RNIHK61_0_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => N_99880_0,
dataf => \GRFPC0.RFA2.RS2SEL\(7),
datae => \GRFPC0.RFA2.RS2SEL\(1),
datad => \GRFPC0.RFA2.RS2SEL\(3));
\GRFPC0_RFA2_RS2SEL_RNIHK61_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000000000ff")
port map (
combout => N_99880_1,
dataf => \GRFPC0.RFA2.RS2SEL\(7),
datae => \GRFPC0.RFA2.RS2SEL\(1),
datad => \GRFPC0.RFA2.RS2SEL\(3));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_O2_0_29_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"1f5f1f1f0f4f0f0f")
port map (
combout => \GRFPU0.GRFPU_X0.N_18868_0\,
dataf => \GRFPU0.GRFPU_X0.N_7321\,
datae => N_110850,
datad => \GRFPU0.GRFPU_X0.N_18880\,
datac => \GRFPU0.GRFPU_X0.N_10059_I\,
datab => \FPI.FLOP\(1),
dataa => \GRFPU0.GRFPU_X0.N_8835\);
GRFPU0_GRFPU_X0_SGNF_2_SQMUXA_1_SUB_RNID6AM1: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"0000000070ff77ff")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
dataf => N_111241,
datae => \GRFPU0.GRFPU_X0.N_18948\,
datad => \GRFPU0.GRFPU_X0.N_7241\,
datac => \GRFPU0.GRFPU_X0.N_18870\,
datab => \GRFPU0.GRFPU_X0.N_18871\,
dataa => \FPI.NONSTD\);
\GRFPU0_GRFPU_X0_ST4_SEL_3_0_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(0),
d => \GRFPU0.GRFPU_X0.N_10060\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SEL_3_1_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(1),
d => \GRFPU0.GRFPU_X0.N_18441_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
\GRFPU0_GRFPU_X0_ST4_SEL_3_2_\: dffeas generic map (
    is_wysiwyg => "true")
port map (
q => \GRFPU0.GRFPU_X0.ST4.SEL_2_0\(2),
d => \GRFPU0.GRFPU_X0.N_18442_I\,
clk => N_36,
clrn => VCC,
	devpor => devpor,
	devclrn => devclrn,
	prn => VCC,
	ena => VCC,
	asdata => GND,
	aload => GND,
	sclr => GND,
	sload => GND);
GRFPU0_GRFPU_X0_UN223_BCO_LSB_RNILIKP3: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000000f0000000")
port map (
combout => \GRFPU0.GRFPU_X0.L30\,
dataf => \GRFPU0.GRFPU_X0.N_14025_1\,
datae => \GRFPU0.GRFPU_X0.L2_0_0_0\(4),
datad => \GRFPU0.GRFPU_X0.L3_2\(5),
datac => \GRFPU0.GRFPU_X0.N_9673\);
\GRFPU0_GRFPU_X0_L1_2_2_RNII7NQ6_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000000c000000000")
port map (
combout => \GRFPU0.GRFPU_X0.N_9666\,
dataf => \GRFPU0.GRFPU_X0.L30\,
datae => \GRFPU0.GRFPU_X0.ST2.DIFF\(42),
datad => \GRFPU0.GRFPU_X0.ST2.DIFF\(43),
datac => \GRFPU0.GRFPU_X0.N_9683\,
datab => \GRFPU0.GRFPU_X0.N_9671\);
GRFPU0_GRFPU_X0_COMB_SGNFINC_INC_M4_0_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c3c0c3000f0c0c00")
port map (
combout => N_82253,
dataf => \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC.M4_0_00\,
datae => \GRFPU0.GRFPU_X0.COMB.S_DP_1_1\,
datad => \GRFPU0.GRFPU_X0.COMB.G_DP_1\,
datac => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(0),
datab => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1));
GRFPU0_GRFPU_X0_COMB_SGNFINC_INC_M4_0_000_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00ffff0000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC.M4_0_000_0\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(1),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(2));
GRFPU0_GRFPU_X0_COMB_SGNFINC_INC_M4_0_00: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfc0cfcfc0c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC.M4_0_00\,
dataf => \GRFPU0.GRFPU_X0.COMB.SGNFINC.INC.M4_0_000_0\,
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(3),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datac => \GRFPU0.GRFPU_X0.ST3.RNDMODE\(1),
datab => \GRFPU0.GRFPU_X0.ST3.REG\(63));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_10_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"c000c000c000c0c0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_10\,
dataf => \FPI.FLOP\(5),
datae => \FPI.FLOP\(6),
datad => \FPI.FLOP\(1),
datac => \GRFPU0.GRFPU_X0.N_10059_I\,
datab => \FPI.OP2\(25));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_33_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"2e2e2eee22222222")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(33),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_10\,
datae => \FPI.FLOP\(5),
datad => \FPI.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.N_8869\,
datab => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(33));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_10_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"e222e222e222e2e2")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_10_0\,
dataf => \FPI.FLOP\(5),
datae => \FPI.FLOP\(6),
datad => \FPI.FLOP\(1),
datac => \FPI.OP2\(0),
datab => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1\(8));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_8_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"757575f500000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(8),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_10_0\,
datae => \FPI.FLOP\(5),
datad => \FPI.FLOP\(6),
datac => \GRFPU0.GRFPU_X0.N_10059_I\,
datab => \GRFPU0.GRFPU_X0.N_8869\,
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN24_DP_I_O2_RNIEBHQ5_0: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"00000fff0fff0fff")
port map (
combout => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA0\,
dataf => \FPI.NONSTD\,
datae => \GRFPU0.GRFPU_X0.N_18871\,
datad => \GRFPU0.GRFPU_X0.N_18948\,
datac => \GRFPU0.GRFPU_X0.N_18954\);
GRFPU0_GRFPU_X0_COMB_UNPACK_UN24_DP_I_O2_RNI31I7B: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"888a888a888a000a")
port map (
combout => \GRFPU0.GRFPU_X0.N_8862\,
dataf => \GRFPU0.GRFPU_X0.SGNF_0_SQMUXA0\,
datae => \GRFPU0.GRFPU_X0.N_18880\,
datad => \FPI.FLOP\(5),
datac => \FPI.FLOP\(6),
datab => \FPI.FLOP\(1),
dataa => \GRFPU0.GRFPU_X0.N_10059_I\);
GRFPU0_GRFPU_X0_COMB_UN7_G_SP: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffffffffffcecec")
port map (
combout => \GRFPU0.GRFPU_X0.N_6041\,
dataf => \GRFPU0.GRFPU_X0.ST3.FARRES\(29),
datae => \GRFPU0.GRFPU_X0.ST3.FARRES\(30),
datad => \GRFPU0.GRFPU_X0.ST3.FARRES\(54),
datac => \GRFPU0.GRFPU_X0.ST3.FARRES\(55),
datab => \GRFPU0.GRFPU_X0.S_SP\,
dataa => \GRFPU0.GRFPU_X0.ST3.FARRES\(31));
\GRFPU0_GRFPU_X0_COMB_QP1_SP_30_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_30\,
dataf => N_28125,
datae => N_28126,
datad => \GRFPU0.FPMUL0.UN1_SIN_3_CARRY_27_0\);
\GRFPU0_GRFPU_X0_COMB_QP1_SP_3_5_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cccffcffccc00c00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.QP1_SP_3\(5),
dataf => \GRFPU0.GRFPU_X0.COMB.QP1_SP_30\,
datae => N_28105,
datad => \GRFPU0.FPMUL0.SX\(120),
datac => \GRFPU0.FPMUL0.UN1_SIN_CARRY_27\,
datab => \GRFPU0.MULO.DRES_1\(102));
\GRFPC0_OP2_10_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.OP2_10\,
dataf => \GRFPU0.GRFPU_X0.ST4.MSGNF\(3),
datae => \GRFPC0.WR2.RREG.RES\(3),
datad => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP2_1_3_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffefffad5c4d5c0")
port map (
combout => \GRFPC0.N_19433\,
dataf => \GRFPC0.OP2_10\,
datae => \GRFPU0.GRFPU_X0.ST4.REG\(3),
datad => \GRFPC0.DIV.RESULT_0_0_3__G5\,
datac => \GRFPU0.GRFPU_X0.N_400_0\,
datab => N_99904_0,
dataa => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP2_10_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.OP2_10_0\,
dataf => \GRFPU0.GRFPU_X0.ST4.MSGNF\(2),
datae => \GRFPC0.WR2.RREG.RES\(2),
datad => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP2_1_2_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fffefffad5c4d5c0")
port map (
combout => \GRFPC0.N_19432\,
dataf => \GRFPC0.OP2_10_0\,
datae => \GRFPU0.GRFPU_X0.ST4.REG\(2),
datad => \GRFPC0.DIV.RESULT_0_0_2__G5\,
datac => \GRFPU0.GRFPU_X0.N_400_0\,
datab => N_99904_0,
dataa => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP2_10_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.OP2_10_1\,
dataf => \GRFPC0.DIV.RESULT_0_0_31__G5\,
datae => \GRFPC0.WR2.RREG.RES\(31),
datad => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP2_1_31_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffd4d0c4c0")
port map (
combout => \GRFPC0.N_19461\,
dataf => \GRFPC0.OP2_10_1\,
datae => \GRFPU0.GRFPU_X0.ST4.MSGNF\(31),
datad => \GRFPU0.GRFPU_X0.ST4.REG\(31),
datac => \GRFPU0.GRFPU_X0.N_400_1\,
datab => N_99904_1,
dataa => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP2_10_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffff00ffff000000")
port map (
combout => \GRFPC0.OP2_10_2\,
dataf => \GRFPC0.DIV.RESULT_0_0_28__G5\,
datae => \GRFPC0.WR2.RREG.RES\(28),
datad => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPC0_OP2_1_28_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffd4d0c4c0")
port map (
combout => \GRFPC0.N_19458\,
dataf => \GRFPC0.OP2_10_2\,
datae => \GRFPU0.GRFPU_X0.ST4.MSGNF\(28),
datad => \GRFPU0.GRFPU_X0.ST4.REG\(28),
datac => \GRFPU0.GRFPU_X0.N_400_1\,
datab => N_99904_0,
dataa => \GRFPC0.RFA2.RS2SEL\(4));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_10_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f4f404f4f4040404")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_10_1\,
dataf => \FPI.OP2\(44),
datae => \FPI.OP2\(47),
datad => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_52_M3_0_A2_0\,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_55_1_0\(52));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_52_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"f0fcfffcf0f0f0f0")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(52),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_10_1\,
datae => \GRFPU0.GRFPU_X0.N_18868\,
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => N_108642,
datab => \GRFPU0.GRFPU_X0.N_18342\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I0_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff000f0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I0\,
dataf => \GRFPU0.GRFPU_X0.N_8835\,
datae => \FPI.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.N_18880\,
datac => \GRFPU0.GRFPU_X0.N_7321\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"d8d8aaaa88d8aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.N_18857_I\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I0\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => N_110850,
datac => \FPI.OP2\(50),
datab => \FPI.OP2\(53),
dataa => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I0_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ffffffffff000f0f")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I0_0\,
dataf => \GRFPU0.GRFPU_X0.N_8835\,
datae => \FPI.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.N_18880\,
datac => \GRFPU0.GRFPU_X0.N_7321\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_I_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"d8d8aaaa88d8aaaa")
port map (
combout => \GRFPU0.GRFPU_X0.N_18856_I\,
dataf => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_1_I0_0\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => N_110850,
datac => \FPI.OP2\(49),
datab => \FPI.OP2\(52),
dataa => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_10_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbfb0bfbfb0b0b0b")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_10_2\,
dataf => \FPI.OP2\(48),
datae => \FPI.OP2\(51),
datad => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_57_M4_E_2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(56));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_56_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0f0f000c000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(56),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_10_2\,
datae => \GRFPU0.GRFPU_X0.N_18868\,
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => N_108646,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(56));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_10_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fbfb0bfbfb0b0b0b")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_10_3\,
dataf => \FPI.OP2\(47),
datae => \FPI.OP2\(50),
datad => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\,
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_1_57_M4_E_2\,
dataa => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49_IV_5\(55));
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_55_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"000f0f0f000c000c")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(55),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_10_3\,
datae => \GRFPU0.GRFPU_X0.N_18868\,
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => N_108668,
datab => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_37\(55));
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_10_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f3005500")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_10\,
dataf => \GRFPU0.GRFPU_X0.N_8835\,
datae => \FPI.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.N_10059_I\,
datac => \GRFPU0.GRFPU_X0.N_18880\,
datab => N_110850,
dataa => \GRFPU0.GRFPU_X0.N_7321\);
\GRFPU0_GRFPU_X0_COMB_VST1_SGNF2_1_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"fff00f0000000000")
port map (
combout => \GRFPU0.DIVROMI\(1),
dataf => \GRFPU0.GRFPU_X0.COMB.VST1.SGNF2_10\,
datae => \FPI.OP2\(48),
datad => \FPI.OP2\(45),
datac => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_10_0_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ee00fa00eeaafaaa")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_10_5\,
dataf => \GRFPU0.GRFPU_X0.ITER.V\,
datae => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\,
datad => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datac => \FPI.OP2\(40),
datab => \FPI.OP2\(43),
dataa => N_111323);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_48_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"cfcfcfcfcccccc00")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1\(48),
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_10_5\,
datae => \GRFPU0.GRFPU_X0.N_18527\,
datad => \GRFPU0.GRFPU_X0.COMB.VITER.R_I_49\(48),
datac => \GRFPU0.GRFPU_X0.N_18868_0\,
datab => N_111323);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB0_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5555555555f5dddd")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0\,
dataf => \GRFPU0.GRFPU_X0.N_8835\,
datae => \FPI.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.N_18880\,
datac => N_110850,
datab => \GRFPU0.GRFPU_X0.N_7321\,
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_37_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333333301233333")
port map (
combout => N_108672,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(32),
datac => \FPI.OP2\(29),
datab => N_111343,
dataa => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB0_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5555555555f5dddd")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_0\,
dataf => \GRFPU0.GRFPU_X0.N_8835\,
datae => \FPI.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.N_18880\,
datac => N_110850,
datab => \GRFPU0.GRFPU_X0.N_7321\,
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_38_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333333301233333")
port map (
combout => N_108658,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_0\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(33),
datac => \FPI.OP2\(30),
datab => N_111329,
dataa => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB0_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5555555555f5dddd")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_1\,
dataf => \GRFPU0.GRFPU_X0.N_8835\,
datae => \FPI.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.N_18880\,
datac => N_110850,
datab => \GRFPU0.GRFPU_X0.N_7321\,
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_39_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333333301233333")
port map (
combout => N_108662,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_1\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(34),
datac => \FPI.OP2\(31),
datab => N_111341,
dataa => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB0_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5555555555f5dddd")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_2\,
dataf => \GRFPU0.GRFPU_X0.N_8835\,
datae => \FPI.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.N_18880\,
datac => N_110850,
datab => \GRFPU0.GRFPU_X0.N_7321\,
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_40_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333333301233333")
port map (
combout => N_108822,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_2\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(35),
datac => \FPI.OP2\(32),
datab => N_111333,
dataa => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB0_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5555555555f5dddd")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_3\,
dataf => \GRFPU0.GRFPU_X0.N_8835\,
datae => \FPI.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.N_18880\,
datac => N_110850,
datab => \GRFPU0.GRFPU_X0.N_7321\,
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_44_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333333302133333")
port map (
combout => N_108656,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_3\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(36),
datac => \FPI.OP2\(39),
datab => N_111319,
dataa => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB0_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5555555555f5dddd")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_4\,
dataf => \GRFPU0.GRFPU_X0.N_8835\,
datae => \FPI.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.N_18880\,
datac => N_110850,
datab => \GRFPU0.GRFPU_X0.N_7321\,
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_45_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333333302133333")
port map (
combout => N_108654,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_4\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(37),
datac => \FPI.OP2\(40),
datab => N_111321,
dataa => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB0_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5555555555f5dddd")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_5\,
dataf => \GRFPU0.GRFPU_X0.N_8835\,
datae => \FPI.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.N_18880\,
datac => N_110850,
datab => \GRFPU0.GRFPU_X0.N_7321\,
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_46_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333333301233333")
port map (
combout => N_108660,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_5\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(41),
datac => \FPI.OP2\(38),
datab => N_111327,
dataa => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB0_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5555555555f5dddd")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_6\,
dataf => \GRFPU0.GRFPU_X0.N_8835\,
datae => \FPI.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.N_18880\,
datac => N_110850,
datab => \GRFPU0.GRFPU_X0.N_7321\,
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_50_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333333302133333")
port map (
combout => N_108824,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_6\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(42),
datac => \FPI.OP2\(45),
datab => N_111335,
dataa => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB0_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5555555555f5dddd")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_7\,
dataf => \GRFPU0.GRFPU_X0.N_8835\,
datae => \FPI.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.N_18880\,
datac => N_110850,
datab => \GRFPU0.GRFPU_X0.N_7321\,
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_59_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333333301233333")
port map (
combout => N_108670,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_7\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(54),
datac => \FPI.OP2\(51),
datab => N_111345,
dataa => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB0_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"5555555555f5dddd")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_8\,
dataf => \GRFPU0.GRFPU_X0.N_8835\,
datae => \FPI.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.N_18880\,
datac => N_110850,
datab => \GRFPU0.GRFPU_X0.N_7321\,
dataa => \GRFPU0.GRFPU_X0.COMB.MULBP_1\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_49_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3333333301233333")
port map (
combout => N_108650,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB0_8\,
datae => \GRFPU0.GRFPU_X0.N_10059_I\,
datad => \FPI.OP2\(44),
datac => \FPI.OP2\(41),
datab => N_111347,
dataa => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_00_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f3005500")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB_00\,
dataf => \GRFPU0.GRFPU_X0.N_8835\,
datae => \FPI.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.N_10059_I\,
datac => \GRFPU0.GRFPU_X0.N_18880\,
datab => N_110850,
dataa => \GRFPU0.GRFPU_X0.N_7321\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_0_47_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3323130303030303")
port map (
combout => N_108826,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB_00\,
datae => \FPI.OP2\(42),
datad => \FPI.OP2\(39),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => N_111325,
dataa => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_00_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"ff00ff00f3005500")
port map (
combout => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB_00_0\,
dataf => \GRFPU0.GRFPU_X0.N_8835\,
datae => \FPI.FLOP\(1),
datad => \GRFPU0.GRFPU_X0.N_10059_I\,
datac => \GRFPU0.GRFPU_X0.N_18880\,
datab => N_110850,
dataa => \GRFPU0.GRFPU_X0.N_7321\);
\GRFPU0_GRFPU_X0_COMB_VITER_MUL2_1_SUB_0_42_\: stratixiii_lcell_comb generic map (
    shared_arith => "off",
    extended_lut => "off",
    lut_mask => X"3313230303030303")
port map (
combout => N_108830,
dataf => \GRFPU0.GRFPU_X0.COMB.VITER.MUL2_1_SUB_00_0\,
datae => \FPI.OP2\(34),
datad => \FPI.OP2\(37),
datac => \GRFPU0.GRFPU_X0.COMB.MULBP_1\,
datab => N_111331,
dataa => \GRFPU0.GRFPU_X0.SGNF_2_SQMUXA_1_0\);
N_35 <= RST_INTERNAL;
N_36 <= CLK_INTERNAL;
N_37 <= HOLDN_INTERNAL;
N_39 <= CPI_FLUSH_INTERNAL;
N_40 <= CPI_EXACK_INTERNAL;
N_41 <= CPI_A_RS1_INTERNAL;
N_42 <= CPI_A_RS1_INTERNAL_0;
N_43 <= CPI_A_RS1_INTERNAL_1;
N_44 <= CPI_A_RS1_INTERNAL_2;
N_45 <= CPI_A_RS1_INTERNAL_3;
N_46 <= CPI_D_PC_INTERNAL;
N_47 <= CPI_D_PC_INTERNAL_0;
N_48 <= CPI_D_PC_INTERNAL_1;
N_49 <= CPI_D_PC_INTERNAL_2;
N_50 <= CPI_D_PC_INTERNAL_3;
N_51 <= CPI_D_PC_INTERNAL_4;
N_52 <= CPI_D_PC_INTERNAL_5;
N_53 <= CPI_D_PC_INTERNAL_6;
N_54 <= CPI_D_PC_INTERNAL_7;
N_55 <= CPI_D_PC_INTERNAL_8;
N_56 <= CPI_D_PC_INTERNAL_9;
N_57 <= CPI_D_PC_INTERNAL_10;
N_58 <= CPI_D_PC_INTERNAL_11;
N_59 <= CPI_D_PC_INTERNAL_12;
N_60 <= CPI_D_PC_INTERNAL_13;
N_61 <= CPI_D_PC_INTERNAL_14;
N_62 <= CPI_D_PC_INTERNAL_15;
N_63 <= CPI_D_PC_INTERNAL_16;
N_64 <= CPI_D_PC_INTERNAL_17;
N_65 <= CPI_D_PC_INTERNAL_18;
N_66 <= CPI_D_PC_INTERNAL_19;
N_67 <= CPI_D_PC_INTERNAL_20;
N_68 <= CPI_D_PC_INTERNAL_21;
N_69 <= CPI_D_PC_INTERNAL_22;
N_70 <= CPI_D_PC_INTERNAL_23;
N_71 <= CPI_D_PC_INTERNAL_24;
N_72 <= CPI_D_PC_INTERNAL_25;
N_73 <= CPI_D_PC_INTERNAL_26;
N_74 <= CPI_D_PC_INTERNAL_27;
N_75 <= CPI_D_PC_INTERNAL_28;
N_76 <= CPI_D_PC_INTERNAL_29;
N_77 <= CPI_D_PC_INTERNAL_30;
N_78 <= CPI_D_INST_INTERNAL;
N_79 <= CPI_D_INST_INTERNAL_0;
N_80 <= CPI_D_INST_INTERNAL_1;
N_81 <= CPI_D_INST_INTERNAL_2;
N_82 <= CPI_D_INST_INTERNAL_3;
N_83 <= CPI_D_INST_INTERNAL_4;
N_84 <= CPI_D_INST_INTERNAL_5;
N_85 <= CPI_D_INST_INTERNAL_6;
N_86 <= CPI_D_INST_INTERNAL_7;
N_87 <= CPI_D_INST_INTERNAL_8;
N_88 <= CPI_D_INST_INTERNAL_9;
N_89 <= CPI_D_INST_INTERNAL_10;
N_90 <= CPI_D_INST_INTERNAL_11;
N_91 <= CPI_D_INST_INTERNAL_12;
N_92 <= CPI_D_INST_INTERNAL_13;
N_93 <= CPI_D_INST_INTERNAL_14;
N_94 <= CPI_D_INST_INTERNAL_15;
N_95 <= CPI_D_INST_INTERNAL_16;
N_96 <= CPI_D_INST_INTERNAL_17;
N_97 <= CPI_D_INST_INTERNAL_18;
N_98 <= CPI_D_INST_INTERNAL_19;
N_99 <= CPI_D_INST_INTERNAL_20;
N_100 <= CPI_D_INST_INTERNAL_21;
N_101 <= CPI_D_INST_INTERNAL_22;
N_102 <= CPI_D_INST_INTERNAL_23;
N_103 <= CPI_D_INST_INTERNAL_24;
N_104 <= CPI_D_INST_INTERNAL_25;
N_105 <= CPI_D_INST_INTERNAL_26;
N_106 <= CPI_D_INST_INTERNAL_27;
N_107 <= CPI_D_INST_INTERNAL_28;
N_108 <= CPI_D_INST_INTERNAL_29;
N_109 <= CPI_D_INST_INTERNAL_30;
N_110 <= CPI_D_CNT_INTERNAL;
N_111 <= CPI_D_CNT_INTERNAL_0;
N_112 <= CPI_D_TRAP_INTERNAL;
N_113 <= CPI_D_ANNUL_INTERNAL;
N_114 <= CPI_D_PV_INTERNAL;
N_115 <= CPI_A_PC_INTERNAL;
N_116 <= CPI_A_PC_INTERNAL_0;
N_117 <= CPI_A_PC_INTERNAL_1;
N_118 <= CPI_A_PC_INTERNAL_2;
N_119 <= CPI_A_PC_INTERNAL_3;
N_120 <= CPI_A_PC_INTERNAL_4;
N_121 <= CPI_A_PC_INTERNAL_5;
N_122 <= CPI_A_PC_INTERNAL_6;
N_123 <= CPI_A_PC_INTERNAL_7;
N_124 <= CPI_A_PC_INTERNAL_8;
N_125 <= CPI_A_PC_INTERNAL_9;
N_126 <= CPI_A_PC_INTERNAL_10;
N_127 <= CPI_A_PC_INTERNAL_11;
N_128 <= CPI_A_PC_INTERNAL_12;
N_129 <= CPI_A_PC_INTERNAL_13;
N_130 <= CPI_A_PC_INTERNAL_14;
N_131 <= CPI_A_PC_INTERNAL_15;
N_132 <= CPI_A_PC_INTERNAL_16;
N_133 <= CPI_A_PC_INTERNAL_17;
N_134 <= CPI_A_PC_INTERNAL_18;
N_135 <= CPI_A_PC_INTERNAL_19;
N_136 <= CPI_A_PC_INTERNAL_20;
N_137 <= CPI_A_PC_INTERNAL_21;
N_138 <= CPI_A_PC_INTERNAL_22;
N_139 <= CPI_A_PC_INTERNAL_23;
N_140 <= CPI_A_PC_INTERNAL_24;
N_141 <= CPI_A_PC_INTERNAL_25;
N_142 <= CPI_A_PC_INTERNAL_26;
N_143 <= CPI_A_PC_INTERNAL_27;
N_144 <= CPI_A_PC_INTERNAL_28;
N_145 <= CPI_A_PC_INTERNAL_29;
N_146 <= CPI_A_PC_INTERNAL_30;
N_147 <= CPI_A_INST_INTERNAL;
N_148 <= CPI_A_INST_INTERNAL_0;
N_149 <= CPI_A_INST_INTERNAL_1;
N_150 <= CPI_A_INST_INTERNAL_2;
N_151 <= CPI_A_INST_INTERNAL_3;
N_152 <= CPI_A_INST_INTERNAL_4;
N_153 <= CPI_A_INST_INTERNAL_5;
N_154 <= CPI_A_INST_INTERNAL_6;
N_155 <= CPI_A_INST_INTERNAL_7;
N_156 <= CPI_A_INST_INTERNAL_8;
N_157 <= CPI_A_INST_INTERNAL_9;
N_158 <= CPI_A_INST_INTERNAL_10;
N_159 <= CPI_A_INST_INTERNAL_11;
N_160 <= CPI_A_INST_INTERNAL_12;
N_161 <= CPI_A_INST_INTERNAL_13;
N_162 <= CPI_A_INST_INTERNAL_14;
N_163 <= CPI_A_INST_INTERNAL_15;
N_164 <= CPI_A_INST_INTERNAL_16;
N_165 <= CPI_A_INST_INTERNAL_17;
N_166 <= CPI_A_INST_INTERNAL_18;
N_167 <= CPI_A_INST_INTERNAL_19;
N_168 <= CPI_A_INST_INTERNAL_20;
N_169 <= CPI_A_INST_INTERNAL_21;
N_170 <= CPI_A_INST_INTERNAL_22;
N_171 <= CPI_A_INST_INTERNAL_23;
N_172 <= CPI_A_INST_INTERNAL_24;
N_173 <= CPI_A_INST_INTERNAL_25;
N_174 <= CPI_A_INST_INTERNAL_26;
N_175 <= CPI_A_INST_INTERNAL_27;
N_176 <= CPI_A_INST_INTERNAL_28;
N_177 <= CPI_A_INST_INTERNAL_29;
N_178 <= CPI_A_INST_INTERNAL_30;
N_179 <= CPI_A_CNT_INTERNAL;
N_180 <= CPI_A_CNT_INTERNAL_0;
N_181 <= CPI_A_TRAP_INTERNAL;
N_182 <= CPI_A_ANNUL_INTERNAL;
N_183 <= CPI_A_PV_INTERNAL;
N_184 <= CPI_E_PC_INTERNAL;
N_185 <= CPI_E_PC_INTERNAL_0;
N_186 <= CPI_E_PC_INTERNAL_1;
N_187 <= CPI_E_PC_INTERNAL_2;
N_188 <= CPI_E_PC_INTERNAL_3;
N_189 <= CPI_E_PC_INTERNAL_4;
N_190 <= CPI_E_PC_INTERNAL_5;
N_191 <= CPI_E_PC_INTERNAL_6;
N_192 <= CPI_E_PC_INTERNAL_7;
N_193 <= CPI_E_PC_INTERNAL_8;
N_194 <= CPI_E_PC_INTERNAL_9;
N_195 <= CPI_E_PC_INTERNAL_10;
N_196 <= CPI_E_PC_INTERNAL_11;
N_197 <= CPI_E_PC_INTERNAL_12;
N_198 <= CPI_E_PC_INTERNAL_13;
N_199 <= CPI_E_PC_INTERNAL_14;
N_200 <= CPI_E_PC_INTERNAL_15;
N_201 <= CPI_E_PC_INTERNAL_16;
N_202 <= CPI_E_PC_INTERNAL_17;
N_203 <= CPI_E_PC_INTERNAL_18;
N_204 <= CPI_E_PC_INTERNAL_19;
N_205 <= CPI_E_PC_INTERNAL_20;
N_206 <= CPI_E_PC_INTERNAL_21;
N_207 <= CPI_E_PC_INTERNAL_22;
N_208 <= CPI_E_PC_INTERNAL_23;
N_209 <= CPI_E_PC_INTERNAL_24;
N_210 <= CPI_E_PC_INTERNAL_25;
N_211 <= CPI_E_PC_INTERNAL_26;
N_212 <= CPI_E_PC_INTERNAL_27;
N_213 <= CPI_E_PC_INTERNAL_28;
N_214 <= CPI_E_PC_INTERNAL_29;
N_215 <= CPI_E_PC_INTERNAL_30;
N_216 <= CPI_E_INST_INTERNAL;
N_217 <= CPI_E_INST_INTERNAL_0;
N_218 <= CPI_E_INST_INTERNAL_1;
N_219 <= CPI_E_INST_INTERNAL_2;
N_220 <= CPI_E_INST_INTERNAL_3;
N_221 <= CPI_E_INST_INTERNAL_4;
N_222 <= CPI_E_INST_INTERNAL_5;
N_223 <= CPI_E_INST_INTERNAL_6;
N_224 <= CPI_E_INST_INTERNAL_7;
N_225 <= CPI_E_INST_INTERNAL_8;
N_226 <= CPI_E_INST_INTERNAL_9;
N_227 <= CPI_E_INST_INTERNAL_10;
N_228 <= CPI_E_INST_INTERNAL_11;
N_229 <= CPI_E_INST_INTERNAL_12;
N_230 <= CPI_E_INST_INTERNAL_13;
N_231 <= CPI_E_INST_INTERNAL_14;
N_232 <= CPI_E_INST_INTERNAL_15;
N_233 <= CPI_E_INST_INTERNAL_16;
N_234 <= CPI_E_INST_INTERNAL_17;
N_235 <= CPI_E_INST_INTERNAL_18;
N_236 <= CPI_E_INST_INTERNAL_19;
N_237 <= CPI_E_INST_INTERNAL_20;
N_238 <= CPI_E_INST_INTERNAL_21;
N_239 <= CPI_E_INST_INTERNAL_22;
N_240 <= CPI_E_INST_INTERNAL_23;
N_241 <= CPI_E_INST_INTERNAL_24;
N_242 <= CPI_E_INST_INTERNAL_25;
N_243 <= CPI_E_INST_INTERNAL_26;
N_244 <= CPI_E_INST_INTERNAL_27;
N_245 <= CPI_E_INST_INTERNAL_28;
N_246 <= CPI_E_INST_INTERNAL_29;
N_247 <= CPI_E_INST_INTERNAL_30;
N_248 <= CPI_E_CNT_INTERNAL;
N_249 <= CPI_E_CNT_INTERNAL_0;
N_250 <= CPI_E_TRAP_INTERNAL;
N_251 <= CPI_E_ANNUL_INTERNAL;
N_252 <= CPI_E_PV_INTERNAL;
N_253 <= CPI_M_PC_INTERNAL;
N_254 <= CPI_M_PC_INTERNAL_0;
N_255 <= CPI_M_PC_INTERNAL_1;
N_256 <= CPI_M_PC_INTERNAL_2;
N_257 <= CPI_M_PC_INTERNAL_3;
N_258 <= CPI_M_PC_INTERNAL_4;
N_259 <= CPI_M_PC_INTERNAL_5;
N_260 <= CPI_M_PC_INTERNAL_6;
N_261 <= CPI_M_PC_INTERNAL_7;
N_262 <= CPI_M_PC_INTERNAL_8;
N_263 <= CPI_M_PC_INTERNAL_9;
N_264 <= CPI_M_PC_INTERNAL_10;
N_265 <= CPI_M_PC_INTERNAL_11;
N_266 <= CPI_M_PC_INTERNAL_12;
N_267 <= CPI_M_PC_INTERNAL_13;
N_268 <= CPI_M_PC_INTERNAL_14;
N_269 <= CPI_M_PC_INTERNAL_15;
N_270 <= CPI_M_PC_INTERNAL_16;
N_271 <= CPI_M_PC_INTERNAL_17;
N_272 <= CPI_M_PC_INTERNAL_18;
N_273 <= CPI_M_PC_INTERNAL_19;
N_274 <= CPI_M_PC_INTERNAL_20;
N_275 <= CPI_M_PC_INTERNAL_21;
N_276 <= CPI_M_PC_INTERNAL_22;
N_277 <= CPI_M_PC_INTERNAL_23;
N_278 <= CPI_M_PC_INTERNAL_24;
N_279 <= CPI_M_PC_INTERNAL_25;
N_280 <= CPI_M_PC_INTERNAL_26;
N_281 <= CPI_M_PC_INTERNAL_27;
N_282 <= CPI_M_PC_INTERNAL_28;
N_283 <= CPI_M_PC_INTERNAL_29;
N_284 <= CPI_M_PC_INTERNAL_30;
N_285 <= CPI_M_INST_INTERNAL;
N_286 <= CPI_M_INST_INTERNAL_0;
N_287 <= CPI_M_INST_INTERNAL_1;
N_288 <= CPI_M_INST_INTERNAL_2;
N_289 <= CPI_M_INST_INTERNAL_3;
N_290 <= CPI_M_INST_INTERNAL_4;
N_291 <= CPI_M_INST_INTERNAL_5;
N_292 <= CPI_M_INST_INTERNAL_6;
N_293 <= CPI_M_INST_INTERNAL_7;
N_294 <= CPI_M_INST_INTERNAL_8;
N_295 <= CPI_M_INST_INTERNAL_9;
N_296 <= CPI_M_INST_INTERNAL_10;
N_297 <= CPI_M_INST_INTERNAL_11;
N_298 <= CPI_M_INST_INTERNAL_12;
N_299 <= CPI_M_INST_INTERNAL_13;
N_300 <= CPI_M_INST_INTERNAL_14;
N_301 <= CPI_M_INST_INTERNAL_15;
N_302 <= CPI_M_INST_INTERNAL_16;
N_303 <= CPI_M_INST_INTERNAL_17;
N_304 <= CPI_M_INST_INTERNAL_18;
N_305 <= CPI_M_INST_INTERNAL_19;
N_306 <= CPI_M_INST_INTERNAL_20;
N_307 <= CPI_M_INST_INTERNAL_21;
N_308 <= CPI_M_INST_INTERNAL_22;
N_309 <= CPI_M_INST_INTERNAL_23;
N_310 <= CPI_M_INST_INTERNAL_24;
N_311 <= CPI_M_INST_INTERNAL_25;
N_312 <= CPI_M_INST_INTERNAL_26;
N_313 <= CPI_M_INST_INTERNAL_27;
N_314 <= CPI_M_INST_INTERNAL_28;
N_315 <= CPI_M_INST_INTERNAL_29;
N_316 <= CPI_M_INST_INTERNAL_30;
N_317 <= CPI_M_CNT_INTERNAL;
N_318 <= CPI_M_CNT_INTERNAL_0;
N_319 <= CPI_M_TRAP_INTERNAL;
N_320 <= CPI_M_ANNUL_INTERNAL;
N_321 <= CPI_M_PV_INTERNAL;
N_322 <= CPI_X_PC_INTERNAL;
N_323 <= CPI_X_PC_INTERNAL_0;
N_324 <= CPI_X_PC_INTERNAL_1;
N_325 <= CPI_X_PC_INTERNAL_2;
N_326 <= CPI_X_PC_INTERNAL_3;
N_327 <= CPI_X_PC_INTERNAL_4;
N_328 <= CPI_X_PC_INTERNAL_5;
N_329 <= CPI_X_PC_INTERNAL_6;
N_330 <= CPI_X_PC_INTERNAL_7;
N_331 <= CPI_X_PC_INTERNAL_8;
N_332 <= CPI_X_PC_INTERNAL_9;
N_333 <= CPI_X_PC_INTERNAL_10;
N_334 <= CPI_X_PC_INTERNAL_11;
N_335 <= CPI_X_PC_INTERNAL_12;
N_336 <= CPI_X_PC_INTERNAL_13;
N_337 <= CPI_X_PC_INTERNAL_14;
N_338 <= CPI_X_PC_INTERNAL_15;
N_339 <= CPI_X_PC_INTERNAL_16;
N_340 <= CPI_X_PC_INTERNAL_17;
N_341 <= CPI_X_PC_INTERNAL_18;
N_342 <= CPI_X_PC_INTERNAL_19;
N_343 <= CPI_X_PC_INTERNAL_20;
N_344 <= CPI_X_PC_INTERNAL_21;
N_345 <= CPI_X_PC_INTERNAL_22;
N_346 <= CPI_X_PC_INTERNAL_23;
N_347 <= CPI_X_PC_INTERNAL_24;
N_348 <= CPI_X_PC_INTERNAL_25;
N_349 <= CPI_X_PC_INTERNAL_26;
N_350 <= CPI_X_PC_INTERNAL_27;
N_351 <= CPI_X_PC_INTERNAL_28;
N_352 <= CPI_X_PC_INTERNAL_29;
N_353 <= CPI_X_PC_INTERNAL_30;
N_354 <= CPI_X_INST_INTERNAL;
N_355 <= CPI_X_INST_INTERNAL_0;
N_356 <= CPI_X_INST_INTERNAL_1;
N_357 <= CPI_X_INST_INTERNAL_2;
N_358 <= CPI_X_INST_INTERNAL_3;
N_359 <= CPI_X_INST_INTERNAL_4;
N_360 <= CPI_X_INST_INTERNAL_5;
N_361 <= CPI_X_INST_INTERNAL_6;
N_362 <= CPI_X_INST_INTERNAL_7;
N_363 <= CPI_X_INST_INTERNAL_8;
N_364 <= CPI_X_INST_INTERNAL_9;
N_365 <= CPI_X_INST_INTERNAL_10;
N_366 <= CPI_X_INST_INTERNAL_11;
N_367 <= CPI_X_INST_INTERNAL_12;
N_368 <= CPI_X_INST_INTERNAL_13;
N_369 <= CPI_X_INST_INTERNAL_14;
N_370 <= CPI_X_INST_INTERNAL_15;
N_371 <= CPI_X_INST_INTERNAL_16;
N_372 <= CPI_X_INST_INTERNAL_17;
N_373 <= CPI_X_INST_INTERNAL_18;
N_374 <= CPI_X_INST_INTERNAL_19;
N_375 <= CPI_X_INST_INTERNAL_20;
N_376 <= CPI_X_INST_INTERNAL_21;
N_377 <= CPI_X_INST_INTERNAL_22;
N_378 <= CPI_X_INST_INTERNAL_23;
N_379 <= CPI_X_INST_INTERNAL_24;
N_380 <= CPI_X_INST_INTERNAL_25;
N_381 <= CPI_X_INST_INTERNAL_26;
N_382 <= CPI_X_INST_INTERNAL_27;
N_383 <= CPI_X_INST_INTERNAL_28;
N_384 <= CPI_X_INST_INTERNAL_29;
N_385 <= CPI_X_INST_INTERNAL_30;
N_386 <= CPI_X_CNT_INTERNAL;
N_387 <= CPI_X_CNT_INTERNAL_0;
N_388 <= CPI_X_TRAP_INTERNAL;
N_389 <= CPI_X_ANNUL_INTERNAL;
N_390 <= CPI_X_PV_INTERNAL;
N_391 <= CPI_LDDATA_INTERNAL;
N_392 <= CPI_LDDATA_INTERNAL_0;
N_393 <= CPI_LDDATA_INTERNAL_1;
N_394 <= CPI_LDDATA_INTERNAL_2;
N_395 <= CPI_LDDATA_INTERNAL_3;
N_396 <= CPI_LDDATA_INTERNAL_4;
N_397 <= CPI_LDDATA_INTERNAL_5;
N_398 <= CPI_LDDATA_INTERNAL_6;
N_399 <= CPI_LDDATA_INTERNAL_7;
N_400 <= CPI_LDDATA_INTERNAL_8;
N_401 <= CPI_LDDATA_INTERNAL_9;
N_402 <= CPI_LDDATA_INTERNAL_10;
N_403 <= CPI_LDDATA_INTERNAL_11;
N_404 <= CPI_LDDATA_INTERNAL_12;
N_405 <= CPI_LDDATA_INTERNAL_13;
N_406 <= CPI_LDDATA_INTERNAL_14;
N_407 <= CPI_LDDATA_INTERNAL_15;
N_408 <= CPI_LDDATA_INTERNAL_16;
N_409 <= CPI_LDDATA_INTERNAL_17;
N_410 <= CPI_LDDATA_INTERNAL_18;
N_411 <= CPI_LDDATA_INTERNAL_19;
N_412 <= CPI_LDDATA_INTERNAL_20;
N_413 <= CPI_LDDATA_INTERNAL_21;
N_414 <= CPI_LDDATA_INTERNAL_22;
N_415 <= CPI_LDDATA_INTERNAL_23;
N_416 <= CPI_LDDATA_INTERNAL_24;
N_417 <= CPI_LDDATA_INTERNAL_25;
N_418 <= CPI_LDDATA_INTERNAL_26;
N_419 <= CPI_LDDATA_INTERNAL_27;
N_420 <= CPI_LDDATA_INTERNAL_28;
N_421 <= CPI_LDDATA_INTERNAL_29;
N_422 <= CPI_LDDATA_INTERNAL_30;
N_423 <= CPI_DBG_ENABLE_INTERNAL;
N_424 <= CPI_DBG_WRITE_INTERNAL;
N_425 <= CPI_DBG_FSR_INTERNAL;
N_426 <= CPI_DBG_ADDR_INTERNAL;
N_427 <= CPI_DBG_ADDR_INTERNAL_0;
N_428 <= CPI_DBG_ADDR_INTERNAL_1;
N_429 <= CPI_DBG_ADDR_INTERNAL_2;
N_430 <= CPI_DBG_ADDR_INTERNAL_3;
N_431 <= CPI_DBG_DATA_INTERNAL;
N_432 <= CPI_DBG_DATA_INTERNAL_0;
N_433 <= CPI_DBG_DATA_INTERNAL_1;
N_434 <= CPI_DBG_DATA_INTERNAL_2;
N_435 <= CPI_DBG_DATA_INTERNAL_3;
N_436 <= CPI_DBG_DATA_INTERNAL_4;
N_437 <= CPI_DBG_DATA_INTERNAL_5;
N_438 <= CPI_DBG_DATA_INTERNAL_6;
N_439 <= CPI_DBG_DATA_INTERNAL_7;
N_440 <= CPI_DBG_DATA_INTERNAL_8;
N_441 <= CPI_DBG_DATA_INTERNAL_9;
N_442 <= CPI_DBG_DATA_INTERNAL_10;
N_443 <= CPI_DBG_DATA_INTERNAL_11;
N_444 <= CPI_DBG_DATA_INTERNAL_12;
N_445 <= CPI_DBG_DATA_INTERNAL_13;
N_446 <= CPI_DBG_DATA_INTERNAL_14;
N_447 <= CPI_DBG_DATA_INTERNAL_15;
N_448 <= CPI_DBG_DATA_INTERNAL_16;
N_449 <= CPI_DBG_DATA_INTERNAL_17;
N_450 <= CPI_DBG_DATA_INTERNAL_18;
N_451 <= CPI_DBG_DATA_INTERNAL_19;
N_452 <= CPI_DBG_DATA_INTERNAL_20;
N_453 <= CPI_DBG_DATA_INTERNAL_21;
N_454 <= CPI_DBG_DATA_INTERNAL_22;
N_455 <= CPI_DBG_DATA_INTERNAL_23;
N_456 <= CPI_DBG_DATA_INTERNAL_24;
N_457 <= CPI_DBG_DATA_INTERNAL_25;
N_458 <= CPI_DBG_DATA_INTERNAL_26;
N_459 <= CPI_DBG_DATA_INTERNAL_27;
N_460 <= CPI_DBG_DATA_INTERNAL_28;
N_461 <= CPI_DBG_DATA_INTERNAL_29;
N_462 <= CPI_DBG_DATA_INTERNAL_30;
N_0 <= CPO_DATAZ(0);
N_1_56 <= CPO_DATAZ(1);
N_2_4 <= CPO_DATAZ(2);
N_3_3 <= CPO_DATAZ(3);
N_4_3 <= CPO_DATAZ(4);
N_5_5 <= CPO_DATAZ(5);
N_6_5 <= CPO_DATAZ(6);
N_7_1 <= CPO_DATAZ(7);
N_8_1 <= CPO_DATAZ(8);
N_9_0 <= CPO_DATAZ(9);
N_10_0 <= CPO_DATAZ(10);
N_11_0 <= CPO_DATAZ(11);
N_12_0 <= CPO_DATAZ(12);
N_13_0 <= CPO_DATAZ(13);
N_14_0 <= CPO_DATAZ(14);
N_15_0 <= CPO_DATAZ(15);
N_16_0 <= CPO_DATAZ(16);
N_17_2 <= CPO_DATAZ(17);
N_18_0 <= CPO_DATAZ(18);
N_19_0 <= CPO_DATAZ(19);
N_20_0 <= CPO_DATAZ(20);
N_21_1 <= CPO_DATAZ(21);
N_22_0 <= CPO_DATAZ(22);
N_23_0 <= CPO_DATAZ(23);
N_24_0 <= CPO_DATAZ(24);
N_25_0 <= CPO_DATAZ(25);
N_26_0 <= CPO_DATAZ(26);
N_27_0 <= CPO_DATAZ(27);
N_28_0 <= CPO_DATAZ(28);
N_29_0 <= CPO_DATAZ(29);
N_30_0 <= CPO_DATAZ(30);
N_31_0 <= CPO_DATAZ(31);
N_32_0 <= CPO_EXCZ;
N_33_0 <= CPO_CCZ(0);
N_34_0 <= CPO_CCZ(1);
N_35_0 <= CPO_CCVZ;
N_36_0 <= CPO_LDLOCKZ;
N_37_0 <= VCC;
N_38_0 <= CPO_DBG_DATAZ(0);
N_39_0 <= CPO_DBG_DATAZ(1);
N_40_0 <= CPO_DBG_DATAZ(2);
N_41_0 <= CPO_DBG_DATAZ(3);
N_42_0 <= CPO_DBG_DATAZ(4);
N_43_0 <= CPO_DBG_DATAZ(5);
N_44_0 <= CPO_DBG_DATAZ(6);
N_45_0 <= CPO_DBG_DATAZ(7);
N_46_0 <= CPO_DBG_DATAZ(8);
N_47_0 <= CPO_DBG_DATAZ(9);
N_48_0 <= CPO_DBG_DATAZ(10);
N_49_0 <= CPO_DBG_DATAZ(11);
N_50_0 <= CPO_DBG_DATAZ(12);
N_51_0 <= CPO_DBG_DATAZ(13);
N_52_0 <= CPO_DBG_DATAZ(14);
N_53_0 <= CPO_DBG_DATAZ(15);
N_54_0 <= CPO_DBG_DATAZ(16);
N_55_0 <= CPO_DBG_DATAZ(17);
N_56_0 <= CPO_DBG_DATAZ(18);
N_57_0 <= CPO_DBG_DATAZ(19);
N_58_0 <= CPO_DBG_DATAZ(20);
N_59_0 <= CPO_DBG_DATAZ(21);
N_60_0 <= CPO_DBG_DATAZ(22);
N_61_0 <= CPO_DBG_DATAZ(23);
N_62_0 <= CPO_DBG_DATAZ(24);
N_63_0 <= CPO_DBG_DATAZ(25);
N_64_0 <= CPO_DBG_DATAZ(26);
N_65_0 <= CPO_DBG_DATAZ(27);
N_66_0 <= CPO_DBG_DATAZ(28);
N_67_0 <= CPO_DBG_DATAZ(29);
N_68_0 <= CPO_DBG_DATAZ(30);
N_69_0 <= CPO_DBG_DATAZ(31);
N_70_0 <= RFI2_RD1ADDRZ(0);
N_71_0 <= RFI2_RD1ADDRZ(1);
N_72_0 <= RFI2_RD1ADDRZ(2);
N_73_0 <= RFI2_RD1ADDRZ(3);
N_74_0 <= RFI2_RD2ADDRZ(0);
N_75_0 <= RFI2_RD2ADDRZ(1);
N_76_0 <= RFI2_RD2ADDRZ(2);
N_77_0 <= RFI2_RD2ADDRZ(3);
N_78_0 <= RFI2_WRADDRZ(0);
N_79_0 <= RFI2_WRADDRZ(1);
N_80_0 <= RFI2_WRADDRZ(2);
N_81_0 <= RFI2_WRADDRZ(3);
N_82_0 <= RFI1_WRDATAZ(0);
N_83_0 <= RFI1_WRDATAZ(1);
N_84_0 <= RFI1_WRDATAZ(2);
N_85_0 <= RFI1_WRDATAZ(3);
N_86_0 <= RFI1_WRDATAZ(4);
N_87_0 <= RFI1_WRDATAZ(5);
N_88_0 <= RFI1_WRDATAZ(6);
N_89_0 <= RFI1_WRDATAZ(7);
N_90_0 <= RFI1_WRDATAZ(8);
N_91_0 <= RFI1_WRDATAZ(9);
N_92_0 <= RFI1_WRDATAZ(10);
N_93_0 <= RFI1_WRDATAZ(11);
N_94_0 <= RFI1_WRDATAZ(12);
N_95_0 <= RFI1_WRDATAZ(13);
N_96_0 <= RFI1_WRDATAZ(14);
N_97_0 <= RFI1_WRDATAZ(15);
N_98_0 <= RFI1_WRDATAZ(16);
N_99_0 <= RFI1_WRDATAZ(17);
N_100_0 <= RFI1_WRDATAZ(18);
N_101_0 <= RFI1_WRDATAZ(19);
N_102_0 <= RFI1_WRDATAZ(20);
N_103_0 <= RFI1_WRDATAZ(21);
N_104_0 <= RFI1_WRDATAZ(22);
N_105_0 <= RFI1_WRDATAZ(23);
N_106_0 <= RFI1_WRDATAZ(24);
N_107_0 <= RFI1_WRDATAZ(25);
N_108_0 <= RFI1_WRDATAZ(26);
N_109_0 <= RFI1_WRDATAZ(27);
N_110_0 <= RFI1_WRDATAZ(28);
N_111_0 <= RFI1_WRDATAZ(29);
N_112_0 <= RFI1_WRDATAZ(30);
N_113_0 <= RFI1_WRDATAZ(31);
N_114_0 <= RFI1_REN1Z;
N_115_0 <= RFI1_REN2Z;
N_116_0 <= RFI1_WRENZ;
N_117_0 <= RFI2_RD1ADDRZ(0);
N_118_0 <= RFI2_RD1ADDRZ(1);
N_119_0 <= RFI2_RD1ADDRZ(2);
N_120_0 <= RFI2_RD1ADDRZ(3);
N_121_0 <= RFI2_RD2ADDRZ(0);
N_122_0 <= RFI2_RD2ADDRZ(1);
N_123_0 <= RFI2_RD2ADDRZ(2);
N_124_0 <= RFI2_RD2ADDRZ(3);
N_125_0 <= RFI2_WRADDRZ(0);
N_126_0 <= RFI2_WRADDRZ(1);
N_127_0 <= RFI2_WRADDRZ(2);
N_128_0 <= RFI2_WRADDRZ(3);
N_129_0 <= RFI2_WRDATAZ(0);
N_130_0 <= RFI2_WRDATAZ(1);
N_131_0 <= RFI2_WRDATAZ(2);
N_132_0 <= RFI2_WRDATAZ(3);
N_133_0 <= RFI2_WRDATAZ(4);
N_134_0 <= RFI2_WRDATAZ(5);
N_135_0 <= RFI2_WRDATAZ(6);
N_136_0 <= RFI2_WRDATAZ(7);
N_137_0 <= RFI2_WRDATAZ(8);
N_138_0 <= RFI2_WRDATAZ(9);
N_139_0 <= RFI2_WRDATAZ(10);
N_140_0 <= RFI2_WRDATAZ(11);
N_141_0 <= RFI2_WRDATAZ(12);
N_142_0 <= RFI2_WRDATAZ(13);
N_143_0 <= RFI2_WRDATAZ(14);
N_144_0 <= RFI2_WRDATAZ(15);
N_145_0 <= RFI2_WRDATAZ(16);
N_146_0 <= RFI2_WRDATAZ(17);
N_147_0 <= RFI2_WRDATAZ(18);
N_148_0 <= RFI2_WRDATAZ(19);
N_149_0 <= RFI2_WRDATAZ(20);
N_150_0 <= RFI2_WRDATAZ(21);
N_151_0 <= RFI2_WRDATAZ(22);
N_152_0 <= RFI2_WRDATAZ(23);
N_153_0 <= RFI2_WRDATAZ(24);
N_154_0 <= RFI2_WRDATAZ(25);
N_155_0 <= RFI2_WRDATAZ(26);
N_156_0 <= RFI2_WRDATAZ(27);
N_157_0 <= RFI2_WRDATAZ(28);
N_158_0 <= RFI2_WRDATAZ(29);
N_159_0 <= RFI2_WRDATAZ(30);
N_160_0 <= RFI2_WRDATAZ(31);
N_161_0 <= RFI2_REN1Z;
N_162_0 <= RFI2_REN2Z;
N_163_0 <= RFI2_WRENZ;
N_627 <= RFO1_DATA1_INTERNAL;
N_628 <= RFO1_DATA1_INTERNAL_0;
N_629 <= RFO1_DATA1_INTERNAL_1;
N_630 <= RFO1_DATA1_INTERNAL_2;
N_631 <= RFO1_DATA1_INTERNAL_3;
N_632 <= RFO1_DATA1_INTERNAL_4;
N_633 <= RFO1_DATA1_INTERNAL_5;
N_634 <= RFO1_DATA1_INTERNAL_6;
N_635 <= RFO1_DATA1_INTERNAL_7;
N_636 <= RFO1_DATA1_INTERNAL_8;
N_637 <= RFO1_DATA1_INTERNAL_9;
N_638 <= RFO1_DATA1_INTERNAL_10;
N_639 <= RFO1_DATA1_INTERNAL_11;
N_640 <= RFO1_DATA1_INTERNAL_12;
N_641 <= RFO1_DATA1_INTERNAL_13;
N_642 <= RFO1_DATA1_INTERNAL_14;
N_643 <= RFO1_DATA1_INTERNAL_15;
N_644 <= RFO1_DATA1_INTERNAL_16;
N_645 <= RFO1_DATA1_INTERNAL_17;
N_646 <= RFO1_DATA1_INTERNAL_18;
N_647 <= RFO1_DATA1_INTERNAL_19;
N_648 <= RFO1_DATA1_INTERNAL_20;
N_649 <= RFO1_DATA1_INTERNAL_21;
N_650 <= RFO1_DATA1_INTERNAL_22;
N_651 <= RFO1_DATA1_INTERNAL_23;
N_652 <= RFO1_DATA1_INTERNAL_24;
N_653 <= RFO1_DATA1_INTERNAL_25;
N_654 <= RFO1_DATA1_INTERNAL_26;
N_655 <= RFO1_DATA1_INTERNAL_27;
N_656 <= RFO1_DATA1_INTERNAL_28;
N_657 <= RFO1_DATA1_INTERNAL_29;
N_658 <= RFO1_DATA1_INTERNAL_30;
N_659 <= RFO1_DATA2_INTERNAL;
N_660 <= RFO1_DATA2_INTERNAL_0;
N_661 <= RFO1_DATA2_INTERNAL_1;
N_662 <= RFO1_DATA2_INTERNAL_2;
N_663 <= RFO1_DATA2_INTERNAL_3;
N_664 <= RFO1_DATA2_INTERNAL_4;
N_665 <= RFO1_DATA2_INTERNAL_5;
N_666 <= RFO1_DATA2_INTERNAL_6;
N_667 <= RFO1_DATA2_INTERNAL_7;
N_668 <= RFO1_DATA2_INTERNAL_8;
N_669 <= RFO1_DATA2_INTERNAL_9;
N_670 <= RFO1_DATA2_INTERNAL_10;
N_671 <= RFO1_DATA2_INTERNAL_11;
N_672 <= RFO1_DATA2_INTERNAL_12;
N_673 <= RFO1_DATA2_INTERNAL_13;
N_674 <= RFO1_DATA2_INTERNAL_14;
N_675 <= RFO1_DATA2_INTERNAL_15;
N_676 <= RFO1_DATA2_INTERNAL_16;
N_677 <= RFO1_DATA2_INTERNAL_17;
N_678 <= RFO1_DATA2_INTERNAL_18;
N_679 <= RFO1_DATA2_INTERNAL_19;
N_680 <= RFO1_DATA2_INTERNAL_20;
N_681 <= RFO1_DATA2_INTERNAL_21;
N_682 <= RFO1_DATA2_INTERNAL_22;
N_683 <= RFO1_DATA2_INTERNAL_23;
N_684 <= RFO1_DATA2_INTERNAL_24;
N_685 <= RFO1_DATA2_INTERNAL_25;
N_686 <= RFO1_DATA2_INTERNAL_26;
N_687 <= RFO1_DATA2_INTERNAL_27;
N_688 <= RFO1_DATA2_INTERNAL_28;
N_689 <= RFO1_DATA2_INTERNAL_29;
N_690 <= RFO1_DATA2_INTERNAL_30;
N_691 <= RFO2_DATA1_INTERNAL;
N_692 <= RFO2_DATA1_INTERNAL_0;
N_693 <= RFO2_DATA1_INTERNAL_1;
N_694 <= RFO2_DATA1_INTERNAL_2;
N_695 <= RFO2_DATA1_INTERNAL_3;
N_696 <= RFO2_DATA1_INTERNAL_4;
N_697 <= RFO2_DATA1_INTERNAL_5;
N_698 <= RFO2_DATA1_INTERNAL_6;
N_699 <= RFO2_DATA1_INTERNAL_7;
N_700 <= RFO2_DATA1_INTERNAL_8;
N_701 <= RFO2_DATA1_INTERNAL_9;
N_702 <= RFO2_DATA1_INTERNAL_10;
N_703 <= RFO2_DATA1_INTERNAL_11;
N_704 <= RFO2_DATA1_INTERNAL_12;
N_705 <= RFO2_DATA1_INTERNAL_13;
N_706 <= RFO2_DATA1_INTERNAL_14;
N_707 <= RFO2_DATA1_INTERNAL_15;
N_708 <= RFO2_DATA1_INTERNAL_16;
N_709 <= RFO2_DATA1_INTERNAL_17;
N_710 <= RFO2_DATA1_INTERNAL_18;
N_711 <= RFO2_DATA1_INTERNAL_19;
N_712 <= RFO2_DATA1_INTERNAL_20;
N_713 <= RFO2_DATA1_INTERNAL_21;
N_714 <= RFO2_DATA1_INTERNAL_22;
N_715 <= RFO2_DATA1_INTERNAL_23;
N_716 <= RFO2_DATA1_INTERNAL_24;
N_717 <= RFO2_DATA1_INTERNAL_25;
N_718 <= RFO2_DATA1_INTERNAL_26;
N_719 <= RFO2_DATA1_INTERNAL_27;
N_720 <= RFO2_DATA1_INTERNAL_28;
N_721 <= RFO2_DATA1_INTERNAL_29;
N_722 <= RFO2_DATA1_INTERNAL_30;
N_723 <= RFO2_DATA2_INTERNAL;
N_724 <= RFO2_DATA2_INTERNAL_0;
N_725 <= RFO2_DATA2_INTERNAL_1;
N_726 <= RFO2_DATA2_INTERNAL_2;
N_727 <= RFO2_DATA2_INTERNAL_3;
N_728 <= RFO2_DATA2_INTERNAL_4;
N_729 <= RFO2_DATA2_INTERNAL_5;
N_730 <= RFO2_DATA2_INTERNAL_6;
N_731 <= RFO2_DATA2_INTERNAL_7;
N_732 <= RFO2_DATA2_INTERNAL_8;
N_733 <= RFO2_DATA2_INTERNAL_9;
N_734 <= RFO2_DATA2_INTERNAL_10;
N_735 <= RFO2_DATA2_INTERNAL_11;
N_736 <= RFO2_DATA2_INTERNAL_12;
N_737 <= RFO2_DATA2_INTERNAL_13;
N_738 <= RFO2_DATA2_INTERNAL_14;
N_739 <= RFO2_DATA2_INTERNAL_15;
N_740 <= RFO2_DATA2_INTERNAL_16;
N_741 <= RFO2_DATA2_INTERNAL_17;
N_742 <= RFO2_DATA2_INTERNAL_18;
N_743 <= RFO2_DATA2_INTERNAL_19;
N_744 <= RFO2_DATA2_INTERNAL_20;
N_745 <= RFO2_DATA2_INTERNAL_21;
N_746 <= RFO2_DATA2_INTERNAL_22;
N_747 <= RFO2_DATA2_INTERNAL_23;
N_748 <= RFO2_DATA2_INTERNAL_24;
N_749 <= RFO2_DATA2_INTERNAL_25;
N_750 <= RFO2_DATA2_INTERNAL_26;
N_751 <= RFO2_DATA2_INTERNAL_27;
N_752 <= RFO2_DATA2_INTERNAL_28;
N_753 <= RFO2_DATA2_INTERNAL_29;
N_754 <= RFO2_DATA2_INTERNAL_30;
cpo_data(0) <= N_0;
cpo_data(1) <= N_1_56;
cpo_data(2) <= N_2_4;
cpo_data(3) <= N_3_3;
cpo_data(4) <= N_4_3;
cpo_data(5) <= N_5_5;
cpo_data(6) <= N_6_5;
cpo_data(7) <= N_7_1;
cpo_data(8) <= N_8_1;
cpo_data(9) <= N_9_0;
cpo_data(10) <= N_10_0;
cpo_data(11) <= N_11_0;
cpo_data(12) <= N_12_0;
cpo_data(13) <= N_13_0;
cpo_data(14) <= N_14_0;
cpo_data(15) <= N_15_0;
cpo_data(16) <= N_16_0;
cpo_data(17) <= N_17_2;
cpo_data(18) <= N_18_0;
cpo_data(19) <= N_19_0;
cpo_data(20) <= N_20_0;
cpo_data(21) <= N_21_1;
cpo_data(22) <= N_22_0;
cpo_data(23) <= N_23_0;
cpo_data(24) <= N_24_0;
cpo_data(25) <= N_25_0;
cpo_data(26) <= N_26_0;
cpo_data(27) <= N_27_0;
cpo_data(28) <= N_28_0;
cpo_data(29) <= N_29_0;
cpo_data(30) <= N_30_0;
cpo_data(31) <= N_31_0;
cpo_exc <= N_32_0;
cpo_cc(0) <= N_33_0;
cpo_cc(1) <= N_34_0;
cpo_ccv <= N_35_0;
cpo_ldlock <= N_36_0;
cpo_holdn <= N_37_0;
cpo_dbg_data(0) <= N_38_0;
cpo_dbg_data(1) <= N_39_0;
cpo_dbg_data(2) <= N_40_0;
cpo_dbg_data(3) <= N_41_0;
cpo_dbg_data(4) <= N_42_0;
cpo_dbg_data(5) <= N_43_0;
cpo_dbg_data(6) <= N_44_0;
cpo_dbg_data(7) <= N_45_0;
cpo_dbg_data(8) <= N_46_0;
cpo_dbg_data(9) <= N_47_0;
cpo_dbg_data(10) <= N_48_0;
cpo_dbg_data(11) <= N_49_0;
cpo_dbg_data(12) <= N_50_0;
cpo_dbg_data(13) <= N_51_0;
cpo_dbg_data(14) <= N_52_0;
cpo_dbg_data(15) <= N_53_0;
cpo_dbg_data(16) <= N_54_0;
cpo_dbg_data(17) <= N_55_0;
cpo_dbg_data(18) <= N_56_0;
cpo_dbg_data(19) <= N_57_0;
cpo_dbg_data(20) <= N_58_0;
cpo_dbg_data(21) <= N_59_0;
cpo_dbg_data(22) <= N_60_0;
cpo_dbg_data(23) <= N_61_0;
cpo_dbg_data(24) <= N_62_0;
cpo_dbg_data(25) <= N_63_0;
cpo_dbg_data(26) <= N_64_0;
cpo_dbg_data(27) <= N_65_0;
cpo_dbg_data(28) <= N_66_0;
cpo_dbg_data(29) <= N_67_0;
cpo_dbg_data(30) <= N_68_0;
cpo_dbg_data(31) <= N_69_0;
rfi1_rd1addr(0) <= N_70_0;
rfi1_rd1addr(1) <= N_71_0;
rfi1_rd1addr(2) <= N_72_0;
rfi1_rd1addr(3) <= N_73_0;
rfi1_rd2addr(0) <= N_74_0;
rfi1_rd2addr(1) <= N_75_0;
rfi1_rd2addr(2) <= N_76_0;
rfi1_rd2addr(3) <= N_77_0;
rfi1_wraddr(0) <= N_78_0;
rfi1_wraddr(1) <= N_79_0;
rfi1_wraddr(2) <= N_80_0;
rfi1_wraddr(3) <= N_81_0;
rfi1_wrdata(0) <= N_82_0;
rfi1_wrdata(1) <= N_83_0;
rfi1_wrdata(2) <= N_84_0;
rfi1_wrdata(3) <= N_85_0;
rfi1_wrdata(4) <= N_86_0;
rfi1_wrdata(5) <= N_87_0;
rfi1_wrdata(6) <= N_88_0;
rfi1_wrdata(7) <= N_89_0;
rfi1_wrdata(8) <= N_90_0;
rfi1_wrdata(9) <= N_91_0;
rfi1_wrdata(10) <= N_92_0;
rfi1_wrdata(11) <= N_93_0;
rfi1_wrdata(12) <= N_94_0;
rfi1_wrdata(13) <= N_95_0;
rfi1_wrdata(14) <= N_96_0;
rfi1_wrdata(15) <= N_97_0;
rfi1_wrdata(16) <= N_98_0;
rfi1_wrdata(17) <= N_99_0;
rfi1_wrdata(18) <= N_100_0;
rfi1_wrdata(19) <= N_101_0;
rfi1_wrdata(20) <= N_102_0;
rfi1_wrdata(21) <= N_103_0;
rfi1_wrdata(22) <= N_104_0;
rfi1_wrdata(23) <= N_105_0;
rfi1_wrdata(24) <= N_106_0;
rfi1_wrdata(25) <= N_107_0;
rfi1_wrdata(26) <= N_108_0;
rfi1_wrdata(27) <= N_109_0;
rfi1_wrdata(28) <= N_110_0;
rfi1_wrdata(29) <= N_111_0;
rfi1_wrdata(30) <= N_112_0;
rfi1_wrdata(31) <= N_113_0;
rfi1_ren1 <= N_114_0;
rfi1_ren2 <= N_115_0;
rfi1_wren <= N_116_0;
rfi2_rd1addr(0) <= N_117_0;
rfi2_rd1addr(1) <= N_118_0;
rfi2_rd1addr(2) <= N_119_0;
rfi2_rd1addr(3) <= N_120_0;
rfi2_rd2addr(0) <= N_121_0;
rfi2_rd2addr(1) <= N_122_0;
rfi2_rd2addr(2) <= N_123_0;
rfi2_rd2addr(3) <= N_124_0;
rfi2_wraddr(0) <= N_125_0;
rfi2_wraddr(1) <= N_126_0;
rfi2_wraddr(2) <= N_127_0;
rfi2_wraddr(3) <= N_128_0;
rfi2_wrdata(0) <= N_129_0;
rfi2_wrdata(1) <= N_130_0;
rfi2_wrdata(2) <= N_131_0;
rfi2_wrdata(3) <= N_132_0;
rfi2_wrdata(4) <= N_133_0;
rfi2_wrdata(5) <= N_134_0;
rfi2_wrdata(6) <= N_135_0;
rfi2_wrdata(7) <= N_136_0;
rfi2_wrdata(8) <= N_137_0;
rfi2_wrdata(9) <= N_138_0;
rfi2_wrdata(10) <= N_139_0;
rfi2_wrdata(11) <= N_140_0;
rfi2_wrdata(12) <= N_141_0;
rfi2_wrdata(13) <= N_142_0;
rfi2_wrdata(14) <= N_143_0;
rfi2_wrdata(15) <= N_144_0;
rfi2_wrdata(16) <= N_145_0;
rfi2_wrdata(17) <= N_146_0;
rfi2_wrdata(18) <= N_147_0;
rfi2_wrdata(19) <= N_148_0;
rfi2_wrdata(20) <= N_149_0;
rfi2_wrdata(21) <= N_150_0;
rfi2_wrdata(22) <= N_151_0;
rfi2_wrdata(23) <= N_152_0;
rfi2_wrdata(24) <= N_153_0;
rfi2_wrdata(25) <= N_154_0;
rfi2_wrdata(26) <= N_155_0;
rfi2_wrdata(27) <= N_156_0;
rfi2_wrdata(28) <= N_157_0;
rfi2_wrdata(29) <= N_158_0;
rfi2_wrdata(30) <= N_159_0;
rfi2_wrdata(31) <= N_160_0;
rfi2_ren1 <= N_161_0;
rfi2_ren2 <= N_162_0;
rfi2_wren <= N_163_0;
RST_INTERNAL <= rst;
CLK_INTERNAL <= clk;
HOLDN_INTERNAL <= holdn;
CPI_FLUSH_INTERNAL <= cpi_flush;
CPI_EXACK_INTERNAL <= cpi_exack;
CPI_A_RS1_INTERNAL <= cpi_a_rs1(0);
CPI_A_RS1_INTERNAL_0 <= cpi_a_rs1(1);
CPI_A_RS1_INTERNAL_1 <= cpi_a_rs1(2);
CPI_A_RS1_INTERNAL_2 <= cpi_a_rs1(3);
CPI_A_RS1_INTERNAL_3 <= cpi_a_rs1(4);
CPI_D_PC_INTERNAL <= cpi_d_pc(0);
CPI_D_PC_INTERNAL_0 <= cpi_d_pc(1);
CPI_D_PC_INTERNAL_1 <= cpi_d_pc(2);
CPI_D_PC_INTERNAL_2 <= cpi_d_pc(3);
CPI_D_PC_INTERNAL_3 <= cpi_d_pc(4);
CPI_D_PC_INTERNAL_4 <= cpi_d_pc(5);
CPI_D_PC_INTERNAL_5 <= cpi_d_pc(6);
CPI_D_PC_INTERNAL_6 <= cpi_d_pc(7);
CPI_D_PC_INTERNAL_7 <= cpi_d_pc(8);
CPI_D_PC_INTERNAL_8 <= cpi_d_pc(9);
CPI_D_PC_INTERNAL_9 <= cpi_d_pc(10);
CPI_D_PC_INTERNAL_10 <= cpi_d_pc(11);
CPI_D_PC_INTERNAL_11 <= cpi_d_pc(12);
CPI_D_PC_INTERNAL_12 <= cpi_d_pc(13);
CPI_D_PC_INTERNAL_13 <= cpi_d_pc(14);
CPI_D_PC_INTERNAL_14 <= cpi_d_pc(15);
CPI_D_PC_INTERNAL_15 <= cpi_d_pc(16);
CPI_D_PC_INTERNAL_16 <= cpi_d_pc(17);
CPI_D_PC_INTERNAL_17 <= cpi_d_pc(18);
CPI_D_PC_INTERNAL_18 <= cpi_d_pc(19);
CPI_D_PC_INTERNAL_19 <= cpi_d_pc(20);
CPI_D_PC_INTERNAL_20 <= cpi_d_pc(21);
CPI_D_PC_INTERNAL_21 <= cpi_d_pc(22);
CPI_D_PC_INTERNAL_22 <= cpi_d_pc(23);
CPI_D_PC_INTERNAL_23 <= cpi_d_pc(24);
CPI_D_PC_INTERNAL_24 <= cpi_d_pc(25);
CPI_D_PC_INTERNAL_25 <= cpi_d_pc(26);
CPI_D_PC_INTERNAL_26 <= cpi_d_pc(27);
CPI_D_PC_INTERNAL_27 <= cpi_d_pc(28);
CPI_D_PC_INTERNAL_28 <= cpi_d_pc(29);
CPI_D_PC_INTERNAL_29 <= cpi_d_pc(30);
CPI_D_PC_INTERNAL_30 <= cpi_d_pc(31);
CPI_D_INST_INTERNAL <= cpi_d_inst(0);
CPI_D_INST_INTERNAL_0 <= cpi_d_inst(1);
CPI_D_INST_INTERNAL_1 <= cpi_d_inst(2);
CPI_D_INST_INTERNAL_2 <= cpi_d_inst(3);
CPI_D_INST_INTERNAL_3 <= cpi_d_inst(4);
CPI_D_INST_INTERNAL_4 <= cpi_d_inst(5);
CPI_D_INST_INTERNAL_5 <= cpi_d_inst(6);
CPI_D_INST_INTERNAL_6 <= cpi_d_inst(7);
CPI_D_INST_INTERNAL_7 <= cpi_d_inst(8);
CPI_D_INST_INTERNAL_8 <= cpi_d_inst(9);
CPI_D_INST_INTERNAL_9 <= cpi_d_inst(10);
CPI_D_INST_INTERNAL_10 <= cpi_d_inst(11);
CPI_D_INST_INTERNAL_11 <= cpi_d_inst(12);
CPI_D_INST_INTERNAL_12 <= cpi_d_inst(13);
CPI_D_INST_INTERNAL_13 <= cpi_d_inst(14);
CPI_D_INST_INTERNAL_14 <= cpi_d_inst(15);
CPI_D_INST_INTERNAL_15 <= cpi_d_inst(16);
CPI_D_INST_INTERNAL_16 <= cpi_d_inst(17);
CPI_D_INST_INTERNAL_17 <= cpi_d_inst(18);
CPI_D_INST_INTERNAL_18 <= cpi_d_inst(19);
CPI_D_INST_INTERNAL_19 <= cpi_d_inst(20);
CPI_D_INST_INTERNAL_20 <= cpi_d_inst(21);
CPI_D_INST_INTERNAL_21 <= cpi_d_inst(22);
CPI_D_INST_INTERNAL_22 <= cpi_d_inst(23);
CPI_D_INST_INTERNAL_23 <= cpi_d_inst(24);
CPI_D_INST_INTERNAL_24 <= cpi_d_inst(25);
CPI_D_INST_INTERNAL_25 <= cpi_d_inst(26);
CPI_D_INST_INTERNAL_26 <= cpi_d_inst(27);
CPI_D_INST_INTERNAL_27 <= cpi_d_inst(28);
CPI_D_INST_INTERNAL_28 <= cpi_d_inst(29);
CPI_D_INST_INTERNAL_29 <= cpi_d_inst(30);
CPI_D_INST_INTERNAL_30 <= cpi_d_inst(31);
CPI_D_CNT_INTERNAL <= cpi_d_cnt(0);
CPI_D_CNT_INTERNAL_0 <= cpi_d_cnt(1);
CPI_D_TRAP_INTERNAL <= cpi_d_trap;
CPI_D_ANNUL_INTERNAL <= cpi_d_annul;
CPI_D_PV_INTERNAL <= cpi_d_pv;
CPI_A_PC_INTERNAL <= cpi_a_pc(0);
CPI_A_PC_INTERNAL_0 <= cpi_a_pc(1);
CPI_A_PC_INTERNAL_1 <= cpi_a_pc(2);
CPI_A_PC_INTERNAL_2 <= cpi_a_pc(3);
CPI_A_PC_INTERNAL_3 <= cpi_a_pc(4);
CPI_A_PC_INTERNAL_4 <= cpi_a_pc(5);
CPI_A_PC_INTERNAL_5 <= cpi_a_pc(6);
CPI_A_PC_INTERNAL_6 <= cpi_a_pc(7);
CPI_A_PC_INTERNAL_7 <= cpi_a_pc(8);
CPI_A_PC_INTERNAL_8 <= cpi_a_pc(9);
CPI_A_PC_INTERNAL_9 <= cpi_a_pc(10);
CPI_A_PC_INTERNAL_10 <= cpi_a_pc(11);
CPI_A_PC_INTERNAL_11 <= cpi_a_pc(12);
CPI_A_PC_INTERNAL_12 <= cpi_a_pc(13);
CPI_A_PC_INTERNAL_13 <= cpi_a_pc(14);
CPI_A_PC_INTERNAL_14 <= cpi_a_pc(15);
CPI_A_PC_INTERNAL_15 <= cpi_a_pc(16);
CPI_A_PC_INTERNAL_16 <= cpi_a_pc(17);
CPI_A_PC_INTERNAL_17 <= cpi_a_pc(18);
CPI_A_PC_INTERNAL_18 <= cpi_a_pc(19);
CPI_A_PC_INTERNAL_19 <= cpi_a_pc(20);
CPI_A_PC_INTERNAL_20 <= cpi_a_pc(21);
CPI_A_PC_INTERNAL_21 <= cpi_a_pc(22);
CPI_A_PC_INTERNAL_22 <= cpi_a_pc(23);
CPI_A_PC_INTERNAL_23 <= cpi_a_pc(24);
CPI_A_PC_INTERNAL_24 <= cpi_a_pc(25);
CPI_A_PC_INTERNAL_25 <= cpi_a_pc(26);
CPI_A_PC_INTERNAL_26 <= cpi_a_pc(27);
CPI_A_PC_INTERNAL_27 <= cpi_a_pc(28);
CPI_A_PC_INTERNAL_28 <= cpi_a_pc(29);
CPI_A_PC_INTERNAL_29 <= cpi_a_pc(30);
CPI_A_PC_INTERNAL_30 <= cpi_a_pc(31);
CPI_A_INST_INTERNAL <= cpi_a_inst(0);
CPI_A_INST_INTERNAL_0 <= cpi_a_inst(1);
CPI_A_INST_INTERNAL_1 <= cpi_a_inst(2);
CPI_A_INST_INTERNAL_2 <= cpi_a_inst(3);
CPI_A_INST_INTERNAL_3 <= cpi_a_inst(4);
CPI_A_INST_INTERNAL_4 <= cpi_a_inst(5);
CPI_A_INST_INTERNAL_5 <= cpi_a_inst(6);
CPI_A_INST_INTERNAL_6 <= cpi_a_inst(7);
CPI_A_INST_INTERNAL_7 <= cpi_a_inst(8);
CPI_A_INST_INTERNAL_8 <= cpi_a_inst(9);
CPI_A_INST_INTERNAL_9 <= cpi_a_inst(10);
CPI_A_INST_INTERNAL_10 <= cpi_a_inst(11);
CPI_A_INST_INTERNAL_11 <= cpi_a_inst(12);
CPI_A_INST_INTERNAL_12 <= cpi_a_inst(13);
CPI_A_INST_INTERNAL_13 <= cpi_a_inst(14);
CPI_A_INST_INTERNAL_14 <= cpi_a_inst(15);
CPI_A_INST_INTERNAL_15 <= cpi_a_inst(16);
CPI_A_INST_INTERNAL_16 <= cpi_a_inst(17);
CPI_A_INST_INTERNAL_17 <= cpi_a_inst(18);
CPI_A_INST_INTERNAL_18 <= cpi_a_inst(19);
CPI_A_INST_INTERNAL_19 <= cpi_a_inst(20);
CPI_A_INST_INTERNAL_20 <= cpi_a_inst(21);
CPI_A_INST_INTERNAL_21 <= cpi_a_inst(22);
CPI_A_INST_INTERNAL_22 <= cpi_a_inst(23);
CPI_A_INST_INTERNAL_23 <= cpi_a_inst(24);
CPI_A_INST_INTERNAL_24 <= cpi_a_inst(25);
CPI_A_INST_INTERNAL_25 <= cpi_a_inst(26);
CPI_A_INST_INTERNAL_26 <= cpi_a_inst(27);
CPI_A_INST_INTERNAL_27 <= cpi_a_inst(28);
CPI_A_INST_INTERNAL_28 <= cpi_a_inst(29);
CPI_A_INST_INTERNAL_29 <= cpi_a_inst(30);
CPI_A_INST_INTERNAL_30 <= cpi_a_inst(31);
CPI_A_CNT_INTERNAL <= cpi_a_cnt(0);
CPI_A_CNT_INTERNAL_0 <= cpi_a_cnt(1);
CPI_A_TRAP_INTERNAL <= cpi_a_trap;
CPI_A_ANNUL_INTERNAL <= cpi_a_annul;
CPI_A_PV_INTERNAL <= cpi_a_pv;
CPI_E_PC_INTERNAL <= cpi_e_pc(0);
CPI_E_PC_INTERNAL_0 <= cpi_e_pc(1);
CPI_E_PC_INTERNAL_1 <= cpi_e_pc(2);
CPI_E_PC_INTERNAL_2 <= cpi_e_pc(3);
CPI_E_PC_INTERNAL_3 <= cpi_e_pc(4);
CPI_E_PC_INTERNAL_4 <= cpi_e_pc(5);
CPI_E_PC_INTERNAL_5 <= cpi_e_pc(6);
CPI_E_PC_INTERNAL_6 <= cpi_e_pc(7);
CPI_E_PC_INTERNAL_7 <= cpi_e_pc(8);
CPI_E_PC_INTERNAL_8 <= cpi_e_pc(9);
CPI_E_PC_INTERNAL_9 <= cpi_e_pc(10);
CPI_E_PC_INTERNAL_10 <= cpi_e_pc(11);
CPI_E_PC_INTERNAL_11 <= cpi_e_pc(12);
CPI_E_PC_INTERNAL_12 <= cpi_e_pc(13);
CPI_E_PC_INTERNAL_13 <= cpi_e_pc(14);
CPI_E_PC_INTERNAL_14 <= cpi_e_pc(15);
CPI_E_PC_INTERNAL_15 <= cpi_e_pc(16);
CPI_E_PC_INTERNAL_16 <= cpi_e_pc(17);
CPI_E_PC_INTERNAL_17 <= cpi_e_pc(18);
CPI_E_PC_INTERNAL_18 <= cpi_e_pc(19);
CPI_E_PC_INTERNAL_19 <= cpi_e_pc(20);
CPI_E_PC_INTERNAL_20 <= cpi_e_pc(21);
CPI_E_PC_INTERNAL_21 <= cpi_e_pc(22);
CPI_E_PC_INTERNAL_22 <= cpi_e_pc(23);
CPI_E_PC_INTERNAL_23 <= cpi_e_pc(24);
CPI_E_PC_INTERNAL_24 <= cpi_e_pc(25);
CPI_E_PC_INTERNAL_25 <= cpi_e_pc(26);
CPI_E_PC_INTERNAL_26 <= cpi_e_pc(27);
CPI_E_PC_INTERNAL_27 <= cpi_e_pc(28);
CPI_E_PC_INTERNAL_28 <= cpi_e_pc(29);
CPI_E_PC_INTERNAL_29 <= cpi_e_pc(30);
CPI_E_PC_INTERNAL_30 <= cpi_e_pc(31);
CPI_E_INST_INTERNAL <= cpi_e_inst(0);
CPI_E_INST_INTERNAL_0 <= cpi_e_inst(1);
CPI_E_INST_INTERNAL_1 <= cpi_e_inst(2);
CPI_E_INST_INTERNAL_2 <= cpi_e_inst(3);
CPI_E_INST_INTERNAL_3 <= cpi_e_inst(4);
CPI_E_INST_INTERNAL_4 <= cpi_e_inst(5);
CPI_E_INST_INTERNAL_5 <= cpi_e_inst(6);
CPI_E_INST_INTERNAL_6 <= cpi_e_inst(7);
CPI_E_INST_INTERNAL_7 <= cpi_e_inst(8);
CPI_E_INST_INTERNAL_8 <= cpi_e_inst(9);
CPI_E_INST_INTERNAL_9 <= cpi_e_inst(10);
CPI_E_INST_INTERNAL_10 <= cpi_e_inst(11);
CPI_E_INST_INTERNAL_11 <= cpi_e_inst(12);
CPI_E_INST_INTERNAL_12 <= cpi_e_inst(13);
CPI_E_INST_INTERNAL_13 <= cpi_e_inst(14);
CPI_E_INST_INTERNAL_14 <= cpi_e_inst(15);
CPI_E_INST_INTERNAL_15 <= cpi_e_inst(16);
CPI_E_INST_INTERNAL_16 <= cpi_e_inst(17);
CPI_E_INST_INTERNAL_17 <= cpi_e_inst(18);
CPI_E_INST_INTERNAL_18 <= cpi_e_inst(19);
CPI_E_INST_INTERNAL_19 <= cpi_e_inst(20);
CPI_E_INST_INTERNAL_20 <= cpi_e_inst(21);
CPI_E_INST_INTERNAL_21 <= cpi_e_inst(22);
CPI_E_INST_INTERNAL_22 <= cpi_e_inst(23);
CPI_E_INST_INTERNAL_23 <= cpi_e_inst(24);
CPI_E_INST_INTERNAL_24 <= cpi_e_inst(25);
CPI_E_INST_INTERNAL_25 <= cpi_e_inst(26);
CPI_E_INST_INTERNAL_26 <= cpi_e_inst(27);
CPI_E_INST_INTERNAL_27 <= cpi_e_inst(28);
CPI_E_INST_INTERNAL_28 <= cpi_e_inst(29);
CPI_E_INST_INTERNAL_29 <= cpi_e_inst(30);
CPI_E_INST_INTERNAL_30 <= cpi_e_inst(31);
CPI_E_CNT_INTERNAL <= cpi_e_cnt(0);
CPI_E_CNT_INTERNAL_0 <= cpi_e_cnt(1);
CPI_E_TRAP_INTERNAL <= cpi_e_trap;
CPI_E_ANNUL_INTERNAL <= cpi_e_annul;
CPI_E_PV_INTERNAL <= cpi_e_pv;
CPI_M_PC_INTERNAL <= cpi_m_pc(0);
CPI_M_PC_INTERNAL_0 <= cpi_m_pc(1);
CPI_M_PC_INTERNAL_1 <= cpi_m_pc(2);
CPI_M_PC_INTERNAL_2 <= cpi_m_pc(3);
CPI_M_PC_INTERNAL_3 <= cpi_m_pc(4);
CPI_M_PC_INTERNAL_4 <= cpi_m_pc(5);
CPI_M_PC_INTERNAL_5 <= cpi_m_pc(6);
CPI_M_PC_INTERNAL_6 <= cpi_m_pc(7);
CPI_M_PC_INTERNAL_7 <= cpi_m_pc(8);
CPI_M_PC_INTERNAL_8 <= cpi_m_pc(9);
CPI_M_PC_INTERNAL_9 <= cpi_m_pc(10);
CPI_M_PC_INTERNAL_10 <= cpi_m_pc(11);
CPI_M_PC_INTERNAL_11 <= cpi_m_pc(12);
CPI_M_PC_INTERNAL_12 <= cpi_m_pc(13);
CPI_M_PC_INTERNAL_13 <= cpi_m_pc(14);
CPI_M_PC_INTERNAL_14 <= cpi_m_pc(15);
CPI_M_PC_INTERNAL_15 <= cpi_m_pc(16);
CPI_M_PC_INTERNAL_16 <= cpi_m_pc(17);
CPI_M_PC_INTERNAL_17 <= cpi_m_pc(18);
CPI_M_PC_INTERNAL_18 <= cpi_m_pc(19);
CPI_M_PC_INTERNAL_19 <= cpi_m_pc(20);
CPI_M_PC_INTERNAL_20 <= cpi_m_pc(21);
CPI_M_PC_INTERNAL_21 <= cpi_m_pc(22);
CPI_M_PC_INTERNAL_22 <= cpi_m_pc(23);
CPI_M_PC_INTERNAL_23 <= cpi_m_pc(24);
CPI_M_PC_INTERNAL_24 <= cpi_m_pc(25);
CPI_M_PC_INTERNAL_25 <= cpi_m_pc(26);
CPI_M_PC_INTERNAL_26 <= cpi_m_pc(27);
CPI_M_PC_INTERNAL_27 <= cpi_m_pc(28);
CPI_M_PC_INTERNAL_28 <= cpi_m_pc(29);
CPI_M_PC_INTERNAL_29 <= cpi_m_pc(30);
CPI_M_PC_INTERNAL_30 <= cpi_m_pc(31);
CPI_M_INST_INTERNAL <= cpi_m_inst(0);
CPI_M_INST_INTERNAL_0 <= cpi_m_inst(1);
CPI_M_INST_INTERNAL_1 <= cpi_m_inst(2);
CPI_M_INST_INTERNAL_2 <= cpi_m_inst(3);
CPI_M_INST_INTERNAL_3 <= cpi_m_inst(4);
CPI_M_INST_INTERNAL_4 <= cpi_m_inst(5);
CPI_M_INST_INTERNAL_5 <= cpi_m_inst(6);
CPI_M_INST_INTERNAL_6 <= cpi_m_inst(7);
CPI_M_INST_INTERNAL_7 <= cpi_m_inst(8);
CPI_M_INST_INTERNAL_8 <= cpi_m_inst(9);
CPI_M_INST_INTERNAL_9 <= cpi_m_inst(10);
CPI_M_INST_INTERNAL_10 <= cpi_m_inst(11);
CPI_M_INST_INTERNAL_11 <= cpi_m_inst(12);
CPI_M_INST_INTERNAL_12 <= cpi_m_inst(13);
CPI_M_INST_INTERNAL_13 <= cpi_m_inst(14);
CPI_M_INST_INTERNAL_14 <= cpi_m_inst(15);
CPI_M_INST_INTERNAL_15 <= cpi_m_inst(16);
CPI_M_INST_INTERNAL_16 <= cpi_m_inst(17);
CPI_M_INST_INTERNAL_17 <= cpi_m_inst(18);
CPI_M_INST_INTERNAL_18 <= cpi_m_inst(19);
CPI_M_INST_INTERNAL_19 <= cpi_m_inst(20);
CPI_M_INST_INTERNAL_20 <= cpi_m_inst(21);
CPI_M_INST_INTERNAL_21 <= cpi_m_inst(22);
CPI_M_INST_INTERNAL_22 <= cpi_m_inst(23);
CPI_M_INST_INTERNAL_23 <= cpi_m_inst(24);
CPI_M_INST_INTERNAL_24 <= cpi_m_inst(25);
CPI_M_INST_INTERNAL_25 <= cpi_m_inst(26);
CPI_M_INST_INTERNAL_26 <= cpi_m_inst(27);
CPI_M_INST_INTERNAL_27 <= cpi_m_inst(28);
CPI_M_INST_INTERNAL_28 <= cpi_m_inst(29);
CPI_M_INST_INTERNAL_29 <= cpi_m_inst(30);
CPI_M_INST_INTERNAL_30 <= cpi_m_inst(31);
CPI_M_CNT_INTERNAL <= cpi_m_cnt(0);
CPI_M_CNT_INTERNAL_0 <= cpi_m_cnt(1);
CPI_M_TRAP_INTERNAL <= cpi_m_trap;
CPI_M_ANNUL_INTERNAL <= cpi_m_annul;
CPI_M_PV_INTERNAL <= cpi_m_pv;
CPI_X_PC_INTERNAL <= cpi_x_pc(0);
CPI_X_PC_INTERNAL_0 <= cpi_x_pc(1);
CPI_X_PC_INTERNAL_1 <= cpi_x_pc(2);
CPI_X_PC_INTERNAL_2 <= cpi_x_pc(3);
CPI_X_PC_INTERNAL_3 <= cpi_x_pc(4);
CPI_X_PC_INTERNAL_4 <= cpi_x_pc(5);
CPI_X_PC_INTERNAL_5 <= cpi_x_pc(6);
CPI_X_PC_INTERNAL_6 <= cpi_x_pc(7);
CPI_X_PC_INTERNAL_7 <= cpi_x_pc(8);
CPI_X_PC_INTERNAL_8 <= cpi_x_pc(9);
CPI_X_PC_INTERNAL_9 <= cpi_x_pc(10);
CPI_X_PC_INTERNAL_10 <= cpi_x_pc(11);
CPI_X_PC_INTERNAL_11 <= cpi_x_pc(12);
CPI_X_PC_INTERNAL_12 <= cpi_x_pc(13);
CPI_X_PC_INTERNAL_13 <= cpi_x_pc(14);
CPI_X_PC_INTERNAL_14 <= cpi_x_pc(15);
CPI_X_PC_INTERNAL_15 <= cpi_x_pc(16);
CPI_X_PC_INTERNAL_16 <= cpi_x_pc(17);
CPI_X_PC_INTERNAL_17 <= cpi_x_pc(18);
CPI_X_PC_INTERNAL_18 <= cpi_x_pc(19);
CPI_X_PC_INTERNAL_19 <= cpi_x_pc(20);
CPI_X_PC_INTERNAL_20 <= cpi_x_pc(21);
CPI_X_PC_INTERNAL_21 <= cpi_x_pc(22);
CPI_X_PC_INTERNAL_22 <= cpi_x_pc(23);
CPI_X_PC_INTERNAL_23 <= cpi_x_pc(24);
CPI_X_PC_INTERNAL_24 <= cpi_x_pc(25);
CPI_X_PC_INTERNAL_25 <= cpi_x_pc(26);
CPI_X_PC_INTERNAL_26 <= cpi_x_pc(27);
CPI_X_PC_INTERNAL_27 <= cpi_x_pc(28);
CPI_X_PC_INTERNAL_28 <= cpi_x_pc(29);
CPI_X_PC_INTERNAL_29 <= cpi_x_pc(30);
CPI_X_PC_INTERNAL_30 <= cpi_x_pc(31);
CPI_X_INST_INTERNAL <= cpi_x_inst(0);
CPI_X_INST_INTERNAL_0 <= cpi_x_inst(1);
CPI_X_INST_INTERNAL_1 <= cpi_x_inst(2);
CPI_X_INST_INTERNAL_2 <= cpi_x_inst(3);
CPI_X_INST_INTERNAL_3 <= cpi_x_inst(4);
CPI_X_INST_INTERNAL_4 <= cpi_x_inst(5);
CPI_X_INST_INTERNAL_5 <= cpi_x_inst(6);
CPI_X_INST_INTERNAL_6 <= cpi_x_inst(7);
CPI_X_INST_INTERNAL_7 <= cpi_x_inst(8);
CPI_X_INST_INTERNAL_8 <= cpi_x_inst(9);
CPI_X_INST_INTERNAL_9 <= cpi_x_inst(10);
CPI_X_INST_INTERNAL_10 <= cpi_x_inst(11);
CPI_X_INST_INTERNAL_11 <= cpi_x_inst(12);
CPI_X_INST_INTERNAL_12 <= cpi_x_inst(13);
CPI_X_INST_INTERNAL_13 <= cpi_x_inst(14);
CPI_X_INST_INTERNAL_14 <= cpi_x_inst(15);
CPI_X_INST_INTERNAL_15 <= cpi_x_inst(16);
CPI_X_INST_INTERNAL_16 <= cpi_x_inst(17);
CPI_X_INST_INTERNAL_17 <= cpi_x_inst(18);
CPI_X_INST_INTERNAL_18 <= cpi_x_inst(19);
CPI_X_INST_INTERNAL_19 <= cpi_x_inst(20);
CPI_X_INST_INTERNAL_20 <= cpi_x_inst(21);
CPI_X_INST_INTERNAL_21 <= cpi_x_inst(22);
CPI_X_INST_INTERNAL_22 <= cpi_x_inst(23);
CPI_X_INST_INTERNAL_23 <= cpi_x_inst(24);
CPI_X_INST_INTERNAL_24 <= cpi_x_inst(25);
CPI_X_INST_INTERNAL_25 <= cpi_x_inst(26);
CPI_X_INST_INTERNAL_26 <= cpi_x_inst(27);
CPI_X_INST_INTERNAL_27 <= cpi_x_inst(28);
CPI_X_INST_INTERNAL_28 <= cpi_x_inst(29);
CPI_X_INST_INTERNAL_29 <= cpi_x_inst(30);
CPI_X_INST_INTERNAL_30 <= cpi_x_inst(31);
CPI_X_CNT_INTERNAL <= cpi_x_cnt(0);
CPI_X_CNT_INTERNAL_0 <= cpi_x_cnt(1);
CPI_X_TRAP_INTERNAL <= cpi_x_trap;
CPI_X_ANNUL_INTERNAL <= cpi_x_annul;
CPI_X_PV_INTERNAL <= cpi_x_pv;
CPI_LDDATA_INTERNAL <= cpi_lddata(0);
CPI_LDDATA_INTERNAL_0 <= cpi_lddata(1);
CPI_LDDATA_INTERNAL_1 <= cpi_lddata(2);
CPI_LDDATA_INTERNAL_2 <= cpi_lddata(3);
CPI_LDDATA_INTERNAL_3 <= cpi_lddata(4);
CPI_LDDATA_INTERNAL_4 <= cpi_lddata(5);
CPI_LDDATA_INTERNAL_5 <= cpi_lddata(6);
CPI_LDDATA_INTERNAL_6 <= cpi_lddata(7);
CPI_LDDATA_INTERNAL_7 <= cpi_lddata(8);
CPI_LDDATA_INTERNAL_8 <= cpi_lddata(9);
CPI_LDDATA_INTERNAL_9 <= cpi_lddata(10);
CPI_LDDATA_INTERNAL_10 <= cpi_lddata(11);
CPI_LDDATA_INTERNAL_11 <= cpi_lddata(12);
CPI_LDDATA_INTERNAL_12 <= cpi_lddata(13);
CPI_LDDATA_INTERNAL_13 <= cpi_lddata(14);
CPI_LDDATA_INTERNAL_14 <= cpi_lddata(15);
CPI_LDDATA_INTERNAL_15 <= cpi_lddata(16);
CPI_LDDATA_INTERNAL_16 <= cpi_lddata(17);
CPI_LDDATA_INTERNAL_17 <= cpi_lddata(18);
CPI_LDDATA_INTERNAL_18 <= cpi_lddata(19);
CPI_LDDATA_INTERNAL_19 <= cpi_lddata(20);
CPI_LDDATA_INTERNAL_20 <= cpi_lddata(21);
CPI_LDDATA_INTERNAL_21 <= cpi_lddata(22);
CPI_LDDATA_INTERNAL_22 <= cpi_lddata(23);
CPI_LDDATA_INTERNAL_23 <= cpi_lddata(24);
CPI_LDDATA_INTERNAL_24 <= cpi_lddata(25);
CPI_LDDATA_INTERNAL_25 <= cpi_lddata(26);
CPI_LDDATA_INTERNAL_26 <= cpi_lddata(27);
CPI_LDDATA_INTERNAL_27 <= cpi_lddata(28);
CPI_LDDATA_INTERNAL_28 <= cpi_lddata(29);
CPI_LDDATA_INTERNAL_29 <= cpi_lddata(30);
CPI_LDDATA_INTERNAL_30 <= cpi_lddata(31);
CPI_DBG_ENABLE_INTERNAL <= cpi_dbg_enable;
CPI_DBG_WRITE_INTERNAL <= cpi_dbg_write;
CPI_DBG_FSR_INTERNAL <= cpi_dbg_fsr;
CPI_DBG_ADDR_INTERNAL <= cpi_dbg_addr(0);
CPI_DBG_ADDR_INTERNAL_0 <= cpi_dbg_addr(1);
CPI_DBG_ADDR_INTERNAL_1 <= cpi_dbg_addr(2);
CPI_DBG_ADDR_INTERNAL_2 <= cpi_dbg_addr(3);
CPI_DBG_ADDR_INTERNAL_3 <= cpi_dbg_addr(4);
CPI_DBG_DATA_INTERNAL <= cpi_dbg_data(0);
CPI_DBG_DATA_INTERNAL_0 <= cpi_dbg_data(1);
CPI_DBG_DATA_INTERNAL_1 <= cpi_dbg_data(2);
CPI_DBG_DATA_INTERNAL_2 <= cpi_dbg_data(3);
CPI_DBG_DATA_INTERNAL_3 <= cpi_dbg_data(4);
CPI_DBG_DATA_INTERNAL_4 <= cpi_dbg_data(5);
CPI_DBG_DATA_INTERNAL_5 <= cpi_dbg_data(6);
CPI_DBG_DATA_INTERNAL_6 <= cpi_dbg_data(7);
CPI_DBG_DATA_INTERNAL_7 <= cpi_dbg_data(8);
CPI_DBG_DATA_INTERNAL_8 <= cpi_dbg_data(9);
CPI_DBG_DATA_INTERNAL_9 <= cpi_dbg_data(10);
CPI_DBG_DATA_INTERNAL_10 <= cpi_dbg_data(11);
CPI_DBG_DATA_INTERNAL_11 <= cpi_dbg_data(12);
CPI_DBG_DATA_INTERNAL_12 <= cpi_dbg_data(13);
CPI_DBG_DATA_INTERNAL_13 <= cpi_dbg_data(14);
CPI_DBG_DATA_INTERNAL_14 <= cpi_dbg_data(15);
CPI_DBG_DATA_INTERNAL_15 <= cpi_dbg_data(16);
CPI_DBG_DATA_INTERNAL_16 <= cpi_dbg_data(17);
CPI_DBG_DATA_INTERNAL_17 <= cpi_dbg_data(18);
CPI_DBG_DATA_INTERNAL_18 <= cpi_dbg_data(19);
CPI_DBG_DATA_INTERNAL_19 <= cpi_dbg_data(20);
CPI_DBG_DATA_INTERNAL_20 <= cpi_dbg_data(21);
CPI_DBG_DATA_INTERNAL_21 <= cpi_dbg_data(22);
CPI_DBG_DATA_INTERNAL_22 <= cpi_dbg_data(23);
CPI_DBG_DATA_INTERNAL_23 <= cpi_dbg_data(24);
CPI_DBG_DATA_INTERNAL_24 <= cpi_dbg_data(25);
CPI_DBG_DATA_INTERNAL_25 <= cpi_dbg_data(26);
CPI_DBG_DATA_INTERNAL_26 <= cpi_dbg_data(27);
CPI_DBG_DATA_INTERNAL_27 <= cpi_dbg_data(28);
CPI_DBG_DATA_INTERNAL_28 <= cpi_dbg_data(29);
CPI_DBG_DATA_INTERNAL_29 <= cpi_dbg_data(30);
CPI_DBG_DATA_INTERNAL_30 <= cpi_dbg_data(31);
RFO1_DATA1_INTERNAL <= rfo1_data1(0);
RFO1_DATA1_INTERNAL_0 <= rfo1_data1(1);
RFO1_DATA1_INTERNAL_1 <= rfo1_data1(2);
RFO1_DATA1_INTERNAL_2 <= rfo1_data1(3);
RFO1_DATA1_INTERNAL_3 <= rfo1_data1(4);
RFO1_DATA1_INTERNAL_4 <= rfo1_data1(5);
RFO1_DATA1_INTERNAL_5 <= rfo1_data1(6);
RFO1_DATA1_INTERNAL_6 <= rfo1_data1(7);
RFO1_DATA1_INTERNAL_7 <= rfo1_data1(8);
RFO1_DATA1_INTERNAL_8 <= rfo1_data1(9);
RFO1_DATA1_INTERNAL_9 <= rfo1_data1(10);
RFO1_DATA1_INTERNAL_10 <= rfo1_data1(11);
RFO1_DATA1_INTERNAL_11 <= rfo1_data1(12);
RFO1_DATA1_INTERNAL_12 <= rfo1_data1(13);
RFO1_DATA1_INTERNAL_13 <= rfo1_data1(14);
RFO1_DATA1_INTERNAL_14 <= rfo1_data1(15);
RFO1_DATA1_INTERNAL_15 <= rfo1_data1(16);
RFO1_DATA1_INTERNAL_16 <= rfo1_data1(17);
RFO1_DATA1_INTERNAL_17 <= rfo1_data1(18);
RFO1_DATA1_INTERNAL_18 <= rfo1_data1(19);
RFO1_DATA1_INTERNAL_19 <= rfo1_data1(20);
RFO1_DATA1_INTERNAL_20 <= rfo1_data1(21);
RFO1_DATA1_INTERNAL_21 <= rfo1_data1(22);
RFO1_DATA1_INTERNAL_22 <= rfo1_data1(23);
RFO1_DATA1_INTERNAL_23 <= rfo1_data1(24);
RFO1_DATA1_INTERNAL_24 <= rfo1_data1(25);
RFO1_DATA1_INTERNAL_25 <= rfo1_data1(26);
RFO1_DATA1_INTERNAL_26 <= rfo1_data1(27);
RFO1_DATA1_INTERNAL_27 <= rfo1_data1(28);
RFO1_DATA1_INTERNAL_28 <= rfo1_data1(29);
RFO1_DATA1_INTERNAL_29 <= rfo1_data1(30);
RFO1_DATA1_INTERNAL_30 <= rfo1_data1(31);
RFO1_DATA2_INTERNAL <= rfo1_data2(0);
RFO1_DATA2_INTERNAL_0 <= rfo1_data2(1);
RFO1_DATA2_INTERNAL_1 <= rfo1_data2(2);
RFO1_DATA2_INTERNAL_2 <= rfo1_data2(3);
RFO1_DATA2_INTERNAL_3 <= rfo1_data2(4);
RFO1_DATA2_INTERNAL_4 <= rfo1_data2(5);
RFO1_DATA2_INTERNAL_5 <= rfo1_data2(6);
RFO1_DATA2_INTERNAL_6 <= rfo1_data2(7);
RFO1_DATA2_INTERNAL_7 <= rfo1_data2(8);
RFO1_DATA2_INTERNAL_8 <= rfo1_data2(9);
RFO1_DATA2_INTERNAL_9 <= rfo1_data2(10);
RFO1_DATA2_INTERNAL_10 <= rfo1_data2(11);
RFO1_DATA2_INTERNAL_11 <= rfo1_data2(12);
RFO1_DATA2_INTERNAL_12 <= rfo1_data2(13);
RFO1_DATA2_INTERNAL_13 <= rfo1_data2(14);
RFO1_DATA2_INTERNAL_14 <= rfo1_data2(15);
RFO1_DATA2_INTERNAL_15 <= rfo1_data2(16);
RFO1_DATA2_INTERNAL_16 <= rfo1_data2(17);
RFO1_DATA2_INTERNAL_17 <= rfo1_data2(18);
RFO1_DATA2_INTERNAL_18 <= rfo1_data2(19);
RFO1_DATA2_INTERNAL_19 <= rfo1_data2(20);
RFO1_DATA2_INTERNAL_20 <= rfo1_data2(21);
RFO1_DATA2_INTERNAL_21 <= rfo1_data2(22);
RFO1_DATA2_INTERNAL_22 <= rfo1_data2(23);
RFO1_DATA2_INTERNAL_23 <= rfo1_data2(24);
RFO1_DATA2_INTERNAL_24 <= rfo1_data2(25);
RFO1_DATA2_INTERNAL_25 <= rfo1_data2(26);
RFO1_DATA2_INTERNAL_26 <= rfo1_data2(27);
RFO1_DATA2_INTERNAL_27 <= rfo1_data2(28);
RFO1_DATA2_INTERNAL_28 <= rfo1_data2(29);
RFO1_DATA2_INTERNAL_29 <= rfo1_data2(30);
RFO1_DATA2_INTERNAL_30 <= rfo1_data2(31);
RFO2_DATA1_INTERNAL <= rfo2_data1(0);
RFO2_DATA1_INTERNAL_0 <= rfo2_data1(1);
RFO2_DATA1_INTERNAL_1 <= rfo2_data1(2);
RFO2_DATA1_INTERNAL_2 <= rfo2_data1(3);
RFO2_DATA1_INTERNAL_3 <= rfo2_data1(4);
RFO2_DATA1_INTERNAL_4 <= rfo2_data1(5);
RFO2_DATA1_INTERNAL_5 <= rfo2_data1(6);
RFO2_DATA1_INTERNAL_6 <= rfo2_data1(7);
RFO2_DATA1_INTERNAL_7 <= rfo2_data1(8);
RFO2_DATA1_INTERNAL_8 <= rfo2_data1(9);
RFO2_DATA1_INTERNAL_9 <= rfo2_data1(10);
RFO2_DATA1_INTERNAL_10 <= rfo2_data1(11);
RFO2_DATA1_INTERNAL_11 <= rfo2_data1(12);
RFO2_DATA1_INTERNAL_12 <= rfo2_data1(13);
RFO2_DATA1_INTERNAL_13 <= rfo2_data1(14);
RFO2_DATA1_INTERNAL_14 <= rfo2_data1(15);
RFO2_DATA1_INTERNAL_15 <= rfo2_data1(16);
RFO2_DATA1_INTERNAL_16 <= rfo2_data1(17);
RFO2_DATA1_INTERNAL_17 <= rfo2_data1(18);
RFO2_DATA1_INTERNAL_18 <= rfo2_data1(19);
RFO2_DATA1_INTERNAL_19 <= rfo2_data1(20);
RFO2_DATA1_INTERNAL_20 <= rfo2_data1(21);
RFO2_DATA1_INTERNAL_21 <= rfo2_data1(22);
RFO2_DATA1_INTERNAL_22 <= rfo2_data1(23);
RFO2_DATA1_INTERNAL_23 <= rfo2_data1(24);
RFO2_DATA1_INTERNAL_24 <= rfo2_data1(25);
RFO2_DATA1_INTERNAL_25 <= rfo2_data1(26);
RFO2_DATA1_INTERNAL_26 <= rfo2_data1(27);
RFO2_DATA1_INTERNAL_27 <= rfo2_data1(28);
RFO2_DATA1_INTERNAL_28 <= rfo2_data1(29);
RFO2_DATA1_INTERNAL_29 <= rfo2_data1(30);
RFO2_DATA1_INTERNAL_30 <= rfo2_data1(31);
RFO2_DATA2_INTERNAL <= rfo2_data2(0);
RFO2_DATA2_INTERNAL_0 <= rfo2_data2(1);
RFO2_DATA2_INTERNAL_1 <= rfo2_data2(2);
RFO2_DATA2_INTERNAL_2 <= rfo2_data2(3);
RFO2_DATA2_INTERNAL_3 <= rfo2_data2(4);
RFO2_DATA2_INTERNAL_4 <= rfo2_data2(5);
RFO2_DATA2_INTERNAL_5 <= rfo2_data2(6);
RFO2_DATA2_INTERNAL_6 <= rfo2_data2(7);
RFO2_DATA2_INTERNAL_7 <= rfo2_data2(8);
RFO2_DATA2_INTERNAL_8 <= rfo2_data2(9);
RFO2_DATA2_INTERNAL_9 <= rfo2_data2(10);
RFO2_DATA2_INTERNAL_10 <= rfo2_data2(11);
RFO2_DATA2_INTERNAL_11 <= rfo2_data2(12);
RFO2_DATA2_INTERNAL_12 <= rfo2_data2(13);
RFO2_DATA2_INTERNAL_13 <= rfo2_data2(14);
RFO2_DATA2_INTERNAL_14 <= rfo2_data2(15);
RFO2_DATA2_INTERNAL_15 <= rfo2_data2(16);
RFO2_DATA2_INTERNAL_16 <= rfo2_data2(17);
RFO2_DATA2_INTERNAL_17 <= rfo2_data2(18);
RFO2_DATA2_INTERNAL_18 <= rfo2_data2(19);
RFO2_DATA2_INTERNAL_19 <= rfo2_data2(20);
RFO2_DATA2_INTERNAL_20 <= rfo2_data2(21);
RFO2_DATA2_INTERNAL_21 <= rfo2_data2(22);
RFO2_DATA2_INTERNAL_22 <= rfo2_data2(23);
RFO2_DATA2_INTERNAL_23 <= rfo2_data2(24);
RFO2_DATA2_INTERNAL_24 <= rfo2_data2(25);
RFO2_DATA2_INTERNAL_25 <= rfo2_data2(26);
RFO2_DATA2_INTERNAL_26 <= rfo2_data2(27);
RFO2_DATA2_INTERNAL_27 <= rfo2_data2(28);
RFO2_DATA2_INTERNAL_28 <= rfo2_data2(29);
RFO2_DATA2_INTERNAL_29 <= rfo2_data2(30);
RFO2_DATA2_INTERNAL_30 <= rfo2_data2(31);
end beh;

